# coding: utf-8
#
#  Copyright (C) 2014-2025  Enrico Rivarola
#
#  This file is part of DcmDict gem (dcm_dict).
#
#  DcmDict is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  DcmDict is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with DcmDict.  If not, see <http://www.gnu.org/licenses/>.
#
#  This software has neither been tested nor approved for clinical use
#  or for incorporation in a medical device.
#  It is the redistributor's or user's responsibility to comply with any
#  applicable local, state, national or international regulations.
#
module DcmDict
  module SourceData
    UidValuesData = [
      { uid_value: '1.2.840.10008.1.1', uid_name: 'Verification SOP Class', uid_key: 'Verification', uid_sym: :verification, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.1.2', uid_name: 'Implicit VR Little Endian: Default Transfer Syntax for DICOM', uid_key: 'ImplicitVRLittleEndian', uid_sym: :implicit_vr_little_endian, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.1', uid_name: 'Explicit VR Little Endian', uid_key: 'ExplicitVRLittleEndian', uid_sym: :explicit_vr_little_endian, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.1.98', uid_name: 'Encapsulated Uncompressed Explicit VR Little Endian', uid_key: 'EncapsulatedUncompressedExplicitVRLittleEndian', uid_sym: :encapsulated_uncompressed_explicit_vr_little_endian, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.1.99', uid_name: 'Deflated Explicit VR Little Endian', uid_key: 'DeflatedExplicitVRLittleEndian', uid_sym: :deflated_explicit_vr_little_endian, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.2', uid_name: 'Explicit VR Big Endian (Retired)', uid_key: 'ExplicitVRBigEndian', uid_sym: :explicit_vr_big_endian, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.4.50', uid_name: 'JPEG Baseline (Process 1): Default Transfer Syntax for Lossy JPEG 8 Bit Image Compression', uid_key: 'JPEGBaseline8Bit', uid_sym: :jpeg_baseline8_bit, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.4.51', uid_name: 'JPEG Extended (Process 2 & 4): Default Transfer Syntax for Lossy JPEG 12 Bit Image Compression (Process 4 only)', uid_key: 'JPEGExtended12Bit', uid_sym: :jpeg_extended12_bit, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.4.52', uid_name: 'JPEG Extended (Process 3 & 5) (Retired)', uid_key: 'JPEGExtended35', uid_sym: :jpeg_extended35, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.4.53', uid_name: 'JPEG Spectral Selection, Non-Hierarchical (Process 6 & 8) (Retired)', uid_key: 'JPEGSpectralSelectionNonHierarchical68', uid_sym: :jpeg_spectral_selection_non_hierarchical68, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.4.54', uid_name: 'JPEG Spectral Selection, Non-Hierarchical (Process 7 & 9) (Retired)', uid_key: 'JPEGSpectralSelectionNonHierarchical79', uid_sym: :jpeg_spectral_selection_non_hierarchical79, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.4.55', uid_name: 'JPEG Full Progression, Non-Hierarchical (Process 10 & 12) (Retired)', uid_key: 'JPEGFullProgressionNonHierarchical1012', uid_sym: :jpeg_full_progression_non_hierarchical1012, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.4.56', uid_name: 'JPEG Full Progression, Non-Hierarchical (Process 11 & 13) (Retired)', uid_key: 'JPEGFullProgressionNonHierarchical1113', uid_sym: :jpeg_full_progression_non_hierarchical1113, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.4.57', uid_name: 'JPEG Lossless, Non-Hierarchical (Process 14)', uid_key: 'JPEGLossless', uid_sym: :jpeg_lossless, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.4.58', uid_name: 'JPEG Lossless, Non-Hierarchical (Process 15) (Retired)', uid_key: 'JPEGLosslessNonHierarchical15', uid_sym: :jpeg_lossless_non_hierarchical15, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.4.59', uid_name: 'JPEG Extended, Hierarchical (Process 16 & 18) (Retired)', uid_key: 'JPEGExtendedHierarchical1618', uid_sym: :jpeg_extended_hierarchical1618, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.4.60', uid_name: 'JPEG Extended, Hierarchical (Process 17 & 19) (Retired)', uid_key: 'JPEGExtendedHierarchical1719', uid_sym: :jpeg_extended_hierarchical1719, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.4.61', uid_name: 'JPEG Spectral Selection, Hierarchical (Process 20 & 22) (Retired)', uid_key: 'JPEGSpectralSelectionHierarchical2022', uid_sym: :jpeg_spectral_selection_hierarchical2022, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.4.62', uid_name: 'JPEG Spectral Selection, Hierarchical (Process 21 & 23) (Retired)', uid_key: 'JPEGSpectralSelectionHierarchical2123', uid_sym: :jpeg_spectral_selection_hierarchical2123, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.4.63', uid_name: 'JPEG Full Progression, Hierarchical (Process 24 & 26) (Retired)', uid_key: 'JPEGFullProgressionHierarchical2426', uid_sym: :jpeg_full_progression_hierarchical2426, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.4.64', uid_name: 'JPEG Full Progression, Hierarchical (Process 25 & 27) (Retired)', uid_key: 'JPEGFullProgressionHierarchical2527', uid_sym: :jpeg_full_progression_hierarchical2527, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.4.65', uid_name: 'JPEG Lossless, Hierarchical (Process 28) (Retired)', uid_key: 'JPEGLosslessHierarchical28', uid_sym: :jpeg_lossless_hierarchical28, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.4.66', uid_name: 'JPEG Lossless, Hierarchical (Process 29) (Retired)', uid_key: 'JPEGLosslessHierarchical29', uid_sym: :jpeg_lossless_hierarchical29, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.4.70', uid_name: 'JPEG Lossless, Non-Hierarchical, First-Order Prediction (Process 14 [Selection Value 1]): Default Transfer Syntax for Lossless JPEG Image Compression', uid_key: 'JPEGLosslessSV1', uid_sym: :jpeg_lossless_sv1, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.4.80', uid_name: 'JPEG-LS Lossless Image Compression', uid_key: 'JPEGLSLossless', uid_sym: :jpegls_lossless, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.4.81', uid_name: 'JPEG-LS Lossy (Near-Lossless) Image Compression', uid_key: 'JPEGLSNearLossless', uid_sym: :jpegls_near_lossless, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.4.90', uid_name: 'JPEG 2000 Image Compression (Lossless Only)', uid_key: 'JPEG2000Lossless', uid_sym: :jpeg2000_lossless, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.4.91', uid_name: 'JPEG 2000 Image Compression', uid_key: 'JPEG2000', uid_sym: :jpeg2000, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.4.92', uid_name: 'JPEG 2000 Part 2 Multi-component Image Compression (Lossless Only)', uid_key: 'JPEG2000MCLossless', uid_sym: :jpeg2000mc_lossless, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.4.93', uid_name: 'JPEG 2000 Part 2 Multi-component Image Compression', uid_key: 'JPEG2000MC', uid_sym: :jpeg2000mc, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.4.94', uid_name: 'JPIP Referenced', uid_key: 'JPIPReferenced', uid_sym: :jpip_referenced, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.4.95', uid_name: 'JPIP Referenced Deflate', uid_key: 'JPIPReferencedDeflate', uid_sym: :jpip_referenced_deflate, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.4.100', uid_name: 'MPEG2 Main Profile / Main Level', uid_key: 'MPEG2MPML', uid_sym: :mpeg2mpml, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.4.100.1', uid_name: 'Fragmentable MPEG2 Main Profile / Main Level', uid_key: 'MPEG2MPMLF', uid_sym: :mpeg2mpmlf, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.4.101', uid_name: 'MPEG2 Main Profile / High Level', uid_key: 'MPEG2MPHL', uid_sym: :mpeg2mphl, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.4.101.1', uid_name: 'Fragmentable MPEG2 Main Profile / High Level', uid_key: 'MPEG2MPHLF', uid_sym: :mpeg2mphlf, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.4.102', uid_name: 'MPEG-4 AVC/H.264 High Profile / Level 4.1', uid_key: 'MPEG4HP41', uid_sym: :mpeg4hp41, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.4.102.1', uid_name: 'Fragmentable MPEG-4 AVC/H.264 High Profile / Level 4.1', uid_key: 'MPEG4HP41F', uid_sym: :mpeg4hp41f, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.4.103', uid_name: 'MPEG-4 AVC/H.264 BD-compatible High Profile / Level 4.1', uid_key: 'MPEG4HP41BD', uid_sym: :mpeg4hp41bd, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.4.103.1', uid_name: 'Fragmentable MPEG-4 AVC/H.264 BD-compatible High Profile / Level 4.1', uid_key: 'MPEG4HP41BDF', uid_sym: :mpeg4hp41bdf, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.4.104', uid_name: 'MPEG-4 AVC/H.264 High Profile / Level 4.2 For 2D Video', uid_key: 'MPEG4HP422D', uid_sym: :mpeg4hp422d, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.4.104.1', uid_name: 'Fragmentable MPEG-4 AVC/H.264 High Profile / Level 4.2 For 2D Video', uid_key: 'MPEG4HP422DF', uid_sym: :mpeg4hp422df, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.4.105', uid_name: 'MPEG-4 AVC/H.264 High Profile / Level 4.2 For 3D Video', uid_key: 'MPEG4HP423D', uid_sym: :mpeg4hp42_3d, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.4.105.1', uid_name: 'Fragmentable MPEG-4 AVC/H.264 High Profile / Level 4.2 For 3D Video', uid_key: 'MPEG4HP423DF', uid_sym: :mpeg4hp42_3df, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.4.106', uid_name: 'MPEG-4 AVC/H.264 Stereo High Profile / Level 4.2', uid_key: 'MPEG4HP42STEREO', uid_sym: :mpeg4hp42stereo, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.4.106.1', uid_name: 'Fragmentable MPEG-4 AVC/H.264 Stereo High Profile / Level 4.2', uid_key: 'MPEG4HP42STEREOF', uid_sym: :mpeg4hp42stereof, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.4.107', uid_name: 'HEVC/H.265 Main Profile / Level 5.1', uid_key: 'HEVCMP51', uid_sym: :hevcmp51, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.4.108', uid_name: 'HEVC/H.265 Main 10 Profile / Level 5.1', uid_key: 'HEVCM10P51', uid_sym: :hevcm10p51, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.4.110', uid_name: 'JPEG XL Lossless', uid_key: 'JPEGXLLossless', uid_sym: :jpegxl_lossless, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.4.111', uid_name: 'JPEG XL JPEG Recompression', uid_key: 'JPEGXLJPEGRecompression', uid_sym: :jpegxljpeg_recompression, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.4.112', uid_name: 'JPEG XL', uid_key: 'JPEGXL', uid_sym: :jpegxl, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.4.201', uid_name: 'High-Throughput JPEG 2000 Image Compression (Lossless Only)', uid_key: 'HTJ2KLossless', uid_sym: :htj2k_lossless, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.4.202', uid_name: 'High-Throughput JPEG 2000 with RPCL Options Image Compression (Lossless Only)', uid_key: 'HTJ2KLosslessRPCL', uid_sym: :htj2k_lossless_rpcl, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.4.203', uid_name: 'High-Throughput JPEG 2000 Image Compression', uid_key: 'HTJ2K', uid_sym: :htj2k, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.4.204', uid_name: 'JPIP HTJ2K Referenced', uid_key: 'JPIPHTJ2KReferenced', uid_sym: :jpiphtj2k_referenced, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.4.205', uid_name: 'JPIP HTJ2K Referenced Deflate', uid_key: 'JPIPHTJ2KReferencedDeflate', uid_sym: :jpiphtj2k_referenced_deflate, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.5', uid_name: 'RLE Lossless', uid_key: 'RLELossless', uid_sym: :rle_lossless, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.6.1', uid_name: 'RFC 2557 MIME encapsulation (Retired)', uid_key: 'RFC2557MIMEEncapsulation', uid_sym: :rfc2557mime_encapsulation, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.6.2', uid_name: 'XML Encoding (Retired)', uid_key: 'XMLEncoding', uid_sym: :xml_encoding, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.7.1', uid_name: 'SMPTE ST 2110-20 Uncompressed Progressive Active Video', uid_key: 'SMPTEST211020UncompressedProgressiveActiveVideo', uid_sym: :smptest211020_uncompressed_progressive_active_video, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.7.2', uid_name: 'SMPTE ST 2110-20 Uncompressed Interlaced Active Video', uid_key: 'SMPTEST211020UncompressedInterlacedActiveVideo', uid_sym: :smptest211020_uncompressed_interlaced_active_video, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.7.3', uid_name: 'SMPTE ST 2110-30 PCM Digital Audio', uid_key: 'SMPTEST211030PCMDigitalAudio', uid_sym: :smptest211030pcm_digital_audio, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.2.8.1', uid_name: 'Deflated Image Frame Compression', uid_key: 'DeflatedImageFrameCompression', uid_sym: :deflated_image_frame_compression, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.3.10', uid_name: 'Media Storage Directory Storage', uid_key: 'MediaStorageDirectoryStorage', uid_sym: :media_storage_directory_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.1.5.1', uid_name: 'Hot Iron Color Palette SOP Instance', uid_key: 'HotIronPalette', uid_sym: :hot_iron_palette, uid_type: :well_known_sop_instance},
      { uid_value: '1.2.840.10008.1.5.2', uid_name: 'PET Color Palette SOP Instance', uid_key: 'PETPalette', uid_sym: :pet_palette, uid_type: :well_known_sop_instance},
      { uid_value: '1.2.840.10008.1.5.3', uid_name: 'Hot Metal Blue Color Palette SOP Instance', uid_key: 'HotMetalBluePalette', uid_sym: :hot_metal_blue_palette, uid_type: :well_known_sop_instance},
      { uid_value: '1.2.840.10008.1.5.4', uid_name: 'PET 20 Step Color Palette SOP Instance', uid_key: 'PET20StepPalette', uid_sym: :pet20_step_palette, uid_type: :well_known_sop_instance},
      { uid_value: '1.2.840.10008.1.5.5', uid_name: 'Spring Color Palette SOP Instance', uid_key: 'SpringPalette', uid_sym: :spring_palette, uid_type: :well_known_sop_instance},
      { uid_value: '1.2.840.10008.1.5.6', uid_name: 'Summer Color Palette SOP Instance', uid_key: 'SummerPalette', uid_sym: :summer_palette, uid_type: :well_known_sop_instance},
      { uid_value: '1.2.840.10008.1.5.7', uid_name: 'Fall Color Palette SOP Instance', uid_key: 'FallPalette', uid_sym: :fall_palette, uid_type: :well_known_sop_instance},
      { uid_value: '1.2.840.10008.1.5.8', uid_name: 'Winter Color Palette SOP Instance', uid_key: 'WinterPalette', uid_sym: :winter_palette, uid_type: :well_known_sop_instance},
      { uid_value: '1.2.840.10008.1.9', uid_name: 'Basic Study Content Notification SOP Class (Retired)', uid_key: 'BasicStudyContentNotification', uid_sym: :basic_study_content_notification, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.1.20', uid_name: 'Papyrus 3 Implicit VR Little Endian (Retired)', uid_key: 'Papyrus3ImplicitVRLittleEndian', uid_sym: :papyrus3_implicit_vr_little_endian, uid_type: :transfer_syntax},
      { uid_value: '1.2.840.10008.1.20.1', uid_name: 'Storage Commitment Push Model SOP Class', uid_key: 'StorageCommitmentPushModel', uid_sym: :storage_commitment_push_model, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.1.20.1.1', uid_name: 'Storage Commitment Push Model SOP Instance', uid_key: 'StorageCommitmentPushModelInstance', uid_sym: :storage_commitment_push_model_instance, uid_type: :well_known_sop_instance},
      { uid_value: '1.2.840.10008.1.20.2', uid_name: 'Storage Commitment Pull Model SOP Class (Retired)', uid_key: 'StorageCommitmentPullModel', uid_sym: :storage_commitment_pull_model, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.1.20.2.1', uid_name: 'Storage Commitment Pull Model SOP Instance (Retired)', uid_key: 'StorageCommitmentPullModelInstance', uid_sym: :storage_commitment_pull_model_instance, uid_type: :well_known_sop_instance},
      { uid_value: '1.2.840.10008.1.40', uid_name: 'Procedural Event Logging SOP Class', uid_key: 'ProceduralEventLogging', uid_sym: :procedural_event_logging, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.1.40.1', uid_name: 'Procedural Event Logging SOP Instance', uid_key: 'ProceduralEventLoggingInstance', uid_sym: :procedural_event_logging_instance, uid_type: :well_known_sop_instance},
      { uid_value: '1.2.840.10008.1.42', uid_name: 'Substance Administration Logging SOP Class', uid_key: 'SubstanceAdministrationLogging', uid_sym: :substance_administration_logging, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.1.42.1', uid_name: 'Substance Administration Logging SOP Instance', uid_key: 'SubstanceAdministrationLoggingInstance', uid_sym: :substance_administration_logging_instance, uid_type: :well_known_sop_instance},
      { uid_value: '1.2.840.10008.2.6.1', uid_name: 'DICOM UID Registry', uid_key: 'DCMUID', uid_sym: :dcmuid, uid_type: :dicom_uids_as_a_coding_scheme},
      { uid_value: '1.2.840.10008.2.16.4', uid_name: 'DICOM Controlled Terminology', uid_key: 'DCM', uid_sym: :dcm, uid_type: :coding_scheme},
      { uid_value: '1.2.840.10008.2.16.5', uid_name: 'Adult Mouse Anatomy Ontology', uid_key: 'MA', uid_sym: :ma, uid_type: :coding_scheme},
      { uid_value: '1.2.840.10008.2.16.6', uid_name: 'Uberon Ontology', uid_key: 'UBERON', uid_sym: :uberon, uid_type: :coding_scheme},
      { uid_value: '1.2.840.10008.2.16.7', uid_name: 'Integrated Taxonomic Information System (ITIS) Taxonomic Serial Number (TSN)', uid_key: 'ITIS_TSN', uid_sym: :itis_tsn, uid_type: :coding_scheme},
      { uid_value: '1.2.840.10008.2.16.8', uid_name: 'Mouse Genome Initiative (MGI)', uid_key: 'MGI', uid_sym: :mgi, uid_type: :coding_scheme},
      { uid_value: '1.2.840.10008.2.16.9', uid_name: 'PubChem Compound CID', uid_key: 'PUBCHEM_CID', uid_sym: :pubchem_cid, uid_type: :coding_scheme},
      { uid_value: '1.2.840.10008.2.16.10', uid_name: 'Dublin Core', uid_key: 'DC', uid_sym: :dc, uid_type: :coding_scheme},
      { uid_value: '1.2.840.10008.2.16.11', uid_name: 'New York University Melanoma Clinical Cooperative Group', uid_key: 'NYUMCCG', uid_sym: :nyumccg, uid_type: :coding_scheme},
      { uid_value: '1.2.840.10008.2.16.12', uid_name: 'Mayo Clinic Non-radiological Images Specific Body Structure Anatomical Surface Region Guide', uid_key: 'MAYONRISBSASRG', uid_sym: :mayonrisbsasrg, uid_type: :coding_scheme},
      { uid_value: '1.2.840.10008.2.16.13', uid_name: 'Image Biomarker Standardisation Initiative', uid_key: 'IBSI', uid_sym: :ibsi, uid_type: :coding_scheme},
      { uid_value: '1.2.840.10008.2.16.14', uid_name: 'Radiomics Ontology', uid_key: 'RO', uid_sym: :ro, uid_type: :coding_scheme},
      { uid_value: '1.2.840.10008.2.16.15', uid_name: 'RadElement', uid_key: 'RADELEMENT', uid_sym: :radelement, uid_type: :coding_scheme},
      { uid_value: '1.2.840.10008.2.16.16', uid_name: 'ICD-11', uid_key: 'I11', uid_sym: :i11, uid_type: :coding_scheme},
      { uid_value: '1.2.840.10008.2.16.17', uid_name: 'Unified numbering system (UNS) for metals and alloys', uid_key: 'UNS', uid_sym: :uns, uid_type: :coding_scheme},
      { uid_value: '1.2.840.10008.2.16.18', uid_name: 'Research Resource Identification', uid_key: 'RRID', uid_sym: :rrid, uid_type: :coding_scheme},
      { uid_value: '1.2.840.10008.3.1.1.1', uid_name: 'DICOM Application Context Name', uid_key: 'DICOMApplicationContext', uid_sym: :dicom_application_context, uid_type: :application_context_name},
      { uid_value: '1.2.840.10008.3.1.2.1.1', uid_name: 'Detached Patient Management SOP Class (Retired)', uid_key: 'DetachedPatientManagement', uid_sym: :detached_patient_management, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.3.1.2.1.4', uid_name: 'Detached Patient Management Meta SOP Class (Retired)', uid_key: 'DetachedPatientManagementMeta', uid_sym: :detached_patient_management_meta, uid_type: :meta_sop_class},
      { uid_value: '1.2.840.10008.3.1.2.2.1', uid_name: 'Detached Visit Management SOP Class (Retired)', uid_key: 'DetachedVisitManagement', uid_sym: :detached_visit_management, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.3.1.2.3.1', uid_name: 'Detached Study Management SOP Class (Retired)', uid_key: 'DetachedStudyManagement', uid_sym: :detached_study_management, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.3.1.2.3.2', uid_name: 'Study Component Management SOP Class (Retired)', uid_key: 'StudyComponentManagement', uid_sym: :study_component_management, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.3.1.2.3.3', uid_name: 'Modality Performed Procedure Step SOP Class', uid_key: 'ModalityPerformedProcedureStep', uid_sym: :modality_performed_procedure_step, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.3.1.2.3.4', uid_name: 'Modality Performed Procedure Step Retrieve SOP Class', uid_key: 'ModalityPerformedProcedureStepRetrieve', uid_sym: :modality_performed_procedure_step_retrieve, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.3.1.2.3.5', uid_name: 'Modality Performed Procedure Step Notification SOP Class', uid_key: 'ModalityPerformedProcedureStepNotification', uid_sym: :modality_performed_procedure_step_notification, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.3.1.2.5.1', uid_name: 'Detached Results Management SOP Class (Retired)', uid_key: 'DetachedResultsManagement', uid_sym: :detached_results_management, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.3.1.2.5.4', uid_name: 'Detached Results Management Meta SOP Class (Retired)', uid_key: 'DetachedResultsManagementMeta', uid_sym: :detached_results_management_meta, uid_type: :meta_sop_class},
      { uid_value: '1.2.840.10008.3.1.2.5.5', uid_name: 'Detached Study Management Meta SOP Class (Retired)', uid_key: 'DetachedStudyManagementMeta', uid_sym: :detached_study_management_meta, uid_type: :meta_sop_class},
      { uid_value: '1.2.840.10008.3.1.2.6.1', uid_name: 'Detached Interpretation Management SOP Class (Retired)', uid_key: 'DetachedInterpretationManagement', uid_sym: :detached_interpretation_management, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.4.2', uid_name: 'Storage Service Class', uid_key: 'Storage', uid_sym: :storage, uid_type: :service_class},
      { uid_value: '1.2.840.10008.5.1.1.1', uid_name: 'Basic Film Session SOP Class', uid_key: 'BasicFilmSession', uid_sym: :basic_film_session, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.1.2', uid_name: 'Basic Film Box SOP Class', uid_key: 'BasicFilmBox', uid_sym: :basic_film_box, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.1.4', uid_name: 'Basic Grayscale Image Box SOP Class', uid_key: 'BasicGrayscaleImageBox', uid_sym: :basic_grayscale_image_box, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.1.4.1', uid_name: 'Basic Color Image Box SOP Class', uid_key: 'BasicColorImageBox', uid_sym: :basic_color_image_box, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.1.4.2', uid_name: 'Referenced Image Box SOP Class (Retired)', uid_key: 'ReferencedImageBox', uid_sym: :referenced_image_box, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.1.9', uid_name: 'Basic Grayscale Print Management Meta SOP Class', uid_key: 'BasicGrayscalePrintManagementMeta', uid_sym: :basic_grayscale_print_management_meta, uid_type: :meta_sop_class},
      { uid_value: '1.2.840.10008.5.1.1.9.1', uid_name: 'Referenced Grayscale Print Management Meta SOP Class (Retired)', uid_key: 'ReferencedGrayscalePrintManagementMeta', uid_sym: :referenced_grayscale_print_management_meta, uid_type: :meta_sop_class},
      { uid_value: '1.2.840.10008.5.1.1.14', uid_name: 'Print Job SOP Class', uid_key: 'PrintJob', uid_sym: :print_job, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.1.15', uid_name: 'Basic Annotation Box SOP Class', uid_key: 'BasicAnnotationBox', uid_sym: :basic_annotation_box, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.1.16', uid_name: 'Printer SOP Class', uid_key: 'Printer', uid_sym: :printer, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.1.16.376', uid_name: 'Printer Configuration Retrieval SOP Class', uid_key: 'PrinterConfigurationRetrieval', uid_sym: :printer_configuration_retrieval, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.1.17', uid_name: 'Printer SOP Instance', uid_key: 'PrinterInstance', uid_sym: :printer_instance, uid_type: :well_known_sop_instance},
      { uid_value: '1.2.840.10008.5.1.1.17.376', uid_name: 'Printer Configuration Retrieval SOP Instance', uid_key: 'PrinterConfigurationRetrievalInstance', uid_sym: :printer_configuration_retrieval_instance, uid_type: :well_known_sop_instance},
      { uid_value: '1.2.840.10008.5.1.1.18', uid_name: 'Basic Color Print Management Meta SOP Class', uid_key: 'BasicColorPrintManagementMeta', uid_sym: :basic_color_print_management_meta, uid_type: :meta_sop_class},
      { uid_value: '1.2.840.10008.5.1.1.18.1', uid_name: 'Referenced Color Print Management Meta SOP Class (Retired)', uid_key: 'ReferencedColorPrintManagementMeta', uid_sym: :referenced_color_print_management_meta, uid_type: :meta_sop_class},
      { uid_value: '1.2.840.10008.5.1.1.22', uid_name: 'VOI LUT Box SOP Class', uid_key: 'VOILUTBox', uid_sym: :voi_lut_box, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.1.23', uid_name: 'Presentation LUT SOP Class', uid_key: 'PresentationLUT', uid_sym: :presentation_lut, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.1.24', uid_name: 'Image Overlay Box SOP Class (Retired)', uid_key: 'ImageOverlayBox', uid_sym: :image_overlay_box, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.1.24.1', uid_name: 'Basic Print Image Overlay Box SOP Class (Retired)', uid_key: 'BasicPrintImageOverlayBox', uid_sym: :basic_print_image_overlay_box, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.1.25', uid_name: 'Print Queue SOP Instance (Retired)', uid_key: 'PrintQueueInstance', uid_sym: :print_queue_instance, uid_type: :well_known_sop_instance},
      { uid_value: '1.2.840.10008.5.1.1.26', uid_name: 'Print Queue Management SOP Class (Retired)', uid_key: 'PrintQueueManagement', uid_sym: :print_queue_management, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.1.27', uid_name: 'Stored Print Storage SOP Class (Retired)', uid_key: 'StoredPrintStorage', uid_sym: :stored_print_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.1.29', uid_name: 'Hardcopy Grayscale Image Storage SOP Class (Retired)', uid_key: 'HardcopyGrayscaleImageStorage', uid_sym: :hardcopy_grayscale_image_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.1.30', uid_name: 'Hardcopy Color Image Storage SOP Class (Retired)', uid_key: 'HardcopyColorImageStorage', uid_sym: :hardcopy_color_image_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.1.31', uid_name: 'Pull Print Request SOP Class (Retired)', uid_key: 'PullPrintRequest', uid_sym: :pull_print_request, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.1.32', uid_name: 'Pull Stored Print Management Meta SOP Class (Retired)', uid_key: 'PullStoredPrintManagementMeta', uid_sym: :pull_stored_print_management_meta, uid_type: :meta_sop_class},
      { uid_value: '1.2.840.10008.5.1.1.33', uid_name: 'Media Creation Management SOP Class UID', uid_key: 'MediaCreationManagement', uid_sym: :media_creation_management, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.1.40', uid_name: 'Display System SOP Class', uid_key: 'DisplaySystem', uid_sym: :display_system, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.1.40.1', uid_name: 'Display System SOP Instance', uid_key: 'DisplaySystemInstance', uid_sym: :display_system_instance, uid_type: :well_known_sop_instance},
      { uid_value: '1.2.840.10008.5.1.4.1.1.1', uid_name: 'Computed Radiography Image Storage', uid_key: 'ComputedRadiographyImageStorage', uid_sym: :computed_radiography_image_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.1.1', uid_name: 'Digital X-Ray Image Storage - For Presentation', uid_key: 'DigitalXRayImageStorageForPresentation', uid_sym: :digital_x_ray_image_storage_for_presentation, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.1.1.1', uid_name: 'Digital X-Ray Image Storage - For Processing', uid_key: 'DigitalXRayImageStorageForProcessing', uid_sym: :digital_x_ray_image_storage_for_processing, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.1.2', uid_name: 'Digital Mammography X-Ray Image Storage - For Presentation', uid_key: 'DigitalMammographyXRayImageStorageForPresentation', uid_sym: :digital_mammography_x_ray_image_storage_for_presentation, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.1.2.1', uid_name: 'Digital Mammography X-Ray Image Storage - For Processing', uid_key: 'DigitalMammographyXRayImageStorageForProcessing', uid_sym: :digital_mammography_x_ray_image_storage_for_processing, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.1.3', uid_name: 'Digital Intra-Oral X-Ray Image Storage - For Presentation', uid_key: 'DigitalIntraOralXRayImageStorageForPresentation', uid_sym: :digital_intra_oral_x_ray_image_storage_for_presentation, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.1.3.1', uid_name: 'Digital Intra-Oral X-Ray Image Storage - For Processing', uid_key: 'DigitalIntraOralXRayImageStorageForProcessing', uid_sym: :digital_intra_oral_x_ray_image_storage_for_processing, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.2', uid_name: 'CT Image Storage', uid_key: 'CTImageStorage', uid_sym: :ct_image_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.2.1', uid_name: 'Enhanced CT Image Storage', uid_key: 'EnhancedCTImageStorage', uid_sym: :enhanced_ct_image_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.2.2', uid_name: 'Legacy Converted Enhanced CT Image Storage', uid_key: 'LegacyConvertedEnhancedCTImageStorage', uid_sym: :legacy_converted_enhanced_ct_image_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.3', uid_name: 'Ultrasound Multi-frame Image Storage (Retired)', uid_key: 'UltrasoundMultiFrameImageStorageRetired', uid_sym: :ultrasound_multi_frame_image_storage_retired, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.3.1', uid_name: 'Ultrasound Multi-frame Image Storage', uid_key: 'UltrasoundMultiFrameImageStorage', uid_sym: :ultrasound_multi_frame_image_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.4', uid_name: 'MR Image Storage', uid_key: 'MRImageStorage', uid_sym: :mr_image_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.4.1', uid_name: 'Enhanced MR Image Storage', uid_key: 'EnhancedMRImageStorage', uid_sym: :enhanced_mr_image_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.4.2', uid_name: 'MR Spectroscopy Storage', uid_key: 'MRSpectroscopyStorage', uid_sym: :mr_spectroscopy_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.4.3', uid_name: 'Enhanced MR Color Image Storage', uid_key: 'EnhancedMRColorImageStorage', uid_sym: :enhanced_mr_color_image_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.4.4', uid_name: 'Legacy Converted Enhanced MR Image Storage', uid_key: 'LegacyConvertedEnhancedMRImageStorage', uid_sym: :legacy_converted_enhanced_mr_image_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.5', uid_name: 'Nuclear Medicine Image Storage (Retired)', uid_key: 'NuclearMedicineImageStorageRetired', uid_sym: :nuclear_medicine_image_storage_retired, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.6', uid_name: 'Ultrasound Image Storage (Retired)', uid_key: 'UltrasoundImageStorageRetired', uid_sym: :ultrasound_image_storage_retired, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.6.1', uid_name: 'Ultrasound Image Storage', uid_key: 'UltrasoundImageStorage', uid_sym: :ultrasound_image_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.6.2', uid_name: 'Enhanced US Volume Storage', uid_key: 'EnhancedUSVolumeStorage', uid_sym: :enhanced_us_volume_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.6.3', uid_name: 'Photoacoustic Image Storage', uid_key: 'PhotoacousticImageStorage', uid_sym: :photoacoustic_image_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.7', uid_name: 'Secondary Capture Image Storage', uid_key: 'SecondaryCaptureImageStorage', uid_sym: :secondary_capture_image_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.7.1', uid_name: 'Multi-frame Single Bit Secondary Capture Image Storage', uid_key: 'MultiFrameSingleBitSecondaryCaptureImageStorage', uid_sym: :multi_frame_single_bit_secondary_capture_image_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.7.2', uid_name: 'Multi-frame Grayscale Byte Secondary Capture Image Storage', uid_key: 'MultiFrameGrayscaleByteSecondaryCaptureImageStorage', uid_sym: :multi_frame_grayscale_byte_secondary_capture_image_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.7.3', uid_name: 'Multi-frame Grayscale Word Secondary Capture Image Storage', uid_key: 'MultiFrameGrayscaleWordSecondaryCaptureImageStorage', uid_sym: :multi_frame_grayscale_word_secondary_capture_image_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.7.4', uid_name: 'Multi-frame True Color Secondary Capture Image Storage', uid_key: 'MultiFrameTrueColorSecondaryCaptureImageStorage', uid_sym: :multi_frame_true_color_secondary_capture_image_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.8', uid_name: 'Standalone Overlay Storage (Retired)', uid_key: 'StandaloneOverlayStorage', uid_sym: :standalone_overlay_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.9', uid_name: 'Standalone Curve Storage (Retired)', uid_key: 'StandaloneCurveStorage', uid_sym: :standalone_curve_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.9.1', uid_name: 'Waveform Storage - Trial (Retired)', uid_key: 'WaveformStorageTrial', uid_sym: :waveform_storage_trial, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.9.1.1', uid_name: '12-lead ECG Waveform Storage', uid_key: 'TwelveLeadECGWaveformStorage', uid_sym: :twelve_lead_ecg_waveform_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.9.1.2', uid_name: 'General ECG Waveform Storage', uid_key: 'GeneralECGWaveformStorage', uid_sym: :general_ecg_waveform_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.9.1.3', uid_name: 'Ambulatory ECG Waveform Storage', uid_key: 'AmbulatoryECGWaveformStorage', uid_sym: :ambulatory_ecg_waveform_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.9.1.4', uid_name: 'General 32-bit ECG Waveform Storage', uid_key: 'General32bitECGWaveformStorage', uid_sym: :general32bit_ecg_waveform_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.9.2.1', uid_name: 'Hemodynamic Waveform Storage', uid_key: 'HemodynamicWaveformStorage', uid_sym: :hemodynamic_waveform_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.9.3.1', uid_name: 'Cardiac Electrophysiology Waveform Storage', uid_key: 'CardiacElectrophysiologyWaveformStorage', uid_sym: :cardiac_electrophysiology_waveform_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.9.4.1', uid_name: 'Basic Voice Audio Waveform Storage', uid_key: 'BasicVoiceAudioWaveformStorage', uid_sym: :basic_voice_audio_waveform_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.9.4.2', uid_name: 'General Audio Waveform Storage', uid_key: 'GeneralAudioWaveformStorage', uid_sym: :general_audio_waveform_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.9.5.1', uid_name: 'Arterial Pulse Waveform Storage', uid_key: 'ArterialPulseWaveformStorage', uid_sym: :arterial_pulse_waveform_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.9.6.1', uid_name: 'Respiratory Waveform Storage', uid_key: 'RespiratoryWaveformStorage', uid_sym: :respiratory_waveform_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.9.6.2', uid_name: 'Multi-channel Respiratory Waveform Storage', uid_key: 'MultichannelRespiratoryWaveformStorage', uid_sym: :multichannel_respiratory_waveform_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.9.7.1', uid_name: 'Routine Scalp Electroencephalogram Waveform Storage', uid_key: 'RoutineScalpElectroencephalogramWaveformStorage', uid_sym: :routine_scalp_electroencephalogram_waveform_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.9.7.2', uid_name: 'Electromyogram Waveform Storage', uid_key: 'ElectromyogramWaveformStorage', uid_sym: :electromyogram_waveform_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.9.7.3', uid_name: 'Electrooculogram Waveform Storage', uid_key: 'ElectrooculogramWaveformStorage', uid_sym: :electrooculogram_waveform_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.9.7.4', uid_name: 'Sleep Electroencephalogram Waveform Storage', uid_key: 'SleepElectroencephalogramWaveformStorage', uid_sym: :sleep_electroencephalogram_waveform_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.9.8.1', uid_name: 'Body Position Waveform Storage', uid_key: 'BodyPositionWaveformStorage', uid_sym: :body_position_waveform_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.9.100.1', uid_name: 'Waveform Presentation State Storage', uid_key: 'WaveformPresentationStateStorage', uid_sym: :waveform_presentation_state_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.9.100.2', uid_name: 'Waveform Acquisition Presentation State Storage', uid_key: 'WaveformAcquisitionPresentationStateStorage', uid_sym: :waveform_acquisition_presentation_state_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.10', uid_name: 'Standalone Modality LUT Storage (Retired)', uid_key: 'StandaloneModalityLUTStorage', uid_sym: :standalone_modality_lut_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.11', uid_name: 'Standalone VOI LUT Storage (Retired)', uid_key: 'StandaloneVOILUTStorage', uid_sym: :standalone_voi_lut_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.11.1', uid_name: 'Grayscale Softcopy Presentation State Storage', uid_key: 'GrayscaleSoftcopyPresentationStateStorage', uid_sym: :grayscale_softcopy_presentation_state_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.11.2', uid_name: 'Color Softcopy Presentation State Storage', uid_key: 'ColorSoftcopyPresentationStateStorage', uid_sym: :color_softcopy_presentation_state_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.11.3', uid_name: 'Pseudo-Color Softcopy Presentation State Storage', uid_key: 'PseudoColorSoftcopyPresentationStateStorage', uid_sym: :pseudo_color_softcopy_presentation_state_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.11.4', uid_name: 'Blending Softcopy Presentation State Storage', uid_key: 'BlendingSoftcopyPresentationStateStorage', uid_sym: :blending_softcopy_presentation_state_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.11.5', uid_name: 'XA/XRF Grayscale Softcopy Presentation State Storage', uid_key: 'XAXRFGrayscaleSoftcopyPresentationStateStorage', uid_sym: :xa_xrf_grayscale_softcopy_presentation_state_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.11.6', uid_name: 'Grayscale Planar MPR Volumetric Presentation State Storage', uid_key: 'GrayscalePlanarMPRVolumetricPresentationStateStorage', uid_sym: :grayscale_planar_mpr_volumetric_presentation_state_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.11.7', uid_name: 'Compositing Planar MPR Volumetric Presentation State Storage', uid_key: 'CompositingPlanarMPRVolumetricPresentationStateStorage', uid_sym: :compositing_planar_mpr_volumetric_presentation_state_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.11.8', uid_name: 'Advanced Blending Presentation State Storage', uid_key: 'AdvancedBlendingPresentationStateStorage', uid_sym: :advanced_blending_presentation_state_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.11.9', uid_name: 'Volume Rendering Volumetric Presentation State Storage', uid_key: 'VolumeRenderingVolumetricPresentationStateStorage', uid_sym: :volume_rendering_volumetric_presentation_state_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.11.10', uid_name: 'Segmented Volume Rendering Volumetric Presentation State Storage', uid_key: 'SegmentedVolumeRenderingVolumetricPresentationStateStorage', uid_sym: :segmented_volume_rendering_volumetric_presentation_state_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.11.11', uid_name: 'Multiple Volume Rendering Volumetric Presentation State Storage', uid_key: 'MultipleVolumeRenderingVolumetricPresentationStateStorage', uid_sym: :multiple_volume_rendering_volumetric_presentation_state_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.11.12', uid_name: 'Variable Modality LUT Softcopy Presentation State Storage', uid_key: 'VariableModalityLUTSoftcopyPresentationStateStorage', uid_sym: :variable_modality_lut_softcopy_presentation_state_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.12.1', uid_name: 'X-Ray Angiographic Image Storage', uid_key: 'XRayAngiographicImageStorage', uid_sym: :x_ray_angiographic_image_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.12.1.1', uid_name: 'Enhanced XA Image Storage', uid_key: 'EnhancedXAImageStorage', uid_sym: :enhanced_xa_image_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.12.2', uid_name: 'X-Ray Radiofluoroscopic Image Storage', uid_key: 'XRayRadiofluoroscopicImageStorage', uid_sym: :x_ray_radiofluoroscopic_image_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.12.2.1', uid_name: 'Enhanced XRF Image Storage', uid_key: 'EnhancedXRFImageStorage', uid_sym: :enhanced_xrf_image_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.12.3', uid_name: 'X-Ray Angiographic Bi-Plane Image Storage (Retired)', uid_key: 'XRayAngiographicBiPlaneImageStorage', uid_sym: :x_ray_angiographic_bi_plane_image_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.12.77', uid_name: '1.2.840.10008.5.1.4.1.1.12.77 (Retired)', uid_key: 'UID_1_2_840_10008_5_1_4_1_1_12_77', uid_sym: :uid_1_2_840_10008_5_1_4_1_1_12_77, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.13.1.1', uid_name: 'X-Ray 3D Angiographic Image Storage', uid_key: 'XRay3DAngiographicImageStorage', uid_sym: :x_ray_3d_angiographic_image_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.13.1.2', uid_name: 'X-Ray 3D Craniofacial Image Storage', uid_key: 'XRay3DCraniofacialImageStorage', uid_sym: :x_ray_3d_craniofacial_image_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.13.1.3', uid_name: 'Breast Tomosynthesis Image Storage', uid_key: 'BreastTomosynthesisImageStorage', uid_sym: :breast_tomosynthesis_image_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.13.1.4', uid_name: 'Breast Projection X-Ray Image Storage - For Presentation', uid_key: 'BreastProjectionXRayImageStorageForPresentation', uid_sym: :breast_projection_x_ray_image_storage_for_presentation, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.13.1.5', uid_name: 'Breast Projection X-Ray Image Storage - For Processing', uid_key: 'BreastProjectionXRayImageStorageForProcessing', uid_sym: :breast_projection_x_ray_image_storage_for_processing, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.14.1', uid_name: 'Intravascular Optical Coherence Tomography Image Storage - For Presentation', uid_key: 'IntravascularOpticalCoherenceTomographyImageStorageForPresentation', uid_sym: :intravascular_optical_coherence_tomography_image_storage_for_presentation, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.14.2', uid_name: 'Intravascular Optical Coherence Tomography Image Storage - For Processing', uid_key: 'IntravascularOpticalCoherenceTomographyImageStorageForProcessing', uid_sym: :intravascular_optical_coherence_tomography_image_storage_for_processing, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.20', uid_name: 'Nuclear Medicine Image Storage', uid_key: 'NuclearMedicineImageStorage', uid_sym: :nuclear_medicine_image_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.30', uid_name: 'Parametric Map Storage', uid_key: 'ParametricMapStorage', uid_sym: :parametric_map_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.40', uid_name: '1.2.840.10008.5.1.4.1.1.40 (Retired)', uid_key: 'UID_1_2_840_10008_5_1_4_1_1_40', uid_sym: :uid_1_2_840_10008_5_1_4_1_1_40, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.66', uid_name: 'Raw Data Storage', uid_key: 'RawDataStorage', uid_sym: :raw_data_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.66.1', uid_name: 'Spatial Registration Storage', uid_key: 'SpatialRegistrationStorage', uid_sym: :spatial_registration_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.66.2', uid_name: 'Spatial Fiducials Storage', uid_key: 'SpatialFiducialsStorage', uid_sym: :spatial_fiducials_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.66.3', uid_name: 'Deformable Spatial Registration Storage', uid_key: 'DeformableSpatialRegistrationStorage', uid_sym: :deformable_spatial_registration_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.66.4', uid_name: 'Segmentation Storage', uid_key: 'SegmentationStorage', uid_sym: :segmentation_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.66.5', uid_name: 'Surface Segmentation Storage', uid_key: 'SurfaceSegmentationStorage', uid_sym: :surface_segmentation_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.66.6', uid_name: 'Tractography Results Storage', uid_key: 'TractographyResultsStorage', uid_sym: :tractography_results_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.66.7', uid_name: 'Label Map Segmentation Storage', uid_key: 'LabelMapSegmentationStorage', uid_sym: :label_map_segmentation_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.66.8', uid_name: 'Height Map Segmentation Storage', uid_key: 'HeightMapSegmentationStorage', uid_sym: :height_map_segmentation_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.67', uid_name: 'Real World Value Mapping Storage', uid_key: 'RealWorldValueMappingStorage', uid_sym: :real_world_value_mapping_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.68.1', uid_name: 'Surface Scan Mesh Storage', uid_key: 'SurfaceScanMeshStorage', uid_sym: :surface_scan_mesh_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.68.2', uid_name: 'Surface Scan Point Cloud Storage', uid_key: 'SurfaceScanPointCloudStorage', uid_sym: :surface_scan_point_cloud_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.77.1', uid_name: 'VL Image Storage - Trial (Retired)', uid_key: 'VLImageStorageTrial', uid_sym: :vl_image_storage_trial, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.77.2', uid_name: 'VL Multi-frame Image Storage - Trial (Retired)', uid_key: 'VLMultiFrameImageStorageTrial', uid_sym: :vl_multi_frame_image_storage_trial, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.77.1.1', uid_name: 'VL Endoscopic Image Storage', uid_key: 'VLEndoscopicImageStorage', uid_sym: :vl_endoscopic_image_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.77.1.1.1', uid_name: 'Video Endoscopic Image Storage', uid_key: 'VideoEndoscopicImageStorage', uid_sym: :video_endoscopic_image_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.77.1.2', uid_name: 'VL Microscopic Image Storage', uid_key: 'VLMicroscopicImageStorage', uid_sym: :vl_microscopic_image_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.77.1.2.1', uid_name: 'Video Microscopic Image Storage', uid_key: 'VideoMicroscopicImageStorage', uid_sym: :video_microscopic_image_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.77.1.3', uid_name: 'VL Slide-Coordinates Microscopic Image Storage', uid_key: 'VLSlideCoordinatesMicroscopicImageStorage', uid_sym: :vl_slide_coordinates_microscopic_image_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.77.1.4', uid_name: 'VL Photographic Image Storage', uid_key: 'VLPhotographicImageStorage', uid_sym: :vl_photographic_image_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.77.1.4.1', uid_name: 'Video Photographic Image Storage', uid_key: 'VideoPhotographicImageStorage', uid_sym: :video_photographic_image_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.77.1.5.1', uid_name: 'Ophthalmic Photography 8 Bit Image Storage', uid_key: 'OphthalmicPhotography8BitImageStorage', uid_sym: :ophthalmic_photography8_bit_image_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.77.1.5.2', uid_name: 'Ophthalmic Photography 16 Bit Image Storage', uid_key: 'OphthalmicPhotography16BitImageStorage', uid_sym: :ophthalmic_photography16_bit_image_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.77.1.5.3', uid_name: 'Stereometric Relationship Storage', uid_key: 'StereometricRelationshipStorage', uid_sym: :stereometric_relationship_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.77.1.5.4', uid_name: 'Ophthalmic Tomography Image Storage', uid_key: 'OphthalmicTomographyImageStorage', uid_sym: :ophthalmic_tomography_image_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.77.1.5.5', uid_name: 'Wide Field Ophthalmic Photography Stereographic Projection Image Storage', uid_key: 'WideFieldOphthalmicPhotographyStereographicProjectionImageStorage', uid_sym: :wide_field_ophthalmic_photography_stereographic_projection_image_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.77.1.5.6', uid_name: 'Wide Field Ophthalmic Photography 3D Coordinates Image Storage', uid_key: 'WideFieldOphthalmicPhotography3DCoordinatesImageStorage', uid_sym: :wide_field_ophthalmic_photography_3d_coordinates_image_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.77.1.5.7', uid_name: 'Ophthalmic Optical Coherence Tomography En Face Image Storage', uid_key: 'OphthalmicOpticalCoherenceTomographyEnFaceImageStorage', uid_sym: :ophthalmic_optical_coherence_tomography_en_face_image_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.77.1.5.8', uid_name: 'Ophthalmic Optical Coherence Tomography B-scan Volume Analysis Storage', uid_key: 'OphthalmicOpticalCoherenceTomographyBscanVolumeAnalysisStorage', uid_sym: :ophthalmic_optical_coherence_tomography_bscan_volume_analysis_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.77.1.6', uid_name: 'VL Whole Slide Microscopy Image Storage', uid_key: 'VLWholeSlideMicroscopyImageStorage', uid_sym: :vl_whole_slide_microscopy_image_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.77.1.7', uid_name: 'Dermoscopic Photography Image Storage', uid_key: 'DermoscopicPhotographyImageStorage', uid_sym: :dermoscopic_photography_image_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.77.1.8', uid_name: 'Confocal Microscopy Image Storage', uid_key: 'ConfocalMicroscopyImageStorage', uid_sym: :confocal_microscopy_image_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.77.1.9', uid_name: 'Confocal Microscopy Tiled Pyramidal Image Storage', uid_key: 'ConfocalMicroscopyTiledPyramidalImageStorage', uid_sym: :confocal_microscopy_tiled_pyramidal_image_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.78.1', uid_name: 'Lensometry Measurements Storage', uid_key: 'LensometryMeasurementsStorage', uid_sym: :lensometry_measurements_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.78.2', uid_name: 'Autorefraction Measurements Storage', uid_key: 'AutorefractionMeasurementsStorage', uid_sym: :autorefraction_measurements_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.78.3', uid_name: 'Keratometry Measurements Storage', uid_key: 'KeratometryMeasurementsStorage', uid_sym: :keratometry_measurements_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.78.4', uid_name: 'Subjective Refraction Measurements Storage', uid_key: 'SubjectiveRefractionMeasurementsStorage', uid_sym: :subjective_refraction_measurements_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.78.5', uid_name: 'Visual Acuity Measurements Storage', uid_key: 'VisualAcuityMeasurementsStorage', uid_sym: :visual_acuity_measurements_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.78.6', uid_name: 'Spectacle Prescription Report Storage', uid_key: 'SpectaclePrescriptionReportStorage', uid_sym: :spectacle_prescription_report_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.78.7', uid_name: 'Ophthalmic Axial Measurements Storage', uid_key: 'OphthalmicAxialMeasurementsStorage', uid_sym: :ophthalmic_axial_measurements_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.78.8', uid_name: 'Intraocular Lens Calculations Storage', uid_key: 'IntraocularLensCalculationsStorage', uid_sym: :intraocular_lens_calculations_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.79.1', uid_name: 'Macular Grid Thickness and Volume Report Storage', uid_key: 'MacularGridThicknessAndVolumeReportStorage', uid_sym: :macular_grid_thickness_and_volume_report_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.80.1', uid_name: 'Ophthalmic Visual Field Static Perimetry Measurements Storage', uid_key: 'OphthalmicVisualFieldStaticPerimetryMeasurementsStorage', uid_sym: :ophthalmic_visual_field_static_perimetry_measurements_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.81.1', uid_name: 'Ophthalmic Thickness Map Storage', uid_key: 'OphthalmicThicknessMapStorage', uid_sym: :ophthalmic_thickness_map_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.82.1', uid_name: 'Corneal Topography Map Storage', uid_key: 'CornealTopographyMapStorage', uid_sym: :corneal_topography_map_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.88.1', uid_name: 'Text SR Storage - Trial (Retired)', uid_key: 'TextSRStorageTrial', uid_sym: :text_sr_storage_trial, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.88.2', uid_name: 'Audio SR Storage - Trial (Retired)', uid_key: 'AudioSRStorageTrial', uid_sym: :audio_sr_storage_trial, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.88.3', uid_name: 'Detail SR Storage - Trial (Retired)', uid_key: 'DetailSRStorageTrial', uid_sym: :detail_sr_storage_trial, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.88.4', uid_name: 'Comprehensive SR Storage - Trial (Retired)', uid_key: 'ComprehensiveSRStorageTrial', uid_sym: :comprehensive_sr_storage_trial, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.88.11', uid_name: 'Basic Text SR Storage', uid_key: 'BasicTextSRStorage', uid_sym: :basic_text_sr_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.88.22', uid_name: 'Enhanced SR Storage', uid_key: 'EnhancedSRStorage', uid_sym: :enhanced_sr_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.88.33', uid_name: 'Comprehensive SR Storage', uid_key: 'ComprehensiveSRStorage', uid_sym: :comprehensive_sr_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.88.34', uid_name: 'Comprehensive 3D SR Storage', uid_key: 'Comprehensive3DSRStorage', uid_sym: :comprehensive_3dsr_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.88.35', uid_name: 'Extensible SR Storage', uid_key: 'ExtensibleSRStorage', uid_sym: :extensible_sr_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.88.40', uid_name: 'Procedure Log Storage', uid_key: 'ProcedureLogStorage', uid_sym: :procedure_log_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.88.50', uid_name: 'Mammography CAD SR Storage', uid_key: 'MammographyCADSRStorage', uid_sym: :mammography_cadsr_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.88.59', uid_name: 'Key Object Selection Document Storage', uid_key: 'KeyObjectSelectionDocumentStorage', uid_sym: :key_object_selection_document_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.88.65', uid_name: 'Chest CAD SR Storage', uid_key: 'ChestCADSRStorage', uid_sym: :chest_cadsr_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.88.67', uid_name: 'X-Ray Radiation Dose SR Storage', uid_key: 'XRayRadiationDoseSRStorage', uid_sym: :x_ray_radiation_dose_sr_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.88.68', uid_name: 'Radiopharmaceutical Radiation Dose SR Storage', uid_key: 'RadiopharmaceuticalRadiationDoseSRStorage', uid_sym: :radiopharmaceutical_radiation_dose_sr_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.88.69', uid_name: 'Colon CAD SR Storage', uid_key: 'ColonCADSRStorage', uid_sym: :colon_cadsr_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.88.70', uid_name: 'Implantation Plan SR Storage', uid_key: 'ImplantationPlanSRStorage', uid_sym: :implantation_plan_sr_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.88.71', uid_name: 'Acquisition Context SR Storage', uid_key: 'AcquisitionContextSRStorage', uid_sym: :acquisition_context_sr_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.88.72', uid_name: 'Simplified Adult Echo SR Storage', uid_key: 'SimplifiedAdultEchoSRStorage', uid_sym: :simplified_adult_echo_sr_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.88.73', uid_name: 'Patient Radiation Dose SR Storage', uid_key: 'PatientRadiationDoseSRStorage', uid_sym: :patient_radiation_dose_sr_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.88.74', uid_name: 'Planned Imaging Agent Administration SR Storage', uid_key: 'PlannedImagingAgentAdministrationSRStorage', uid_sym: :planned_imaging_agent_administration_sr_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.88.75', uid_name: 'Performed Imaging Agent Administration SR Storage', uid_key: 'PerformedImagingAgentAdministrationSRStorage', uid_sym: :performed_imaging_agent_administration_sr_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.88.76', uid_name: 'Enhanced X-Ray Radiation Dose SR Storage', uid_key: 'EnhancedXRayRadiationDoseSRStorage', uid_sym: :enhanced_x_ray_radiation_dose_sr_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.88.77', uid_name: 'Waveform Annotation SR Storage', uid_key: 'WaveformAnnotationSRStorage', uid_sym: :waveform_annotation_sr_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.90.1', uid_name: 'Content Assessment Results Storage', uid_key: 'ContentAssessmentResultsStorage', uid_sym: :content_assessment_results_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.91.1', uid_name: 'Microscopy Bulk Simple Annotations Storage', uid_key: 'MicroscopyBulkSimpleAnnotationsStorage', uid_sym: :microscopy_bulk_simple_annotations_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.104.1', uid_name: 'Encapsulated PDF Storage', uid_key: 'EncapsulatedPDFStorage', uid_sym: :encapsulated_pdf_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.104.2', uid_name: 'Encapsulated CDA Storage', uid_key: 'EncapsulatedCDAStorage', uid_sym: :encapsulated_cda_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.104.3', uid_name: 'Encapsulated STL Storage', uid_key: 'EncapsulatedSTLStorage', uid_sym: :encapsulated_stl_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.104.4', uid_name: 'Encapsulated OBJ Storage', uid_key: 'EncapsulatedOBJStorage', uid_sym: :encapsulated_obj_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.104.5', uid_name: 'Encapsulated MTL Storage', uid_key: 'EncapsulatedMTLStorage', uid_sym: :encapsulated_mtl_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.128', uid_name: 'Positron Emission Tomography Image Storage', uid_key: 'PositronEmissionTomographyImageStorage', uid_sym: :positron_emission_tomography_image_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.128.1', uid_name: 'Legacy Converted Enhanced PET Image Storage', uid_key: 'LegacyConvertedEnhancedPETImageStorage', uid_sym: :legacy_converted_enhanced_pet_image_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.129', uid_name: 'Standalone PET Curve Storage (Retired)', uid_key: 'StandalonePETCurveStorage', uid_sym: :standalone_pet_curve_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.130', uid_name: 'Enhanced PET Image Storage', uid_key: 'EnhancedPETImageStorage', uid_sym: :enhanced_pet_image_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.131', uid_name: 'Basic Structured Display Storage', uid_key: 'BasicStructuredDisplayStorage', uid_sym: :basic_structured_display_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.200.1', uid_name: 'CT Defined Procedure Protocol Storage', uid_key: 'CTDefinedProcedureProtocolStorage', uid_sym: :ct_defined_procedure_protocol_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.200.2', uid_name: 'CT Performed Procedure Protocol Storage', uid_key: 'CTPerformedProcedureProtocolStorage', uid_sym: :ct_performed_procedure_protocol_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.200.3', uid_name: 'Protocol Approval Storage', uid_key: 'ProtocolApprovalStorage', uid_sym: :protocol_approval_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.200.4', uid_name: 'Protocol Approval Information Model - FIND', uid_key: 'ProtocolApprovalInformationModelFind', uid_sym: :protocol_approval_information_model_find, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.200.5', uid_name: 'Protocol Approval Information Model - MOVE', uid_key: 'ProtocolApprovalInformationModelMove', uid_sym: :protocol_approval_information_model_move, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.200.6', uid_name: 'Protocol Approval Information Model - GET', uid_key: 'ProtocolApprovalInformationModelGet', uid_sym: :protocol_approval_information_model_get, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.200.7', uid_name: 'XA Defined Procedure Protocol Storage', uid_key: 'XADefinedProcedureProtocolStorage', uid_sym: :xa_defined_procedure_protocol_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.200.8', uid_name: 'XA Performed Procedure Protocol Storage', uid_key: 'XAPerformedProcedureProtocolStorage', uid_sym: :xa_performed_procedure_protocol_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.201.1', uid_name: 'Inventory Storage', uid_key: 'InventoryStorage', uid_sym: :inventory_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.201.2', uid_name: 'Inventory - FIND', uid_key: 'InventoryFind', uid_sym: :inventory_find, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.201.3', uid_name: 'Inventory - MOVE', uid_key: 'InventoryMove', uid_sym: :inventory_move, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.201.4', uid_name: 'Inventory - GET', uid_key: 'InventoryGet', uid_sym: :inventory_get, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.201.5', uid_name: 'Inventory Creation', uid_key: 'InventoryCreation', uid_sym: :inventory_creation, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.201.6', uid_name: 'Repository Query', uid_key: 'RepositoryQuery', uid_sym: :repository_query, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.201.1.1', uid_name: 'Storage Management SOP Instance', uid_key: 'StorageManagementInstance', uid_sym: :storage_management_instance, uid_type: :well_known_sop_instance},
      { uid_value: '1.2.840.10008.5.1.4.1.1.481.1', uid_name: 'RT Image Storage', uid_key: 'RTImageStorage', uid_sym: :rt_image_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.481.2', uid_name: 'RT Dose Storage', uid_key: 'RTDoseStorage', uid_sym: :rt_dose_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.481.3', uid_name: 'RT Structure Set Storage', uid_key: 'RTStructureSetStorage', uid_sym: :rt_structure_set_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.481.4', uid_name: 'RT Beams Treatment Record Storage', uid_key: 'RTBeamsTreatmentRecordStorage', uid_sym: :rt_beams_treatment_record_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.481.5', uid_name: 'RT Plan Storage', uid_key: 'RTPlanStorage', uid_sym: :rt_plan_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.481.6', uid_name: 'RT Brachy Treatment Record Storage', uid_key: 'RTBrachyTreatmentRecordStorage', uid_sym: :rt_brachy_treatment_record_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.481.7', uid_name: 'RT Treatment Summary Record Storage', uid_key: 'RTTreatmentSummaryRecordStorage', uid_sym: :rt_treatment_summary_record_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.481.8', uid_name: 'RT Ion Plan Storage', uid_key: 'RTIonPlanStorage', uid_sym: :rt_ion_plan_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.481.9', uid_name: 'RT Ion Beams Treatment Record Storage', uid_key: 'RTIonBeamsTreatmentRecordStorage', uid_sym: :rt_ion_beams_treatment_record_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.481.10', uid_name: 'RT Physician Intent Storage', uid_key: 'RTPhysicianIntentStorage', uid_sym: :rt_physician_intent_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.481.11', uid_name: 'RT Segment Annotation Storage', uid_key: 'RTSegmentAnnotationStorage', uid_sym: :rt_segment_annotation_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.481.12', uid_name: 'RT Radiation Set Storage', uid_key: 'RTRadiationSetStorage', uid_sym: :rt_radiation_set_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.481.13', uid_name: 'C-Arm Photon-Electron Radiation Storage', uid_key: 'CArmPhotonElectronRadiationStorage', uid_sym: :c_arm_photon_electron_radiation_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.481.14', uid_name: 'Tomotherapeutic Radiation Storage', uid_key: 'TomotherapeuticRadiationStorage', uid_sym: :tomotherapeutic_radiation_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.481.15', uid_name: 'Robotic-Arm Radiation Storage', uid_key: 'RoboticArmRadiationStorage', uid_sym: :robotic_arm_radiation_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.481.16', uid_name: 'RT Radiation Record Set Storage', uid_key: 'RTRadiationRecordSetStorage', uid_sym: :rt_radiation_record_set_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.481.17', uid_name: 'RT Radiation Salvage Record Storage', uid_key: 'RTRadiationSalvageRecordStorage', uid_sym: :rt_radiation_salvage_record_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.481.18', uid_name: 'Tomotherapeutic Radiation Record Storage', uid_key: 'TomotherapeuticRadiationRecordStorage', uid_sym: :tomotherapeutic_radiation_record_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.481.19', uid_name: 'C-Arm Photon-Electron Radiation Record Storage', uid_key: 'CArmPhotonElectronRadiationRecordStorage', uid_sym: :c_arm_photon_electron_radiation_record_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.481.20', uid_name: 'Robotic Radiation Record Storage', uid_key: 'RoboticRadiationRecordStorage', uid_sym: :robotic_radiation_record_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.481.21', uid_name: 'RT Radiation Set Delivery Instruction Storage', uid_key: 'RTRadiationSetDeliveryInstructionStorage', uid_sym: :rt_radiation_set_delivery_instruction_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.481.22', uid_name: 'RT Treatment Preparation Storage', uid_key: 'RTTreatmentPreparationStorage', uid_sym: :rt_treatment_preparation_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.481.23', uid_name: 'Enhanced RT Image Storage', uid_key: 'EnhancedRTImageStorage', uid_sym: :enhanced_rt_image_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.481.24', uid_name: 'Enhanced Continuous RT Image Storage', uid_key: 'EnhancedContinuousRTImageStorage', uid_sym: :enhanced_continuous_rt_image_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.481.25', uid_name: 'RT Patient Position Acquisition Instruction Storage', uid_key: 'RTPatientPositionAcquisitionInstructionStorage', uid_sym: :rt_patient_position_acquisition_instruction_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.501.1', uid_name: 'DICOS CT Image Storage', uid_key: 'DICOSCTImageStorage', uid_sym: :dicosct_image_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.501.2.1', uid_name: 'DICOS Digital X-Ray Image Storage - For Presentation', uid_key: 'DICOSDigitalXRayImageStorageForPresentation', uid_sym: :dicos_digital_x_ray_image_storage_for_presentation, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.501.2.2', uid_name: 'DICOS Digital X-Ray Image Storage - For Processing', uid_key: 'DICOSDigitalXRayImageStorageForProcessing', uid_sym: :dicos_digital_x_ray_image_storage_for_processing, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.501.3', uid_name: 'DICOS Threat Detection Report Storage', uid_key: 'DICOSThreatDetectionReportStorage', uid_sym: :dicos_threat_detection_report_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.501.4', uid_name: 'DICOS 2D AIT Storage', uid_key: 'DICOS2DAITStorage', uid_sym: :dicos2dait_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.501.5', uid_name: 'DICOS 3D AIT Storage', uid_key: 'DICOS3DAITStorage', uid_sym: :dicos_3dait_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.501.6', uid_name: 'DICOS Quadrupole Resonance (QR) Storage', uid_key: 'DICOSQuadrupoleResonanceStorage', uid_sym: :dicos_quadrupole_resonance_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.601.1', uid_name: 'Eddy Current Image Storage', uid_key: 'EddyCurrentImageStorage', uid_sym: :eddy_current_image_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.601.2', uid_name: 'Eddy Current Multi-frame Image Storage', uid_key: 'EddyCurrentMultiFrameImageStorage', uid_sym: :eddy_current_multi_frame_image_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.601.3', uid_name: 'Thermography Image Storage', uid_key: 'ThermographyImageStorage', uid_sym: :thermography_image_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.601.4', uid_name: 'Thermography Multi-frame Image Storage', uid_key: 'ThermographyMultiFrameImageStorage', uid_sym: :thermography_multi_frame_image_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.1.601.5', uid_name: 'Ultrasound Waveform Storage', uid_key: 'UltrasoundWaveformStorage', uid_sym: :ultrasound_waveform_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.2.1.1', uid_name: 'Patient Root Query/Retrieve Information Model - FIND', uid_key: 'PatientRootQueryRetrieveInformationModelFind', uid_sym: :patient_root_query_retrieve_information_model_find, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.2.1.2', uid_name: 'Patient Root Query/Retrieve Information Model - MOVE', uid_key: 'PatientRootQueryRetrieveInformationModelMove', uid_sym: :patient_root_query_retrieve_information_model_move, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.2.1.3', uid_name: 'Patient Root Query/Retrieve Information Model - GET', uid_key: 'PatientRootQueryRetrieveInformationModelGet', uid_sym: :patient_root_query_retrieve_information_model_get, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.2.2.1', uid_name: 'Study Root Query/Retrieve Information Model - FIND', uid_key: 'StudyRootQueryRetrieveInformationModelFind', uid_sym: :study_root_query_retrieve_information_model_find, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.2.2.2', uid_name: 'Study Root Query/Retrieve Information Model - MOVE', uid_key: 'StudyRootQueryRetrieveInformationModelMove', uid_sym: :study_root_query_retrieve_information_model_move, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.2.2.3', uid_name: 'Study Root Query/Retrieve Information Model - GET', uid_key: 'StudyRootQueryRetrieveInformationModelGet', uid_sym: :study_root_query_retrieve_information_model_get, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.2.3.1', uid_name: 'Patient/Study Only Query/Retrieve Information Model - FIND (Retired)', uid_key: 'PatientStudyOnlyQueryRetrieveInformationModelFind', uid_sym: :patient_study_only_query_retrieve_information_model_find, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.2.3.2', uid_name: 'Patient/Study Only Query/Retrieve Information Model - MOVE (Retired)', uid_key: 'PatientStudyOnlyQueryRetrieveInformationModelMove', uid_sym: :patient_study_only_query_retrieve_information_model_move, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.2.3.3', uid_name: 'Patient/Study Only Query/Retrieve Information Model - GET (Retired)', uid_key: 'PatientStudyOnlyQueryRetrieveInformationModelGet', uid_sym: :patient_study_only_query_retrieve_information_model_get, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.2.4.2', uid_name: 'Composite Instance Root Retrieve - MOVE', uid_key: 'CompositeInstanceRootRetrieveMove', uid_sym: :composite_instance_root_retrieve_move, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.2.4.3', uid_name: 'Composite Instance Root Retrieve - GET', uid_key: 'CompositeInstanceRootRetrieveGet', uid_sym: :composite_instance_root_retrieve_get, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.1.2.5.3', uid_name: 'Composite Instance Retrieve Without Bulk Data - GET', uid_key: 'CompositeInstanceRetrieveWithoutBulkDataGet', uid_sym: :composite_instance_retrieve_without_bulk_data_get, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.20.1', uid_name: 'Defined Procedure Protocol Information Model - FIND', uid_key: 'DefinedProcedureProtocolInformationModelFind', uid_sym: :defined_procedure_protocol_information_model_find, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.20.2', uid_name: 'Defined Procedure Protocol Information Model - MOVE', uid_key: 'DefinedProcedureProtocolInformationModelMove', uid_sym: :defined_procedure_protocol_information_model_move, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.20.3', uid_name: 'Defined Procedure Protocol Information Model - GET', uid_key: 'DefinedProcedureProtocolInformationModelGet', uid_sym: :defined_procedure_protocol_information_model_get, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.31', uid_name: 'Modality Worklist Information Model - FIND', uid_key: 'ModalityWorklistInformationModelFind', uid_sym: :modality_worklist_information_model_find, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.32', uid_name: 'General Purpose Worklist Management Meta SOP Class (Retired)', uid_key: 'GeneralPurposeWorklistManagementMeta', uid_sym: :general_purpose_worklist_management_meta, uid_type: :meta_sop_class},
      { uid_value: '1.2.840.10008.5.1.4.32.1', uid_name: 'General Purpose Worklist Information Model - FIND (Retired)', uid_key: 'GeneralPurposeWorklistInformationModelFind', uid_sym: :general_purpose_worklist_information_model_find, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.32.2', uid_name: 'General Purpose Scheduled Procedure Step SOP Class (Retired)', uid_key: 'GeneralPurposeScheduledProcedureStep', uid_sym: :general_purpose_scheduled_procedure_step, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.32.3', uid_name: 'General Purpose Performed Procedure Step SOP Class (Retired)', uid_key: 'GeneralPurposePerformedProcedureStep', uid_sym: :general_purpose_performed_procedure_step, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.33', uid_name: 'Instance Availability Notification SOP Class', uid_key: 'InstanceAvailabilityNotification', uid_sym: :instance_availability_notification, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.34.1', uid_name: 'RT Beams Delivery Instruction Storage - Trial (Retired)', uid_key: 'RTBeamsDeliveryInstructionStorageTrial', uid_sym: :rt_beams_delivery_instruction_storage_trial, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.34.2', uid_name: 'RT Conventional Machine Verification - Trial (Retired)', uid_key: 'RTConventionalMachineVerificationTrial', uid_sym: :rt_conventional_machine_verification_trial, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.34.3', uid_name: 'RT Ion Machine Verification - Trial (Retired)', uid_key: 'RTIonMachineVerificationTrial', uid_sym: :rt_ion_machine_verification_trial, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.34.4', uid_name: 'Unified Worklist and Procedure Step Service Class - Trial (Retired)', uid_key: 'UnifiedWorklistAndProcedureStepTrial', uid_sym: :unified_worklist_and_procedure_step_trial, uid_type: :service_class},
      { uid_value: '1.2.840.10008.5.1.4.34.4.1', uid_name: 'Unified Procedure Step - Push SOP Class - Trial (Retired)', uid_key: 'UnifiedProcedureStepPushTrial', uid_sym: :unified_procedure_step_push_trial, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.34.4.2', uid_name: 'Unified Procedure Step - Watch SOP Class - Trial (Retired)', uid_key: 'UnifiedProcedureStepWatchTrial', uid_sym: :unified_procedure_step_watch_trial, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.34.4.3', uid_name: 'Unified Procedure Step - Pull SOP Class - Trial (Retired)', uid_key: 'UnifiedProcedureStepPullTrial', uid_sym: :unified_procedure_step_pull_trial, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.34.4.4', uid_name: 'Unified Procedure Step - Event SOP Class - Trial (Retired)', uid_key: 'UnifiedProcedureStepEventTrial', uid_sym: :unified_procedure_step_event_trial, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.34.5', uid_name: 'UPS Global Subscription SOP Instance', uid_key: 'UPSGlobalSubscriptionInstance', uid_sym: :ups_global_subscription_instance, uid_type: :well_known_sop_instance},
      { uid_value: '1.2.840.10008.5.1.4.34.5.1', uid_name: 'UPS Filtered Global Subscription SOP Instance', uid_key: 'UPSFilteredGlobalSubscriptionInstance', uid_sym: :ups_filtered_global_subscription_instance, uid_type: :well_known_sop_instance},
      { uid_value: '1.2.840.10008.5.1.4.34.6', uid_name: 'Unified Worklist and Procedure Step Service Class', uid_key: 'UnifiedWorklistAndProcedureStep', uid_sym: :unified_worklist_and_procedure_step, uid_type: :service_class},
      { uid_value: '1.2.840.10008.5.1.4.34.6.1', uid_name: 'Unified Procedure Step - Push SOP Class', uid_key: 'UnifiedProcedureStepPush', uid_sym: :unified_procedure_step_push, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.34.6.2', uid_name: 'Unified Procedure Step - Watch SOP Class', uid_key: 'UnifiedProcedureStepWatch', uid_sym: :unified_procedure_step_watch, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.34.6.3', uid_name: 'Unified Procedure Step - Pull SOP Class', uid_key: 'UnifiedProcedureStepPull', uid_sym: :unified_procedure_step_pull, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.34.6.4', uid_name: 'Unified Procedure Step - Event SOP Class', uid_key: 'UnifiedProcedureStepEvent', uid_sym: :unified_procedure_step_event, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.34.6.5', uid_name: 'Unified Procedure Step - Query SOP Class', uid_key: 'UnifiedProcedureStepQuery', uid_sym: :unified_procedure_step_query, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.34.7', uid_name: 'RT Beams Delivery Instruction Storage', uid_key: 'RTBeamsDeliveryInstructionStorage', uid_sym: :rt_beams_delivery_instruction_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.34.8', uid_name: 'RT Conventional Machine Verification', uid_key: 'RTConventionalMachineVerification', uid_sym: :rt_conventional_machine_verification, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.34.9', uid_name: 'RT Ion Machine Verification', uid_key: 'RTIonMachineVerification', uid_sym: :rt_ion_machine_verification, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.34.10', uid_name: 'RT Brachy Application Setup Delivery Instruction Storage', uid_key: 'RTBrachyApplicationSetupDeliveryInstructionStorage', uid_sym: :rt_brachy_application_setup_delivery_instruction_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.37.1', uid_name: 'General Relevant Patient Information Query', uid_key: 'GeneralRelevantPatientInformationQuery', uid_sym: :general_relevant_patient_information_query, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.37.2', uid_name: 'Breast Imaging Relevant Patient Information Query', uid_key: 'BreastImagingRelevantPatientInformationQuery', uid_sym: :breast_imaging_relevant_patient_information_query, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.37.3', uid_name: 'Cardiac Relevant Patient Information Query', uid_key: 'CardiacRelevantPatientInformationQuery', uid_sym: :cardiac_relevant_patient_information_query, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.38.1', uid_name: 'Hanging Protocol Storage', uid_key: 'HangingProtocolStorage', uid_sym: :hanging_protocol_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.38.2', uid_name: 'Hanging Protocol Information Model - FIND', uid_key: 'HangingProtocolInformationModelFind', uid_sym: :hanging_protocol_information_model_find, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.38.3', uid_name: 'Hanging Protocol Information Model - MOVE', uid_key: 'HangingProtocolInformationModelMove', uid_sym: :hanging_protocol_information_model_move, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.38.4', uid_name: 'Hanging Protocol Information Model - GET', uid_key: 'HangingProtocolInformationModelGet', uid_sym: :hanging_protocol_information_model_get, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.39.1', uid_name: 'Color Palette Storage', uid_key: 'ColorPaletteStorage', uid_sym: :color_palette_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.39.2', uid_name: 'Color Palette Query/Retrieve Information Model - FIND', uid_key: 'ColorPaletteQueryRetrieveInformationModelFind', uid_sym: :color_palette_query_retrieve_information_model_find, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.39.3', uid_name: 'Color Palette Query/Retrieve Information Model - MOVE', uid_key: 'ColorPaletteQueryRetrieveInformationModelMove', uid_sym: :color_palette_query_retrieve_information_model_move, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.39.4', uid_name: 'Color Palette Query/Retrieve Information Model - GET', uid_key: 'ColorPaletteQueryRetrieveInformationModelGet', uid_sym: :color_palette_query_retrieve_information_model_get, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.41', uid_name: 'Product Characteristics Query SOP Class', uid_key: 'ProductCharacteristicsQuery', uid_sym: :product_characteristics_query, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.42', uid_name: 'Substance Approval Query SOP Class', uid_key: 'SubstanceApprovalQuery', uid_sym: :substance_approval_query, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.43.1', uid_name: 'Generic Implant Template Storage', uid_key: 'GenericImplantTemplateStorage', uid_sym: :generic_implant_template_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.43.2', uid_name: 'Generic Implant Template Information Model - FIND', uid_key: 'GenericImplantTemplateInformationModelFind', uid_sym: :generic_implant_template_information_model_find, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.43.3', uid_name: 'Generic Implant Template Information Model - MOVE', uid_key: 'GenericImplantTemplateInformationModelMove', uid_sym: :generic_implant_template_information_model_move, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.43.4', uid_name: 'Generic Implant Template Information Model - GET', uid_key: 'GenericImplantTemplateInformationModelGet', uid_sym: :generic_implant_template_information_model_get, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.44.1', uid_name: 'Implant Assembly Template Storage', uid_key: 'ImplantAssemblyTemplateStorage', uid_sym: :implant_assembly_template_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.44.2', uid_name: 'Implant Assembly Template Information Model - FIND', uid_key: 'ImplantAssemblyTemplateInformationModelFind', uid_sym: :implant_assembly_template_information_model_find, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.44.3', uid_name: 'Implant Assembly Template Information Model - MOVE', uid_key: 'ImplantAssemblyTemplateInformationModelMove', uid_sym: :implant_assembly_template_information_model_move, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.44.4', uid_name: 'Implant Assembly Template Information Model - GET', uid_key: 'ImplantAssemblyTemplateInformationModelGet', uid_sym: :implant_assembly_template_information_model_get, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.45.1', uid_name: 'Implant Template Group Storage', uid_key: 'ImplantTemplateGroupStorage', uid_sym: :implant_template_group_storage, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.45.2', uid_name: 'Implant Template Group Information Model - FIND', uid_key: 'ImplantTemplateGroupInformationModelFind', uid_sym: :implant_template_group_information_model_find, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.45.3', uid_name: 'Implant Template Group Information Model - MOVE', uid_key: 'ImplantTemplateGroupInformationModelMove', uid_sym: :implant_template_group_information_model_move, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.5.1.4.45.4', uid_name: 'Implant Template Group Information Model - GET', uid_key: 'ImplantTemplateGroupInformationModelGet', uid_sym: :implant_template_group_information_model_get, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.7.1.1', uid_name: 'Native DICOM Model', uid_key: 'NativeDICOMModel', uid_sym: :native_dicom_model, uid_type: :application_hosting_model},
      { uid_value: '1.2.840.10008.7.1.2', uid_name: 'Abstract Multi-Dimensional Image Model', uid_key: 'AbstractMultiDimensionalImageModel', uid_sym: :abstract_multi_dimensional_image_model, uid_type: :application_hosting_model},
      { uid_value: '1.2.840.10008.8.1.1', uid_name: 'DICOM Content Mapping Resource', uid_key: 'DICOMContentMappingResource', uid_sym: :dicom_content_mapping_resource, uid_type: :mapping_resource},
      { uid_value: '1.2.840.10008.10.1', uid_name: 'Video Endoscopic Image Real-Time Communication', uid_key: 'VideoEndoscopicImageRealTimeCommunication', uid_sym: :video_endoscopic_image_real_time_communication, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.10.2', uid_name: 'Video Photographic Image Real-Time Communication', uid_key: 'VideoPhotographicImageRealTimeCommunication', uid_sym: :video_photographic_image_real_time_communication, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.10.3', uid_name: 'Audio Waveform Real-Time Communication', uid_key: 'AudioWaveformRealTimeCommunication', uid_sym: :audio_waveform_real_time_communication, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.10.4', uid_name: 'Rendition Selection Document Real-Time Communication', uid_key: 'RenditionSelectionDocumentRealTimeCommunication', uid_sym: :rendition_selection_document_real_time_communication, uid_type: :sop_class},
      { uid_value: '1.2.840.10008.15.0.3.1', uid_name: 'dicomDeviceName', uid_key: 'dicomDeviceName', uid_sym: :dicom_device_name, uid_type: :ldap_oid},
      { uid_value: '1.2.840.10008.15.0.3.2', uid_name: 'dicomDescription', uid_key: 'dicomDescription', uid_sym: :dicom_description, uid_type: :ldap_oid},
      { uid_value: '1.2.840.10008.15.0.3.3', uid_name: 'dicomManufacturer', uid_key: 'dicomManufacturer', uid_sym: :dicom_manufacturer, uid_type: :ldap_oid},
      { uid_value: '1.2.840.10008.15.0.3.4', uid_name: 'dicomManufacturerModelName', uid_key: 'dicomManufacturerModelName', uid_sym: :dicom_manufacturer_model_name, uid_type: :ldap_oid},
      { uid_value: '1.2.840.10008.15.0.3.5', uid_name: 'dicomSoftwareVersion', uid_key: 'dicomSoftwareVersion', uid_sym: :dicom_software_version, uid_type: :ldap_oid},
      { uid_value: '1.2.840.10008.15.0.3.6', uid_name: 'dicomVendorData', uid_key: 'dicomVendorData', uid_sym: :dicom_vendor_data, uid_type: :ldap_oid},
      { uid_value: '1.2.840.10008.15.0.3.7', uid_name: 'dicomAETitle', uid_key: 'dicomAETitle', uid_sym: :dicom_ae_title, uid_type: :ldap_oid},
      { uid_value: '1.2.840.10008.15.0.3.8', uid_name: 'dicomNetworkConnectionReference', uid_key: 'dicomNetworkConnectionReference', uid_sym: :dicom_network_connection_reference, uid_type: :ldap_oid},
      { uid_value: '1.2.840.10008.15.0.3.9', uid_name: 'dicomApplicationCluster', uid_key: 'dicomApplicationCluster', uid_sym: :dicom_application_cluster, uid_type: :ldap_oid},
      { uid_value: '1.2.840.10008.15.0.3.10', uid_name: 'dicomAssociationInitiator', uid_key: 'dicomAssociationInitiator', uid_sym: :dicom_association_initiator, uid_type: :ldap_oid},
      { uid_value: '1.2.840.10008.15.0.3.11', uid_name: 'dicomAssociationAcceptor', uid_key: 'dicomAssociationAcceptor', uid_sym: :dicom_association_acceptor, uid_type: :ldap_oid},
      { uid_value: '1.2.840.10008.15.0.3.12', uid_name: 'dicomHostname', uid_key: 'dicomHostname', uid_sym: :dicom_hostname, uid_type: :ldap_oid},
      { uid_value: '1.2.840.10008.15.0.3.13', uid_name: 'dicomPort', uid_key: 'dicomPort', uid_sym: :dicom_port, uid_type: :ldap_oid},
      { uid_value: '1.2.840.10008.15.0.3.14', uid_name: 'dicomSOPClass', uid_key: 'dicomSOPClass', uid_sym: :dicom_sop_class, uid_type: :ldap_oid},
      { uid_value: '1.2.840.10008.15.0.3.15', uid_name: 'dicomTransferRole', uid_key: 'dicomTransferRole', uid_sym: :dicom_transfer_role, uid_type: :ldap_oid},
      { uid_value: '1.2.840.10008.15.0.3.16', uid_name: 'dicomTransferSyntax', uid_key: 'dicomTransferSyntax', uid_sym: :dicom_transfer_syntax, uid_type: :ldap_oid},
      { uid_value: '1.2.840.10008.15.0.3.17', uid_name: 'dicomPrimaryDeviceType', uid_key: 'dicomPrimaryDeviceType', uid_sym: :dicom_primary_device_type, uid_type: :ldap_oid},
      { uid_value: '1.2.840.10008.15.0.3.18', uid_name: 'dicomRelatedDeviceReference', uid_key: 'dicomRelatedDeviceReference', uid_sym: :dicom_related_device_reference, uid_type: :ldap_oid},
      { uid_value: '1.2.840.10008.15.0.3.19', uid_name: 'dicomPreferredCalledAETitle', uid_key: 'dicomPreferredCalledAETitle', uid_sym: :dicom_preferred_called_ae_title, uid_type: :ldap_oid},
      { uid_value: '1.2.840.10008.15.0.3.20', uid_name: 'dicomTLSCyphersuite', uid_key: 'dicomTLSCyphersuite', uid_sym: :dicom_tls_cyphersuite, uid_type: :ldap_oid},
      { uid_value: '1.2.840.10008.15.0.3.21', uid_name: 'dicomAuthorizedNodeCertificateReference', uid_key: 'dicomAuthorizedNodeCertificateReference', uid_sym: :dicom_authorized_node_certificate_reference, uid_type: :ldap_oid},
      { uid_value: '1.2.840.10008.15.0.3.22', uid_name: 'dicomThisNodeCertificateReference', uid_key: 'dicomThisNodeCertificateReference', uid_sym: :dicom_this_node_certificate_reference, uid_type: :ldap_oid},
      { uid_value: '1.2.840.10008.15.0.3.23', uid_name: 'dicomInstalled', uid_key: 'dicomInstalled', uid_sym: :dicom_installed, uid_type: :ldap_oid},
      { uid_value: '1.2.840.10008.15.0.3.24', uid_name: 'dicomStationName', uid_key: 'dicomStationName', uid_sym: :dicom_station_name, uid_type: :ldap_oid},
      { uid_value: '1.2.840.10008.15.0.3.25', uid_name: 'dicomDeviceSerialNumber', uid_key: 'dicomDeviceSerialNumber', uid_sym: :dicom_device_serial_number, uid_type: :ldap_oid},
      { uid_value: '1.2.840.10008.15.0.3.26', uid_name: 'dicomInstitutionName', uid_key: 'dicomInstitutionName', uid_sym: :dicom_institution_name, uid_type: :ldap_oid},
      { uid_value: '1.2.840.10008.15.0.3.27', uid_name: 'dicomInstitutionAddress', uid_key: 'dicomInstitutionAddress', uid_sym: :dicom_institution_address, uid_type: :ldap_oid},
      { uid_value: '1.2.840.10008.15.0.3.28', uid_name: 'dicomInstitutionDepartmentName', uid_key: 'dicomInstitutionDepartmentName', uid_sym: :dicom_institution_department_name, uid_type: :ldap_oid},
      { uid_value: '1.2.840.10008.15.0.3.29', uid_name: 'dicomIssuerOfPatientID', uid_key: 'dicomIssuerOfPatientID', uid_sym: :dicom_issuer_of_patient_id, uid_type: :ldap_oid},
      { uid_value: '1.2.840.10008.15.0.3.30', uid_name: 'dicomPreferredCallingAETitle', uid_key: 'dicomPreferredCallingAETitle', uid_sym: :dicom_preferred_calling_ae_title, uid_type: :ldap_oid},
      { uid_value: '1.2.840.10008.15.0.3.31', uid_name: 'dicomSupportedCharacterSet', uid_key: 'dicomSupportedCharacterSet', uid_sym: :dicom_supported_character_set, uid_type: :ldap_oid},
      { uid_value: '1.2.840.10008.15.0.4.1', uid_name: 'dicomConfigurationRoot', uid_key: 'dicomConfigurationRoot', uid_sym: :dicom_configuration_root, uid_type: :ldap_oid},
      { uid_value: '1.2.840.10008.15.0.4.2', uid_name: 'dicomDevicesRoot', uid_key: 'dicomDevicesRoot', uid_sym: :dicom_devices_root, uid_type: :ldap_oid},
      { uid_value: '1.2.840.10008.15.0.4.3', uid_name: 'dicomUniqueAETitlesRegistryRoot', uid_key: 'dicomUniqueAETitlesRegistryRoot', uid_sym: :dicom_unique_ae_titles_registry_root, uid_type: :ldap_oid},
      { uid_value: '1.2.840.10008.15.0.4.4', uid_name: 'dicomDevice', uid_key: 'dicomDevice', uid_sym: :dicom_device, uid_type: :ldap_oid},
      { uid_value: '1.2.840.10008.15.0.4.5', uid_name: 'dicomNetworkAE', uid_key: 'dicomNetworkAE', uid_sym: :dicom_network_ae, uid_type: :ldap_oid},
      { uid_value: '1.2.840.10008.15.0.4.6', uid_name: 'dicomNetworkConnection', uid_key: 'dicomNetworkConnection', uid_sym: :dicom_network_connection, uid_type: :ldap_oid},
      { uid_value: '1.2.840.10008.15.0.4.7', uid_name: 'dicomUniqueAETitle', uid_key: 'dicomUniqueAETitle', uid_sym: :dicom_unique_ae_title, uid_type: :ldap_oid},
      { uid_value: '1.2.840.10008.15.0.4.8', uid_name: 'dicomTransferCapability', uid_key: 'dicomTransferCapability', uid_sym: :dicom_transfer_capability, uid_type: :ldap_oid},
      { uid_value: '1.2.840.10008.15.1.1', uid_name: 'Universal Coordinated Time', uid_key: 'UTC', uid_sym: :utc, uid_type: :synchronization_frame_of_reference},
      { uid_value: '1.2.840.10008.1.4.1.1', uid_name: 'Talairach Brain Atlas Frame of Reference', uid_key: 'TalairachBrainAtlas', uid_sym: :talairach_brain_atlas, uid_type: :well_known_frame_of_reference},
      { uid_value: '1.2.840.10008.1.4.1.2', uid_name: 'SPM2 T1 Frame of Reference', uid_key: 'SPM2T1', uid_sym: :spm2t1, uid_type: :well_known_frame_of_reference},
      { uid_value: '1.2.840.10008.1.4.1.3', uid_name: 'SPM2 T2 Frame of Reference', uid_key: 'SPM2T2', uid_sym: :spm2t2, uid_type: :well_known_frame_of_reference},
      { uid_value: '1.2.840.10008.1.4.1.4', uid_name: 'SPM2 PD Frame of Reference', uid_key: 'SPM2PD', uid_sym: :spm2pd, uid_type: :well_known_frame_of_reference},
      { uid_value: '1.2.840.10008.1.4.1.5', uid_name: 'SPM2 EPI Frame of Reference', uid_key: 'SPM2EPI', uid_sym: :spm2epi, uid_type: :well_known_frame_of_reference},
      { uid_value: '1.2.840.10008.1.4.1.6', uid_name: 'SPM2 FIL T1 Frame of Reference', uid_key: 'SPM2FILT1', uid_sym: :spm2filt1, uid_type: :well_known_frame_of_reference},
      { uid_value: '1.2.840.10008.1.4.1.7', uid_name: 'SPM2 PET Frame of Reference', uid_key: 'SPM2PET', uid_sym: :spm2pet, uid_type: :well_known_frame_of_reference},
      { uid_value: '1.2.840.10008.1.4.1.8', uid_name: 'SPM2 TRANSM Frame of Reference', uid_key: 'SPM2TRANSM', uid_sym: :spm2transm, uid_type: :well_known_frame_of_reference},
      { uid_value: '1.2.840.10008.1.4.1.9', uid_name: 'SPM2 SPECT Frame of Reference', uid_key: 'SPM2SPECT', uid_sym: :spm2spect, uid_type: :well_known_frame_of_reference},
      { uid_value: '1.2.840.10008.1.4.1.10', uid_name: 'SPM2 GRAY Frame of Reference', uid_key: 'SPM2GRAY', uid_sym: :spm2gray, uid_type: :well_known_frame_of_reference},
      { uid_value: '1.2.840.10008.1.4.1.11', uid_name: 'SPM2 WHITE Frame of Reference', uid_key: 'SPM2WHITE', uid_sym: :spm2white, uid_type: :well_known_frame_of_reference},
      { uid_value: '1.2.840.10008.1.4.1.12', uid_name: 'SPM2 CSF Frame of Reference', uid_key: 'SPM2CSF', uid_sym: :spm2csf, uid_type: :well_known_frame_of_reference},
      { uid_value: '1.2.840.10008.1.4.1.13', uid_name: 'SPM2 BRAINMASK Frame of Reference', uid_key: 'SPM2BRAINMASK', uid_sym: :spm2brainmask, uid_type: :well_known_frame_of_reference},
      { uid_value: '1.2.840.10008.1.4.1.14', uid_name: 'SPM2 AVG305T1 Frame of Reference', uid_key: 'SPM2AVG305T1', uid_sym: :spm2avg305t1, uid_type: :well_known_frame_of_reference},
      { uid_value: '1.2.840.10008.1.4.1.15', uid_name: 'SPM2 AVG152T1 Frame of Reference', uid_key: 'SPM2AVG152T1', uid_sym: :spm2avg152t1, uid_type: :well_known_frame_of_reference},
      { uid_value: '1.2.840.10008.1.4.1.16', uid_name: 'SPM2 AVG152T2 Frame of Reference', uid_key: 'SPM2AVG152T2', uid_sym: :spm2avg152t2, uid_type: :well_known_frame_of_reference},
      { uid_value: '1.2.840.10008.1.4.1.17', uid_name: 'SPM2 AVG152PD Frame of Reference', uid_key: 'SPM2AVG152PD', uid_sym: :spm2avg152pd, uid_type: :well_known_frame_of_reference},
      { uid_value: '1.2.840.10008.1.4.1.18', uid_name: 'SPM2 SINGLESUBJT1 Frame of Reference', uid_key: 'SPM2SINGLESUBJT1', uid_sym: :spm2singlesubjt1, uid_type: :well_known_frame_of_reference},
      { uid_value: '1.2.840.10008.1.4.2.1', uid_name: 'ICBM 452 T1 Frame of Reference', uid_key: 'ICBM452T1', uid_sym: :icbm452t1, uid_type: :well_known_frame_of_reference},
      { uid_value: '1.2.840.10008.1.4.2.2', uid_name: 'ICBM Single Subject MRI Frame of Reference', uid_key: 'ICBMSingleSubjectMRI', uid_sym: :icbm_single_subject_mri, uid_type: :well_known_frame_of_reference},
      { uid_value: '1.2.840.10008.1.4.3.1', uid_name: 'IEC 61217 Fixed Coordinate System Frame of Reference', uid_key: 'IEC61217FixedCoordinateSystem', uid_sym: :iec61217_fixed_coordinate_system, uid_type: :well_known_frame_of_reference},
      { uid_value: '1.2.840.10008.1.4.3.2', uid_name: 'Standard Robotic-Arm Coordinate System Frame of Reference', uid_key: 'StandardRoboticArmCoordinateSystem', uid_sym: :standard_robotic_arm_coordinate_system, uid_type: :well_known_frame_of_reference},
      { uid_value: '1.2.840.10008.1.4.3.3', uid_name: 'IEC 61217 Table Top Coordinate System Frame of Reference', uid_key: 'IEC61217TableTopCoordinateSystem', uid_sym: :iec61217_table_top_coordinate_system, uid_type: :well_known_frame_of_reference},
      { uid_value: '1.2.840.10008.1.4.4.1', uid_name: 'SRI24 Frame of Reference', uid_key: 'SRI24', uid_sym: :sri24, uid_type: :well_known_frame_of_reference},
      { uid_value: '1.2.840.10008.1.4.5.1', uid_name: 'Colin27 Frame of Reference', uid_key: 'Colin27', uid_sym: :colin27, uid_type: :well_known_frame_of_reference},
      { uid_value: '1.2.840.10008.1.4.6.1', uid_name: 'LPBA40/AIR Frame of Reference', uid_key: 'LPBA40AIR', uid_sym: :lpba40air, uid_type: :well_known_frame_of_reference},
      { uid_value: '1.2.840.10008.1.4.6.2', uid_name: 'LPBA40/FLIRT Frame of Reference', uid_key: 'LPBA40FLIRT', uid_sym: :lpba40flirt, uid_type: :well_known_frame_of_reference},
      { uid_value: '1.2.840.10008.1.4.6.3', uid_name: 'LPBA40/SPM5 Frame of Reference', uid_key: 'LPBA40SPM5', uid_sym: :lpba40spm5, uid_type: :well_known_frame_of_reference},
    ]
  end
end
