# coding: utf-8
#
#  Copyright (C) 2014-2025  Enrico Rivarola
#
#  This file is part of DcmDict gem (dcm_dict).
#
#  DcmDict is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  DcmDict is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with DcmDict.  If not, see <http://www.gnu.org/licenses/>.
#
#  This software has neither been tested nor approved for clinical use
#  or for incorporation in a medical device.
#  It is the redistributor's or user's responsibility to comply with any
#  applicable local, state, national or international regulations.
#
module DcmDict
  module SourceData
    DataElementsData = [
      { tag_ps: '(0000,0000)', tag_name: "Command Group Length", tag_key: 'CommandGroupLength', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0000,0000)', tag_sym: :command_group_length, tag_ndm: '00000000', tag_ary: [0x0000,0x0000], tag_multiple: false, tag_note: 'The even number of bytes from the end of the value field to the beginning of the next group.'},
      { tag_ps: '(0000,0002)', tag_name: "Affected SOP Class UID", tag_key: 'AffectedSOPClassUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0000,0002)', tag_sym: :affected_sop_class_uid, tag_ndm: '00000002', tag_ary: [0x0000,0x0002], tag_multiple: false, tag_note: 'The affected SOP Class UID associated with the operation.'},
      { tag_ps: '(0000,0003)', tag_name: "Requested SOP Class UID", tag_key: 'RequestedSOPClassUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0000,0003)', tag_sym: :requested_sop_class_uid, tag_ndm: '00000003', tag_ary: [0x0000,0x0003], tag_multiple: false, tag_note: 'The requested SOP Class UID associated with the operation.'},
      { tag_ps: '(0000,0100)', tag_name: "Command Field", tag_key: 'CommandField', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0000,0100)', tag_sym: :command_field, tag_ndm: '00000100', tag_ary: [0x0000,0x0100], tag_multiple: false, tag_note: 'This field distinguishes the DIMSE operation conveyed by this Message. This field shall be set to one of the following values:
0001H C-STORE-RQ
8001H C-STORE-RSP
0010H C-GET-RQ
8010H C-GET-RSP
0020H C-FIND-RQ
8020H C-FIND-RSP
0021H C-MOVE-RQ
8021H C-MOVE-RSP
0030H C-ECHO-RQ
8030H C-ECHO-RSP
0100H N-EVENT-REPORT-RQ
8100H N-EVENT-REPORT-RSP
0110H N-GET-RQ
8110H N-GET-RSP
0120H N-SET-RQ
8120H N-SET-RSP
0130H N-ACTION-RQ
8130H N-ACTION-RSP
0140H N-CREATE-RQ
8140H N-CREATE-RSP
0150H N-DELETE-RQ
8150H N-DELETE-RSP
0FFFH C-CANCEL-RQ'},
      { tag_ps: '(0000,0110)', tag_name: "Message ID", tag_key: 'MessageID', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0000,0110)', tag_sym: :message_id, tag_ndm: '00000110', tag_ary: [0x0000,0x0110], tag_multiple: false, tag_note: 'Implementation-specific value that distinguishes this Message from other Messages.'},
      { tag_ps: '(0000,0120)', tag_name: "Message ID Being Responded To", tag_key: 'MessageIDBeingRespondedTo', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0000,0120)', tag_sym: :message_id_being_responded_to, tag_ndm: '00000120', tag_ary: [0x0000,0x0120], tag_multiple: false, tag_note: 'Shall be set to the value of the Message ID (0000,0110) field used in associated request Message.'},
      { tag_ps: '(0000,0600)', tag_name: "Move Destination", tag_key: 'MoveDestination', tag_vr: [:AE], tag_vm: ["1"], tag_str: '(0000,0600)', tag_sym: :move_destination, tag_ndm: '00000600', tag_ary: [0x0000,0x0600], tag_multiple: false, tag_note: 'Shall be set to the DICOM AE Title of the destination DICOM AE to which the C-STORE sub-operations are being performed.'},
      { tag_ps: '(0000,0700)', tag_name: "Priority", tag_key: 'Priority', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0000,0700)', tag_sym: :priority, tag_ndm: '00000700', tag_ary: [0x0000,0x0700], tag_multiple: false, tag_note: 'The priority shall be set to one of the following values:
LOW = 0002H
MEDIUM = 0000H
HIGH = 0001H'},
      { tag_ps: '(0000,0800)', tag_name: "Command Data Set Type", tag_key: 'CommandDataSetType', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0000,0800)', tag_sym: :command_data_set_type, tag_ndm: '00000800', tag_ary: [0x0000,0x0800], tag_multiple: false, tag_note: 'This field indicates if a Data Set is present in the Message. This field shall be set to the value of 0101H if no Data Set is present; any other value indicates a Data Set is included in the Message.'},
      { tag_ps: '(0000,0900)', tag_name: "Status", tag_key: 'Status', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0000,0900)', tag_sym: :status, tag_ndm: '00000900', tag_ary: [0x0000,0x0900], tag_multiple: false, tag_note: 'Confirmation status of the operation. See .'},
      { tag_ps: '(0000,0901)', tag_name: "Offending Element", tag_key: 'OffendingElement', tag_vr: [:AT], tag_vm: ["1-n"], tag_str: '(0000,0901)', tag_sym: :offending_element, tag_ndm: '00000901', tag_ary: [0x0000,0x0901], tag_multiple: false, tag_note: 'If status is Cxxx, then this field contains a list of the elements in which the error was detected.'},
      { tag_ps: '(0000,0902)', tag_name: "Error Comment", tag_key: 'ErrorComment', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0000,0902)', tag_sym: :error_comment, tag_ndm: '00000902', tag_ary: [0x0000,0x0902], tag_multiple: false, tag_note: 'This field contains an application-specific text description of the error detected.

Only characters from the Default Character Repertoire may be used.'},
      { tag_ps: '(0000,0903)', tag_name: "Error ID", tag_key: 'ErrorID', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0000,0903)', tag_sym: :error_id, tag_ndm: '00000903', tag_ary: [0x0000,0x0903], tag_multiple: false, tag_note: 'This field shall optionally contain an application-specific error code.'},
      { tag_ps: '(0000,1000)', tag_name: "Affected SOP Instance UID", tag_key: 'AffectedSOPInstanceUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0000,1000)', tag_sym: :affected_sop_instance_uid, tag_ndm: '00001000', tag_ary: [0x0000,0x1000], tag_multiple: false, tag_note: 'Contains the UID of the SOP Instance for which this operation occurred.'},
      { tag_ps: '(0000,1001)', tag_name: "Requested SOP Instance UID", tag_key: 'RequestedSOPInstanceUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0000,1001)', tag_sym: :requested_sop_instance_uid, tag_ndm: '00001001', tag_ary: [0x0000,0x1001], tag_multiple: false, tag_note: 'Contains the UID of the SOP Instance for which this operation occurred.'},
      { tag_ps: '(0000,1002)', tag_name: "Event Type ID", tag_key: 'EventTypeID', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0000,1002)', tag_sym: :event_type_id, tag_ndm: '00001002', tag_ary: [0x0000,0x1002], tag_multiple: false, tag_note: 'Values for this field are application-specific.'},
      { tag_ps: '(0000,1005)', tag_name: "Attribute Identifier List", tag_key: 'AttributeIdentifierList', tag_vr: [:AT], tag_vm: ["1-n"], tag_str: '(0000,1005)', tag_sym: :attribute_identifier_list, tag_ndm: '00001005', tag_ary: [0x0000,0x1005], tag_multiple: false, tag_note: 'This field contains an Attribute Tag for each of the n Attributes applicable.'},
      { tag_ps: '(0000,1008)', tag_name: "Action Type ID", tag_key: 'ActionTypeID', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0000,1008)', tag_sym: :action_type_id, tag_ndm: '00001008', tag_ary: [0x0000,0x1008], tag_multiple: false, tag_note: 'Values for this field are application-specific.'},
      { tag_ps: '(0000,1020)', tag_name: "Number of Remaining Sub-operations", tag_key: 'NumberOfRemainingSuboperations', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0000,1020)', tag_sym: :number_of_remaining_suboperations, tag_ndm: '00001020', tag_ary: [0x0000,0x1020], tag_multiple: false, tag_note: 'The number of remaining C-STORE sub-operations to be invoked for the operation.'},
      { tag_ps: '(0000,1021)', tag_name: "Number of Completed Sub-operations", tag_key: 'NumberOfCompletedSuboperations', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0000,1021)', tag_sym: :number_of_completed_suboperations, tag_ndm: '00001021', tag_ary: [0x0000,0x1021], tag_multiple: false, tag_note: 'The number of C-STORE sub-operations associated with this operation that have completed successfully.'},
      { tag_ps: '(0000,1022)', tag_name: "Number of Failed Sub-operations", tag_key: 'NumberOfFailedSuboperations', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0000,1022)', tag_sym: :number_of_failed_suboperations, tag_ndm: '00001022', tag_ary: [0x0000,0x1022], tag_multiple: false, tag_note: 'The number of C-STORE sub-operations associated with this operation that have failed.'},
      { tag_ps: '(0000,1023)', tag_name: "Number of Warning Sub-operations", tag_key: 'NumberOfWarningSuboperations', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0000,1023)', tag_sym: :number_of_warning_suboperations, tag_ndm: '00001023', tag_ary: [0x0000,0x1023], tag_multiple: false, tag_note: 'The number of C-STORE sub-operations associated with this operation that generated warning responses.'},
      { tag_ps: '(0000,1030)', tag_name: "Move Originator Application Entity Title", tag_key: 'MoveOriginatorApplicationEntityTitle', tag_vr: [:AE], tag_vm: ["1"], tag_str: '(0000,1030)', tag_sym: :move_originator_application_entity_title, tag_ndm: '00001030', tag_ary: [0x0000,0x1030], tag_multiple: false, tag_note: 'Contains the DICOM AE Title of the DICOM AE that invoked the C-MOVE operation from which this C-STORE sub-operation is being performed.'},
      { tag_ps: '(0000,1031)', tag_name: "Move Originator Message ID", tag_key: 'MoveOriginatorMessageID', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0000,1031)', tag_sym: :move_originator_message_id, tag_ndm: '00001031', tag_ary: [0x0000,0x1031], tag_multiple: false, tag_note: 'Contains the Message ID (0000,0110) of the C-MOVE-RQ Message from which this C-STORE sub-operation is being performed.'},
      { tag_ps: '(0000,0001)', tag_name: "Command Length to End", tag_key: 'CommandLengthToEnd', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0000,0001)', tag_sym: :command_length_to_end, tag_ndm: '00000001', tag_ary: [0x0000,0x0001], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(0000,0010)', tag_name: "Command Recognition Code", tag_key: 'CommandRecognitionCode', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0000,0010)', tag_sym: :command_recognition_code, tag_ndm: '00000010', tag_ary: [0x0000,0x0010], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(0000,0200)', tag_name: "Initiator", tag_key: 'Initiator', tag_vr: [:AE], tag_vm: ["1"], tag_str: '(0000,0200)', tag_sym: :initiator, tag_ndm: '00000200', tag_ary: [0x0000,0x0200], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(0000,0300)', tag_name: "Receiver", tag_key: 'Receiver', tag_vr: [:AE], tag_vm: ["1"], tag_str: '(0000,0300)', tag_sym: :receiver, tag_ndm: '00000300', tag_ary: [0x0000,0x0300], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(0000,0400)', tag_name: "Find Location", tag_key: 'FindLocation', tag_vr: [:AE], tag_vm: ["1"], tag_str: '(0000,0400)', tag_sym: :find_location, tag_ndm: '00000400', tag_ary: [0x0000,0x0400], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(0000,0850)', tag_name: "Number of Matches", tag_key: 'NumberOfMatches', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0000,0850)', tag_sym: :number_of_matches, tag_ndm: '00000850', tag_ary: [0x0000,0x0850], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(0000,0860)', tag_name: "Response Sequence Number", tag_key: 'ResponseSequenceNumber', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0000,0860)', tag_sym: :response_sequence_number, tag_ndm: '00000860', tag_ary: [0x0000,0x0860], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(0000,4000)', tag_name: "Dialog Receiver", tag_key: 'DialogReceiver', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(0000,4000)', tag_sym: :dialog_receiver, tag_ndm: '00004000', tag_ary: [0x0000,0x4000], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(0000,4010)', tag_name: "Terminal Type", tag_key: 'TerminalType', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(0000,4010)', tag_sym: :terminal_type, tag_ndm: '00004010', tag_ary: [0x0000,0x4010], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(0000,5010)', tag_name: "Message Set ID", tag_key: 'MessageSetID', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0000,5010)', tag_sym: :message_set_id, tag_ndm: '00005010', tag_ary: [0x0000,0x5010], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(0000,5020)', tag_name: "End Message ID", tag_key: 'EndMessageID', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0000,5020)', tag_sym: :end_message_id, tag_ndm: '00005020', tag_ary: [0x0000,0x5020], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(0000,5110)', tag_name: "Display Format", tag_key: 'DisplayFormat', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(0000,5110)', tag_sym: :display_format, tag_ndm: '00005110', tag_ary: [0x0000,0x5110], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(0000,5120)', tag_name: "Page Position ID", tag_key: 'PagePositionID', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(0000,5120)', tag_sym: :page_position_id, tag_ndm: '00005120', tag_ary: [0x0000,0x5120], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(0000,5130)', tag_name: "Text Format ID", tag_key: 'TextFormatID', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0000,5130)', tag_sym: :text_format_id, tag_ndm: '00005130', tag_ary: [0x0000,0x5130], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(0000,5140)', tag_name: "Normal/Reverse", tag_key: 'NormalReverse', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0000,5140)', tag_sym: :normal_reverse, tag_ndm: '00005140', tag_ary: [0x0000,0x5140], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(0000,5150)', tag_name: "Add Gray Scale", tag_key: 'AddGrayScale', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0000,5150)', tag_sym: :add_gray_scale, tag_ndm: '00005150', tag_ary: [0x0000,0x5150], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(0000,5160)', tag_name: "Borders", tag_key: 'Borders', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0000,5160)', tag_sym: :borders, tag_ndm: '00005160', tag_ary: [0x0000,0x5160], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(0000,5170)', tag_name: "Copies", tag_key: 'Copies', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0000,5170)', tag_sym: :copies, tag_ndm: '00005170', tag_ary: [0x0000,0x5170], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(0000,5180)', tag_name: "Command Magnification Type", tag_key: 'CommandMagnificationType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0000,5180)', tag_sym: :command_magnification_type, tag_ndm: '00005180', tag_ary: [0x0000,0x5180], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(0000,5190)', tag_name: "Erase", tag_key: 'Erase', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0000,5190)', tag_sym: :erase, tag_ndm: '00005190', tag_ary: [0x0000,0x5190], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(0000,51A0)', tag_name: "Print", tag_key: 'Print', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0000,51A0)', tag_sym: :print, tag_ndm: '000051A0', tag_ary: [0x0000,0x51A0], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(0000,51B0)', tag_name: "Overlays", tag_key: 'Overlays', tag_vr: [:US], tag_vm: ["1-n"], tag_str: '(0000,51B0)', tag_sym: :overlays, tag_ndm: '000051B0', tag_ary: [0x0000,0x51B0], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(0002,0000)', tag_name: "File Meta Information Group Length", tag_key: 'FileMetaInformationGroupLength', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0002,0000)', tag_sym: :file_meta_information_group_length, tag_ndm: '00020000', tag_ary: [0x0002,0x0000], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0002,0001)', tag_name: "File Meta Information Version", tag_key: 'FileMetaInformationVersion', tag_vr: [:OB], tag_vm: ["1"], tag_str: '(0002,0001)', tag_sym: :file_meta_information_version, tag_ndm: '00020001', tag_ary: [0x0002,0x0001], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0002,0002)', tag_name: "Media Storage SOP Class UID", tag_key: 'MediaStorageSOPClassUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0002,0002)', tag_sym: :media_storage_sop_class_uid, tag_ndm: '00020002', tag_ary: [0x0002,0x0002], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0002,0003)', tag_name: "Media Storage SOP Instance UID", tag_key: 'MediaStorageSOPInstanceUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0002,0003)', tag_sym: :media_storage_sop_instance_uid, tag_ndm: '00020003', tag_ary: [0x0002,0x0003], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0002,0010)', tag_name: "Transfer Syntax UID", tag_key: 'TransferSyntaxUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0002,0010)', tag_sym: :transfer_syntax_uid, tag_ndm: '00020010', tag_ary: [0x0002,0x0010], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0002,0012)', tag_name: "Implementation Class UID", tag_key: 'ImplementationClassUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0002,0012)', tag_sym: :implementation_class_uid, tag_ndm: '00020012', tag_ary: [0x0002,0x0012], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0002,0013)', tag_name: "Implementation Version Name", tag_key: 'ImplementationVersionName', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0002,0013)', tag_sym: :implementation_version_name, tag_ndm: '00020013', tag_ary: [0x0002,0x0013], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0002,0016)', tag_name: "Source Application Entity Title", tag_key: 'SourceApplicationEntityTitle', tag_vr: [:AE], tag_vm: ["1"], tag_str: '(0002,0016)', tag_sym: :source_application_entity_title, tag_ndm: '00020016', tag_ary: [0x0002,0x0016], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0002,0017)', tag_name: "Sending Application Entity Title", tag_key: 'SendingApplicationEntityTitle', tag_vr: [:AE], tag_vm: ["1"], tag_str: '(0002,0017)', tag_sym: :sending_application_entity_title, tag_ndm: '00020017', tag_ary: [0x0002,0x0017], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0002,0018)', tag_name: "Receiving Application Entity Title", tag_key: 'ReceivingApplicationEntityTitle', tag_vr: [:AE], tag_vm: ["1"], tag_str: '(0002,0018)', tag_sym: :receiving_application_entity_title, tag_ndm: '00020018', tag_ary: [0x0002,0x0018], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0002,0026)', tag_name: "Source Presentation Address", tag_key: 'SourcePresentationAddress', tag_vr: [:UR], tag_vm: ["1"], tag_str: '(0002,0026)', tag_sym: :source_presentation_address, tag_ndm: '00020026', tag_ary: [0x0002,0x0026], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0002,0027)', tag_name: "Sending Presentation Address", tag_key: 'SendingPresentationAddress', tag_vr: [:UR], tag_vm: ["1"], tag_str: '(0002,0027)', tag_sym: :sending_presentation_address, tag_ndm: '00020027', tag_ary: [0x0002,0x0027], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0002,0028)', tag_name: "Receiving Presentation Address", tag_key: 'ReceivingPresentationAddress', tag_vr: [:UR], tag_vm: ["1"], tag_str: '(0002,0028)', tag_sym: :receiving_presentation_address, tag_ndm: '00020028', tag_ary: [0x0002,0x0028], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0002,0031)', tag_name: "RTV Meta Information Version", tag_key: 'RTVMetaInformationVersion', tag_vr: [:OB], tag_vm: ["1"], tag_str: '(0002,0031)', tag_sym: :rtv_meta_information_version, tag_ndm: '00020031', tag_ary: [0x0002,0x0031], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0002,0032)', tag_name: "RTV Communication SOP Class UID", tag_key: 'RTVCommunicationSOPClassUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0002,0032)', tag_sym: :rtv_communication_sop_class_uid, tag_ndm: '00020032', tag_ary: [0x0002,0x0032], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0002,0033)', tag_name: "RTV Communication SOP Instance UID", tag_key: 'RTVCommunicationSOPInstanceUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0002,0033)', tag_sym: :rtv_communication_sop_instance_uid, tag_ndm: '00020033', tag_ary: [0x0002,0x0033], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0002,0035)', tag_name: "RTV Source Identifier", tag_key: 'RTVSourceIdentifier', tag_vr: [:OB], tag_vm: ["1"], tag_str: '(0002,0035)', tag_sym: :rtv_source_identifier, tag_ndm: '00020035', tag_ary: [0x0002,0x0035], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0002,0036)', tag_name: "RTV Flow Identifier", tag_key: 'RTVFlowIdentifier', tag_vr: [:OB], tag_vm: ["1"], tag_str: '(0002,0036)', tag_sym: :rtv_flow_identifier, tag_ndm: '00020036', tag_ary: [0x0002,0x0036], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0002,0037)', tag_name: "RTV Flow RTP Sampling Rate", tag_key: 'RTVFlowRTPSamplingRate', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0002,0037)', tag_sym: :rtv_flow_rtp_sampling_rate, tag_ndm: '00020037', tag_ary: [0x0002,0x0037], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0002,0038)', tag_name: "RTV Flow Actual Frame Duration", tag_key: 'RTVFlowActualFrameDuration', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0002,0038)', tag_sym: :rtv_flow_actual_frame_duration, tag_ndm: '00020038', tag_ary: [0x0002,0x0038], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0002,0100)', tag_name: "Private Information Creator UID", tag_key: 'PrivateInformationCreatorUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0002,0100)', tag_sym: :private_information_creator_uid, tag_ndm: '00020100', tag_ary: [0x0002,0x0100], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0002,0102)', tag_name: "Private Information", tag_key: 'PrivateInformation', tag_vr: [:OB], tag_vm: ["1"], tag_str: '(0002,0102)', tag_sym: :private_information, tag_ndm: '00020102', tag_ary: [0x0002,0x0102], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0004,1130)', tag_name: "File-set ID", tag_key: 'FileSetID', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0004,1130)', tag_sym: :file_set_id, tag_ndm: '00041130', tag_ary: [0x0004,0x1130], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0004,1141)', tag_name: "File-set Descriptor File ID", tag_key: 'FileSetDescriptorFileID', tag_vr: [:CS], tag_vm: ["1-8"], tag_str: '(0004,1141)', tag_sym: :file_set_descriptor_file_id, tag_ndm: '00041141', tag_ary: [0x0004,0x1141], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0004,1142)', tag_name: "Specific Character Set of File-set Descriptor File", tag_key: 'SpecificCharacterSetOfFileSetDescriptorFile', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0004,1142)', tag_sym: :specific_character_set_of_file_set_descriptor_file, tag_ndm: '00041142', tag_ary: [0x0004,0x1142], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0004,1200)', tag_name: "Offset of the First Directory Record of the Root Directory Entity", tag_key: 'OffsetOfTheFirstDirectoryRecordOfTheRootDirectoryEntity', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0004,1200)', tag_sym: :offset_of_the_first_directory_record_of_the_root_directory_entity, tag_ndm: '00041200', tag_ary: [0x0004,0x1200], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0004,1202)', tag_name: "Offset of the Last Directory Record of the Root Directory Entity", tag_key: 'OffsetOfTheLastDirectoryRecordOfTheRootDirectoryEntity', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0004,1202)', tag_sym: :offset_of_the_last_directory_record_of_the_root_directory_entity, tag_ndm: '00041202', tag_ary: [0x0004,0x1202], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0004,1212)', tag_name: "File-set Consistency Flag", tag_key: 'FileSetConsistencyFlag', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0004,1212)', tag_sym: :file_set_consistency_flag, tag_ndm: '00041212', tag_ary: [0x0004,0x1212], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0004,1220)', tag_name: "Directory Record Sequence", tag_key: 'DirectoryRecordSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0004,1220)', tag_sym: :directory_record_sequence, tag_ndm: '00041220', tag_ary: [0x0004,0x1220], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0004,1400)', tag_name: "Offset of the Next Directory Record", tag_key: 'OffsetOfTheNextDirectoryRecord', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0004,1400)', tag_sym: :offset_of_the_next_directory_record, tag_ndm: '00041400', tag_ary: [0x0004,0x1400], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0004,1410)', tag_name: "Record In-use Flag", tag_key: 'RecordInUseFlag', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0004,1410)', tag_sym: :record_in_use_flag, tag_ndm: '00041410', tag_ary: [0x0004,0x1410], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0004,1420)', tag_name: "Offset of Referenced Lower-Level Directory Entity", tag_key: 'OffsetOfReferencedLowerLevelDirectoryEntity', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0004,1420)', tag_sym: :offset_of_referenced_lower_level_directory_entity, tag_ndm: '00041420', tag_ary: [0x0004,0x1420], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0004,1430)', tag_name: "Directory Record Type", tag_key: 'DirectoryRecordType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0004,1430)', tag_sym: :directory_record_type, tag_ndm: '00041430', tag_ary: [0x0004,0x1430], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0004,1432)', tag_name: "Private Record UID", tag_key: 'PrivateRecordUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0004,1432)', tag_sym: :private_record_uid, tag_ndm: '00041432', tag_ary: [0x0004,0x1432], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0004,1500)', tag_name: "Referenced File ID", tag_key: 'ReferencedFileID', tag_vr: [:CS], tag_vm: ["1-8"], tag_str: '(0004,1500)', tag_sym: :referenced_file_id, tag_ndm: '00041500', tag_ary: [0x0004,0x1500], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0004,1504)', tag_name: "MRDR Directory Record Offset", tag_key: 'MRDRDirectoryRecordOffset', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0004,1504)', tag_sym: :mrdr_directory_record_offset, tag_ndm: '00041504', tag_ary: [0x0004,0x1504], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(0004,1510)', tag_name: "Referenced SOP Class UID in File", tag_key: 'ReferencedSOPClassUIDInFile', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0004,1510)', tag_sym: :referenced_sop_class_uid_in_file, tag_ndm: '00041510', tag_ary: [0x0004,0x1510], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0004,1511)', tag_name: "Referenced SOP Instance UID in File", tag_key: 'ReferencedSOPInstanceUIDInFile', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0004,1511)', tag_sym: :referenced_sop_instance_uid_in_file, tag_ndm: '00041511', tag_ary: [0x0004,0x1511], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0004,1512)', tag_name: "Referenced Transfer Syntax UID in File", tag_key: 'ReferencedTransferSyntaxUIDInFile', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0004,1512)', tag_sym: :referenced_transfer_syntax_uid_in_file, tag_ndm: '00041512', tag_ary: [0x0004,0x1512], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0004,151A)', tag_name: "Referenced Related General SOP Class UID in File", tag_key: 'ReferencedRelatedGeneralSOPClassUIDInFile', tag_vr: [:UI], tag_vm: ["1-n"], tag_str: '(0004,151A)', tag_sym: :referenced_related_general_sop_class_uid_in_file, tag_ndm: '0004151A', tag_ary: [0x0004,0x151A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0004,1600)', tag_name: "Number of References", tag_key: 'NumberOfReferences', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0004,1600)', tag_sym: :number_of_references, tag_ndm: '00041600', tag_ary: [0x0004,0x1600], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(0008,0001)', tag_name: "Length to End", tag_key: 'LengthToEnd', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0008,0001)', tag_sym: :length_to_end, tag_ndm: '00080001', tag_ary: [0x0008,0x0001], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(0008,0005)', tag_name: "Specific Character Set", tag_key: 'SpecificCharacterSet', tag_vr: [:CS], tag_vm: ["1-n"], tag_str: '(0008,0005)', tag_sym: :specific_character_set, tag_ndm: '00080005', tag_ary: [0x0008,0x0005], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0006)', tag_name: "Language Code Sequence", tag_key: 'LanguageCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,0006)', tag_sym: :language_code_sequence, tag_ndm: '00080006', tag_ary: [0x0008,0x0006], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0008)', tag_name: "Image Type", tag_key: 'ImageType', tag_vr: [:CS], tag_vm: ["2-n"], tag_str: '(0008,0008)', tag_sym: :image_type, tag_ndm: '00080008', tag_ary: [0x0008,0x0008], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0010)', tag_name: "Recognition Code", tag_key: 'RecognitionCode', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0008,0010)', tag_sym: :recognition_code, tag_ndm: '00080010', tag_ary: [0x0008,0x0010], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(0008,0012)', tag_name: "Instance Creation Date", tag_key: 'InstanceCreationDate', tag_vr: [:DA], tag_vm: ["1"], tag_str: '(0008,0012)', tag_sym: :instance_creation_date, tag_ndm: '00080012', tag_ary: [0x0008,0x0012], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0013)', tag_name: "Instance Creation Time", tag_key: 'InstanceCreationTime', tag_vr: [:TM], tag_vm: ["1"], tag_str: '(0008,0013)', tag_sym: :instance_creation_time, tag_ndm: '00080013', tag_ary: [0x0008,0x0013], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0014)', tag_name: "Instance Creator UID", tag_key: 'InstanceCreatorUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0008,0014)', tag_sym: :instance_creator_uid, tag_ndm: '00080014', tag_ary: [0x0008,0x0014], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0015)', tag_name: "Instance Coercion DateTime", tag_key: 'InstanceCoercionDateTime', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(0008,0015)', tag_sym: :instance_coercion_date_time, tag_ndm: '00080015', tag_ary: [0x0008,0x0015], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0016)', tag_name: "SOP Class UID", tag_key: 'SOPClassUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0008,0016)', tag_sym: :sop_class_uid, tag_ndm: '00080016', tag_ary: [0x0008,0x0016], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0017)', tag_name: "Acquisition UID", tag_key: 'AcquisitionUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0008,0017)', tag_sym: :acquisition_uid, tag_ndm: '00080017', tag_ary: [0x0008,0x0017], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0018)', tag_name: "SOP Instance UID", tag_key: 'SOPInstanceUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0008,0018)', tag_sym: :sop_instance_uid, tag_ndm: '00080018', tag_ary: [0x0008,0x0018], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0019)', tag_name: "Pyramid UID", tag_key: 'PyramidUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0008,0019)', tag_sym: :pyramid_uid, tag_ndm: '00080019', tag_ary: [0x0008,0x0019], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,001A)', tag_name: "Related General SOP Class UID", tag_key: 'RelatedGeneralSOPClassUID', tag_vr: [:UI], tag_vm: ["1-n"], tag_str: '(0008,001A)', tag_sym: :related_general_sop_class_uid, tag_ndm: '0008001A', tag_ary: [0x0008,0x001A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,001B)', tag_name: "Original Specialized SOP Class UID", tag_key: 'OriginalSpecializedSOPClassUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0008,001B)', tag_sym: :original_specialized_sop_class_uid, tag_ndm: '0008001B', tag_ary: [0x0008,0x001B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,001C)', tag_name: "Synthetic Data", tag_key: 'SyntheticData', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0008,001C)', tag_sym: :synthetic_data, tag_ndm: '0008001C', tag_ary: [0x0008,0x001C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0020)', tag_name: "Study Date", tag_key: 'StudyDate', tag_vr: [:DA], tag_vm: ["1"], tag_str: '(0008,0020)', tag_sym: :study_date, tag_ndm: '00080020', tag_ary: [0x0008,0x0020], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0021)', tag_name: "Series Date", tag_key: 'SeriesDate', tag_vr: [:DA], tag_vm: ["1"], tag_str: '(0008,0021)', tag_sym: :series_date, tag_ndm: '00080021', tag_ary: [0x0008,0x0021], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0022)', tag_name: "Acquisition Date", tag_key: 'AcquisitionDate', tag_vr: [:DA], tag_vm: ["1"], tag_str: '(0008,0022)', tag_sym: :acquisition_date, tag_ndm: '00080022', tag_ary: [0x0008,0x0022], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0023)', tag_name: "Content Date", tag_key: 'ContentDate', tag_vr: [:DA], tag_vm: ["1"], tag_str: '(0008,0023)', tag_sym: :content_date, tag_ndm: '00080023', tag_ary: [0x0008,0x0023], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0024)', tag_name: "Overlay Date", tag_key: 'OverlayDate', tag_vr: [:DA], tag_vm: ["1"], tag_str: '(0008,0024)', tag_sym: :overlay_date, tag_ndm: '00080024', tag_ary: [0x0008,0x0024], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(0008,0025)', tag_name: "Curve Date", tag_key: 'CurveDate', tag_vr: [:DA], tag_vm: ["1"], tag_str: '(0008,0025)', tag_sym: :curve_date, tag_ndm: '00080025', tag_ary: [0x0008,0x0025], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(0008,002A)', tag_name: "Acquisition DateTime", tag_key: 'AcquisitionDateTime', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(0008,002A)', tag_sym: :acquisition_date_time, tag_ndm: '0008002A', tag_ary: [0x0008,0x002A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0030)', tag_name: "Study Time", tag_key: 'StudyTime', tag_vr: [:TM], tag_vm: ["1"], tag_str: '(0008,0030)', tag_sym: :study_time, tag_ndm: '00080030', tag_ary: [0x0008,0x0030], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0031)', tag_name: "Series Time", tag_key: 'SeriesTime', tag_vr: [:TM], tag_vm: ["1"], tag_str: '(0008,0031)', tag_sym: :series_time, tag_ndm: '00080031', tag_ary: [0x0008,0x0031], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0032)', tag_name: "Acquisition Time", tag_key: 'AcquisitionTime', tag_vr: [:TM], tag_vm: ["1"], tag_str: '(0008,0032)', tag_sym: :acquisition_time, tag_ndm: '00080032', tag_ary: [0x0008,0x0032], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0033)', tag_name: "Content Time", tag_key: 'ContentTime', tag_vr: [:TM], tag_vm: ["1"], tag_str: '(0008,0033)', tag_sym: :content_time, tag_ndm: '00080033', tag_ary: [0x0008,0x0033], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0034)', tag_name: "Overlay Time", tag_key: 'OverlayTime', tag_vr: [:TM], tag_vm: ["1"], tag_str: '(0008,0034)', tag_sym: :overlay_time, tag_ndm: '00080034', tag_ary: [0x0008,0x0034], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(0008,0035)', tag_name: "Curve Time", tag_key: 'CurveTime', tag_vr: [:TM], tag_vm: ["1"], tag_str: '(0008,0035)', tag_sym: :curve_time, tag_ndm: '00080035', tag_ary: [0x0008,0x0035], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(0008,0040)', tag_name: "Data Set Type", tag_key: 'DataSetType', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0008,0040)', tag_sym: :data_set_type, tag_ndm: '00080040', tag_ary: [0x0008,0x0040], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(0008,0041)', tag_name: "Data Set Subtype", tag_key: 'DataSetSubtype', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0008,0041)', tag_sym: :data_set_subtype, tag_ndm: '00080041', tag_ary: [0x0008,0x0041], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(0008,0042)', tag_name: "Nuclear Medicine Series Type", tag_key: 'NuclearMedicineSeriesType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0008,0042)', tag_sym: :nuclear_medicine_series_type, tag_ndm: '00080042', tag_ary: [0x0008,0x0042], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(0008,0050)', tag_name: "Accession Number", tag_key: 'AccessionNumber', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0008,0050)', tag_sym: :accession_number, tag_ndm: '00080050', tag_ary: [0x0008,0x0050], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0051)', tag_name: "Issuer of Accession Number Sequence", tag_key: 'IssuerOfAccessionNumberSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,0051)', tag_sym: :issuer_of_accession_number_sequence, tag_ndm: '00080051', tag_ary: [0x0008,0x0051], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0052)', tag_name: "Query/Retrieve Level", tag_key: 'QueryRetrieveLevel', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0008,0052)', tag_sym: :query_retrieve_level, tag_ndm: '00080052', tag_ary: [0x0008,0x0052], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0053)', tag_name: "Query/Retrieve View", tag_key: 'QueryRetrieveView', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0008,0053)', tag_sym: :query_retrieve_view, tag_ndm: '00080053', tag_ary: [0x0008,0x0053], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0054)', tag_name: "Retrieve AE Title", tag_key: 'RetrieveAETitle', tag_vr: [:AE], tag_vm: ["1-n"], tag_str: '(0008,0054)', tag_sym: :retrieve_ae_title, tag_ndm: '00080054', tag_ary: [0x0008,0x0054], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0055)', tag_name: "Station AE Title", tag_key: 'StationAETitle', tag_vr: [:AE], tag_vm: ["1"], tag_str: '(0008,0055)', tag_sym: :station_ae_title, tag_ndm: '00080055', tag_ary: [0x0008,0x0055], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0056)', tag_name: "Instance Availability", tag_key: 'InstanceAvailability', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0008,0056)', tag_sym: :instance_availability, tag_ndm: '00080056', tag_ary: [0x0008,0x0056], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0058)', tag_name: "Failed SOP Instance UID List", tag_key: 'FailedSOPInstanceUIDList', tag_vr: [:UI], tag_vm: ["1-n"], tag_str: '(0008,0058)', tag_sym: :failed_sop_instance_uid_list, tag_ndm: '00080058', tag_ary: [0x0008,0x0058], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0060)', tag_name: "Modality", tag_key: 'Modality', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0008,0060)', tag_sym: :modality, tag_ndm: '00080060', tag_ary: [0x0008,0x0060], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0061)', tag_name: "Modalities in Study", tag_key: 'ModalitiesInStudy', tag_vr: [:CS], tag_vm: ["1-n"], tag_str: '(0008,0061)', tag_sym: :modalities_in_study, tag_ndm: '00080061', tag_ary: [0x0008,0x0061], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0062)', tag_name: "SOP Classes in Study", tag_key: 'SOPClassesInStudy', tag_vr: [:UI], tag_vm: ["1-n"], tag_str: '(0008,0062)', tag_sym: :sop_classes_in_study, tag_ndm: '00080062', tag_ary: [0x0008,0x0062], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0063)', tag_name: "Anatomic Regions in Study Code Sequence", tag_key: 'AnatomicRegionsInStudyCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,0063)', tag_sym: :anatomic_regions_in_study_code_sequence, tag_ndm: '00080063', tag_ary: [0x0008,0x0063], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0064)', tag_name: "Conversion Type", tag_key: 'ConversionType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0008,0064)', tag_sym: :conversion_type, tag_ndm: '00080064', tag_ary: [0x0008,0x0064], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0068)', tag_name: "Presentation Intent Type", tag_key: 'PresentationIntentType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0008,0068)', tag_sym: :presentation_intent_type, tag_ndm: '00080068', tag_ary: [0x0008,0x0068], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0070)', tag_name: "Manufacturer", tag_key: 'Manufacturer', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0008,0070)', tag_sym: :manufacturer, tag_ndm: '00080070', tag_ary: [0x0008,0x0070], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0080)', tag_name: "Institution Name", tag_key: 'InstitutionName', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0008,0080)', tag_sym: :institution_name, tag_ndm: '00080080', tag_ary: [0x0008,0x0080], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0081)', tag_name: "Institution Address", tag_key: 'InstitutionAddress', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0008,0081)', tag_sym: :institution_address, tag_ndm: '00080081', tag_ary: [0x0008,0x0081], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0082)', tag_name: "Institution Code Sequence", tag_key: 'InstitutionCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,0082)', tag_sym: :institution_code_sequence, tag_ndm: '00080082', tag_ary: [0x0008,0x0082], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0090)', tag_name: "Referring Physician's Name", tag_key: 'ReferringPhysicianName', tag_vr: [:PN], tag_vm: ["1"], tag_str: '(0008,0090)', tag_sym: :referring_physician_name, tag_ndm: '00080090', tag_ary: [0x0008,0x0090], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0092)', tag_name: "Referring Physician's Address", tag_key: 'ReferringPhysicianAddress', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0008,0092)', tag_sym: :referring_physician_address, tag_ndm: '00080092', tag_ary: [0x0008,0x0092], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0094)', tag_name: "Referring Physician's Telephone Numbers", tag_key: 'ReferringPhysicianTelephoneNumbers', tag_vr: [:SH], tag_vm: ["1-n"], tag_str: '(0008,0094)', tag_sym: :referring_physician_telephone_numbers, tag_ndm: '00080094', tag_ary: [0x0008,0x0094], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0096)', tag_name: "Referring Physician Identification Sequence", tag_key: 'ReferringPhysicianIdentificationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,0096)', tag_sym: :referring_physician_identification_sequence, tag_ndm: '00080096', tag_ary: [0x0008,0x0096], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,009C)', tag_name: "Consulting Physician's Name", tag_key: 'ConsultingPhysicianName', tag_vr: [:PN], tag_vm: ["1-n"], tag_str: '(0008,009C)', tag_sym: :consulting_physician_name, tag_ndm: '0008009C', tag_ary: [0x0008,0x009C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,009D)', tag_name: "Consulting Physician Identification Sequence", tag_key: 'ConsultingPhysicianIdentificationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,009D)', tag_sym: :consulting_physician_identification_sequence, tag_ndm: '0008009D', tag_ary: [0x0008,0x009D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0100)', tag_name: "Code Value", tag_key: 'CodeValue', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0008,0100)', tag_sym: :code_value, tag_ndm: '00080100', tag_ary: [0x0008,0x0100], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0101)', tag_name: "Extended Code Value", tag_key: 'ExtendedCodeValue', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0008,0101)', tag_sym: :extended_code_value, tag_ndm: '00080101', tag_ary: [0x0008,0x0101], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(0008,0102)', tag_name: "Coding Scheme Designator", tag_key: 'CodingSchemeDesignator', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0008,0102)', tag_sym: :coding_scheme_designator, tag_ndm: '00080102', tag_ary: [0x0008,0x0102], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0103)', tag_name: "Coding Scheme Version", tag_key: 'CodingSchemeVersion', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0008,0103)', tag_sym: :coding_scheme_version, tag_ndm: '00080103', tag_ary: [0x0008,0x0103], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0104)', tag_name: "Code Meaning", tag_key: 'CodeMeaning', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0008,0104)', tag_sym: :code_meaning, tag_ndm: '00080104', tag_ary: [0x0008,0x0104], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0105)', tag_name: "Mapping Resource", tag_key: 'MappingResource', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0008,0105)', tag_sym: :mapping_resource, tag_ndm: '00080105', tag_ary: [0x0008,0x0105], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0106)', tag_name: "Context Group Version", tag_key: 'ContextGroupVersion', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(0008,0106)', tag_sym: :context_group_version, tag_ndm: '00080106', tag_ary: [0x0008,0x0106], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0107)', tag_name: "Context Group Local Version", tag_key: 'ContextGroupLocalVersion', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(0008,0107)', tag_sym: :context_group_local_version, tag_ndm: '00080107', tag_ary: [0x0008,0x0107], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0108)', tag_name: "Extended Code Meaning", tag_key: 'ExtendedCodeMeaning', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(0008,0108)', tag_sym: :extended_code_meaning, tag_ndm: '00080108', tag_ary: [0x0008,0x0108], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(0008,0109)', tag_name: "Coding Scheme Resources Sequence", tag_key: 'CodingSchemeResourcesSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,0109)', tag_sym: :coding_scheme_resources_sequence, tag_ndm: '00080109', tag_ary: [0x0008,0x0109], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,010A)', tag_name: "Coding Scheme URL Type", tag_key: 'CodingSchemeURLType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0008,010A)', tag_sym: :coding_scheme_url_type, tag_ndm: '0008010A', tag_ary: [0x0008,0x010A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,010B)', tag_name: "Context Group Extension Flag", tag_key: 'ContextGroupExtensionFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0008,010B)', tag_sym: :context_group_extension_flag, tag_ndm: '0008010B', tag_ary: [0x0008,0x010B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,010C)', tag_name: "Coding Scheme UID", tag_key: 'CodingSchemeUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0008,010C)', tag_sym: :coding_scheme_uid, tag_ndm: '0008010C', tag_ary: [0x0008,0x010C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,010D)', tag_name: "Context Group Extension Creator UID", tag_key: 'ContextGroupExtensionCreatorUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0008,010D)', tag_sym: :context_group_extension_creator_uid, tag_ndm: '0008010D', tag_ary: [0x0008,0x010D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,010E)', tag_name: "Coding Scheme URL", tag_key: 'CodingSchemeURL', tag_vr: [:UR], tag_vm: ["1"], tag_str: '(0008,010E)', tag_sym: :coding_scheme_url, tag_ndm: '0008010E', tag_ary: [0x0008,0x010E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,010F)', tag_name: "Context Identifier", tag_key: 'ContextIdentifier', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0008,010F)', tag_sym: :context_identifier, tag_ndm: '0008010F', tag_ary: [0x0008,0x010F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0110)', tag_name: "Coding Scheme Identification Sequence", tag_key: 'CodingSchemeIdentificationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,0110)', tag_sym: :coding_scheme_identification_sequence, tag_ndm: '00080110', tag_ary: [0x0008,0x0110], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0112)', tag_name: "Coding Scheme Registry", tag_key: 'CodingSchemeRegistry', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0008,0112)', tag_sym: :coding_scheme_registry, tag_ndm: '00080112', tag_ary: [0x0008,0x0112], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0114)', tag_name: "Coding Scheme External ID", tag_key: 'CodingSchemeExternalID', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0008,0114)', tag_sym: :coding_scheme_external_id, tag_ndm: '00080114', tag_ary: [0x0008,0x0114], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0115)', tag_name: "Coding Scheme Name", tag_key: 'CodingSchemeName', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0008,0115)', tag_sym: :coding_scheme_name, tag_ndm: '00080115', tag_ary: [0x0008,0x0115], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0116)', tag_name: "Coding Scheme Responsible Organization", tag_key: 'CodingSchemeResponsibleOrganization', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0008,0116)', tag_sym: :coding_scheme_responsible_organization, tag_ndm: '00080116', tag_ary: [0x0008,0x0116], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0117)', tag_name: "Context UID", tag_key: 'ContextUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0008,0117)', tag_sym: :context_uid, tag_ndm: '00080117', tag_ary: [0x0008,0x0117], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0118)', tag_name: "Mapping Resource UID", tag_key: 'MappingResourceUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0008,0118)', tag_sym: :mapping_resource_uid, tag_ndm: '00080118', tag_ary: [0x0008,0x0118], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0119)', tag_name: "Long Code Value", tag_key: 'LongCodeValue', tag_vr: [:UC], tag_vm: ["1"], tag_str: '(0008,0119)', tag_sym: :long_code_value, tag_ndm: '00080119', tag_ary: [0x0008,0x0119], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0120)', tag_name: "URN Code Value", tag_key: 'URNCodeValue', tag_vr: [:UR], tag_vm: ["1"], tag_str: '(0008,0120)', tag_sym: :urn_code_value, tag_ndm: '00080120', tag_ary: [0x0008,0x0120], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0121)', tag_name: "Equivalent Code Sequence", tag_key: 'EquivalentCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,0121)', tag_sym: :equivalent_code_sequence, tag_ndm: '00080121', tag_ary: [0x0008,0x0121], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0122)', tag_name: "Mapping Resource Name", tag_key: 'MappingResourceName', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0008,0122)', tag_sym: :mapping_resource_name, tag_ndm: '00080122', tag_ary: [0x0008,0x0122], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0123)', tag_name: "Context Group Identification Sequence", tag_key: 'ContextGroupIdentificationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,0123)', tag_sym: :context_group_identification_sequence, tag_ndm: '00080123', tag_ary: [0x0008,0x0123], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0124)', tag_name: "Mapping Resource Identification Sequence", tag_key: 'MappingResourceIdentificationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,0124)', tag_sym: :mapping_resource_identification_sequence, tag_ndm: '00080124', tag_ary: [0x0008,0x0124], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0201)', tag_name: "Timezone Offset From UTC", tag_key: 'TimezoneOffsetFromUTC', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0008,0201)', tag_sym: :timezone_offset_from_utc, tag_ndm: '00080201', tag_ary: [0x0008,0x0201], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0202)', tag_name: "Placeholder (0008,0202)", tag_key: 'Placeholder_0008_0202', tag_vr: [:UN], tag_vm: ["1"], tag_str: '(0008,0202)', tag_sym: :placeholder_0008_0202, tag_ndm: '00080202', tag_ary: [0x0008,0x0202], tag_multiple: false, tag_note: 'RET (2020c)'},
      { tag_ps: '(0008,0220)', tag_name: "Responsible Group Code Sequence", tag_key: 'ResponsibleGroupCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,0220)', tag_sym: :responsible_group_code_sequence, tag_ndm: '00080220', tag_ary: [0x0008,0x0220], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0221)', tag_name: "Equipment Modality", tag_key: 'EquipmentModality', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0008,0221)', tag_sym: :equipment_modality, tag_ndm: '00080221', tag_ary: [0x0008,0x0221], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0222)', tag_name: "Manufacturer's Related Model Group", tag_key: 'ManufacturerRelatedModelGroup', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0008,0222)', tag_sym: :manufacturer_related_model_group, tag_ndm: '00080222', tag_ary: [0x0008,0x0222], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0300)', tag_name: "Private Data Element Characteristics Sequence", tag_key: 'PrivateDataElementCharacteristicsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,0300)', tag_sym: :private_data_element_characteristics_sequence, tag_ndm: '00080300', tag_ary: [0x0008,0x0300], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0301)', tag_name: "Private Group Reference", tag_key: 'PrivateGroupReference', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0008,0301)', tag_sym: :private_group_reference, tag_ndm: '00080301', tag_ary: [0x0008,0x0301], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0302)', tag_name: "Private Creator Reference", tag_key: 'PrivateCreatorReference', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0008,0302)', tag_sym: :private_creator_reference, tag_ndm: '00080302', tag_ary: [0x0008,0x0302], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0303)', tag_name: "Block Identifying Information Status", tag_key: 'BlockIdentifyingInformationStatus', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0008,0303)', tag_sym: :block_identifying_information_status, tag_ndm: '00080303', tag_ary: [0x0008,0x0303], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0304)', tag_name: "Nonidentifying Private Elements", tag_key: 'NonidentifyingPrivateElements', tag_vr: [:US], tag_vm: ["1-n"], tag_str: '(0008,0304)', tag_sym: :nonidentifying_private_elements, tag_ndm: '00080304', tag_ary: [0x0008,0x0304], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0306)', tag_name: "Identifying Private Elements", tag_key: 'IdentifyingPrivateElements', tag_vr: [:US], tag_vm: ["1-n"], tag_str: '(0008,0306)', tag_sym: :identifying_private_elements, tag_ndm: '00080306', tag_ary: [0x0008,0x0306], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0305)', tag_name: "Deidentification Action Sequence", tag_key: 'DeidentificationActionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,0305)', tag_sym: :deidentification_action_sequence, tag_ndm: '00080305', tag_ary: [0x0008,0x0305], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0307)', tag_name: "Deidentification Action", tag_key: 'DeidentificationAction', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0008,0307)', tag_sym: :deidentification_action, tag_ndm: '00080307', tag_ary: [0x0008,0x0307], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0308)', tag_name: "Private Data Element", tag_key: 'PrivateDataElement', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0008,0308)', tag_sym: :private_data_element, tag_ndm: '00080308', tag_ary: [0x0008,0x0308], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0309)', tag_name: "Private Data Element Value Multiplicity", tag_key: 'PrivateDataElementValueMultiplicity', tag_vr: [:UL], tag_vm: ["1-3"], tag_str: '(0008,0309)', tag_sym: :private_data_element_value_multiplicity, tag_ndm: '00080309', tag_ary: [0x0008,0x0309], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,030A)', tag_name: "Private Data Element Value Representation", tag_key: 'PrivateDataElementValueRepresentation', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0008,030A)', tag_sym: :private_data_element_value_representation, tag_ndm: '0008030A', tag_ary: [0x0008,0x030A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,030B)', tag_name: "Private Data Element Number of Items", tag_key: 'PrivateDataElementNumberOfItems', tag_vr: [:UL], tag_vm: ["1-2"], tag_str: '(0008,030B)', tag_sym: :private_data_element_number_of_items, tag_ndm: '0008030B', tag_ary: [0x0008,0x030B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,030C)', tag_name: "Private Data Element Name", tag_key: 'PrivateDataElementName', tag_vr: [:UC], tag_vm: ["1"], tag_str: '(0008,030C)', tag_sym: :private_data_element_name, tag_ndm: '0008030C', tag_ary: [0x0008,0x030C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,030D)', tag_name: "Private Data Element Keyword", tag_key: 'PrivateDataElementKeyword', tag_vr: [:UC], tag_vm: ["1"], tag_str: '(0008,030D)', tag_sym: :private_data_element_keyword, tag_ndm: '0008030D', tag_ary: [0x0008,0x030D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,030E)', tag_name: "Private Data Element Description", tag_key: 'PrivateDataElementDescription', tag_vr: [:UT], tag_vm: ["1"], tag_str: '(0008,030E)', tag_sym: :private_data_element_description, tag_ndm: '0008030E', tag_ary: [0x0008,0x030E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,030F)', tag_name: "Private Data Element Encoding", tag_key: 'PrivateDataElementEncoding', tag_vr: [:UT], tag_vm: ["1"], tag_str: '(0008,030F)', tag_sym: :private_data_element_encoding, tag_ndm: '0008030F', tag_ary: [0x0008,0x030F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0310)', tag_name: "Private Data Element Definition Sequence", tag_key: 'PrivateDataElementDefinitionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,0310)', tag_sym: :private_data_element_definition_sequence, tag_ndm: '00080310', tag_ary: [0x0008,0x0310], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0400)', tag_name: "Scope of Inventory Sequence", tag_key: 'ScopeOfInventorySequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,0400)', tag_sym: :scope_of_inventory_sequence, tag_ndm: '00080400', tag_ary: [0x0008,0x0400], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0401)', tag_name: "Inventory Purpose", tag_key: 'InventoryPurpose', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(0008,0401)', tag_sym: :inventory_purpose, tag_ndm: '00080401', tag_ary: [0x0008,0x0401], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0402)', tag_name: "Inventory Instance Description", tag_key: 'InventoryInstanceDescription', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(0008,0402)', tag_sym: :inventory_instance_description, tag_ndm: '00080402', tag_ary: [0x0008,0x0402], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0403)', tag_name: "Inventory Level", tag_key: 'InventoryLevel', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0008,0403)', tag_sym: :inventory_level, tag_ndm: '00080403', tag_ary: [0x0008,0x0403], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0404)', tag_name: "Item Inventory DateTime", tag_key: 'ItemInventoryDateTime', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(0008,0404)', tag_sym: :item_inventory_date_time, tag_ndm: '00080404', tag_ary: [0x0008,0x0404], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0405)', tag_name: "Removed from Operational Use", tag_key: 'RemovedFromOperationalUse', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0008,0405)', tag_sym: :removed_from_operational_use, tag_ndm: '00080405', tag_ary: [0x0008,0x0405], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0406)', tag_name: "Reason for Removal Code Sequence", tag_key: 'ReasonForRemovalCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,0406)', tag_sym: :reason_for_removal_code_sequence, tag_ndm: '00080406', tag_ary: [0x0008,0x0406], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0407)', tag_name: "Stored Instance Base URI", tag_key: 'StoredInstanceBaseURI', tag_vr: [:UR], tag_vm: ["1"], tag_str: '(0008,0407)', tag_sym: :stored_instance_base_uri, tag_ndm: '00080407', tag_ary: [0x0008,0x0407], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0408)', tag_name: "Folder Access URI", tag_key: 'FolderAccessURI', tag_vr: [:UR], tag_vm: ["1"], tag_str: '(0008,0408)', tag_sym: :folder_access_uri, tag_ndm: '00080408', tag_ary: [0x0008,0x0408], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0409)', tag_name: "File Access URI", tag_key: 'FileAccessURI', tag_vr: [:UR], tag_vm: ["1"], tag_str: '(0008,0409)', tag_sym: :file_access_uri, tag_ndm: '00080409', tag_ary: [0x0008,0x0409], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,040A)', tag_name: "Container File Type", tag_key: 'ContainerFileType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0008,040A)', tag_sym: :container_file_type, tag_ndm: '0008040A', tag_ary: [0x0008,0x040A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,040B)', tag_name: "Filename in Container", tag_key: 'FilenameInContainer', tag_vr: [:UR], tag_vm: ["1"], tag_str: '(0008,040B)', tag_sym: :filename_in_container, tag_ndm: '0008040B', tag_ary: [0x0008,0x040B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,040C)', tag_name: "File Offset in Container", tag_key: 'FileOffsetInContainer', tag_vr: [:UV], tag_vm: ["1"], tag_str: '(0008,040C)', tag_sym: :file_offset_in_container, tag_ndm: '0008040C', tag_ary: [0x0008,0x040C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,040D)', tag_name: "File Length in Container", tag_key: 'FileLengthInContainer', tag_vr: [:UV], tag_vm: ["1"], tag_str: '(0008,040D)', tag_sym: :file_length_in_container, tag_ndm: '0008040D', tag_ary: [0x0008,0x040D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,040E)', tag_name: "Stored Instance Transfer Syntax UID", tag_key: 'StoredInstanceTransferSyntaxUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0008,040E)', tag_sym: :stored_instance_transfer_syntax_uid, tag_ndm: '0008040E', tag_ary: [0x0008,0x040E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,040F)', tag_name: "Extended Matching Mechanisms", tag_key: 'ExtendedMatchingMechanisms', tag_vr: [:CS], tag_vm: ["1-n"], tag_str: '(0008,040F)', tag_sym: :extended_matching_mechanisms, tag_ndm: '0008040F', tag_ary: [0x0008,0x040F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0410)', tag_name: "Range Matching Sequence", tag_key: 'RangeMatchingSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,0410)', tag_sym: :range_matching_sequence, tag_ndm: '00080410', tag_ary: [0x0008,0x0410], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0411)', tag_name: "List of UID Matching Sequence", tag_key: 'ListOfUIDMatchingSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,0411)', tag_sym: :list_of_uid_matching_sequence, tag_ndm: '00080411', tag_ary: [0x0008,0x0411], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0412)', tag_name: "Empty Value Matching Sequence", tag_key: 'EmptyValueMatchingSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,0412)', tag_sym: :empty_value_matching_sequence, tag_ndm: '00080412', tag_ary: [0x0008,0x0412], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0413)', tag_name: "General Matching Sequence", tag_key: 'GeneralMatchingSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,0413)', tag_sym: :general_matching_sequence, tag_ndm: '00080413', tag_ary: [0x0008,0x0413], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0414)', tag_name: "Requested Status Interval", tag_key: 'RequestedStatusInterval', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0008,0414)', tag_sym: :requested_status_interval, tag_ndm: '00080414', tag_ary: [0x0008,0x0414], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0415)', tag_name: "Retain Instances", tag_key: 'RetainInstances', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0008,0415)', tag_sym: :retain_instances, tag_ndm: '00080415', tag_ary: [0x0008,0x0415], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0416)', tag_name: "Expiration DateTime", tag_key: 'ExpirationDateTime', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(0008,0416)', tag_sym: :expiration_date_time, tag_ndm: '00080416', tag_ary: [0x0008,0x0416], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0417)', tag_name: "Transaction Status", tag_key: 'TransactionStatus', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0008,0417)', tag_sym: :transaction_status, tag_ndm: '00080417', tag_ary: [0x0008,0x0417], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0418)', tag_name: "Transaction Status Comment", tag_key: 'TransactionStatusComment', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(0008,0418)', tag_sym: :transaction_status_comment, tag_ndm: '00080418', tag_ary: [0x0008,0x0418], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0419)', tag_name: "File Set Access Sequence", tag_key: 'FileSetAccessSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,0419)', tag_sym: :file_set_access_sequence, tag_ndm: '00080419', tag_ary: [0x0008,0x0419], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,041A)', tag_name: "File Access Sequence", tag_key: 'FileAccessSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,041A)', tag_sym: :file_access_sequence, tag_ndm: '0008041A', tag_ary: [0x0008,0x041A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,041B)', tag_name: "Record Key", tag_key: 'RecordKey', tag_vr: [:OB], tag_vm: ["1"], tag_str: '(0008,041B)', tag_sym: :record_key, tag_ndm: '0008041B', tag_ary: [0x0008,0x041B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,041C)', tag_name: "Prior Record Key", tag_key: 'PriorRecordKey', tag_vr: [:OB], tag_vm: ["1"], tag_str: '(0008,041C)', tag_sym: :prior_record_key, tag_ndm: '0008041C', tag_ary: [0x0008,0x041C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,041D)', tag_name: "Metadata Sequence", tag_key: 'MetadataSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,041D)', tag_sym: :metadata_sequence, tag_ndm: '0008041D', tag_ary: [0x0008,0x041D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,041E)', tag_name: "Updated Metadata Sequence", tag_key: 'UpdatedMetadataSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,041E)', tag_sym: :updated_metadata_sequence, tag_ndm: '0008041E', tag_ary: [0x0008,0x041E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,041F)', tag_name: "Study Update DateTime", tag_key: 'StudyUpdateDateTime', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(0008,041F)', tag_sym: :study_update_date_time, tag_ndm: '0008041F', tag_ary: [0x0008,0x041F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0420)', tag_name: "Inventory Access End Points Sequence", tag_key: 'InventoryAccessEndPointsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,0420)', tag_sym: :inventory_access_end_points_sequence, tag_ndm: '00080420', tag_ary: [0x0008,0x0420], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0421)', tag_name: "Study Access End Points Sequence", tag_key: 'StudyAccessEndPointsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,0421)', tag_sym: :study_access_end_points_sequence, tag_ndm: '00080421', tag_ary: [0x0008,0x0421], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0422)', tag_name: "Incorporated Inventory Instance Sequence", tag_key: 'IncorporatedInventoryInstanceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,0422)', tag_sym: :incorporated_inventory_instance_sequence, tag_ndm: '00080422', tag_ary: [0x0008,0x0422], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0423)', tag_name: "Inventoried Studies Sequence", tag_key: 'InventoriedStudiesSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,0423)', tag_sym: :inventoried_studies_sequence, tag_ndm: '00080423', tag_ary: [0x0008,0x0423], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0424)', tag_name: "Inventoried Series Sequence", tag_key: 'InventoriedSeriesSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,0424)', tag_sym: :inventoried_series_sequence, tag_ndm: '00080424', tag_ary: [0x0008,0x0424], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0425)', tag_name: "Inventoried Instances Sequence", tag_key: 'InventoriedInstancesSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,0425)', tag_sym: :inventoried_instances_sequence, tag_ndm: '00080425', tag_ary: [0x0008,0x0425], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0426)', tag_name: "Inventory Completion Status", tag_key: 'InventoryCompletionStatus', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0008,0426)', tag_sym: :inventory_completion_status, tag_ndm: '00080426', tag_ary: [0x0008,0x0426], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0427)', tag_name: "Number of Study Records in Instance", tag_key: 'NumberOfStudyRecordsInInstance', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0008,0427)', tag_sym: :number_of_study_records_in_instance, tag_ndm: '00080427', tag_ary: [0x0008,0x0427], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0428)', tag_name: "Total Number of Study Records", tag_key: 'TotalNumberOfStudyRecords', tag_vr: [:UV], tag_vm: ["1"], tag_str: '(0008,0428)', tag_sym: :total_number_of_study_records, tag_ndm: '00080428', tag_ary: [0x0008,0x0428], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,0429)', tag_name: "Maximum Number of Records", tag_key: 'MaximumNumberOfRecords', tag_vr: [:UV], tag_vm: ["1"], tag_str: '(0008,0429)', tag_sym: :maximum_number_of_records, tag_ndm: '00080429', tag_ary: [0x0008,0x0429], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,1000)', tag_name: "Network ID", tag_key: 'NetworkID', tag_vr: [:AE], tag_vm: ["1"], tag_str: '(0008,1000)', tag_sym: :network_id, tag_ndm: '00081000', tag_ary: [0x0008,0x1000], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(0008,1010)', tag_name: "Station Name", tag_key: 'StationName', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0008,1010)', tag_sym: :station_name, tag_ndm: '00081010', tag_ary: [0x0008,0x1010], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,1030)', tag_name: "Study Description", tag_key: 'StudyDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0008,1030)', tag_sym: :study_description, tag_ndm: '00081030', tag_ary: [0x0008,0x1030], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,1032)', tag_name: "Procedure Code Sequence", tag_key: 'ProcedureCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,1032)', tag_sym: :procedure_code_sequence, tag_ndm: '00081032', tag_ary: [0x0008,0x1032], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,103E)', tag_name: "Series Description", tag_key: 'SeriesDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0008,103E)', tag_sym: :series_description, tag_ndm: '0008103E', tag_ary: [0x0008,0x103E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,103F)', tag_name: "Series Description Code Sequence", tag_key: 'SeriesDescriptionCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,103F)', tag_sym: :series_description_code_sequence, tag_ndm: '0008103F', tag_ary: [0x0008,0x103F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,1040)', tag_name: "Institutional Department Name", tag_key: 'InstitutionalDepartmentName', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0008,1040)', tag_sym: :institutional_department_name, tag_ndm: '00081040', tag_ary: [0x0008,0x1040], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,1041)', tag_name: "Institutional Department Type Code Sequence", tag_key: 'InstitutionalDepartmentTypeCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,1041)', tag_sym: :institutional_department_type_code_sequence, tag_ndm: '00081041', tag_ary: [0x0008,0x1041], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,1048)', tag_name: "Physician(s) of Record", tag_key: 'PhysiciansOfRecord', tag_vr: [:PN], tag_vm: ["1-n"], tag_str: '(0008,1048)', tag_sym: :physicians_of_record, tag_ndm: '00081048', tag_ary: [0x0008,0x1048], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,1049)', tag_name: "Physician(s) of Record Identification Sequence", tag_key: 'PhysiciansOfRecordIdentificationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,1049)', tag_sym: :physicians_of_record_identification_sequence, tag_ndm: '00081049', tag_ary: [0x0008,0x1049], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,1050)', tag_name: "Performing Physician's Name", tag_key: 'PerformingPhysicianName', tag_vr: [:PN], tag_vm: ["1-n"], tag_str: '(0008,1050)', tag_sym: :performing_physician_name, tag_ndm: '00081050', tag_ary: [0x0008,0x1050], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,1052)', tag_name: "Performing Physician Identification Sequence", tag_key: 'PerformingPhysicianIdentificationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,1052)', tag_sym: :performing_physician_identification_sequence, tag_ndm: '00081052', tag_ary: [0x0008,0x1052], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,1060)', tag_name: "Name of Physician(s) Reading Study", tag_key: 'NameOfPhysiciansReadingStudy', tag_vr: [:PN], tag_vm: ["1-n"], tag_str: '(0008,1060)', tag_sym: :name_of_physicians_reading_study, tag_ndm: '00081060', tag_ary: [0x0008,0x1060], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,1062)', tag_name: "Physician(s) Reading Study Identification Sequence", tag_key: 'PhysiciansReadingStudyIdentificationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,1062)', tag_sym: :physicians_reading_study_identification_sequence, tag_ndm: '00081062', tag_ary: [0x0008,0x1062], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,1070)', tag_name: "Operators' Name", tag_key: 'OperatorsName', tag_vr: [:PN], tag_vm: ["1-n"], tag_str: '(0008,1070)', tag_sym: :operators_name, tag_ndm: '00081070', tag_ary: [0x0008,0x1070], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,1072)', tag_name: "Operator Identification Sequence", tag_key: 'OperatorIdentificationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,1072)', tag_sym: :operator_identification_sequence, tag_ndm: '00081072', tag_ary: [0x0008,0x1072], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,1080)', tag_name: "Admitting Diagnoses Description", tag_key: 'AdmittingDiagnosesDescription', tag_vr: [:LO], tag_vm: ["1-n"], tag_str: '(0008,1080)', tag_sym: :admitting_diagnoses_description, tag_ndm: '00081080', tag_ary: [0x0008,0x1080], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,1084)', tag_name: "Admitting Diagnoses Code Sequence", tag_key: 'AdmittingDiagnosesCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,1084)', tag_sym: :admitting_diagnoses_code_sequence, tag_ndm: '00081084', tag_ary: [0x0008,0x1084], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,1088)', tag_name: "Pyramid Description", tag_key: 'PyramidDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0008,1088)', tag_sym: :pyramid_description, tag_ndm: '00081088', tag_ary: [0x0008,0x1088], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,1090)', tag_name: "Manufacturer's Model Name", tag_key: 'ManufacturerModelName', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0008,1090)', tag_sym: :manufacturer_model_name, tag_ndm: '00081090', tag_ary: [0x0008,0x1090], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,1100)', tag_name: "Referenced Results Sequence", tag_key: 'ReferencedResultsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,1100)', tag_sym: :referenced_results_sequence, tag_ndm: '00081100', tag_ary: [0x0008,0x1100], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(0008,1110)', tag_name: "Referenced Study Sequence", tag_key: 'ReferencedStudySequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,1110)', tag_sym: :referenced_study_sequence, tag_ndm: '00081110', tag_ary: [0x0008,0x1110], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,1111)', tag_name: "Referenced Performed Procedure Step Sequence", tag_key: 'ReferencedPerformedProcedureStepSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,1111)', tag_sym: :referenced_performed_procedure_step_sequence, tag_ndm: '00081111', tag_ary: [0x0008,0x1111], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,1112)', tag_name: "Referenced Instances by SOP Class Sequence", tag_key: 'ReferencedInstancesBySOPClassSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,1112)', tag_sym: :referenced_instances_by_sop_class_sequence, tag_ndm: '00081112', tag_ary: [0x0008,0x1112], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,1115)', tag_name: "Referenced Series Sequence", tag_key: 'ReferencedSeriesSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,1115)', tag_sym: :referenced_series_sequence, tag_ndm: '00081115', tag_ary: [0x0008,0x1115], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,1120)', tag_name: "Referenced Patient Sequence", tag_key: 'ReferencedPatientSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,1120)', tag_sym: :referenced_patient_sequence, tag_ndm: '00081120', tag_ary: [0x0008,0x1120], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,1125)', tag_name: "Referenced Visit Sequence", tag_key: 'ReferencedVisitSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,1125)', tag_sym: :referenced_visit_sequence, tag_ndm: '00081125', tag_ary: [0x0008,0x1125], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,1130)', tag_name: "Referenced Overlay Sequence", tag_key: 'ReferencedOverlaySequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,1130)', tag_sym: :referenced_overlay_sequence, tag_ndm: '00081130', tag_ary: [0x0008,0x1130], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(0008,1134)', tag_name: "Referenced Stereometric Instance Sequence", tag_key: 'ReferencedStereometricInstanceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,1134)', tag_sym: :referenced_stereometric_instance_sequence, tag_ndm: '00081134', tag_ary: [0x0008,0x1134], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,113A)', tag_name: "Referenced Waveform Sequence", tag_key: 'ReferencedWaveformSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,113A)', tag_sym: :referenced_waveform_sequence, tag_ndm: '0008113A', tag_ary: [0x0008,0x113A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,1140)', tag_name: "Referenced Image Sequence", tag_key: 'ReferencedImageSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,1140)', tag_sym: :referenced_image_sequence, tag_ndm: '00081140', tag_ary: [0x0008,0x1140], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,1145)', tag_name: "Referenced Curve Sequence", tag_key: 'ReferencedCurveSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,1145)', tag_sym: :referenced_curve_sequence, tag_ndm: '00081145', tag_ary: [0x0008,0x1145], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(0008,114A)', tag_name: "Referenced Instance Sequence", tag_key: 'ReferencedInstanceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,114A)', tag_sym: :referenced_instance_sequence, tag_ndm: '0008114A', tag_ary: [0x0008,0x114A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,114B)', tag_name: "Referenced Real World Value Mapping Instance Sequence", tag_key: 'ReferencedRealWorldValueMappingInstanceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,114B)', tag_sym: :referenced_real_world_value_mapping_instance_sequence, tag_ndm: '0008114B', tag_ary: [0x0008,0x114B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,114C)', tag_name: "Referenced Segmentation Sequence", tag_key: 'ReferencedSegmentationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,114C)', tag_sym: :referenced_segmentation_sequence, tag_ndm: '0008114C', tag_ary: [0x0008,0x114C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,114D)', tag_name: "Referenced Surface Segmentation Sequence", tag_key: 'ReferencedSurfaceSegmentationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,114D)', tag_sym: :referenced_surface_segmentation_sequence, tag_ndm: '0008114D', tag_ary: [0x0008,0x114D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,1150)', tag_name: "Referenced SOP Class UID", tag_key: 'ReferencedSOPClassUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0008,1150)', tag_sym: :referenced_sop_class_uid, tag_ndm: '00081150', tag_ary: [0x0008,0x1150], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,1155)', tag_name: "Referenced SOP Instance UID", tag_key: 'ReferencedSOPInstanceUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0008,1155)', tag_sym: :referenced_sop_instance_uid, tag_ndm: '00081155', tag_ary: [0x0008,0x1155], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,1156)', tag_name: "Definition Source Sequence", tag_key: 'DefinitionSourceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,1156)', tag_sym: :definition_source_sequence, tag_ndm: '00081156', tag_ary: [0x0008,0x1156], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,115A)', tag_name: "SOP Classes Supported", tag_key: 'SOPClassesSupported', tag_vr: [:UI], tag_vm: ["1-n"], tag_str: '(0008,115A)', tag_sym: :sop_classes_supported, tag_ndm: '0008115A', tag_ary: [0x0008,0x115A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,1160)', tag_name: "Referenced Frame Number", tag_key: 'ReferencedFrameNumber', tag_vr: [:IS], tag_vm: ["1-n"], tag_str: '(0008,1160)', tag_sym: :referenced_frame_number, tag_ndm: '00081160', tag_ary: [0x0008,0x1160], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,1161)', tag_name: "Simple Frame List", tag_key: 'SimpleFrameList', tag_vr: [:UL], tag_vm: ["1-n"], tag_str: '(0008,1161)', tag_sym: :simple_frame_list, tag_ndm: '00081161', tag_ary: [0x0008,0x1161], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,1162)', tag_name: "Calculated Frame List", tag_key: 'CalculatedFrameList', tag_vr: [:UL], tag_vm: ["3-3n"], tag_str: '(0008,1162)', tag_sym: :calculated_frame_list, tag_ndm: '00081162', tag_ary: [0x0008,0x1162], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,1163)', tag_name: "Time Range", tag_key: 'TimeRange', tag_vr: [:FD], tag_vm: ["2"], tag_str: '(0008,1163)', tag_sym: :time_range, tag_ndm: '00081163', tag_ary: [0x0008,0x1163], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,1164)', tag_name: "Frame Extraction Sequence", tag_key: 'FrameExtractionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,1164)', tag_sym: :frame_extraction_sequence, tag_ndm: '00081164', tag_ary: [0x0008,0x1164], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,1167)', tag_name: "Multi-frame Source SOP Instance UID", tag_key: 'MultiFrameSourceSOPInstanceUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0008,1167)', tag_sym: :multi_frame_source_sop_instance_uid, tag_ndm: '00081167', tag_ary: [0x0008,0x1167], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,1190)', tag_name: "Retrieve URL", tag_key: 'RetrieveURL', tag_vr: [:UR], tag_vm: ["1"], tag_str: '(0008,1190)', tag_sym: :retrieve_url, tag_ndm: '00081190', tag_ary: [0x0008,0x1190], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,1195)', tag_name: "Transaction UID", tag_key: 'TransactionUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0008,1195)', tag_sym: :transaction_uid, tag_ndm: '00081195', tag_ary: [0x0008,0x1195], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,1196)', tag_name: "Warning Reason", tag_key: 'WarningReason', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0008,1196)', tag_sym: :warning_reason, tag_ndm: '00081196', tag_ary: [0x0008,0x1196], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,1197)', tag_name: "Failure Reason", tag_key: 'FailureReason', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0008,1197)', tag_sym: :failure_reason, tag_ndm: '00081197', tag_ary: [0x0008,0x1197], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,1198)', tag_name: "Failed SOP Sequence", tag_key: 'FailedSOPSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,1198)', tag_sym: :failed_sop_sequence, tag_ndm: '00081198', tag_ary: [0x0008,0x1198], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,1199)', tag_name: "Referenced SOP Sequence", tag_key: 'ReferencedSOPSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,1199)', tag_sym: :referenced_sop_sequence, tag_ndm: '00081199', tag_ary: [0x0008,0x1199], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,119A)', tag_name: "Other Failures Sequence", tag_key: 'OtherFailuresSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,119A)', tag_sym: :other_failures_sequence, tag_ndm: '0008119A', tag_ary: [0x0008,0x119A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,119B)', tag_name: "Failed Study Sequence", tag_key: 'FailedStudySequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,119B)', tag_sym: :failed_study_sequence, tag_ndm: '0008119B', tag_ary: [0x0008,0x119B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,1200)', tag_name: "Studies Containing Other Referenced Instances Sequence", tag_key: 'StudiesContainingOtherReferencedInstancesSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,1200)', tag_sym: :studies_containing_other_referenced_instances_sequence, tag_ndm: '00081200', tag_ary: [0x0008,0x1200], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,1250)', tag_name: "Related Series Sequence", tag_key: 'RelatedSeriesSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,1250)', tag_sym: :related_series_sequence, tag_ndm: '00081250', tag_ary: [0x0008,0x1250], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,1301)', tag_name: "Principal Diagnosis Code Sequence", tag_key: 'PrincipalDiagnosisCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,1301)', tag_sym: :principal_diagnosis_code_sequence, tag_ndm: '00081301', tag_ary: [0x0008,0x1301], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,1302)', tag_name: "Primary Diagnosis Code Sequence", tag_key: 'PrimaryDiagnosisCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,1302)', tag_sym: :primary_diagnosis_code_sequence, tag_ndm: '00081302', tag_ary: [0x0008,0x1302], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,1303)', tag_name: "Secondary Diagnoses Code Sequence", tag_key: 'SecondaryDiagnosesCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,1303)', tag_sym: :secondary_diagnoses_code_sequence, tag_ndm: '00081303', tag_ary: [0x0008,0x1303], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,1304)', tag_name: "Histological Diagnoses Code Sequence", tag_key: 'HistologicalDiagnosesCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,1304)', tag_sym: :histological_diagnoses_code_sequence, tag_ndm: '00081304', tag_ary: [0x0008,0x1304], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,2110)', tag_name: "Lossy Image Compression (Retired)", tag_key: 'LossyImageCompressionRetired', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0008,2110)', tag_sym: :lossy_image_compression_retired, tag_ndm: '00082110', tag_ary: [0x0008,0x2110], tag_multiple: false, tag_note: 'RET (1993)'},
      { tag_ps: '(0008,2111)', tag_name: "Derivation Description", tag_key: 'DerivationDescription', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0008,2111)', tag_sym: :derivation_description, tag_ndm: '00082111', tag_ary: [0x0008,0x2111], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,2112)', tag_name: "Source Image Sequence", tag_key: 'SourceImageSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,2112)', tag_sym: :source_image_sequence, tag_ndm: '00082112', tag_ary: [0x0008,0x2112], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,2120)', tag_name: "Stage Name", tag_key: 'StageName', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0008,2120)', tag_sym: :stage_name, tag_ndm: '00082120', tag_ary: [0x0008,0x2120], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,2122)', tag_name: "Stage Number", tag_key: 'StageNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0008,2122)', tag_sym: :stage_number, tag_ndm: '00082122', tag_ary: [0x0008,0x2122], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,2124)', tag_name: "Number of Stages", tag_key: 'NumberOfStages', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0008,2124)', tag_sym: :number_of_stages, tag_ndm: '00082124', tag_ary: [0x0008,0x2124], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,2127)', tag_name: "View Name", tag_key: 'ViewName', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0008,2127)', tag_sym: :view_name, tag_ndm: '00082127', tag_ary: [0x0008,0x2127], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,2128)', tag_name: "View Number", tag_key: 'ViewNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0008,2128)', tag_sym: :view_number, tag_ndm: '00082128', tag_ary: [0x0008,0x2128], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,2129)', tag_name: "Number of Event Timers", tag_key: 'NumberOfEventTimers', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0008,2129)', tag_sym: :number_of_event_timers, tag_ndm: '00082129', tag_ary: [0x0008,0x2129], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,212A)', tag_name: "Number of Views in Stage", tag_key: 'NumberOfViewsInStage', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0008,212A)', tag_sym: :number_of_views_in_stage, tag_ndm: '0008212A', tag_ary: [0x0008,0x212A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,2130)', tag_name: "Event Elapsed Time(s)", tag_key: 'EventElapsedTimes', tag_vr: [:DS], tag_vm: ["1-n"], tag_str: '(0008,2130)', tag_sym: :event_elapsed_times, tag_ndm: '00082130', tag_ary: [0x0008,0x2130], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,2132)', tag_name: "Event Timer Name(s)", tag_key: 'EventTimerNames', tag_vr: [:LO], tag_vm: ["1-n"], tag_str: '(0008,2132)', tag_sym: :event_timer_names, tag_ndm: '00082132', tag_ary: [0x0008,0x2132], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,2133)', tag_name: "Event Timer Sequence", tag_key: 'EventTimerSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,2133)', tag_sym: :event_timer_sequence, tag_ndm: '00082133', tag_ary: [0x0008,0x2133], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,2134)', tag_name: "Event Time Offset", tag_key: 'EventTimeOffset', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0008,2134)', tag_sym: :event_time_offset, tag_ndm: '00082134', tag_ary: [0x0008,0x2134], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,2135)', tag_name: "Event Code Sequence", tag_key: 'EventCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,2135)', tag_sym: :event_code_sequence, tag_ndm: '00082135', tag_ary: [0x0008,0x2135], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,2142)', tag_name: "Start Trim", tag_key: 'StartTrim', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0008,2142)', tag_sym: :start_trim, tag_ndm: '00082142', tag_ary: [0x0008,0x2142], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,2143)', tag_name: "Stop Trim", tag_key: 'StopTrim', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0008,2143)', tag_sym: :stop_trim, tag_ndm: '00082143', tag_ary: [0x0008,0x2143], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,2144)', tag_name: "Recommended Display Frame Rate", tag_key: 'RecommendedDisplayFrameRate', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0008,2144)', tag_sym: :recommended_display_frame_rate, tag_ndm: '00082144', tag_ary: [0x0008,0x2144], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,2200)', tag_name: "Transducer Position", tag_key: 'TransducerPosition', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0008,2200)', tag_sym: :transducer_position, tag_ndm: '00082200', tag_ary: [0x0008,0x2200], tag_multiple: false, tag_note: 'RET (1993)'},
      { tag_ps: '(0008,2204)', tag_name: "Transducer Orientation", tag_key: 'TransducerOrientation', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0008,2204)', tag_sym: :transducer_orientation, tag_ndm: '00082204', tag_ary: [0x0008,0x2204], tag_multiple: false, tag_note: 'RET (1993)'},
      { tag_ps: '(0008,2208)', tag_name: "Anatomic Structure", tag_key: 'AnatomicStructure', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0008,2208)', tag_sym: :anatomic_structure, tag_ndm: '00082208', tag_ary: [0x0008,0x2208], tag_multiple: false, tag_note: 'RET (1993)'},
      { tag_ps: '(0008,2218)', tag_name: "Anatomic Region Sequence", tag_key: 'AnatomicRegionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,2218)', tag_sym: :anatomic_region_sequence, tag_ndm: '00082218', tag_ary: [0x0008,0x2218], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,2220)', tag_name: "Anatomic Region Modifier Sequence", tag_key: 'AnatomicRegionModifierSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,2220)', tag_sym: :anatomic_region_modifier_sequence, tag_ndm: '00082220', tag_ary: [0x0008,0x2220], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,2228)', tag_name: "Primary Anatomic Structure Sequence", tag_key: 'PrimaryAnatomicStructureSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,2228)', tag_sym: :primary_anatomic_structure_sequence, tag_ndm: '00082228', tag_ary: [0x0008,0x2228], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,2229)', tag_name: "Anatomic Structure, Space or Region Sequence", tag_key: 'AnatomicStructureSpaceOrRegionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,2229)', tag_sym: :anatomic_structure_space_or_region_sequence, tag_ndm: '00082229', tag_ary: [0x0008,0x2229], tag_multiple: false, tag_note: 'RET (2017c)'},
      { tag_ps: '(0008,2230)', tag_name: "Primary Anatomic Structure Modifier Sequence", tag_key: 'PrimaryAnatomicStructureModifierSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,2230)', tag_sym: :primary_anatomic_structure_modifier_sequence, tag_ndm: '00082230', tag_ary: [0x0008,0x2230], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,2240)', tag_name: "Transducer Position Sequence", tag_key: 'TransducerPositionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,2240)', tag_sym: :transducer_position_sequence, tag_ndm: '00082240', tag_ary: [0x0008,0x2240], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(0008,2242)', tag_name: "Transducer Position Modifier Sequence", tag_key: 'TransducerPositionModifierSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,2242)', tag_sym: :transducer_position_modifier_sequence, tag_ndm: '00082242', tag_ary: [0x0008,0x2242], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(0008,2244)', tag_name: "Transducer Orientation Sequence", tag_key: 'TransducerOrientationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,2244)', tag_sym: :transducer_orientation_sequence, tag_ndm: '00082244', tag_ary: [0x0008,0x2244], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(0008,2246)', tag_name: "Transducer Orientation Modifier Sequence", tag_key: 'TransducerOrientationModifierSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,2246)', tag_sym: :transducer_orientation_modifier_sequence, tag_ndm: '00082246', tag_ary: [0x0008,0x2246], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(0008,2251)', tag_name: "Anatomic Structure Space Or Region Code Sequence (Trial)", tag_key: 'AnatomicStructureSpaceOrRegionCodeSequenceTrial', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,2251)', tag_sym: :anatomic_structure_space_or_region_code_sequence_trial, tag_ndm: '00082251', tag_ary: [0x0008,0x2251], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0008,2253)', tag_name: "Anatomic Portal Of Entrance Code Sequence (Trial)", tag_key: 'AnatomicPortalOfEntranceCodeSequenceTrial', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,2253)', tag_sym: :anatomic_portal_of_entrance_code_sequence_trial, tag_ndm: '00082253', tag_ary: [0x0008,0x2253], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0008,2255)', tag_name: "Anatomic Approach Direction Code Sequence (Trial)", tag_key: 'AnatomicApproachDirectionCodeSequenceTrial', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,2255)', tag_sym: :anatomic_approach_direction_code_sequence_trial, tag_ndm: '00082255', tag_ary: [0x0008,0x2255], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0008,2256)', tag_name: "Anatomic Perspective Description (Trial)", tag_key: 'AnatomicPerspectiveDescriptionTrial', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0008,2256)', tag_sym: :anatomic_perspective_description_trial, tag_ndm: '00082256', tag_ary: [0x0008,0x2256], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0008,2257)', tag_name: "Anatomic Perspective Code Sequence (Trial)", tag_key: 'AnatomicPerspectiveCodeSequenceTrial', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,2257)', tag_sym: :anatomic_perspective_code_sequence_trial, tag_ndm: '00082257', tag_ary: [0x0008,0x2257], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0008,2258)', tag_name: "Anatomic Location Of Examining Instrument Description (Trial)", tag_key: 'AnatomicLocationOfExaminingInstrumentDescriptionTrial', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0008,2258)', tag_sym: :anatomic_location_of_examining_instrument_description_trial, tag_ndm: '00082258', tag_ary: [0x0008,0x2258], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0008,2259)', tag_name: "Anatomic Location Of Examining Instrument Code Sequence (Trial)", tag_key: 'AnatomicLocationOfExaminingInstrumentCodeSequenceTrial', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,2259)', tag_sym: :anatomic_location_of_examining_instrument_code_sequence_trial, tag_ndm: '00082259', tag_ary: [0x0008,0x2259], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0008,225A)', tag_name: "Anatomic Structure Space Or Region Modifier Code Sequence (Trial)", tag_key: 'AnatomicStructureSpaceOrRegionModifierCodeSequenceTrial', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,225A)', tag_sym: :anatomic_structure_space_or_region_modifier_code_sequence_trial, tag_ndm: '0008225A', tag_ary: [0x0008,0x225A], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0008,225C)', tag_name: "On Axis Background Anatomic Structure Code Sequence (Trial)", tag_key: 'OnAxisBackgroundAnatomicStructureCodeSequenceTrial', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,225C)', tag_sym: :on_axis_background_anatomic_structure_code_sequence_trial, tag_ndm: '0008225C', tag_ary: [0x0008,0x225C], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0008,3001)', tag_name: "Alternate Representation Sequence", tag_key: 'AlternateRepresentationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,3001)', tag_sym: :alternate_representation_sequence, tag_ndm: '00083001', tag_ary: [0x0008,0x3001], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,3002)', tag_name: "Available Transfer Syntax UID", tag_key: 'AvailableTransferSyntaxUID', tag_vr: [:UI], tag_vm: ["1-n"], tag_str: '(0008,3002)', tag_sym: :available_transfer_syntax_uid, tag_ndm: '00083002', tag_ary: [0x0008,0x3002], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,3010)', tag_name: "Irradiation Event UID", tag_key: 'IrradiationEventUID', tag_vr: [:UI], tag_vm: ["1-n"], tag_str: '(0008,3010)', tag_sym: :irradiation_event_uid, tag_ndm: '00083010', tag_ary: [0x0008,0x3010], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,3011)', tag_name: "Source Irradiation Event Sequence", tag_key: 'SourceIrradiationEventSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,3011)', tag_sym: :source_irradiation_event_sequence, tag_ndm: '00083011', tag_ary: [0x0008,0x3011], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,3012)', tag_name: "Radiopharmaceutical Administration Event UID", tag_key: 'RadiopharmaceuticalAdministrationEventUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0008,3012)', tag_sym: :radiopharmaceutical_administration_event_uid, tag_ndm: '00083012', tag_ary: [0x0008,0x3012], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,4000)', tag_name: "Identifying Comments", tag_key: 'IdentifyingComments', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(0008,4000)', tag_sym: :identifying_comments, tag_ndm: '00084000', tag_ary: [0x0008,0x4000], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(0008,9007)', tag_name: "Frame Type", tag_key: 'FrameType', tag_vr: [:CS], tag_vm: ["4-5"], tag_str: '(0008,9007)', tag_sym: :frame_type, tag_ndm: '00089007', tag_ary: [0x0008,0x9007], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,9092)', tag_name: "Referenced Image Evidence Sequence", tag_key: 'ReferencedImageEvidenceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,9092)', tag_sym: :referenced_image_evidence_sequence, tag_ndm: '00089092', tag_ary: [0x0008,0x9092], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,9121)', tag_name: "Referenced Raw Data Sequence", tag_key: 'ReferencedRawDataSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,9121)', tag_sym: :referenced_raw_data_sequence, tag_ndm: '00089121', tag_ary: [0x0008,0x9121], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,9123)', tag_name: "Creator-Version UID", tag_key: 'CreatorVersionUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0008,9123)', tag_sym: :creator_version_uid, tag_ndm: '00089123', tag_ary: [0x0008,0x9123], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,9124)', tag_name: "Derivation Image Sequence", tag_key: 'DerivationImageSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,9124)', tag_sym: :derivation_image_sequence, tag_ndm: '00089124', tag_ary: [0x0008,0x9124], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,9154)', tag_name: "Source Image Evidence Sequence", tag_key: 'SourceImageEvidenceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,9154)', tag_sym: :source_image_evidence_sequence, tag_ndm: '00089154', tag_ary: [0x0008,0x9154], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,9205)', tag_name: "Pixel Presentation", tag_key: 'PixelPresentation', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0008,9205)', tag_sym: :pixel_presentation, tag_ndm: '00089205', tag_ary: [0x0008,0x9205], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,9206)', tag_name: "Volumetric Properties", tag_key: 'VolumetricProperties', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0008,9206)', tag_sym: :volumetric_properties, tag_ndm: '00089206', tag_ary: [0x0008,0x9206], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,9207)', tag_name: "Volume Based Calculation Technique", tag_key: 'VolumeBasedCalculationTechnique', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0008,9207)', tag_sym: :volume_based_calculation_technique, tag_ndm: '00089207', tag_ary: [0x0008,0x9207], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,9208)', tag_name: "Complex Image Component", tag_key: 'ComplexImageComponent', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0008,9208)', tag_sym: :complex_image_component, tag_ndm: '00089208', tag_ary: [0x0008,0x9208], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,9209)', tag_name: "Acquisition Contrast", tag_key: 'AcquisitionContrast', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0008,9209)', tag_sym: :acquisition_contrast, tag_ndm: '00089209', tag_ary: [0x0008,0x9209], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,9215)', tag_name: "Derivation Code Sequence", tag_key: 'DerivationCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,9215)', tag_sym: :derivation_code_sequence, tag_ndm: '00089215', tag_ary: [0x0008,0x9215], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,9237)', tag_name: "Referenced Presentation State Sequence", tag_key: 'ReferencedPresentationStateSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,9237)', tag_sym: :referenced_presentation_state_sequence, tag_ndm: '00089237', tag_ary: [0x0008,0x9237], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,9410)', tag_name: "Referenced Other Plane Sequence", tag_key: 'ReferencedOtherPlaneSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,9410)', tag_sym: :referenced_other_plane_sequence, tag_ndm: '00089410', tag_ary: [0x0008,0x9410], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,9458)', tag_name: "Frame Display Sequence", tag_key: 'FrameDisplaySequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0008,9458)', tag_sym: :frame_display_sequence, tag_ndm: '00089458', tag_ary: [0x0008,0x9458], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,9459)', tag_name: "Recommended Display Frame Rate in Float", tag_key: 'RecommendedDisplayFrameRateInFloat', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0008,9459)', tag_sym: :recommended_display_frame_rate_in_float, tag_ndm: '00089459', tag_ary: [0x0008,0x9459], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0008,9460)', tag_name: "Skip Frame Range Flag", tag_key: 'SkipFrameRangeFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0008,9460)', tag_sym: :skip_frame_range_flag, tag_ndm: '00089460', tag_ary: [0x0008,0x9460], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,0010)', tag_name: "Patient's Name", tag_key: 'PatientName', tag_vr: [:PN], tag_vm: ["1"], tag_str: '(0010,0010)', tag_sym: :patient_name, tag_ndm: '00100010', tag_ary: [0x0010,0x0010], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,0011)', tag_name: "Person Names to Use Sequence", tag_key: 'PersonNamesToUseSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0010,0011)', tag_sym: :person_names_to_use_sequence, tag_ndm: '00100011', tag_ary: [0x0010,0x0011], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,0012)', tag_name: "Name to Use", tag_key: 'NameToUse', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(0010,0012)', tag_sym: :name_to_use, tag_ndm: '00100012', tag_ary: [0x0010,0x0012], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,0013)', tag_name: "Name to Use Comment", tag_key: 'NameToUseComment', tag_vr: [:UT], tag_vm: ["1"], tag_str: '(0010,0013)', tag_sym: :name_to_use_comment, tag_ndm: '00100013', tag_ary: [0x0010,0x0013], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,0014)', tag_name: "Third Person Pronouns Sequence", tag_key: 'ThirdPersonPronounsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0010,0014)', tag_sym: :third_person_pronouns_sequence, tag_ndm: '00100014', tag_ary: [0x0010,0x0014], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,0015)', tag_name: "Pronoun Code Sequence", tag_key: 'PronounCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0010,0015)', tag_sym: :pronoun_code_sequence, tag_ndm: '00100015', tag_ary: [0x0010,0x0015], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,0016)', tag_name: "Pronoun Comment", tag_key: 'PronounComment', tag_vr: [:UT], tag_vm: ["1"], tag_str: '(0010,0016)', tag_sym: :pronoun_comment, tag_ndm: '00100016', tag_ary: [0x0010,0x0016], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,0020)', tag_name: "Patient ID", tag_key: 'PatientID', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0010,0020)', tag_sym: :patient_id, tag_ndm: '00100020', tag_ary: [0x0010,0x0020], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,0021)', tag_name: "Issuer of Patient ID", tag_key: 'IssuerOfPatientID', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0010,0021)', tag_sym: :issuer_of_patient_id, tag_ndm: '00100021', tag_ary: [0x0010,0x0021], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,0022)', tag_name: "Type of Patient ID", tag_key: 'TypeOfPatientID', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0010,0022)', tag_sym: :type_of_patient_id, tag_ndm: '00100022', tag_ary: [0x0010,0x0022], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,0024)', tag_name: "Issuer of Patient ID Qualifiers Sequence", tag_key: 'IssuerOfPatientIDQualifiersSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0010,0024)', tag_sym: :issuer_of_patient_id_qualifiers_sequence, tag_ndm: '00100024', tag_ary: [0x0010,0x0024], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,0026)', tag_name: "Source Patient Group Identification Sequence", tag_key: 'SourcePatientGroupIdentificationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0010,0026)', tag_sym: :source_patient_group_identification_sequence, tag_ndm: '00100026', tag_ary: [0x0010,0x0026], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,0027)', tag_name: "Group of Patients Identification Sequence", tag_key: 'GroupOfPatientsIdentificationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0010,0027)', tag_sym: :group_of_patients_identification_sequence, tag_ndm: '00100027', tag_ary: [0x0010,0x0027], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,0028)', tag_name: "Subject Relative Position in Image", tag_key: 'SubjectRelativePositionInImage', tag_vr: [:US], tag_vm: ["3"], tag_str: '(0010,0028)', tag_sym: :subject_relative_position_in_image, tag_ndm: '00100028', tag_ary: [0x0010,0x0028], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,0030)', tag_name: "Patient's Birth Date", tag_key: 'PatientBirthDate', tag_vr: [:DA], tag_vm: ["1"], tag_str: '(0010,0030)', tag_sym: :patient_birth_date, tag_ndm: '00100030', tag_ary: [0x0010,0x0030], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,0032)', tag_name: "Patient's Birth Time", tag_key: 'PatientBirthTime', tag_vr: [:TM], tag_vm: ["1"], tag_str: '(0010,0032)', tag_sym: :patient_birth_time, tag_ndm: '00100032', tag_ary: [0x0010,0x0032], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,0033)', tag_name: "Patient's Birth Date in Alternative Calendar", tag_key: 'PatientBirthDateInAlternativeCalendar', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0010,0033)', tag_sym: :patient_birth_date_in_alternative_calendar, tag_ndm: '00100033', tag_ary: [0x0010,0x0033], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,0034)', tag_name: "Patient's Death Date in Alternative Calendar", tag_key: 'PatientDeathDateInAlternativeCalendar', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0010,0034)', tag_sym: :patient_death_date_in_alternative_calendar, tag_ndm: '00100034', tag_ary: [0x0010,0x0034], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,0035)', tag_name: "Patient's Alternative Calendar", tag_key: 'PatientAlternativeCalendar', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0010,0035)', tag_sym: :patient_alternative_calendar, tag_ndm: '00100035', tag_ary: [0x0010,0x0035], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,0040)', tag_name: "Patient's Sex", tag_key: 'PatientSex', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0010,0040)', tag_sym: :patient_sex, tag_ndm: '00100040', tag_ary: [0x0010,0x0040], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,0041)', tag_name: "Gender Identity Sequence", tag_key: 'GenderIdentitySequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0010,0041)', tag_sym: :gender_identity_sequence, tag_ndm: '00100041', tag_ary: [0x0010,0x0041], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,0042)', tag_name: "Sex Parameters for Clinical Use Category Comment", tag_key: 'SexParametersForClinicalUseCategoryComment', tag_vr: [:UT], tag_vm: ["1"], tag_str: '(0010,0042)', tag_sym: :sex_parameters_for_clinical_use_category_comment, tag_ndm: '00100042', tag_ary: [0x0010,0x0042], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,0043)', tag_name: "Sex Parameters for Clinical Use Category Sequence", tag_key: 'SexParametersForClinicalUseCategorySequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0010,0043)', tag_sym: :sex_parameters_for_clinical_use_category_sequence, tag_ndm: '00100043', tag_ary: [0x0010,0x0043], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,0044)', tag_name: "Gender Identity Code Sequence", tag_key: 'GenderIdentityCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0010,0044)', tag_sym: :gender_identity_code_sequence, tag_ndm: '00100044', tag_ary: [0x0010,0x0044], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,0045)', tag_name: "Gender Identity Comment", tag_key: 'GenderIdentityComment', tag_vr: [:UT], tag_vm: ["1"], tag_str: '(0010,0045)', tag_sym: :gender_identity_comment, tag_ndm: '00100045', tag_ary: [0x0010,0x0045], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,0046)', tag_name: "Sex Parameters for Clinical Use Category Code Sequence", tag_key: 'SexParametersForClinicalUseCategoryCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0010,0046)', tag_sym: :sex_parameters_for_clinical_use_category_code_sequence, tag_ndm: '00100046', tag_ary: [0x0010,0x0046], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,0047)', tag_name: "Sex Parameters for Clinical Use Category Reference", tag_key: 'SexParametersForClinicalUseCategoryReference', tag_vr: [:UR], tag_vm: ["1-n"], tag_str: '(0010,0047)', tag_sym: :sex_parameters_for_clinical_use_category_reference, tag_ndm: '00100047', tag_ary: [0x0010,0x0047], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,0050)', tag_name: "Patient's Insurance Plan Code Sequence", tag_key: 'PatientInsurancePlanCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0010,0050)', tag_sym: :patient_insurance_plan_code_sequence, tag_ndm: '00100050', tag_ary: [0x0010,0x0050], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,0101)', tag_name: "Patient's Primary Language Code Sequence", tag_key: 'PatientPrimaryLanguageCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0010,0101)', tag_sym: :patient_primary_language_code_sequence, tag_ndm: '00100101', tag_ary: [0x0010,0x0101], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,0102)', tag_name: "Patient's Primary Language Modifier Code Sequence", tag_key: 'PatientPrimaryLanguageModifierCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0010,0102)', tag_sym: :patient_primary_language_modifier_code_sequence, tag_ndm: '00100102', tag_ary: [0x0010,0x0102], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,0200)', tag_name: "Quality Control Subject", tag_key: 'QualityControlSubject', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0010,0200)', tag_sym: :quality_control_subject, tag_ndm: '00100200', tag_ary: [0x0010,0x0200], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,0201)', tag_name: "Quality Control Subject Type Code Sequence", tag_key: 'QualityControlSubjectTypeCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0010,0201)', tag_sym: :quality_control_subject_type_code_sequence, tag_ndm: '00100201', tag_ary: [0x0010,0x0201], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,0212)', tag_name: "Strain Description", tag_key: 'StrainDescription', tag_vr: [:UC], tag_vm: ["1"], tag_str: '(0010,0212)', tag_sym: :strain_description, tag_ndm: '00100212', tag_ary: [0x0010,0x0212], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,0213)', tag_name: "Strain Nomenclature", tag_key: 'StrainNomenclature', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0010,0213)', tag_sym: :strain_nomenclature, tag_ndm: '00100213', tag_ary: [0x0010,0x0213], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,0214)', tag_name: "Strain Stock Number", tag_key: 'StrainStockNumber', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0010,0214)', tag_sym: :strain_stock_number, tag_ndm: '00100214', tag_ary: [0x0010,0x0214], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,0215)', tag_name: "Strain Source Registry Code Sequence", tag_key: 'StrainSourceRegistryCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0010,0215)', tag_sym: :strain_source_registry_code_sequence, tag_ndm: '00100215', tag_ary: [0x0010,0x0215], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,0216)', tag_name: "Strain Stock Sequence", tag_key: 'StrainStockSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0010,0216)', tag_sym: :strain_stock_sequence, tag_ndm: '00100216', tag_ary: [0x0010,0x0216], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,0217)', tag_name: "Strain Source", tag_key: 'StrainSource', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0010,0217)', tag_sym: :strain_source, tag_ndm: '00100217', tag_ary: [0x0010,0x0217], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,0218)', tag_name: "Strain Additional Information", tag_key: 'StrainAdditionalInformation', tag_vr: [:UT], tag_vm: ["1"], tag_str: '(0010,0218)', tag_sym: :strain_additional_information, tag_ndm: '00100218', tag_ary: [0x0010,0x0218], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,0219)', tag_name: "Strain Code Sequence", tag_key: 'StrainCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0010,0219)', tag_sym: :strain_code_sequence, tag_ndm: '00100219', tag_ary: [0x0010,0x0219], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,0221)', tag_name: "Genetic Modifications Sequence", tag_key: 'GeneticModificationsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0010,0221)', tag_sym: :genetic_modifications_sequence, tag_ndm: '00100221', tag_ary: [0x0010,0x0221], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,0222)', tag_name: "Genetic Modifications Description", tag_key: 'GeneticModificationsDescription', tag_vr: [:UC], tag_vm: ["1"], tag_str: '(0010,0222)', tag_sym: :genetic_modifications_description, tag_ndm: '00100222', tag_ary: [0x0010,0x0222], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,0223)', tag_name: "Genetic Modifications Nomenclature", tag_key: 'GeneticModificationsNomenclature', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0010,0223)', tag_sym: :genetic_modifications_nomenclature, tag_ndm: '00100223', tag_ary: [0x0010,0x0223], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,0229)', tag_name: "Genetic Modifications Code Sequence", tag_key: 'GeneticModificationsCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0010,0229)', tag_sym: :genetic_modifications_code_sequence, tag_ndm: '00100229', tag_ary: [0x0010,0x0229], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,1000)', tag_name: "Other Patient IDs", tag_key: 'OtherPatientIDs', tag_vr: [:LO], tag_vm: ["1-n"], tag_str: '(0010,1000)', tag_sym: :other_patient_ids, tag_ndm: '00101000', tag_ary: [0x0010,0x1000], tag_multiple: false, tag_note: 'RET (2017a)'},
      { tag_ps: '(0010,1001)', tag_name: "Other Patient Names", tag_key: 'OtherPatientNames', tag_vr: [:PN], tag_vm: ["1-n"], tag_str: '(0010,1001)', tag_sym: :other_patient_names, tag_ndm: '00101001', tag_ary: [0x0010,0x1001], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,1002)', tag_name: "Other Patient IDs Sequence", tag_key: 'OtherPatientIDsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0010,1002)', tag_sym: :other_patient_ids_sequence, tag_ndm: '00101002', tag_ary: [0x0010,0x1002], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,1005)', tag_name: "Patient's Birth Name", tag_key: 'PatientBirthName', tag_vr: [:PN], tag_vm: ["1"], tag_str: '(0010,1005)', tag_sym: :patient_birth_name, tag_ndm: '00101005', tag_ary: [0x0010,0x1005], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,1010)', tag_name: "Patient's Age", tag_key: 'PatientAge', tag_vr: [:AS], tag_vm: ["1"], tag_str: '(0010,1010)', tag_sym: :patient_age, tag_ndm: '00101010', tag_ary: [0x0010,0x1010], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,1020)', tag_name: "Patient's Size", tag_key: 'PatientSize', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0010,1020)', tag_sym: :patient_size, tag_ndm: '00101020', tag_ary: [0x0010,0x1020], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,1021)', tag_name: "Patient's Size Code Sequence", tag_key: 'PatientSizeCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0010,1021)', tag_sym: :patient_size_code_sequence, tag_ndm: '00101021', tag_ary: [0x0010,0x1021], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,1022)', tag_name: "Patient's Body Mass Index", tag_key: 'PatientBodyMassIndex', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0010,1022)', tag_sym: :patient_body_mass_index, tag_ndm: '00101022', tag_ary: [0x0010,0x1022], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,1023)', tag_name: "Measured AP Dimension", tag_key: 'MeasuredAPDimension', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0010,1023)', tag_sym: :measured_ap_dimension, tag_ndm: '00101023', tag_ary: [0x0010,0x1023], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,1024)', tag_name: "Measured Lateral Dimension", tag_key: 'MeasuredLateralDimension', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0010,1024)', tag_sym: :measured_lateral_dimension, tag_ndm: '00101024', tag_ary: [0x0010,0x1024], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,1030)', tag_name: "Patient's Weight", tag_key: 'PatientWeight', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0010,1030)', tag_sym: :patient_weight, tag_ndm: '00101030', tag_ary: [0x0010,0x1030], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,1040)', tag_name: "Patient's Address", tag_key: 'PatientAddress', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0010,1040)', tag_sym: :patient_address, tag_ndm: '00101040', tag_ary: [0x0010,0x1040], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,1050)', tag_name: "Insurance Plan Identification", tag_key: 'InsurancePlanIdentification', tag_vr: [:LO], tag_vm: ["1-n"], tag_str: '(0010,1050)', tag_sym: :insurance_plan_identification, tag_ndm: '00101050', tag_ary: [0x0010,0x1050], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(0010,1060)', tag_name: "Patient's Mother's Birth Name", tag_key: 'PatientMotherBirthName', tag_vr: [:PN], tag_vm: ["1"], tag_str: '(0010,1060)', tag_sym: :patient_mother_birth_name, tag_ndm: '00101060', tag_ary: [0x0010,0x1060], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,1080)', tag_name: "Military Rank", tag_key: 'MilitaryRank', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0010,1080)', tag_sym: :military_rank, tag_ndm: '00101080', tag_ary: [0x0010,0x1080], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,1081)', tag_name: "Branch of Service", tag_key: 'BranchOfService', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0010,1081)', tag_sym: :branch_of_service, tag_ndm: '00101081', tag_ary: [0x0010,0x1081], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,1090)', tag_name: "Medical Record Locator", tag_key: 'MedicalRecordLocator', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0010,1090)', tag_sym: :medical_record_locator, tag_ndm: '00101090', tag_ary: [0x0010,0x1090], tag_multiple: false, tag_note: 'RET (2017a)'},
      { tag_ps: '(0010,1100)', tag_name: "Referenced Patient Photo Sequence", tag_key: 'ReferencedPatientPhotoSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0010,1100)', tag_sym: :referenced_patient_photo_sequence, tag_ndm: '00101100', tag_ary: [0x0010,0x1100], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,2000)', tag_name: "Medical Alerts", tag_key: 'MedicalAlerts', tag_vr: [:LO], tag_vm: ["1-n"], tag_str: '(0010,2000)', tag_sym: :medical_alerts, tag_ndm: '00102000', tag_ary: [0x0010,0x2000], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,2110)', tag_name: "Allergies", tag_key: 'Allergies', tag_vr: [:LO], tag_vm: ["1-n"], tag_str: '(0010,2110)', tag_sym: :allergies, tag_ndm: '00102110', tag_ary: [0x0010,0x2110], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,2150)', tag_name: "Country of Residence", tag_key: 'CountryOfResidence', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0010,2150)', tag_sym: :country_of_residence, tag_ndm: '00102150', tag_ary: [0x0010,0x2150], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,2152)', tag_name: "Region of Residence", tag_key: 'RegionOfResidence', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0010,2152)', tag_sym: :region_of_residence, tag_ndm: '00102152', tag_ary: [0x0010,0x2152], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,2154)', tag_name: "Patient's Telephone Numbers", tag_key: 'PatientTelephoneNumbers', tag_vr: [:SH], tag_vm: ["1-n"], tag_str: '(0010,2154)', tag_sym: :patient_telephone_numbers, tag_ndm: '00102154', tag_ary: [0x0010,0x2154], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,2155)', tag_name: "Patient's Telecom Information", tag_key: 'PatientTelecomInformation', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(0010,2155)', tag_sym: :patient_telecom_information, tag_ndm: '00102155', tag_ary: [0x0010,0x2155], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,2160)', tag_name: "Ethnic Group", tag_key: 'EthnicGroup', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0010,2160)', tag_sym: :ethnic_group, tag_ndm: '00102160', tag_ary: [0x0010,0x2160], tag_multiple: false, tag_note: 'RET (2025a)'},
      { tag_ps: '(0010,2161)', tag_name: "Ethnic Group Code Sequence", tag_key: 'EthnicGroupCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0010,2161)', tag_sym: :ethnic_group_code_sequence, tag_ndm: '00102161', tag_ary: [0x0010,0x2161], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,2162)', tag_name: "Ethnic Groups", tag_key: 'EthnicGroups', tag_vr: [:UC], tag_vm: ["1-n"], tag_str: '(0010,2162)', tag_sym: :ethnic_groups, tag_ndm: '00102162', tag_ary: [0x0010,0x2162], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,2180)', tag_name: "Occupation", tag_key: 'Occupation', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0010,2180)', tag_sym: :occupation, tag_ndm: '00102180', tag_ary: [0x0010,0x2180], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,21A0)', tag_name: "Smoking Status", tag_key: 'SmokingStatus', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0010,21A0)', tag_sym: :smoking_status, tag_ndm: '001021A0', tag_ary: [0x0010,0x21A0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,21B0)', tag_name: "Additional Patient History", tag_key: 'AdditionalPatientHistory', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(0010,21B0)', tag_sym: :additional_patient_history, tag_ndm: '001021B0', tag_ary: [0x0010,0x21B0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,21C0)', tag_name: "Pregnancy Status", tag_key: 'PregnancyStatus', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0010,21C0)', tag_sym: :pregnancy_status, tag_ndm: '001021C0', tag_ary: [0x0010,0x21C0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,21D0)', tag_name: "Last Menstrual Date", tag_key: 'LastMenstrualDate', tag_vr: [:DA], tag_vm: ["1"], tag_str: '(0010,21D0)', tag_sym: :last_menstrual_date, tag_ndm: '001021D0', tag_ary: [0x0010,0x21D0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,21F0)', tag_name: "Patient's Religious Preference", tag_key: 'PatientReligiousPreference', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0010,21F0)', tag_sym: :patient_religious_preference, tag_ndm: '001021F0', tag_ary: [0x0010,0x21F0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,2201)', tag_name: "Patient Species Description", tag_key: 'PatientSpeciesDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0010,2201)', tag_sym: :patient_species_description, tag_ndm: '00102201', tag_ary: [0x0010,0x2201], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,2202)', tag_name: "Patient Species Code Sequence", tag_key: 'PatientSpeciesCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0010,2202)', tag_sym: :patient_species_code_sequence, tag_ndm: '00102202', tag_ary: [0x0010,0x2202], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,2203)', tag_name: "Patient's Sex Neutered", tag_key: 'PatientSexNeutered', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0010,2203)', tag_sym: :patient_sex_neutered, tag_ndm: '00102203', tag_ary: [0x0010,0x2203], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,2210)', tag_name: "Anatomical Orientation Type", tag_key: 'AnatomicalOrientationType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0010,2210)', tag_sym: :anatomical_orientation_type, tag_ndm: '00102210', tag_ary: [0x0010,0x2210], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,2292)', tag_name: "Patient Breed Description", tag_key: 'PatientBreedDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0010,2292)', tag_sym: :patient_breed_description, tag_ndm: '00102292', tag_ary: [0x0010,0x2292], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,2293)', tag_name: "Patient Breed Code Sequence", tag_key: 'PatientBreedCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0010,2293)', tag_sym: :patient_breed_code_sequence, tag_ndm: '00102293', tag_ary: [0x0010,0x2293], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,2294)', tag_name: "Breed Registration Sequence", tag_key: 'BreedRegistrationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0010,2294)', tag_sym: :breed_registration_sequence, tag_ndm: '00102294', tag_ary: [0x0010,0x2294], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,2295)', tag_name: "Breed Registration Number", tag_key: 'BreedRegistrationNumber', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0010,2295)', tag_sym: :breed_registration_number, tag_ndm: '00102295', tag_ary: [0x0010,0x2295], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,2296)', tag_name: "Breed Registry Code Sequence", tag_key: 'BreedRegistryCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0010,2296)', tag_sym: :breed_registry_code_sequence, tag_ndm: '00102296', tag_ary: [0x0010,0x2296], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,2297)', tag_name: "Responsible Person", tag_key: 'ResponsiblePerson', tag_vr: [:PN], tag_vm: ["1"], tag_str: '(0010,2297)', tag_sym: :responsible_person, tag_ndm: '00102297', tag_ary: [0x0010,0x2297], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,2298)', tag_name: "Responsible Person Role", tag_key: 'ResponsiblePersonRole', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0010,2298)', tag_sym: :responsible_person_role, tag_ndm: '00102298', tag_ary: [0x0010,0x2298], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,2299)', tag_name: "Responsible Organization", tag_key: 'ResponsibleOrganization', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0010,2299)', tag_sym: :responsible_organization, tag_ndm: '00102299', tag_ary: [0x0010,0x2299], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,4000)', tag_name: "Patient Comments", tag_key: 'PatientComments', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(0010,4000)', tag_sym: :patient_comments, tag_ndm: '00104000', tag_ary: [0x0010,0x4000], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0010,9431)', tag_name: "Examined Body Thickness", tag_key: 'ExaminedBodyThickness', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0010,9431)', tag_sym: :examined_body_thickness, tag_ndm: '00109431', tag_ary: [0x0010,0x9431], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0012,0010)', tag_name: "Clinical Trial Sponsor Name", tag_key: 'ClinicalTrialSponsorName', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0012,0010)', tag_sym: :clinical_trial_sponsor_name, tag_ndm: '00120010', tag_ary: [0x0012,0x0010], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0012,0020)', tag_name: "Clinical Trial Protocol ID", tag_key: 'ClinicalTrialProtocolID', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0012,0020)', tag_sym: :clinical_trial_protocol_id, tag_ndm: '00120020', tag_ary: [0x0012,0x0020], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0012,0021)', tag_name: "Clinical Trial Protocol Name", tag_key: 'ClinicalTrialProtocolName', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0012,0021)', tag_sym: :clinical_trial_protocol_name, tag_ndm: '00120021', tag_ary: [0x0012,0x0021], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0012,0022)', tag_name: "Issuer of Clinical Trial Protocol ID", tag_key: 'IssuerOfClinicalTrialProtocolID', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0012,0022)', tag_sym: :issuer_of_clinical_trial_protocol_id, tag_ndm: '00120022', tag_ary: [0x0012,0x0022], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0012,0023)', tag_name: "Other Clinical Trial Protocol IDs Sequence", tag_key: 'OtherClinicalTrialProtocolIDsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0012,0023)', tag_sym: :other_clinical_trial_protocol_ids_sequence, tag_ndm: '00120023', tag_ary: [0x0012,0x0023], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0012,0030)', tag_name: "Clinical Trial Site ID", tag_key: 'ClinicalTrialSiteID', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0012,0030)', tag_sym: :clinical_trial_site_id, tag_ndm: '00120030', tag_ary: [0x0012,0x0030], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0012,0031)', tag_name: "Clinical Trial Site Name", tag_key: 'ClinicalTrialSiteName', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0012,0031)', tag_sym: :clinical_trial_site_name, tag_ndm: '00120031', tag_ary: [0x0012,0x0031], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0012,0032)', tag_name: "Issuer of Clinical Trial Site ID", tag_key: 'IssuerOfClinicalTrialSiteID', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0012,0032)', tag_sym: :issuer_of_clinical_trial_site_id, tag_ndm: '00120032', tag_ary: [0x0012,0x0032], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0012,0040)', tag_name: "Clinical Trial Subject ID", tag_key: 'ClinicalTrialSubjectID', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0012,0040)', tag_sym: :clinical_trial_subject_id, tag_ndm: '00120040', tag_ary: [0x0012,0x0040], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0012,0041)', tag_name: "Issuer of Clinical Trial Subject ID", tag_key: 'IssuerOfClinicalTrialSubjectID', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0012,0041)', tag_sym: :issuer_of_clinical_trial_subject_id, tag_ndm: '00120041', tag_ary: [0x0012,0x0041], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0012,0042)', tag_name: "Clinical Trial Subject Reading ID", tag_key: 'ClinicalTrialSubjectReadingID', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0012,0042)', tag_sym: :clinical_trial_subject_reading_id, tag_ndm: '00120042', tag_ary: [0x0012,0x0042], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0012,0043)', tag_name: "Issuer of Clinical Trial Subject Reading ID", tag_key: 'IssuerOfClinicalTrialSubjectReadingID', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0012,0043)', tag_sym: :issuer_of_clinical_trial_subject_reading_id, tag_ndm: '00120043', tag_ary: [0x0012,0x0043], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0012,0050)', tag_name: "Clinical Trial Time Point ID", tag_key: 'ClinicalTrialTimePointID', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0012,0050)', tag_sym: :clinical_trial_time_point_id, tag_ndm: '00120050', tag_ary: [0x0012,0x0050], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0012,0051)', tag_name: "Clinical Trial Time Point Description", tag_key: 'ClinicalTrialTimePointDescription', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0012,0051)', tag_sym: :clinical_trial_time_point_description, tag_ndm: '00120051', tag_ary: [0x0012,0x0051], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0012,0052)', tag_name: "Longitudinal Temporal Offset from Event", tag_key: 'LongitudinalTemporalOffsetFromEvent', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0012,0052)', tag_sym: :longitudinal_temporal_offset_from_event, tag_ndm: '00120052', tag_ary: [0x0012,0x0052], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0012,0053)', tag_name: "Longitudinal Temporal Event Type", tag_key: 'LongitudinalTemporalEventType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0012,0053)', tag_sym: :longitudinal_temporal_event_type, tag_ndm: '00120053', tag_ary: [0x0012,0x0053], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0012,0054)', tag_name: "Clinical Trial Time Point Type Code Sequence", tag_key: 'ClinicalTrialTimePointTypeCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0012,0054)', tag_sym: :clinical_trial_time_point_type_code_sequence, tag_ndm: '00120054', tag_ary: [0x0012,0x0054], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0012,0055)', tag_name: "Issuer of Clinical Trial Time Point ID", tag_key: 'IssuerOfClinicalTrialTimePointID', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0012,0055)', tag_sym: :issuer_of_clinical_trial_time_point_id, tag_ndm: '00120055', tag_ary: [0x0012,0x0055], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0012,0060)', tag_name: "Clinical Trial Coordinating Center Name", tag_key: 'ClinicalTrialCoordinatingCenterName', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0012,0060)', tag_sym: :clinical_trial_coordinating_center_name, tag_ndm: '00120060', tag_ary: [0x0012,0x0060], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0012,0062)', tag_name: "Patient Identity Removed", tag_key: 'PatientIdentityRemoved', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0012,0062)', tag_sym: :patient_identity_removed, tag_ndm: '00120062', tag_ary: [0x0012,0x0062], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0012,0063)', tag_name: "De-identification Method", tag_key: 'DeidentificationMethod', tag_vr: [:LO], tag_vm: ["1-n"], tag_str: '(0012,0063)', tag_sym: :deidentification_method, tag_ndm: '00120063', tag_ary: [0x0012,0x0063], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0012,0064)', tag_name: "De-identification Method Code Sequence", tag_key: 'DeidentificationMethodCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0012,0064)', tag_sym: :deidentification_method_code_sequence, tag_ndm: '00120064', tag_ary: [0x0012,0x0064], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0012,0071)', tag_name: "Clinical Trial Series ID", tag_key: 'ClinicalTrialSeriesID', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0012,0071)', tag_sym: :clinical_trial_series_id, tag_ndm: '00120071', tag_ary: [0x0012,0x0071], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0012,0072)', tag_name: "Clinical Trial Series Description", tag_key: 'ClinicalTrialSeriesDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0012,0072)', tag_sym: :clinical_trial_series_description, tag_ndm: '00120072', tag_ary: [0x0012,0x0072], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0012,0073)', tag_name: "Issuer of Clinical Trial Series ID", tag_key: 'IssuerOfClinicalTrialSeriesID', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0012,0073)', tag_sym: :issuer_of_clinical_trial_series_id, tag_ndm: '00120073', tag_ary: [0x0012,0x0073], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0012,0081)', tag_name: "Clinical Trial Protocol Ethics Committee Name", tag_key: 'ClinicalTrialProtocolEthicsCommitteeName', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0012,0081)', tag_sym: :clinical_trial_protocol_ethics_committee_name, tag_ndm: '00120081', tag_ary: [0x0012,0x0081], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0012,0082)', tag_name: "Clinical Trial Protocol Ethics Committee Approval Number", tag_key: 'ClinicalTrialProtocolEthicsCommitteeApprovalNumber', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0012,0082)', tag_sym: :clinical_trial_protocol_ethics_committee_approval_number, tag_ndm: '00120082', tag_ary: [0x0012,0x0082], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0012,0083)', tag_name: "Consent for Clinical Trial Use Sequence", tag_key: 'ConsentForClinicalTrialUseSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0012,0083)', tag_sym: :consent_for_clinical_trial_use_sequence, tag_ndm: '00120083', tag_ary: [0x0012,0x0083], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0012,0084)', tag_name: "Distribution Type", tag_key: 'DistributionType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0012,0084)', tag_sym: :distribution_type, tag_ndm: '00120084', tag_ary: [0x0012,0x0084], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0012,0085)', tag_name: "Consent for Distribution Flag", tag_key: 'ConsentForDistributionFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0012,0085)', tag_sym: :consent_for_distribution_flag, tag_ndm: '00120085', tag_ary: [0x0012,0x0085], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0012,0086)', tag_name: "Ethics Committee Approval Effectiveness Start Date", tag_key: 'EthicsCommitteeApprovalEffectivenessStartDate', tag_vr: [:DA], tag_vm: ["1"], tag_str: '(0012,0086)', tag_sym: :ethics_committee_approval_effectiveness_start_date, tag_ndm: '00120086', tag_ary: [0x0012,0x0086], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0012,0087)', tag_name: "Ethics Committee Approval Effectiveness End Date", tag_key: 'EthicsCommitteeApprovalEffectivenessEndDate', tag_vr: [:DA], tag_vm: ["1"], tag_str: '(0012,0087)', tag_sym: :ethics_committee_approval_effectiveness_end_date, tag_ndm: '00120087', tag_ary: [0x0012,0x0087], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0014,0023)', tag_name: "CAD File Format", tag_key: 'CADFileFormat', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0014,0023)', tag_sym: :cad_file_format, tag_ndm: '00140023', tag_ary: [0x0014,0x0023], tag_multiple: false, tag_note: 'RET (2011)'},
      { tag_ps: '(0014,0024)', tag_name: "Component Reference System", tag_key: 'ComponentReferenceSystem', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0014,0024)', tag_sym: :component_reference_system, tag_ndm: '00140024', tag_ary: [0x0014,0x0024], tag_multiple: false, tag_note: 'RET (2011)'},
      { tag_ps: '(0014,0025)', tag_name: "Component Manufacturing Procedure", tag_key: 'ComponentManufacturingProcedure', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0014,0025)', tag_sym: :component_manufacturing_procedure, tag_ndm: '00140025', tag_ary: [0x0014,0x0025], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,0028)', tag_name: "Component Manufacturer", tag_key: 'ComponentManufacturer', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0014,0028)', tag_sym: :component_manufacturer, tag_ndm: '00140028', tag_ary: [0x0014,0x0028], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,0030)', tag_name: "Material Thickness", tag_key: 'MaterialThickness', tag_vr: [:DS], tag_vm: ["1-n"], tag_str: '(0014,0030)', tag_sym: :material_thickness, tag_ndm: '00140030', tag_ary: [0x0014,0x0030], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,0032)', tag_name: "Material Pipe Diameter", tag_key: 'MaterialPipeDiameter', tag_vr: [:DS], tag_vm: ["1-n"], tag_str: '(0014,0032)', tag_sym: :material_pipe_diameter, tag_ndm: '00140032', tag_ary: [0x0014,0x0032], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,0034)', tag_name: "Material Isolation Diameter", tag_key: 'MaterialIsolationDiameter', tag_vr: [:DS], tag_vm: ["1-n"], tag_str: '(0014,0034)', tag_sym: :material_isolation_diameter, tag_ndm: '00140034', tag_ary: [0x0014,0x0034], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,0042)', tag_name: "Material Grade", tag_key: 'MaterialGrade', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0014,0042)', tag_sym: :material_grade, tag_ndm: '00140042', tag_ary: [0x0014,0x0042], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,0044)', tag_name: "Material Properties Description", tag_key: 'MaterialPropertiesDescription', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0014,0044)', tag_sym: :material_properties_description, tag_ndm: '00140044', tag_ary: [0x0014,0x0044], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,0045)', tag_name: "Material Properties File Format (Retired)", tag_key: 'MaterialPropertiesFileFormatRetired', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0014,0045)', tag_sym: :material_properties_file_format_retired, tag_ndm: '00140045', tag_ary: [0x0014,0x0045], tag_multiple: false, tag_note: 'RET (2011)'},
      { tag_ps: '(0014,0046)', tag_name: "Material Notes", tag_key: 'MaterialNotes', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(0014,0046)', tag_sym: :material_notes, tag_ndm: '00140046', tag_ary: [0x0014,0x0046], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,0050)', tag_name: "Component Shape", tag_key: 'ComponentShape', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0014,0050)', tag_sym: :component_shape, tag_ndm: '00140050', tag_ary: [0x0014,0x0050], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,0052)', tag_name: "Curvature Type", tag_key: 'CurvatureType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0014,0052)', tag_sym: :curvature_type, tag_ndm: '00140052', tag_ary: [0x0014,0x0052], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,0054)', tag_name: "Outer Diameter", tag_key: 'OuterDiameter', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,0054)', tag_sym: :outer_diameter, tag_ndm: '00140054', tag_ary: [0x0014,0x0054], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,0056)', tag_name: "Inner Diameter", tag_key: 'InnerDiameter', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,0056)', tag_sym: :inner_diameter, tag_ndm: '00140056', tag_ary: [0x0014,0x0056], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,0100)', tag_name: "Component Welder IDs", tag_key: 'ComponentWelderIDs', tag_vr: [:LO], tag_vm: ["1-n"], tag_str: '(0014,0100)', tag_sym: :component_welder_ids, tag_ndm: '00140100', tag_ary: [0x0014,0x0100], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,0101)', tag_name: "Secondary Approval Status", tag_key: 'SecondaryApprovalStatus', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0014,0101)', tag_sym: :secondary_approval_status, tag_ndm: '00140101', tag_ary: [0x0014,0x0101], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,0102)', tag_name: "Secondary Review Date", tag_key: 'SecondaryReviewDate', tag_vr: [:DA], tag_vm: ["1"], tag_str: '(0014,0102)', tag_sym: :secondary_review_date, tag_ndm: '00140102', tag_ary: [0x0014,0x0102], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,0103)', tag_name: "Secondary Review Time", tag_key: 'SecondaryReviewTime', tag_vr: [:TM], tag_vm: ["1"], tag_str: '(0014,0103)', tag_sym: :secondary_review_time, tag_ndm: '00140103', tag_ary: [0x0014,0x0103], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,0104)', tag_name: "Secondary Reviewer Name", tag_key: 'SecondaryReviewerName', tag_vr: [:PN], tag_vm: ["1"], tag_str: '(0014,0104)', tag_sym: :secondary_reviewer_name, tag_ndm: '00140104', tag_ary: [0x0014,0x0104], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,0105)', tag_name: "Repair ID", tag_key: 'RepairID', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0014,0105)', tag_sym: :repair_id, tag_ndm: '00140105', tag_ary: [0x0014,0x0105], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,0106)', tag_name: "Multiple Component Approval Sequence", tag_key: 'MultipleComponentApprovalSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0014,0106)', tag_sym: :multiple_component_approval_sequence, tag_ndm: '00140106', tag_ary: [0x0014,0x0106], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,0107)', tag_name: "Other Approval Status", tag_key: 'OtherApprovalStatus', tag_vr: [:CS], tag_vm: ["1-n"], tag_str: '(0014,0107)', tag_sym: :other_approval_status, tag_ndm: '00140107', tag_ary: [0x0014,0x0107], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,0108)', tag_name: "Other Secondary Approval Status", tag_key: 'OtherSecondaryApprovalStatus', tag_vr: [:CS], tag_vm: ["1-n"], tag_str: '(0014,0108)', tag_sym: :other_secondary_approval_status, tag_ndm: '00140108', tag_ary: [0x0014,0x0108], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,0200)', tag_name: "Data Element Label Sequence", tag_key: 'DataElementLabelSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0014,0200)', tag_sym: :data_element_label_sequence, tag_ndm: '00140200', tag_ary: [0x0014,0x0200], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,0201)', tag_name: "Data Element Label Item Sequence", tag_key: 'DataElementLabelItemSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0014,0201)', tag_sym: :data_element_label_item_sequence, tag_ndm: '00140201', tag_ary: [0x0014,0x0201], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,0202)', tag_name: "Data Element", tag_key: 'DataElement', tag_vr: [:AT], tag_vm: ["1"], tag_str: '(0014,0202)', tag_sym: :data_element, tag_ndm: '00140202', tag_ary: [0x0014,0x0202], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,0203)', tag_name: "Data Element Name", tag_key: 'DataElementName', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0014,0203)', tag_sym: :data_element_name, tag_ndm: '00140203', tag_ary: [0x0014,0x0203], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,0204)', tag_name: "Data Element Description", tag_key: 'DataElementDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0014,0204)', tag_sym: :data_element_description, tag_ndm: '00140204', tag_ary: [0x0014,0x0204], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,0205)', tag_name: "Data Element Conditionality", tag_key: 'DataElementConditionality', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0014,0205)', tag_sym: :data_element_conditionality, tag_ndm: '00140205', tag_ary: [0x0014,0x0205], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,0206)', tag_name: "Data Element Minimum Characters", tag_key: 'DataElementMinimumCharacters', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0014,0206)', tag_sym: :data_element_minimum_characters, tag_ndm: '00140206', tag_ary: [0x0014,0x0206], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,0207)', tag_name: "Data Element Maximum Characters", tag_key: 'DataElementMaximumCharacters', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0014,0207)', tag_sym: :data_element_maximum_characters, tag_ndm: '00140207', tag_ary: [0x0014,0x0207], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,1010)', tag_name: "Actual Environmental Conditions", tag_key: 'ActualEnvironmentalConditions', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0014,1010)', tag_sym: :actual_environmental_conditions, tag_ndm: '00141010', tag_ary: [0x0014,0x1010], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,1020)', tag_name: "Expiry Date", tag_key: 'ExpiryDate', tag_vr: [:DA], tag_vm: ["1"], tag_str: '(0014,1020)', tag_sym: :expiry_date, tag_ndm: '00141020', tag_ary: [0x0014,0x1020], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,1040)', tag_name: "Environmental Conditions", tag_key: 'EnvironmentalConditions', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0014,1040)', tag_sym: :environmental_conditions, tag_ndm: '00141040', tag_ary: [0x0014,0x1040], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,2002)', tag_name: "Evaluator Sequence", tag_key: 'EvaluatorSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0014,2002)', tag_sym: :evaluator_sequence, tag_ndm: '00142002', tag_ary: [0x0014,0x2002], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,2004)', tag_name: "Evaluator Number", tag_key: 'EvaluatorNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0014,2004)', tag_sym: :evaluator_number, tag_ndm: '00142004', tag_ary: [0x0014,0x2004], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,2006)', tag_name: "Evaluator Name", tag_key: 'EvaluatorName', tag_vr: [:PN], tag_vm: ["1"], tag_str: '(0014,2006)', tag_sym: :evaluator_name, tag_ndm: '00142006', tag_ary: [0x0014,0x2006], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,2008)', tag_name: "Evaluation Attempt", tag_key: 'EvaluationAttempt', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0014,2008)', tag_sym: :evaluation_attempt, tag_ndm: '00142008', tag_ary: [0x0014,0x2008], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,2012)', tag_name: "Indication Sequence", tag_key: 'IndicationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0014,2012)', tag_sym: :indication_sequence, tag_ndm: '00142012', tag_ary: [0x0014,0x2012], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,2014)', tag_name: "Indication Number", tag_key: 'IndicationNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0014,2014)', tag_sym: :indication_number, tag_ndm: '00142014', tag_ary: [0x0014,0x2014], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,2016)', tag_name: "Indication Label", tag_key: 'IndicationLabel', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0014,2016)', tag_sym: :indication_label, tag_ndm: '00142016', tag_ary: [0x0014,0x2016], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,2018)', tag_name: "Indication Description", tag_key: 'IndicationDescription', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0014,2018)', tag_sym: :indication_description, tag_ndm: '00142018', tag_ary: [0x0014,0x2018], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,201A)', tag_name: "Indication Type", tag_key: 'IndicationType', tag_vr: [:CS], tag_vm: ["1-n"], tag_str: '(0014,201A)', tag_sym: :indication_type, tag_ndm: '0014201A', tag_ary: [0x0014,0x201A], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,201C)', tag_name: "Indication Disposition", tag_key: 'IndicationDisposition', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0014,201C)', tag_sym: :indication_disposition, tag_ndm: '0014201C', tag_ary: [0x0014,0x201C], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,201E)', tag_name: "Indication ROI Sequence", tag_key: 'IndicationROISequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0014,201E)', tag_sym: :indication_roi_sequence, tag_ndm: '0014201E', tag_ary: [0x0014,0x201E], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,2030)', tag_name: "Indication Physical Property Sequence", tag_key: 'IndicationPhysicalPropertySequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0014,2030)', tag_sym: :indication_physical_property_sequence, tag_ndm: '00142030', tag_ary: [0x0014,0x2030], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,2032)', tag_name: "Property Label", tag_key: 'PropertyLabel', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0014,2032)', tag_sym: :property_label, tag_ndm: '00142032', tag_ary: [0x0014,0x2032], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,2202)', tag_name: "Coordinate System Number of Axes", tag_key: 'CoordinateSystemNumberOfAxes', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0014,2202)', tag_sym: :coordinate_system_number_of_axes, tag_ndm: '00142202', tag_ary: [0x0014,0x2202], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,2204)', tag_name: "Coordinate System Axes Sequence", tag_key: 'CoordinateSystemAxesSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0014,2204)', tag_sym: :coordinate_system_axes_sequence, tag_ndm: '00142204', tag_ary: [0x0014,0x2204], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,2206)', tag_name: "Coordinate System Axis Description", tag_key: 'CoordinateSystemAxisDescription', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0014,2206)', tag_sym: :coordinate_system_axis_description, tag_ndm: '00142206', tag_ary: [0x0014,0x2206], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,2208)', tag_name: "Coordinate System Data Set Mapping", tag_key: 'CoordinateSystemDataSetMapping', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0014,2208)', tag_sym: :coordinate_system_data_set_mapping, tag_ndm: '00142208', tag_ary: [0x0014,0x2208], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,220A)', tag_name: "Coordinate System Axis Number", tag_key: 'CoordinateSystemAxisNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0014,220A)', tag_sym: :coordinate_system_axis_number, tag_ndm: '0014220A', tag_ary: [0x0014,0x220A], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,220C)', tag_name: "Coordinate System Axis Type", tag_key: 'CoordinateSystemAxisType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0014,220C)', tag_sym: :coordinate_system_axis_type, tag_ndm: '0014220C', tag_ary: [0x0014,0x220C], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,220E)', tag_name: "Coordinate System Axis Units", tag_key: 'CoordinateSystemAxisUnits', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0014,220E)', tag_sym: :coordinate_system_axis_units, tag_ndm: '0014220E', tag_ary: [0x0014,0x220E], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,2210)', tag_name: "Coordinate System Axis Values", tag_key: 'CoordinateSystemAxisValues', tag_vr: [:OB], tag_vm: ["1"], tag_str: '(0014,2210)', tag_sym: :coordinate_system_axis_values, tag_ndm: '00142210', tag_ary: [0x0014,0x2210], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,2220)', tag_name: "Coordinate System Transform Sequence", tag_key: 'CoordinateSystemTransformSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0014,2220)', tag_sym: :coordinate_system_transform_sequence, tag_ndm: '00142220', tag_ary: [0x0014,0x2220], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,2222)', tag_name: "Transform Description", tag_key: 'TransformDescription', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0014,2222)', tag_sym: :transform_description, tag_ndm: '00142222', tag_ary: [0x0014,0x2222], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,2224)', tag_name: "Transform Number of Axes", tag_key: 'TransformNumberOfAxes', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0014,2224)', tag_sym: :transform_number_of_axes, tag_ndm: '00142224', tag_ary: [0x0014,0x2224], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,2226)', tag_name: "Transform Order of Axes", tag_key: 'TransformOrderOfAxes', tag_vr: [:IS], tag_vm: ["1-n"], tag_str: '(0014,2226)', tag_sym: :transform_order_of_axes, tag_ndm: '00142226', tag_ary: [0x0014,0x2226], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,2228)', tag_name: "Transformed Axis Units", tag_key: 'TransformedAxisUnits', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0014,2228)', tag_sym: :transformed_axis_units, tag_ndm: '00142228', tag_ary: [0x0014,0x2228], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,222A)', tag_name: "Coordinate System Transform Rotation and Scale Matrix", tag_key: 'CoordinateSystemTransformRotationAndScaleMatrix', tag_vr: [:DS], tag_vm: ["1-n"], tag_str: '(0014,222A)', tag_sym: :coordinate_system_transform_rotation_and_scale_matrix, tag_ndm: '0014222A', tag_ary: [0x0014,0x222A], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,222C)', tag_name: "Coordinate System Transform Translation Matrix", tag_key: 'CoordinateSystemTransformTranslationMatrix', tag_vr: [:DS], tag_vm: ["1-n"], tag_str: '(0014,222C)', tag_sym: :coordinate_system_transform_translation_matrix, tag_ndm: '0014222C', tag_ary: [0x0014,0x222C], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,3011)', tag_name: "Internal Detector Frame Time", tag_key: 'InternalDetectorFrameTime', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,3011)', tag_sym: :internal_detector_frame_time, tag_ndm: '00143011', tag_ary: [0x0014,0x3011], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,3012)', tag_name: "Number of Frames Integrated", tag_key: 'NumberOfFramesIntegrated', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,3012)', tag_sym: :number_of_frames_integrated, tag_ndm: '00143012', tag_ary: [0x0014,0x3012], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,3020)', tag_name: "Detector Temperature Sequence", tag_key: 'DetectorTemperatureSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0014,3020)', tag_sym: :detector_temperature_sequence, tag_ndm: '00143020', tag_ary: [0x0014,0x3020], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,3022)', tag_name: "Sensor Name", tag_key: 'SensorName', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0014,3022)', tag_sym: :sensor_name, tag_ndm: '00143022', tag_ary: [0x0014,0x3022], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,3024)', tag_name: "Horizontal Offset of Sensor", tag_key: 'HorizontalOffsetOfSensor', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,3024)', tag_sym: :horizontal_offset_of_sensor, tag_ndm: '00143024', tag_ary: [0x0014,0x3024], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,3026)', tag_name: "Vertical Offset of Sensor", tag_key: 'VerticalOffsetOfSensor', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,3026)', tag_sym: :vertical_offset_of_sensor, tag_ndm: '00143026', tag_ary: [0x0014,0x3026], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,3028)', tag_name: "Sensor Temperature", tag_key: 'SensorTemperature', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,3028)', tag_sym: :sensor_temperature, tag_ndm: '00143028', tag_ary: [0x0014,0x3028], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,3040)', tag_name: "Dark Current Sequence", tag_key: 'DarkCurrentSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0014,3040)', tag_sym: :dark_current_sequence, tag_ndm: '00143040', tag_ary: [0x0014,0x3040], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,3050)', tag_name: "Dark Current Counts", tag_key: 'DarkCurrentCounts', tag_vr: [:OB, :OW], tag_vm: ["1"], tag_str: '(0014,3050)', tag_sym: :dark_current_counts, tag_ndm: '00143050', tag_ary: [0x0014,0x3050], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,3060)', tag_name: "Gain Correction Reference Sequence", tag_key: 'GainCorrectionReferenceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0014,3060)', tag_sym: :gain_correction_reference_sequence, tag_ndm: '00143060', tag_ary: [0x0014,0x3060], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,3070)', tag_name: "Air Counts", tag_key: 'AirCounts', tag_vr: [:OB, :OW], tag_vm: ["1"], tag_str: '(0014,3070)', tag_sym: :air_counts, tag_ndm: '00143070', tag_ary: [0x0014,0x3070], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,3071)', tag_name: "KV Used in Gain Calibration", tag_key: 'KVUsedInGainCalibration', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,3071)', tag_sym: :kv_used_in_gain_calibration, tag_ndm: '00143071', tag_ary: [0x0014,0x3071], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,3072)', tag_name: "MA Used in Gain Calibration", tag_key: 'MAUsedInGainCalibration', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,3072)', tag_sym: :ma_used_in_gain_calibration, tag_ndm: '00143072', tag_ary: [0x0014,0x3072], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,3073)', tag_name: "Number of Frames Used for Integration", tag_key: 'NumberOfFramesUsedForIntegration', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,3073)', tag_sym: :number_of_frames_used_for_integration, tag_ndm: '00143073', tag_ary: [0x0014,0x3073], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,3074)', tag_name: "Filter Material Used in Gain Calibration", tag_key: 'FilterMaterialUsedInGainCalibration', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0014,3074)', tag_sym: :filter_material_used_in_gain_calibration, tag_ndm: '00143074', tag_ary: [0x0014,0x3074], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,3075)', tag_name: "Filter Thickness Used in Gain Calibration", tag_key: 'FilterThicknessUsedInGainCalibration', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,3075)', tag_sym: :filter_thickness_used_in_gain_calibration, tag_ndm: '00143075', tag_ary: [0x0014,0x3075], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,3076)', tag_name: "Date of Gain Calibration", tag_key: 'DateOfGainCalibration', tag_vr: [:DA], tag_vm: ["1"], tag_str: '(0014,3076)', tag_sym: :date_of_gain_calibration, tag_ndm: '00143076', tag_ary: [0x0014,0x3076], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,3077)', tag_name: "Time of Gain Calibration", tag_key: 'TimeOfGainCalibration', tag_vr: [:TM], tag_vm: ["1"], tag_str: '(0014,3077)', tag_sym: :time_of_gain_calibration, tag_ndm: '00143077', tag_ary: [0x0014,0x3077], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,3080)', tag_name: "Bad Pixel Image", tag_key: 'BadPixelImage', tag_vr: [:OB], tag_vm: ["1"], tag_str: '(0014,3080)', tag_sym: :bad_pixel_image, tag_ndm: '00143080', tag_ary: [0x0014,0x3080], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,3099)', tag_name: "Calibration Notes", tag_key: 'CalibrationNotes', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(0014,3099)', tag_sym: :calibration_notes, tag_ndm: '00143099', tag_ary: [0x0014,0x3099], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,3100)', tag_name: "Linearity Correction Technique", tag_key: 'LinearityCorrectionTechnique', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(0014,3100)', tag_sym: :linearity_correction_technique, tag_ndm: '00143100', tag_ary: [0x0014,0x3100], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,3101)', tag_name: "Beam Hardening Correction Technique", tag_key: 'BeamHardeningCorrectionTechnique', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(0014,3101)', tag_sym: :beam_hardening_correction_technique, tag_ndm: '00143101', tag_ary: [0x0014,0x3101], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4002)', tag_name: "Pulser Equipment Sequence", tag_key: 'PulserEquipmentSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0014,4002)', tag_sym: :pulser_equipment_sequence, tag_ndm: '00144002', tag_ary: [0x0014,0x4002], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4004)', tag_name: "Pulser Type", tag_key: 'PulserType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0014,4004)', tag_sym: :pulser_type, tag_ndm: '00144004', tag_ary: [0x0014,0x4004], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4006)', tag_name: "Pulser Notes", tag_key: 'PulserNotes', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(0014,4006)', tag_sym: :pulser_notes, tag_ndm: '00144006', tag_ary: [0x0014,0x4006], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4008)', tag_name: "Receiver Equipment Sequence", tag_key: 'ReceiverEquipmentSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0014,4008)', tag_sym: :receiver_equipment_sequence, tag_ndm: '00144008', tag_ary: [0x0014,0x4008], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,400A)', tag_name: "Amplifier Type", tag_key: 'AmplifierType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0014,400A)', tag_sym: :amplifier_type, tag_ndm: '0014400A', tag_ary: [0x0014,0x400A], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,400C)', tag_name: "Receiver Notes", tag_key: 'ReceiverNotes', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(0014,400C)', tag_sym: :receiver_notes, tag_ndm: '0014400C', tag_ary: [0x0014,0x400C], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,400E)', tag_name: "Pre-Amplifier Equipment Sequence", tag_key: 'PreAmplifierEquipmentSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0014,400E)', tag_sym: :pre_amplifier_equipment_sequence, tag_ndm: '0014400E', tag_ary: [0x0014,0x400E], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,400F)', tag_name: "Pre-Amplifier Notes", tag_key: 'PreAmplifierNotes', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(0014,400F)', tag_sym: :pre_amplifier_notes, tag_ndm: '0014400F', tag_ary: [0x0014,0x400F], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4010)', tag_name: "Transmit Transducer Sequence", tag_key: 'TransmitTransducerSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0014,4010)', tag_sym: :transmit_transducer_sequence, tag_ndm: '00144010', tag_ary: [0x0014,0x4010], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4011)', tag_name: "Receive Transducer Sequence", tag_key: 'ReceiveTransducerSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0014,4011)', tag_sym: :receive_transducer_sequence, tag_ndm: '00144011', tag_ary: [0x0014,0x4011], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4012)', tag_name: "Number of Elements", tag_key: 'NumberOfElements', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0014,4012)', tag_sym: :number_of_elements, tag_ndm: '00144012', tag_ary: [0x0014,0x4012], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4013)', tag_name: "Element Shape", tag_key: 'ElementShape', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0014,4013)', tag_sym: :element_shape, tag_ndm: '00144013', tag_ary: [0x0014,0x4013], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4014)', tag_name: "Element Dimension A", tag_key: 'ElementDimensionA', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,4014)', tag_sym: :element_dimension_a, tag_ndm: '00144014', tag_ary: [0x0014,0x4014], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4015)', tag_name: "Element Dimension B", tag_key: 'ElementDimensionB', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,4015)', tag_sym: :element_dimension_b, tag_ndm: '00144015', tag_ary: [0x0014,0x4015], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4016)', tag_name: "Element Pitch A", tag_key: 'ElementPitchA', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,4016)', tag_sym: :element_pitch_a, tag_ndm: '00144016', tag_ary: [0x0014,0x4016], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4017)', tag_name: "Measured Beam Dimension A", tag_key: 'MeasuredBeamDimensionA', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,4017)', tag_sym: :measured_beam_dimension_a, tag_ndm: '00144017', tag_ary: [0x0014,0x4017], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4018)', tag_name: "Measured Beam Dimension B", tag_key: 'MeasuredBeamDimensionB', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,4018)', tag_sym: :measured_beam_dimension_b, tag_ndm: '00144018', tag_ary: [0x0014,0x4018], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4019)', tag_name: "Location of Measured Beam Diameter", tag_key: 'LocationOfMeasuredBeamDiameter', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,4019)', tag_sym: :location_of_measured_beam_diameter, tag_ndm: '00144019', tag_ary: [0x0014,0x4019], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,401A)', tag_name: "Nominal Frequency", tag_key: 'NominalFrequency', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,401A)', tag_sym: :nominal_frequency, tag_ndm: '0014401A', tag_ary: [0x0014,0x401A], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,401B)', tag_name: "Measured Center Frequency", tag_key: 'MeasuredCenterFrequency', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,401B)', tag_sym: :measured_center_frequency, tag_ndm: '0014401B', tag_ary: [0x0014,0x401B], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,401C)', tag_name: "Measured Bandwidth", tag_key: 'MeasuredBandwidth', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,401C)', tag_sym: :measured_bandwidth, tag_ndm: '0014401C', tag_ary: [0x0014,0x401C], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,401D)', tag_name: "Element Pitch B", tag_key: 'ElementPitchB', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,401D)', tag_sym: :element_pitch_b, tag_ndm: '0014401D', tag_ary: [0x0014,0x401D], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4020)', tag_name: "Pulser Settings Sequence", tag_key: 'PulserSettingsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0014,4020)', tag_sym: :pulser_settings_sequence, tag_ndm: '00144020', tag_ary: [0x0014,0x4020], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4022)', tag_name: "Pulse Width", tag_key: 'PulseWidth', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,4022)', tag_sym: :pulse_width, tag_ndm: '00144022', tag_ary: [0x0014,0x4022], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4024)', tag_name: "Excitation Frequency", tag_key: 'ExcitationFrequency', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,4024)', tag_sym: :excitation_frequency, tag_ndm: '00144024', tag_ary: [0x0014,0x4024], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4026)', tag_name: "Modulation Type", tag_key: 'ModulationType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0014,4026)', tag_sym: :modulation_type, tag_ndm: '00144026', tag_ary: [0x0014,0x4026], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4028)', tag_name: "Damping", tag_key: 'Damping', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,4028)', tag_sym: :damping, tag_ndm: '00144028', tag_ary: [0x0014,0x4028], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4030)', tag_name: "Receiver Settings Sequence", tag_key: 'ReceiverSettingsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0014,4030)', tag_sym: :receiver_settings_sequence, tag_ndm: '00144030', tag_ary: [0x0014,0x4030], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4031)', tag_name: "Acquired Soundpath Length", tag_key: 'AcquiredSoundpathLength', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,4031)', tag_sym: :acquired_soundpath_length, tag_ndm: '00144031', tag_ary: [0x0014,0x4031], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4032)', tag_name: "Acquisition Compression Type", tag_key: 'AcquisitionCompressionType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0014,4032)', tag_sym: :acquisition_compression_type, tag_ndm: '00144032', tag_ary: [0x0014,0x4032], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4033)', tag_name: "Acquisition Sample Size", tag_key: 'AcquisitionSampleSize', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0014,4033)', tag_sym: :acquisition_sample_size, tag_ndm: '00144033', tag_ary: [0x0014,0x4033], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4034)', tag_name: "Rectifier Smoothing", tag_key: 'RectifierSmoothing', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,4034)', tag_sym: :rectifier_smoothing, tag_ndm: '00144034', tag_ary: [0x0014,0x4034], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4035)', tag_name: "DAC Sequence", tag_key: 'DACSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0014,4035)', tag_sym: :dac_sequence, tag_ndm: '00144035', tag_ary: [0x0014,0x4035], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4036)', tag_name: "DAC Type", tag_key: 'DACType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0014,4036)', tag_sym: :dac_type, tag_ndm: '00144036', tag_ary: [0x0014,0x4036], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4038)', tag_name: "DAC Gain Points", tag_key: 'DACGainPoints', tag_vr: [:DS], tag_vm: ["1-n"], tag_str: '(0014,4038)', tag_sym: :dac_gain_points, tag_ndm: '00144038', tag_ary: [0x0014,0x4038], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,403A)', tag_name: "DAC Time Points", tag_key: 'DACTimePoints', tag_vr: [:DS], tag_vm: ["1-n"], tag_str: '(0014,403A)', tag_sym: :dac_time_points, tag_ndm: '0014403A', tag_ary: [0x0014,0x403A], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,403C)', tag_name: "DAC Amplitude", tag_key: 'DACAmplitude', tag_vr: [:DS], tag_vm: ["1-n"], tag_str: '(0014,403C)', tag_sym: :dac_amplitude, tag_ndm: '0014403C', tag_ary: [0x0014,0x403C], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4040)', tag_name: "Pre-Amplifier Settings Sequence", tag_key: 'PreAmplifierSettingsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0014,4040)', tag_sym: :pre_amplifier_settings_sequence, tag_ndm: '00144040', tag_ary: [0x0014,0x4040], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4050)', tag_name: "Transmit Transducer Settings Sequence", tag_key: 'TransmitTransducerSettingsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0014,4050)', tag_sym: :transmit_transducer_settings_sequence, tag_ndm: '00144050', tag_ary: [0x0014,0x4050], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4051)', tag_name: "Receive Transducer Settings Sequence", tag_key: 'ReceiveTransducerSettingsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0014,4051)', tag_sym: :receive_transducer_settings_sequence, tag_ndm: '00144051', tag_ary: [0x0014,0x4051], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4052)', tag_name: "Incident Angle", tag_key: 'IncidentAngle', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,4052)', tag_sym: :incident_angle, tag_ndm: '00144052', tag_ary: [0x0014,0x4052], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4054)', tag_name: "Coupling Technique", tag_key: 'CouplingTechnique', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0014,4054)', tag_sym: :coupling_technique, tag_ndm: '00144054', tag_ary: [0x0014,0x4054], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4056)', tag_name: "Coupling Medium", tag_key: 'CouplingMedium', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0014,4056)', tag_sym: :coupling_medium, tag_ndm: '00144056', tag_ary: [0x0014,0x4056], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4057)', tag_name: "Coupling Velocity", tag_key: 'CouplingVelocity', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,4057)', tag_sym: :coupling_velocity, tag_ndm: '00144057', tag_ary: [0x0014,0x4057], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4058)', tag_name: "Probe Center Location X", tag_key: 'ProbeCenterLocationX', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,4058)', tag_sym: :probe_center_location_x, tag_ndm: '00144058', tag_ary: [0x0014,0x4058], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4059)', tag_name: "Probe Center Location Z", tag_key: 'ProbeCenterLocationZ', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,4059)', tag_sym: :probe_center_location_z, tag_ndm: '00144059', tag_ary: [0x0014,0x4059], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,405A)', tag_name: "Sound Path Length", tag_key: 'SoundPathLength', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,405A)', tag_sym: :sound_path_length, tag_ndm: '0014405A', tag_ary: [0x0014,0x405A], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,405C)', tag_name: "Delay Law Identifier", tag_key: 'DelayLawIdentifier', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0014,405C)', tag_sym: :delay_law_identifier, tag_ndm: '0014405C', tag_ary: [0x0014,0x405C], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4060)', tag_name: "Gate Settings Sequence", tag_key: 'GateSettingsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0014,4060)', tag_sym: :gate_settings_sequence, tag_ndm: '00144060', tag_ary: [0x0014,0x4060], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4062)', tag_name: "Gate Threshold", tag_key: 'GateThreshold', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,4062)', tag_sym: :gate_threshold, tag_ndm: '00144062', tag_ary: [0x0014,0x4062], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4064)', tag_name: "Velocity of Sound", tag_key: 'VelocityOfSound', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,4064)', tag_sym: :velocity_of_sound, tag_ndm: '00144064', tag_ary: [0x0014,0x4064], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4070)', tag_name: "Calibration Settings Sequence", tag_key: 'CalibrationSettingsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0014,4070)', tag_sym: :calibration_settings_sequence, tag_ndm: '00144070', tag_ary: [0x0014,0x4070], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4072)', tag_name: "Calibration Procedure", tag_key: 'CalibrationProcedure', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0014,4072)', tag_sym: :calibration_procedure, tag_ndm: '00144072', tag_ary: [0x0014,0x4072], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4074)', tag_name: "Procedure Version", tag_key: 'ProcedureVersion', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0014,4074)', tag_sym: :procedure_version, tag_ndm: '00144074', tag_ary: [0x0014,0x4074], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4076)', tag_name: "Procedure Creation Date", tag_key: 'ProcedureCreationDate', tag_vr: [:DA], tag_vm: ["1"], tag_str: '(0014,4076)', tag_sym: :procedure_creation_date, tag_ndm: '00144076', tag_ary: [0x0014,0x4076], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4078)', tag_name: "Procedure Expiration Date", tag_key: 'ProcedureExpirationDate', tag_vr: [:DA], tag_vm: ["1"], tag_str: '(0014,4078)', tag_sym: :procedure_expiration_date, tag_ndm: '00144078', tag_ary: [0x0014,0x4078], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,407A)', tag_name: "Procedure Last Modified Date", tag_key: 'ProcedureLastModifiedDate', tag_vr: [:DA], tag_vm: ["1"], tag_str: '(0014,407A)', tag_sym: :procedure_last_modified_date, tag_ndm: '0014407A', tag_ary: [0x0014,0x407A], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,407C)', tag_name: "Calibration Time", tag_key: 'CalibrationTime', tag_vr: [:TM], tag_vm: ["1-n"], tag_str: '(0014,407C)', tag_sym: :calibration_time, tag_ndm: '0014407C', tag_ary: [0x0014,0x407C], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,407E)', tag_name: "Calibration Date", tag_key: 'CalibrationDate', tag_vr: [:DA], tag_vm: ["1-n"], tag_str: '(0014,407E)', tag_sym: :calibration_date, tag_ndm: '0014407E', tag_ary: [0x0014,0x407E], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4080)', tag_name: "Probe Drive Equipment Sequence", tag_key: 'ProbeDriveEquipmentSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0014,4080)', tag_sym: :probe_drive_equipment_sequence, tag_ndm: '00144080', tag_ary: [0x0014,0x4080], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4081)', tag_name: "Drive Type", tag_key: 'DriveType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0014,4081)', tag_sym: :drive_type, tag_ndm: '00144081', tag_ary: [0x0014,0x4081], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4082)', tag_name: "Probe Drive Notes", tag_key: 'ProbeDriveNotes', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(0014,4082)', tag_sym: :probe_drive_notes, tag_ndm: '00144082', tag_ary: [0x0014,0x4082], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4083)', tag_name: "Drive Probe Sequence", tag_key: 'DriveProbeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0014,4083)', tag_sym: :drive_probe_sequence, tag_ndm: '00144083', tag_ary: [0x0014,0x4083], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4084)', tag_name: "Probe Inductance", tag_key: 'ProbeInductance', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,4084)', tag_sym: :probe_inductance, tag_ndm: '00144084', tag_ary: [0x0014,0x4084], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4085)', tag_name: "Probe Resistance", tag_key: 'ProbeResistance', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,4085)', tag_sym: :probe_resistance, tag_ndm: '00144085', tag_ary: [0x0014,0x4085], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4086)', tag_name: "Receive Probe Sequence", tag_key: 'ReceiveProbeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0014,4086)', tag_sym: :receive_probe_sequence, tag_ndm: '00144086', tag_ary: [0x0014,0x4086], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4087)', tag_name: "Probe Drive Settings Sequence", tag_key: 'ProbeDriveSettingsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0014,4087)', tag_sym: :probe_drive_settings_sequence, tag_ndm: '00144087', tag_ary: [0x0014,0x4087], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4088)', tag_name: "Bridge Resistors", tag_key: 'BridgeResistors', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,4088)', tag_sym: :bridge_resistors, tag_ndm: '00144088', tag_ary: [0x0014,0x4088], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4089)', tag_name: "Probe Orientation Angle", tag_key: 'ProbeOrientationAngle', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,4089)', tag_sym: :probe_orientation_angle, tag_ndm: '00144089', tag_ary: [0x0014,0x4089], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,408B)', tag_name: "User Selected Gain Y", tag_key: 'UserSelectedGainY', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,408B)', tag_sym: :user_selected_gain_y, tag_ndm: '0014408B', tag_ary: [0x0014,0x408B], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,408C)', tag_name: "User Selected Phase", tag_key: 'UserSelectedPhase', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,408C)', tag_sym: :user_selected_phase, tag_ndm: '0014408C', tag_ary: [0x0014,0x408C], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,408D)', tag_name: "User Selected Offset X", tag_key: 'UserSelectedOffsetX', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,408D)', tag_sym: :user_selected_offset_x, tag_ndm: '0014408D', tag_ary: [0x0014,0x408D], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,408E)', tag_name: "User Selected Offset Y", tag_key: 'UserSelectedOffsetY', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,408E)', tag_sym: :user_selected_offset_y, tag_ndm: '0014408E', tag_ary: [0x0014,0x408E], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4091)', tag_name: "Channel Settings Sequence", tag_key: 'ChannelSettingsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0014,4091)', tag_sym: :channel_settings_sequence, tag_ndm: '00144091', tag_ary: [0x0014,0x4091], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4092)', tag_name: "Channel Threshold", tag_key: 'ChannelThreshold', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,4092)', tag_sym: :channel_threshold, tag_ndm: '00144092', tag_ary: [0x0014,0x4092], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,409A)', tag_name: "Scanner Settings Sequence", tag_key: 'ScannerSettingsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0014,409A)', tag_sym: :scanner_settings_sequence, tag_ndm: '0014409A', tag_ary: [0x0014,0x409A], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,409B)', tag_name: "Scan Procedure", tag_key: 'ScanProcedure', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0014,409B)', tag_sym: :scan_procedure, tag_ndm: '0014409B', tag_ary: [0x0014,0x409B], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,409C)', tag_name: "Translation Rate X", tag_key: 'TranslationRateX', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,409C)', tag_sym: :translation_rate_x, tag_ndm: '0014409C', tag_ary: [0x0014,0x409C], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,409D)', tag_name: "Translation Rate Y", tag_key: 'TranslationRateY', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,409D)', tag_sym: :translation_rate_y, tag_ndm: '0014409D', tag_ary: [0x0014,0x409D], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,409F)', tag_name: "Channel Overlap", tag_key: 'ChannelOverlap', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,409F)', tag_sym: :channel_overlap, tag_ndm: '0014409F', tag_ary: [0x0014,0x409F], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,40A0)', tag_name: "Image Quality Indicator Type", tag_key: 'ImageQualityIndicatorType', tag_vr: [:LO], tag_vm: ["1-n"], tag_str: '(0014,40A0)', tag_sym: :image_quality_indicator_type, tag_ndm: '001440A0', tag_ary: [0x0014,0x40A0], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,40A1)', tag_name: "Image Quality Indicator Material", tag_key: 'ImageQualityIndicatorMaterial', tag_vr: [:LO], tag_vm: ["1-n"], tag_str: '(0014,40A1)', tag_sym: :image_quality_indicator_material, tag_ndm: '001440A1', tag_ary: [0x0014,0x40A1], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,40A2)', tag_name: "Image Quality Indicator Size", tag_key: 'ImageQualityIndicatorSize', tag_vr: [:LO], tag_vm: ["1-n"], tag_str: '(0014,40A2)', tag_sym: :image_quality_indicator_size, tag_ndm: '001440A2', tag_ary: [0x0014,0x40A2], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4101)', tag_name: "Wave Dimensions Definition Sequence", tag_key: 'WaveDimensionsDefinitionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0014,4101)', tag_sym: :wave_dimensions_definition_sequence, tag_ndm: '00144101', tag_ary: [0x0014,0x4101], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4102)', tag_name: "Wave Dimension Number", tag_key: 'WaveDimensionNumber', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0014,4102)', tag_sym: :wave_dimension_number, tag_ndm: '00144102', tag_ary: [0x0014,0x4102], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4103)', tag_name: "Wave Dimension Description", tag_key: 'WaveDimensionDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0014,4103)', tag_sym: :wave_dimension_description, tag_ndm: '00144103', tag_ary: [0x0014,0x4103], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4104)', tag_name: "Wave Dimension Unit", tag_key: 'WaveDimensionUnit', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0014,4104)', tag_sym: :wave_dimension_unit, tag_ndm: '00144104', tag_ary: [0x0014,0x4104], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4105)', tag_name: "Wave Dimension Value Type", tag_key: 'WaveDimensionValueType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0014,4105)', tag_sym: :wave_dimension_value_type, tag_ndm: '00144105', tag_ary: [0x0014,0x4105], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4106)', tag_name: "Wave Dimension Values Sequence", tag_key: 'WaveDimensionValuesSequence', tag_vr: [:SQ], tag_vm: ["1-n"], tag_str: '(0014,4106)', tag_sym: :wave_dimension_values_sequence, tag_ndm: '00144106', tag_ary: [0x0014,0x4106], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4107)', tag_name: "Referenced Wave Dimension", tag_key: 'ReferencedWaveDimension', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0014,4107)', tag_sym: :referenced_wave_dimension, tag_ndm: '00144107', tag_ary: [0x0014,0x4107], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4108)', tag_name: "Integer Numeric Value", tag_key: 'IntegerNumericValue', tag_vr: [:SL], tag_vm: ["1"], tag_str: '(0014,4108)', tag_sym: :integer_numeric_value, tag_ndm: '00144108', tag_ary: [0x0014,0x4108], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,4109)', tag_name: "Byte Numeric Value", tag_key: 'ByteNumericValue', tag_vr: [:OB], tag_vm: ["1"], tag_str: '(0014,4109)', tag_sym: :byte_numeric_value, tag_ndm: '00144109', tag_ary: [0x0014,0x4109], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,410A)', tag_name: "Short Numeric Value", tag_key: 'ShortNumericValue', tag_vr: [:OW], tag_vm: ["1"], tag_str: '(0014,410A)', tag_sym: :short_numeric_value, tag_ndm: '0014410A', tag_ary: [0x0014,0x410A], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,410B)', tag_name: "Single Precision Floating Point Numeric Value", tag_key: 'SinglePrecisionFloatingPointNumericValue', tag_vr: [:OF], tag_vm: ["1"], tag_str: '(0014,410B)', tag_sym: :single_precision_floating_point_numeric_value, tag_ndm: '0014410B', tag_ary: [0x0014,0x410B], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,410C)', tag_name: "Double Precision Floating Point Numeric Value", tag_key: 'DoublePrecisionFloatingPointNumericValue', tag_vr: [:OD], tag_vm: ["1"], tag_str: '(0014,410C)', tag_sym: :double_precision_floating_point_numeric_value, tag_ndm: '0014410C', tag_ary: [0x0014,0x410C], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,5002)', tag_name: "LINAC Energy", tag_key: 'LINACEnergy', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0014,5002)', tag_sym: :linac_energy, tag_ndm: '00145002', tag_ary: [0x0014,0x5002], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,5004)', tag_name: "LINAC Output", tag_key: 'LINACOutput', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0014,5004)', tag_sym: :linac_output, tag_ndm: '00145004', tag_ary: [0x0014,0x5004], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,5100)', tag_name: "Active Aperture", tag_key: 'ActiveAperture', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0014,5100)', tag_sym: :active_aperture, tag_ndm: '00145100', tag_ary: [0x0014,0x5100], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,5101)', tag_name: "Total Aperture", tag_key: 'TotalAperture', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,5101)', tag_sym: :total_aperture, tag_ndm: '00145101', tag_ary: [0x0014,0x5101], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,5102)', tag_name: "Aperture Elevation", tag_key: 'ApertureElevation', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,5102)', tag_sym: :aperture_elevation, tag_ndm: '00145102', tag_ary: [0x0014,0x5102], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,5103)', tag_name: "Main Lobe Angle", tag_key: 'MainLobeAngle', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,5103)', tag_sym: :main_lobe_angle, tag_ndm: '00145103', tag_ary: [0x0014,0x5103], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,5104)', tag_name: "Main Roof Angle", tag_key: 'MainRoofAngle', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,5104)', tag_sym: :main_roof_angle, tag_ndm: '00145104', tag_ary: [0x0014,0x5104], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,5105)', tag_name: "Connector Type", tag_key: 'ConnectorType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0014,5105)', tag_sym: :connector_type, tag_ndm: '00145105', tag_ary: [0x0014,0x5105], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,5106)', tag_name: "Wedge Model Number", tag_key: 'WedgeModelNumber', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0014,5106)', tag_sym: :wedge_model_number, tag_ndm: '00145106', tag_ary: [0x0014,0x5106], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,5107)', tag_name: "Wedge Angle Float", tag_key: 'WedgeAngleFloat', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,5107)', tag_sym: :wedge_angle_float, tag_ndm: '00145107', tag_ary: [0x0014,0x5107], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,5108)', tag_name: "Wedge Roof Angle", tag_key: 'WedgeRoofAngle', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,5108)', tag_sym: :wedge_roof_angle, tag_ndm: '00145108', tag_ary: [0x0014,0x5108], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,5109)', tag_name: "Wedge Element 1 Position", tag_key: 'WedgeElement1Position', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0014,5109)', tag_sym: :wedge_element1_position, tag_ndm: '00145109', tag_ary: [0x0014,0x5109], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,510A)', tag_name: "Wedge Material Velocity", tag_key: 'WedgeMaterialVelocity', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,510A)', tag_sym: :wedge_material_velocity, tag_ndm: '0014510A', tag_ary: [0x0014,0x510A], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,510B)', tag_name: "Wedge Material", tag_key: 'WedgeMaterial', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0014,510B)', tag_sym: :wedge_material, tag_ndm: '0014510B', tag_ary: [0x0014,0x510B], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,510C)', tag_name: "Wedge Offset Z", tag_key: 'WedgeOffsetZ', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,510C)', tag_sym: :wedge_offset_z, tag_ndm: '0014510C', tag_ary: [0x0014,0x510C], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,510D)', tag_name: "Wedge Origin Offset X", tag_key: 'WedgeOriginOffsetX', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,510D)', tag_sym: :wedge_origin_offset_x, tag_ndm: '0014510D', tag_ary: [0x0014,0x510D], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,510E)', tag_name: "Wedge Time Delay", tag_key: 'WedgeTimeDelay', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,510E)', tag_sym: :wedge_time_delay, tag_ndm: '0014510E', tag_ary: [0x0014,0x510E], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,510F)', tag_name: "Wedge Name", tag_key: 'WedgeName', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0014,510F)', tag_sym: :wedge_name, tag_ndm: '0014510F', tag_ary: [0x0014,0x510F], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,5110)', tag_name: "Wedge Manufacturer Name", tag_key: 'WedgeManufacturerName', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0014,5110)', tag_sym: :wedge_manufacturer_name, tag_ndm: '00145110', tag_ary: [0x0014,0x5110], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,5111)', tag_name: "Wedge Description", tag_key: 'WedgeDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0014,5111)', tag_sym: :wedge_description, tag_ndm: '00145111', tag_ary: [0x0014,0x5111], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,5112)', tag_name: "Nominal Beam Angle", tag_key: 'NominalBeamAngle', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,5112)', tag_sym: :nominal_beam_angle, tag_ndm: '00145112', tag_ary: [0x0014,0x5112], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,5113)', tag_name: "Wedge Offset X", tag_key: 'WedgeOffsetX', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,5113)', tag_sym: :wedge_offset_x, tag_ndm: '00145113', tag_ary: [0x0014,0x5113], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,5114)', tag_name: "Wedge Offset Y", tag_key: 'WedgeOffsetY', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,5114)', tag_sym: :wedge_offset_y, tag_ndm: '00145114', tag_ary: [0x0014,0x5114], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,5115)', tag_name: "Wedge Total Length", tag_key: 'WedgeTotalLength', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,5115)', tag_sym: :wedge_total_length, tag_ndm: '00145115', tag_ary: [0x0014,0x5115], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,5116)', tag_name: "Wedge In Contact Length", tag_key: 'WedgeInContactLength', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,5116)', tag_sym: :wedge_in_contact_length, tag_ndm: '00145116', tag_ary: [0x0014,0x5116], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,5117)', tag_name: "Wedge Front Gap", tag_key: 'WedgeFrontGap', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,5117)', tag_sym: :wedge_front_gap, tag_ndm: '00145117', tag_ary: [0x0014,0x5117], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,5118)', tag_name: "Wedge Total Height", tag_key: 'WedgeTotalHeight', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,5118)', tag_sym: :wedge_total_height, tag_ndm: '00145118', tag_ary: [0x0014,0x5118], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,5119)', tag_name: "Wedge Front Height", tag_key: 'WedgeFrontHeight', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,5119)', tag_sym: :wedge_front_height, tag_ndm: '00145119', tag_ary: [0x0014,0x5119], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,511A)', tag_name: "Wedge Rear Height", tag_key: 'WedgeRearHeight', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,511A)', tag_sym: :wedge_rear_height, tag_ndm: '0014511A', tag_ary: [0x0014,0x511A], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,511B)', tag_name: "Wedge Total Width", tag_key: 'WedgeTotalWidth', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,511B)', tag_sym: :wedge_total_width, tag_ndm: '0014511B', tag_ary: [0x0014,0x511B], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,511C)', tag_name: "Wedge In Contact Width", tag_key: 'WedgeInContactWidth', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,511C)', tag_sym: :wedge_in_contact_width, tag_ndm: '0014511C', tag_ary: [0x0014,0x511C], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,511D)', tag_name: "Wedge Chamfer Height", tag_key: 'WedgeChamferHeight', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,511D)', tag_sym: :wedge_chamfer_height, tag_ndm: '0014511D', tag_ary: [0x0014,0x511D], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,511E)', tag_name: "Wedge Curve", tag_key: 'WedgeCurve', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0014,511E)', tag_sym: :wedge_curve, tag_ndm: '0014511E', tag_ary: [0x0014,0x511E], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,511F)', tag_name: "Radius Along the Wedge", tag_key: 'RadiusAlongWedge', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,511F)', tag_sym: :radius_along_wedge, tag_ndm: '0014511F', tag_ary: [0x0014,0x511F], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,6001)', tag_name: "Thermal Camera Settings Sequence", tag_key: 'ThermalCameraSettingsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0014,6001)', tag_sym: :thermal_camera_settings_sequence, tag_ndm: '00146001', tag_ary: [0x0014,0x6001], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,6002)', tag_name: "Acquisition Frame Rate", tag_key: 'AcquisitionFrameRate', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,6002)', tag_sym: :acquisition_frame_rate, tag_ndm: '00146002', tag_ary: [0x0014,0x6002], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,6003)', tag_name: "Integration Time", tag_key: 'IntegrationTime', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,6003)', tag_sym: :integration_time, tag_ndm: '00146003', tag_ary: [0x0014,0x6003], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,6004)', tag_name: "Number of Calibration Frames", tag_key: 'NumberOfCalibrationFrames', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,6004)', tag_sym: :number_of_calibration_frames, tag_ndm: '00146004', tag_ary: [0x0014,0x6004], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,6005)', tag_name: "Number of Rows in Full Acquisition Image", tag_key: 'NumberOfRowsInFullAcquisitionImage', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,6005)', tag_sym: :number_of_rows_in_full_acquisition_image, tag_ndm: '00146005', tag_ary: [0x0014,0x6005], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,6006)', tag_name: "Number Of Columns in Full Acquisition Image", tag_key: 'NumberOfColumnsInFullAcquisitionImage', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,6006)', tag_sym: :number_of_columns_in_full_acquisition_image, tag_ndm: '00146006', tag_ary: [0x0014,0x6006], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,6007)', tag_name: "Thermal Source Settings Sequence", tag_key: 'ThermalSourceSettingsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0014,6007)', tag_sym: :thermal_source_settings_sequence, tag_ndm: '00146007', tag_ary: [0x0014,0x6007], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,6008)', tag_name: "Source Horizontal Pitch", tag_key: 'SourceHorizontalPitch', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,6008)', tag_sym: :source_horizontal_pitch, tag_ndm: '00146008', tag_ary: [0x0014,0x6008], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,6009)', tag_name: "Source Vertical Pitch", tag_key: 'SourceVerticalPitch', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,6009)', tag_sym: :source_vertical_pitch, tag_ndm: '00146009', tag_ary: [0x0014,0x6009], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,600A)', tag_name: "Source Horizontal Scan Speed", tag_key: 'SourceHorizontalScanSpeed', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,600A)', tag_sym: :source_horizontal_scan_speed, tag_ndm: '0014600A', tag_ary: [0x0014,0x600A], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,600B)', tag_name: "Thermal Source Modulation Frequency", tag_key: 'ThermalSourceModulationFrequency', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,600B)', tag_sym: :thermal_source_modulation_frequency, tag_ndm: '0014600B', tag_ary: [0x0014,0x600B], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,600C)', tag_name: "Induction Source Setting Sequence", tag_key: 'InductionSourceSettingSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0014,600C)', tag_sym: :induction_source_setting_sequence, tag_ndm: '0014600C', tag_ary: [0x0014,0x600C], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,600D)', tag_name: "Coil Frequency", tag_key: 'CoilFrequency', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,600D)', tag_sym: :coil_frequency, tag_ndm: '0014600D', tag_ary: [0x0014,0x600D], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,600E)', tag_name: "Current Amplitude Across Coil", tag_key: 'CurrentAmplitudeAcrossCoil', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,600E)', tag_sym: :current_amplitude_across_coil, tag_ndm: '0014600E', tag_ary: [0x0014,0x600E], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,600F)', tag_name: "Flash Source Setting Sequence", tag_key: 'FlashSourceSettingSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0014,600F)', tag_sym: :flash_source_setting_sequence, tag_ndm: '0014600F', tag_ary: [0x0014,0x600F], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,6010)', tag_name: "Flash Duration", tag_key: 'FlashDuration', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,6010)', tag_sym: :flash_duration, tag_ndm: '00146010', tag_ary: [0x0014,0x6010], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,6011)', tag_name: "Flash Frame Number", tag_key: 'FlashFrameNumber', tag_vr: [:DS], tag_vm: ["1-n"], tag_str: '(0014,6011)', tag_sym: :flash_frame_number, tag_ndm: '00146011', tag_ary: [0x0014,0x6011], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,6012)', tag_name: "Laser Source Setting Sequence", tag_key: 'LaserSourceSettingSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0014,6012)', tag_sym: :laser_source_setting_sequence, tag_ndm: '00146012', tag_ary: [0x0014,0x6012], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,6013)', tag_name: "Horizontal Laser Spot Dimension", tag_key: 'HorizontalLaserSpotDimension', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,6013)', tag_sym: :horizontal_laser_spot_dimension, tag_ndm: '00146013', tag_ary: [0x0014,0x6013], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,6014)', tag_name: "Vertical Laser Spot Dimension", tag_key: 'VerticalLaserSpotDimension', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,6014)', tag_sym: :vertical_laser_spot_dimension, tag_ndm: '00146014', tag_ary: [0x0014,0x6014], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,6015)', tag_name: "Laser Wavelength", tag_key: 'LaserWavelength', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,6015)', tag_sym: :laser_wavelength, tag_ndm: '00146015', tag_ary: [0x0014,0x6015], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,6016)', tag_name: "Laser Power", tag_key: 'LaserPower', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,6016)', tag_sym: :laser_power, tag_ndm: '00146016', tag_ary: [0x0014,0x6016], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,6017)', tag_name: "Forced Gas Setting Sequence", tag_key: 'ForcedGasSettingSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0014,6017)', tag_sym: :forced_gas_setting_sequence, tag_ndm: '00146017', tag_ary: [0x0014,0x6017], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,6018)', tag_name: "Vibration Source Setting Sequence", tag_key: 'VibrationSourceSettingSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0014,6018)', tag_sym: :vibration_source_setting_sequence, tag_ndm: '00146018', tag_ary: [0x0014,0x6018], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,6019)', tag_name: "Vibration Excitation Frequency", tag_key: 'VibrationExcitationFrequency', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,6019)', tag_sym: :vibration_excitation_frequency, tag_ndm: '00146019', tag_ary: [0x0014,0x6019], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,601A)', tag_name: "Vibration Excitation Voltage", tag_key: 'VibrationExcitationVoltage', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,601A)', tag_sym: :vibration_excitation_voltage, tag_ndm: '0014601A', tag_ary: [0x0014,0x601A], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,601B)', tag_name: "Thermography Data Capture Method", tag_key: 'ThermographyDataCaptureMethod', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0014,601B)', tag_sym: :thermography_data_capture_method, tag_ndm: '0014601B', tag_ary: [0x0014,0x601B], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,601C)', tag_name: "Thermal Technique", tag_key: 'ThermalTechnique', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0014,601C)', tag_sym: :thermal_technique, tag_ndm: '0014601C', tag_ary: [0x0014,0x601C], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,601D)', tag_name: "Thermal Camera Core Sequence", tag_key: 'ThermalCameraCoreSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0014,601D)', tag_sym: :thermal_camera_core_sequence, tag_ndm: '0014601D', tag_ary: [0x0014,0x601D], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,601E)', tag_name: "Detector Wavelength Range", tag_key: 'DetectorWavelengthRange', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0014,601E)', tag_sym: :detector_wavelength_range, tag_ndm: '0014601E', tag_ary: [0x0014,0x601E], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,601F)', tag_name: "Thermal Camera Calibration Type", tag_key: 'ThermalCameraCalibrationType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0014,601F)', tag_sym: :thermal_camera_calibration_type, tag_ndm: '0014601F', tag_ary: [0x0014,0x601F], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,6020)', tag_name: "Acquisition Image Counter", tag_key: 'AcquisitionImageCounter', tag_vr: [:UV], tag_vm: ["1"], tag_str: '(0014,6020)', tag_sym: :acquisition_image_counter, tag_ndm: '00146020', tag_ary: [0x0014,0x6020], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,6021)', tag_name: "Front Panel Temperature", tag_key: 'FrontPanelTemperature', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,6021)', tag_sym: :front_panel_temperature, tag_ndm: '00146021', tag_ary: [0x0014,0x6021], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,6022)', tag_name: "Air Gap Temperature", tag_key: 'AirGapTemperature', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,6022)', tag_sym: :air_gap_temperature, tag_ndm: '00146022', tag_ary: [0x0014,0x6022], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,6023)', tag_name: "Vertical Pixel Size", tag_key: 'VerticalPixelSize', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,6023)', tag_sym: :vertical_pixel_size, tag_ndm: '00146023', tag_ary: [0x0014,0x6023], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,6024)', tag_name: "Horizontal Pixel Size", tag_key: 'HorizontalPixelSize', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,6024)', tag_sym: :horizontal_pixel_size, tag_ndm: '00146024', tag_ary: [0x0014,0x6024], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,6025)', tag_name: "Data Streaming Protocol", tag_key: 'DataStreamingProtocol', tag_vr: [:ST], tag_vm: ["1-n"], tag_str: '(0014,6025)', tag_sym: :data_streaming_protocol, tag_ndm: '00146025', tag_ary: [0x0014,0x6025], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,6026)', tag_name: "Lens Sequence", tag_key: 'LensSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0014,6026)', tag_sym: :lens_sequence, tag_ndm: '00146026', tag_ary: [0x0014,0x6026], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,6027)', tag_name: "Field of View", tag_key: 'FieldOfView', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,6027)', tag_sym: :field_of_view, tag_ndm: '00146027', tag_ary: [0x0014,0x6027], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,6028)', tag_name: "Lens Filter Manufacturer", tag_key: 'LensFilterManufacturer', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0014,6028)', tag_sym: :lens_filter_manufacturer, tag_ndm: '00146028', tag_ary: [0x0014,0x6028], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,6029)', tag_name: "Cutoff Filter Type", tag_key: 'CutoffFilterType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0014,6029)', tag_sym: :cutoff_filter_type, tag_ndm: '00146029', tag_ary: [0x0014,0x6029], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,602A)', tag_name: "Lens Filter Cut-Off Wavelength", tag_key: 'LensFilterCutOffWavelength', tag_vr: [:DS], tag_vm: ["1-n"], tag_str: '(0014,602A)', tag_sym: :lens_filter_cut_off_wavelength, tag_ndm: '0014602A', tag_ary: [0x0014,0x602A], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,602B)', tag_name: "Thermal Source Sequence", tag_key: 'ThermalSourceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0014,602B)', tag_sym: :thermal_source_sequence, tag_ndm: '0014602B', tag_ary: [0x0014,0x602B], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,602C)', tag_name: "Thermal Source Motion State", tag_key: 'ThermalSourceMotionState', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0014,602C)', tag_sym: :thermal_source_motion_state, tag_ndm: '0014602C', tag_ary: [0x0014,0x602C], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,602D)', tag_name: "Thermal Source Motion Type", tag_key: 'ThermalSourceMotionType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0014,602D)', tag_sym: :thermal_source_motion_type, tag_ndm: '0014602D', tag_ary: [0x0014,0x602D], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,602E)', tag_name: "Induction Heating Sequence", tag_key: 'InductionHeatingSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0014,602E)', tag_sym: :induction_heating_sequence, tag_ndm: '0014602E', tag_ary: [0x0014,0x602E], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,602F)', tag_name: "Coil Configuration ID", tag_key: 'CoilConfigurationID', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0014,602F)', tag_sym: :coil_configuration_id, tag_ndm: '0014602F', tag_ary: [0x0014,0x602F], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,6030)', tag_name: "Number of Turns in Coil", tag_key: 'NumberOfTurnsInCoil', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,6030)', tag_sym: :number_of_turns_in_coil, tag_ndm: '00146030', tag_ary: [0x0014,0x6030], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,6031)', tag_name: "Shape of Individual Turn", tag_key: 'ShapeOfIndividualTurn', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0014,6031)', tag_sym: :shape_of_individual_turn, tag_ndm: '00146031', tag_ary: [0x0014,0x6031], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,6032)', tag_name: "Size of Individual Turn", tag_key: 'SizeOfIndividualTurn', tag_vr: [:DS], tag_vm: ["1-n"], tag_str: '(0014,6032)', tag_sym: :size_of_individual_turn, tag_ndm: '00146032', tag_ary: [0x0014,0x6032], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,6033)', tag_name: "Distance Between Turns", tag_key: 'DistanceBetweenTurns', tag_vr: [:DS], tag_vm: ["1-n"], tag_str: '(0014,6033)', tag_sym: :distance_between_turns, tag_ndm: '00146033', tag_ary: [0x0014,0x6033], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,6034)', tag_name: "Flash Heating Sequence", tag_key: 'FlashHeatingSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0014,6034)', tag_sym: :flash_heating_sequence, tag_ndm: '00146034', tag_ary: [0x0014,0x6034], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,6035)', tag_name: "Number of Lamps", tag_key: 'NumberOfLamps', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,6035)', tag_sym: :number_of_lamps, tag_ndm: '00146035', tag_ary: [0x0014,0x6035], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,6036)', tag_name: "Flash Synchronization Protocol", tag_key: 'FlashSynchronizationProtocol', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0014,6036)', tag_sym: :flash_synchronization_protocol, tag_ndm: '00146036', tag_ary: [0x0014,0x6036], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,6037)', tag_name: "Flash Modification Status", tag_key: 'FlashModificationStatus', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0014,6037)', tag_sym: :flash_modification_status, tag_ndm: '00146037', tag_ary: [0x0014,0x6037], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,6038)', tag_name: "Laser Heating Sequence", tag_key: 'LaserHeatingSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0014,6038)', tag_sym: :laser_heating_sequence, tag_ndm: '00146038', tag_ary: [0x0014,0x6038], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,6039)', tag_name: "Laser Manufacturer", tag_key: 'LaserManufacturer', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0014,6039)', tag_sym: :laser_manufacturer, tag_ndm: '00146039', tag_ary: [0x0014,0x6039], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,603A)', tag_name: "Laser Model Number", tag_key: 'LaserModelNumber', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0014,603A)', tag_sym: :laser_model_number, tag_ndm: '0014603A', tag_ary: [0x0014,0x603A], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,603B)', tag_name: "Laser Type Description", tag_key: 'LaserTypeDescription', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0014,603B)', tag_sym: :laser_type_description, tag_ndm: '0014603B', tag_ary: [0x0014,0x603B], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,603C)', tag_name: "Forced Gas Heating Sequence", tag_key: 'ForcedGasHeatingSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0014,603C)', tag_sym: :forced_gas_heating_sequence, tag_ndm: '0014603C', tag_ary: [0x0014,0x603C], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,603D)', tag_name: "Gas Used for Heating/Cooling Part", tag_key: 'GasUsedForHeatingCoolingPart', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0014,603D)', tag_sym: :gas_used_for_heating_cooling_part, tag_ndm: '0014603D', tag_ary: [0x0014,0x603D], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,603E)', tag_name: "Vibration/Sonic Heating Sequence", tag_key: 'VibrationSonicHeatingSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0014,603E)', tag_sym: :vibration_sonic_heating_sequence, tag_ndm: '0014603E', tag_ary: [0x0014,0x603E], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,603F)', tag_name: "Probe Manufacturer", tag_key: 'ProbeManufacturer', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0014,603F)', tag_sym: :probe_manufacturer, tag_ndm: '0014603F', tag_ary: [0x0014,0x603F], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,6040)', tag_name: "Probe Model Number", tag_key: 'ProbeModelNumber', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0014,6040)', tag_sym: :probe_model_number, tag_ndm: '00146040', tag_ary: [0x0014,0x6040], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,6041)', tag_name: "Aperture Size", tag_key: 'ApertureSize', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,6041)', tag_sym: :aperture_size, tag_ndm: '00146041', tag_ary: [0x0014,0x6041], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,6042)', tag_name: "Probe Resonant Frequency", tag_key: 'ProbeResonantFrequency', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,6042)', tag_sym: :probe_resonant_frequency, tag_ndm: '00146042', tag_ary: [0x0014,0x6042], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,6043)', tag_name: "Heat Source Description", tag_key: 'HeatSourceDescription', tag_vr: [:UT], tag_vm: ["1"], tag_str: '(0014,6043)', tag_sym: :heat_source_description, tag_ndm: '00146043', tag_ary: [0x0014,0x6043], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,6044)', tag_name: "Surface Preparation with Optical Coating", tag_key: 'SurfacePreparationWithOpticalCoating', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0014,6044)', tag_sym: :surface_preparation_with_optical_coating, tag_ndm: '00146044', tag_ary: [0x0014,0x6044], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,6045)', tag_name: "Optical Coating Type", tag_key: 'OpticalCoatingType', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0014,6045)', tag_sym: :optical_coating_type, tag_ndm: '00146045', tag_ary: [0x0014,0x6045], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,6046)', tag_name: "Thermal Conductivity of Exposed Surface", tag_key: 'ThermalConductivityOfExposedSurface', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,6046)', tag_sym: :thermal_conductivity_of_exposed_surface, tag_ndm: '00146046', tag_ary: [0x0014,0x6046], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,6047)', tag_name: "Material Density", tag_key: 'MaterialDensity', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,6047)', tag_sym: :material_density, tag_ndm: '00146047', tag_ary: [0x0014,0x6047], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,6048)', tag_name: "Specific Heat of Inspection Surface", tag_key: 'SpecificHeatOfInspectionSurface', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,6048)', tag_sym: :specific_heat_of_inspection_surface, tag_ndm: '00146048', tag_ary: [0x0014,0x6048], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,6049)', tag_name: "Emissivity of Inspection Surface", tag_key: 'EmissivityOfInspectionSurface', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,6049)', tag_sym: :emissivity_of_inspection_surface, tag_ndm: '00146049', tag_ary: [0x0014,0x6049], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,604A)', tag_name: "Electromagnetic Classification of Inspection Surface", tag_key: 'ElectromagneticClassificationOfInspectionSurface', tag_vr: [:CS], tag_vm: ["1-n"], tag_str: '(0014,604A)', tag_sym: :electromagnetic_classification_of_inspection_surface, tag_ndm: '0014604A', tag_ary: [0x0014,0x604A], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,604C)', tag_name: "Moving Window Size", tag_key: 'MovingWindowSize', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,604C)', tag_sym: :moving_window_size, tag_ndm: '0014604C', tag_ary: [0x0014,0x604C], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,604D)', tag_name: "Moving Window Type", tag_key: 'MovingWindowType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0014,604D)', tag_sym: :moving_window_type, tag_ndm: '0014604D', tag_ary: [0x0014,0x604D], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,604E)', tag_name: "Moving Window Weights", tag_key: 'MovingWindowWeights', tag_vr: [:DS], tag_vm: ["1-n"], tag_str: '(0014,604E)', tag_sym: :moving_window_weights, tag_ndm: '0014604E', tag_ary: [0x0014,0x604E], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,604F)', tag_name: "Moving Window Pitch", tag_key: 'MovingWindowPitch', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,604F)', tag_sym: :moving_window_pitch, tag_ndm: '0014604F', tag_ary: [0x0014,0x604F], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,6050)', tag_name: "Moving Window Padding Scheme", tag_key: 'MovingWindowPaddingScheme', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0014,6050)', tag_sym: :moving_window_padding_scheme, tag_ndm: '00146050', tag_ary: [0x0014,0x6050], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,6051)', tag_name: "Moving Window Padding Sength", tag_key: 'MovingWindowPaddingLength', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,6051)', tag_sym: :moving_window_padding_length, tag_ndm: '00146051', tag_ary: [0x0014,0x6051], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,6052)', tag_name: "Spatial Filtering Parameters Sequence", tag_key: 'SpatialFilteringParametersSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0014,6052)', tag_sym: :spatial_filtering_parameters_sequence, tag_ndm: '00146052', tag_ary: [0x0014,0x6052], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,6053)', tag_name: "Spatial Filtering Scheme", tag_key: 'SpatialFilteringScheme', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0014,6053)', tag_sym: :spatial_filtering_scheme, tag_ndm: '00146053', tag_ary: [0x0014,0x6053], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,6056)', tag_name: "Horizontal Moving Window Size", tag_key: 'HorizontalMovingWindowSize', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,6056)', tag_sym: :horizontal_moving_window_size, tag_ndm: '00146056', tag_ary: [0x0014,0x6056], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,6057)', tag_name: "Vertical Moving Window Size", tag_key: 'VerticalMovingWindowSize', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,6057)', tag_sym: :vertical_moving_window_size, tag_ndm: '00146057', tag_ary: [0x0014,0x6057], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,6059)', tag_name: "Polynomial Fitting Sequence", tag_key: 'PolynomialFittingSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0014,6059)', tag_sym: :polynomial_fitting_sequence, tag_ndm: '00146059', tag_ary: [0x0014,0x6059], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,605A)', tag_name: "Fitting Data Type", tag_key: 'FittingDataType', tag_vr: [:CS], tag_vm: ["1-n"], tag_str: '(0014,605A)', tag_sym: :fitting_data_type, tag_ndm: '0014605A', tag_ary: [0x0014,0x605A], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,605B)', tag_name: "Operation on Time Axis Before Fitting", tag_key: 'OperationOnTimeAxisBeforeFitting', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0014,605B)', tag_sym: :operation_on_time_axis_before_fitting, tag_ndm: '0014605B', tag_ary: [0x0014,0x605B], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,605C)', tag_name: "Operation on Pixel Intensity Before Fitting", tag_key: 'OperationOnPixelIntensityBeforeFitting', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0014,605C)', tag_sym: :operation_on_pixel_intensity_before_fitting, tag_ndm: '0014605C', tag_ary: [0x0014,0x605C], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,605D)', tag_name: "Order of Polynomial", tag_key: 'OrderOfPolynomial', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0014,605D)', tag_sym: :order_of_polynomial, tag_ndm: '0014605D', tag_ary: [0x0014,0x605D], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,605E)', tag_name: "Independent Variable for Polynomial Fit", tag_key: 'IndependentVariableForPolynomialFit', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0014,605E)', tag_sym: :independent_variable_for_polynomial_fit, tag_ndm: '0014605E', tag_ary: [0x0014,0x605E], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,605F)', tag_name: "PolynomialCoefficients", tag_key: 'PolynomialCoefficients', tag_vr: [:DS], tag_vm: ["1-n"], tag_str: '(0014,605F)', tag_sym: :polynomial_coefficients, tag_ndm: '0014605F', tag_ary: [0x0014,0x605F], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0014,6060)', tag_name: "Thermography Pixel Data Unit", tag_key: 'ThermographyPixelDataUnit', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0014,6060)', tag_sym: :thermography_pixel_data_unit, tag_ndm: '00146060', tag_ary: [0x0014,0x6060], tag_multiple: false, tag_note: 'DICONDE'},
      { tag_ps: '(0016,0001)', tag_name: "White Point", tag_key: 'WhitePoint', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0016,0001)', tag_sym: :white_point, tag_ndm: '00160001', tag_ary: [0x0016,0x0001], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0002)', tag_name: "Primary Chromaticities", tag_key: 'PrimaryChromaticities', tag_vr: [:DS], tag_vm: ["3"], tag_str: '(0016,0002)', tag_sym: :primary_chromaticities, tag_ndm: '00160002', tag_ary: [0x0016,0x0002], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0003)', tag_name: "Battery Level", tag_key: 'BatteryLevel', tag_vr: [:UT], tag_vm: ["1"], tag_str: '(0016,0003)', tag_sym: :battery_level, tag_ndm: '00160003', tag_ary: [0x0016,0x0003], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0004)', tag_name: "Exposure Time in Seconds", tag_key: 'ExposureTimeInSeconds', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0016,0004)', tag_sym: :exposure_time_in_seconds, tag_ndm: '00160004', tag_ary: [0x0016,0x0004], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0005)', tag_name: "F-Number", tag_key: 'FNumber', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0016,0005)', tag_sym: :f_number, tag_ndm: '00160005', tag_ary: [0x0016,0x0005], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0006)', tag_name: "OECF Rows", tag_key: 'OECFRows', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0016,0006)', tag_sym: :oecf_rows, tag_ndm: '00160006', tag_ary: [0x0016,0x0006], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0007)', tag_name: "OECF Columns", tag_key: 'OECFColumns', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0016,0007)', tag_sym: :oecf_columns, tag_ndm: '00160007', tag_ary: [0x0016,0x0007], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0008)', tag_name: "OECF Column Names", tag_key: 'OECFColumnNames', tag_vr: [:UC], tag_vm: ["1-n"], tag_str: '(0016,0008)', tag_sym: :oecf_column_names, tag_ndm: '00160008', tag_ary: [0x0016,0x0008], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0009)', tag_name: "OECF Values", tag_key: 'OECFValues', tag_vr: [:DS], tag_vm: ["1-n"], tag_str: '(0016,0009)', tag_sym: :oecf_values, tag_ndm: '00160009', tag_ary: [0x0016,0x0009], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,000A)', tag_name: "Spatial Frequency Response Rows", tag_key: 'SpatialFrequencyResponseRows', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0016,000A)', tag_sym: :spatial_frequency_response_rows, tag_ndm: '0016000A', tag_ary: [0x0016,0x000A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,000B)', tag_name: "Spatial Frequency Response Columns", tag_key: 'SpatialFrequencyResponseColumns', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0016,000B)', tag_sym: :spatial_frequency_response_columns, tag_ndm: '0016000B', tag_ary: [0x0016,0x000B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,000C)', tag_name: "Spatial Frequency Response Column Names", tag_key: 'SpatialFrequencyResponseColumnNames', tag_vr: [:UC], tag_vm: ["1-n"], tag_str: '(0016,000C)', tag_sym: :spatial_frequency_response_column_names, tag_ndm: '0016000C', tag_ary: [0x0016,0x000C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,000D)', tag_name: "Spatial Frequency Response Values", tag_key: 'SpatialFrequencyResponseValues', tag_vr: [:DS], tag_vm: ["1-n"], tag_str: '(0016,000D)', tag_sym: :spatial_frequency_response_values, tag_ndm: '0016000D', tag_ary: [0x0016,0x000D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,000E)', tag_name: "Color Filter Array Pattern Rows", tag_key: 'ColorFilterArrayPatternRows', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0016,000E)', tag_sym: :color_filter_array_pattern_rows, tag_ndm: '0016000E', tag_ary: [0x0016,0x000E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,000F)', tag_name: "Color Filter Array Pattern Columns", tag_key: 'ColorFilterArrayPatternColumns', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0016,000F)', tag_sym: :color_filter_array_pattern_columns, tag_ndm: '0016000F', tag_ary: [0x0016,0x000F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0010)', tag_name: "Color Filter Array Pattern Values", tag_key: 'ColorFilterArrayPatternValues', tag_vr: [:DS], tag_vm: ["1-n"], tag_str: '(0016,0010)', tag_sym: :color_filter_array_pattern_values, tag_ndm: '00160010', tag_ary: [0x0016,0x0010], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0011)', tag_name: "Flash Firing Status", tag_key: 'FlashFiringStatus', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0016,0011)', tag_sym: :flash_firing_status, tag_ndm: '00160011', tag_ary: [0x0016,0x0011], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0012)', tag_name: "Flash Return Status", tag_key: 'FlashReturnStatus', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0016,0012)', tag_sym: :flash_return_status, tag_ndm: '00160012', tag_ary: [0x0016,0x0012], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0013)', tag_name: "Flash Mode", tag_key: 'FlashMode', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0016,0013)', tag_sym: :flash_mode, tag_ndm: '00160013', tag_ary: [0x0016,0x0013], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0014)', tag_name: "Flash Function Present", tag_key: 'FlashFunctionPresent', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0016,0014)', tag_sym: :flash_function_present, tag_ndm: '00160014', tag_ary: [0x0016,0x0014], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0015)', tag_name: "Flash Red Eye Mode", tag_key: 'FlashRedEyeMode', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0016,0015)', tag_sym: :flash_red_eye_mode, tag_ndm: '00160015', tag_ary: [0x0016,0x0015], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0016)', tag_name: "Exposure Program", tag_key: 'ExposureProgram', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0016,0016)', tag_sym: :exposure_program, tag_ndm: '00160016', tag_ary: [0x0016,0x0016], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0017)', tag_name: "Spectral Sensitivity", tag_key: 'SpectralSensitivity', tag_vr: [:UT], tag_vm: ["1"], tag_str: '(0016,0017)', tag_sym: :spectral_sensitivity, tag_ndm: '00160017', tag_ary: [0x0016,0x0017], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0018)', tag_name: "Photographic Sensitivity", tag_key: 'PhotographicSensitivity', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0016,0018)', tag_sym: :photographic_sensitivity, tag_ndm: '00160018', tag_ary: [0x0016,0x0018], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0019)', tag_name: "Self Timer Mode", tag_key: 'SelfTimerMode', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0016,0019)', tag_sym: :self_timer_mode, tag_ndm: '00160019', tag_ary: [0x0016,0x0019], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,001A)', tag_name: "Sensitivity Type", tag_key: 'SensitivityType', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0016,001A)', tag_sym: :sensitivity_type, tag_ndm: '0016001A', tag_ary: [0x0016,0x001A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,001B)', tag_name: "Standard Output Sensitivity", tag_key: 'StandardOutputSensitivity', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0016,001B)', tag_sym: :standard_output_sensitivity, tag_ndm: '0016001B', tag_ary: [0x0016,0x001B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,001C)', tag_name: "Recommended Exposure Index", tag_key: 'RecommendedExposureIndex', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0016,001C)', tag_sym: :recommended_exposure_index, tag_ndm: '0016001C', tag_ary: [0x0016,0x001C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,001D)', tag_name: "ISO Speed", tag_key: 'ISOSpeed', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0016,001D)', tag_sym: :iso_speed, tag_ndm: '0016001D', tag_ary: [0x0016,0x001D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,001E)', tag_name: "ISO Speed Latitude yyy", tag_key: 'ISOSpeedLatitudeyyy', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0016,001E)', tag_sym: :iso_speed_latitudeyyy, tag_ndm: '0016001E', tag_ary: [0x0016,0x001E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,001F)', tag_name: "ISO Speed Latitude zzz", tag_key: 'ISOSpeedLatitudezzz', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0016,001F)', tag_sym: :iso_speed_latitudezzz, tag_ndm: '0016001F', tag_ary: [0x0016,0x001F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0020)', tag_name: "EXIF Version", tag_key: 'EXIFVersion', tag_vr: [:UT], tag_vm: ["1"], tag_str: '(0016,0020)', tag_sym: :exif_version, tag_ndm: '00160020', tag_ary: [0x0016,0x0020], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0021)', tag_name: "Shutter Speed Value", tag_key: 'ShutterSpeedValue', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0016,0021)', tag_sym: :shutter_speed_value, tag_ndm: '00160021', tag_ary: [0x0016,0x0021], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0022)', tag_name: "Aperture Value", tag_key: 'ApertureValue', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0016,0022)', tag_sym: :aperture_value, tag_ndm: '00160022', tag_ary: [0x0016,0x0022], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0023)', tag_name: "Brightness Value", tag_key: 'BrightnessValue', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0016,0023)', tag_sym: :brightness_value, tag_ndm: '00160023', tag_ary: [0x0016,0x0023], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0024)', tag_name: "Exposure Bias Value", tag_key: 'ExposureBiasValue', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0016,0024)', tag_sym: :exposure_bias_value, tag_ndm: '00160024', tag_ary: [0x0016,0x0024], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0025)', tag_name: "Max Aperture Value", tag_key: 'MaxApertureValue', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0016,0025)', tag_sym: :max_aperture_value, tag_ndm: '00160025', tag_ary: [0x0016,0x0025], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0026)', tag_name: "Subject Distance", tag_key: 'SubjectDistance', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0016,0026)', tag_sym: :subject_distance, tag_ndm: '00160026', tag_ary: [0x0016,0x0026], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0027)', tag_name: "Metering Mode", tag_key: 'MeteringMode', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0016,0027)', tag_sym: :metering_mode, tag_ndm: '00160027', tag_ary: [0x0016,0x0027], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0028)', tag_name: "Light Source", tag_key: 'LightSource', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0016,0028)', tag_sym: :light_source, tag_ndm: '00160028', tag_ary: [0x0016,0x0028], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0029)', tag_name: "Focal Length", tag_key: 'FocalLength', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0016,0029)', tag_sym: :focal_length, tag_ndm: '00160029', tag_ary: [0x0016,0x0029], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,002A)', tag_name: "Subject Area", tag_key: 'SubjectArea', tag_vr: [:IS], tag_vm: ["2-4"], tag_str: '(0016,002A)', tag_sym: :subject_area, tag_ndm: '0016002A', tag_ary: [0x0016,0x002A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,002B)', tag_name: "Maker Note", tag_key: 'MakerNote', tag_vr: [:OB], tag_vm: ["1"], tag_str: '(0016,002B)', tag_sym: :maker_note, tag_ndm: '0016002B', tag_ary: [0x0016,0x002B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0030)', tag_name: "Temperature", tag_key: 'Temperature', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0016,0030)', tag_sym: :temperature, tag_ndm: '00160030', tag_ary: [0x0016,0x0030], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0031)', tag_name: "Humidity", tag_key: 'Humidity', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0016,0031)', tag_sym: :humidity, tag_ndm: '00160031', tag_ary: [0x0016,0x0031], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0032)', tag_name: "Pressure", tag_key: 'Pressure', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0016,0032)', tag_sym: :pressure, tag_ndm: '00160032', tag_ary: [0x0016,0x0032], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0033)', tag_name: "Water Depth", tag_key: 'WaterDepth', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0016,0033)', tag_sym: :water_depth, tag_ndm: '00160033', tag_ary: [0x0016,0x0033], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0034)', tag_name: "Acceleration", tag_key: 'Acceleration', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0016,0034)', tag_sym: :acceleration, tag_ndm: '00160034', tag_ary: [0x0016,0x0034], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0035)', tag_name: "Camera Elevation Angle", tag_key: 'CameraElevationAngle', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0016,0035)', tag_sym: :camera_elevation_angle, tag_ndm: '00160035', tag_ary: [0x0016,0x0035], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0036)', tag_name: "Flash Energy", tag_key: 'FlashEnergy', tag_vr: [:DS], tag_vm: ["1-2"], tag_str: '(0016,0036)', tag_sym: :flash_energy, tag_ndm: '00160036', tag_ary: [0x0016,0x0036], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0037)', tag_name: "Subject Location", tag_key: 'SubjectLocation', tag_vr: [:IS], tag_vm: ["2"], tag_str: '(0016,0037)', tag_sym: :subject_location, tag_ndm: '00160037', tag_ary: [0x0016,0x0037], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0038)', tag_name: "Photographic Exposure Index", tag_key: 'PhotographicExposureIndex', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0016,0038)', tag_sym: :photographic_exposure_index, tag_ndm: '00160038', tag_ary: [0x0016,0x0038], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0039)', tag_name: "Sensing Method", tag_key: 'SensingMethod', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0016,0039)', tag_sym: :sensing_method, tag_ndm: '00160039', tag_ary: [0x0016,0x0039], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,003A)', tag_name: "File Source", tag_key: 'FileSource', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0016,003A)', tag_sym: :file_source, tag_ndm: '0016003A', tag_ary: [0x0016,0x003A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,003B)', tag_name: "Scene Type", tag_key: 'SceneType', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0016,003B)', tag_sym: :scene_type, tag_ndm: '0016003B', tag_ary: [0x0016,0x003B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0041)', tag_name: "Custom Rendered", tag_key: 'CustomRendered', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0016,0041)', tag_sym: :custom_rendered, tag_ndm: '00160041', tag_ary: [0x0016,0x0041], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0042)', tag_name: "Exposure Mode", tag_key: 'ExposureMode', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0016,0042)', tag_sym: :exposure_mode, tag_ndm: '00160042', tag_ary: [0x0016,0x0042], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0043)', tag_name: "White Balance", tag_key: 'WhiteBalance', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0016,0043)', tag_sym: :white_balance, tag_ndm: '00160043', tag_ary: [0x0016,0x0043], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0044)', tag_name: "Digital Zoom Ratio", tag_key: 'DigitalZoomRatio', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0016,0044)', tag_sym: :digital_zoom_ratio, tag_ndm: '00160044', tag_ary: [0x0016,0x0044], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0045)', tag_name: "Focal Length In 35mm Film", tag_key: 'FocalLengthIn35mmFilm', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0016,0045)', tag_sym: :focal_length_in35mm_film, tag_ndm: '00160045', tag_ary: [0x0016,0x0045], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0046)', tag_name: "Scene Capture Type", tag_key: 'SceneCaptureType', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0016,0046)', tag_sym: :scene_capture_type, tag_ndm: '00160046', tag_ary: [0x0016,0x0046], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0047)', tag_name: "Gain Control", tag_key: 'GainControl', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0016,0047)', tag_sym: :gain_control, tag_ndm: '00160047', tag_ary: [0x0016,0x0047], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0048)', tag_name: "Contrast", tag_key: 'Contrast', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0016,0048)', tag_sym: :contrast, tag_ndm: '00160048', tag_ary: [0x0016,0x0048], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0049)', tag_name: "Saturation", tag_key: 'Saturation', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0016,0049)', tag_sym: :saturation, tag_ndm: '00160049', tag_ary: [0x0016,0x0049], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,004A)', tag_name: "Sharpness", tag_key: 'Sharpness', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0016,004A)', tag_sym: :sharpness, tag_ndm: '0016004A', tag_ary: [0x0016,0x004A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,004B)', tag_name: "Device Setting Description", tag_key: 'DeviceSettingDescription', tag_vr: [:OB], tag_vm: ["1"], tag_str: '(0016,004B)', tag_sym: :device_setting_description, tag_ndm: '0016004B', tag_ary: [0x0016,0x004B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,004C)', tag_name: "Subject Distance Range", tag_key: 'SubjectDistanceRange', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0016,004C)', tag_sym: :subject_distance_range, tag_ndm: '0016004C', tag_ary: [0x0016,0x004C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,004D)', tag_name: "Camera Owner Name", tag_key: 'CameraOwnerName', tag_vr: [:UT], tag_vm: ["1"], tag_str: '(0016,004D)', tag_sym: :camera_owner_name, tag_ndm: '0016004D', tag_ary: [0x0016,0x004D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,004E)', tag_name: "Lens Specification", tag_key: 'LensSpecification', tag_vr: [:DS], tag_vm: ["4"], tag_str: '(0016,004E)', tag_sym: :lens_specification, tag_ndm: '0016004E', tag_ary: [0x0016,0x004E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,004F)', tag_name: "Lens Make", tag_key: 'LensMake', tag_vr: [:UT], tag_vm: ["1"], tag_str: '(0016,004F)', tag_sym: :lens_make, tag_ndm: '0016004F', tag_ary: [0x0016,0x004F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0050)', tag_name: "Lens Model", tag_key: 'LensModel', tag_vr: [:UT], tag_vm: ["1"], tag_str: '(0016,0050)', tag_sym: :lens_model, tag_ndm: '00160050', tag_ary: [0x0016,0x0050], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0051)', tag_name: "Lens Serial Number", tag_key: 'LensSerialNumber', tag_vr: [:UT], tag_vm: ["1"], tag_str: '(0016,0051)', tag_sym: :lens_serial_number, tag_ndm: '00160051', tag_ary: [0x0016,0x0051], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0061)', tag_name: "Interoperability Index", tag_key: 'InteroperabilityIndex', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0016,0061)', tag_sym: :interoperability_index, tag_ndm: '00160061', tag_ary: [0x0016,0x0061], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0062)', tag_name: "Interoperability Version", tag_key: 'InteroperabilityVersion', tag_vr: [:OB], tag_vm: ["1"], tag_str: '(0016,0062)', tag_sym: :interoperability_version, tag_ndm: '00160062', tag_ary: [0x0016,0x0062], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0070)', tag_name: "GPS Version ID", tag_key: 'GPSVersionID', tag_vr: [:OB], tag_vm: ["1"], tag_str: '(0016,0070)', tag_sym: :gps_version_id, tag_ndm: '00160070', tag_ary: [0x0016,0x0070], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0071)', tag_name: "GPS Latitude Ref", tag_key: 'GPSLatitudeRef', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0016,0071)', tag_sym: :gps_latitude_ref, tag_ndm: '00160071', tag_ary: [0x0016,0x0071], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0072)', tag_name: "GPS Latitude", tag_key: 'GPSLatitude', tag_vr: [:DS], tag_vm: ["3"], tag_str: '(0016,0072)', tag_sym: :gps_latitude, tag_ndm: '00160072', tag_ary: [0x0016,0x0072], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0073)', tag_name: "GPS Longitude Ref", tag_key: 'GPSLongitudeRef', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0016,0073)', tag_sym: :gps_longitude_ref, tag_ndm: '00160073', tag_ary: [0x0016,0x0073], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0074)', tag_name: "GPS Longitude", tag_key: 'GPSLongitude', tag_vr: [:DS], tag_vm: ["3"], tag_str: '(0016,0074)', tag_sym: :gps_longitude, tag_ndm: '00160074', tag_ary: [0x0016,0x0074], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0075)', tag_name: "GPS Altitude Ref", tag_key: 'GPSAltitudeRef', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0016,0075)', tag_sym: :gps_altitude_ref, tag_ndm: '00160075', tag_ary: [0x0016,0x0075], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0076)', tag_name: "GPS Altitude", tag_key: 'GPSAltitude', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0016,0076)', tag_sym: :gps_altitude, tag_ndm: '00160076', tag_ary: [0x0016,0x0076], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0077)', tag_name: "GPS Time Stamp", tag_key: 'GPSTimeStamp', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(0016,0077)', tag_sym: :gps_time_stamp, tag_ndm: '00160077', tag_ary: [0x0016,0x0077], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0078)', tag_name: "GPS Satellites", tag_key: 'GPSSatellites', tag_vr: [:UT], tag_vm: ["1"], tag_str: '(0016,0078)', tag_sym: :gps_satellites, tag_ndm: '00160078', tag_ary: [0x0016,0x0078], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0079)', tag_name: "GPS Status", tag_key: 'GPSStatus', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0016,0079)', tag_sym: :gps_status, tag_ndm: '00160079', tag_ary: [0x0016,0x0079], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,007A)', tag_name: "GPS Measure Mode", tag_key: 'GPSMeasureMode', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0016,007A)', tag_sym: :gps_measure_mode, tag_ndm: '0016007A', tag_ary: [0x0016,0x007A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,007B)', tag_name: "GPS DOP", tag_key: 'GPSDOP', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0016,007B)', tag_sym: :gpsdop, tag_ndm: '0016007B', tag_ary: [0x0016,0x007B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,007C)', tag_name: "GPS Speed Ref", tag_key: 'GPSSpeedRef', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0016,007C)', tag_sym: :gps_speed_ref, tag_ndm: '0016007C', tag_ary: [0x0016,0x007C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,007D)', tag_name: "GPS Speed", tag_key: 'GPSSpeed', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0016,007D)', tag_sym: :gps_speed, tag_ndm: '0016007D', tag_ary: [0x0016,0x007D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,007E)', tag_name: "GPS Track Ref", tag_key: 'GPSTrackRef', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0016,007E)', tag_sym: :gps_track_ref, tag_ndm: '0016007E', tag_ary: [0x0016,0x007E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,007F)', tag_name: "GPS Track", tag_key: 'GPSTrack', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0016,007F)', tag_sym: :gps_track, tag_ndm: '0016007F', tag_ary: [0x0016,0x007F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0080)', tag_name: "GPS Img Direction Ref", tag_key: 'GPSImgDirectionRef', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0016,0080)', tag_sym: :gps_img_direction_ref, tag_ndm: '00160080', tag_ary: [0x0016,0x0080], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0081)', tag_name: "GPS Img Direction", tag_key: 'GPSImgDirection', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0016,0081)', tag_sym: :gps_img_direction, tag_ndm: '00160081', tag_ary: [0x0016,0x0081], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0082)', tag_name: "GPS Map Datum", tag_key: 'GPSMapDatum', tag_vr: [:UT], tag_vm: ["1"], tag_str: '(0016,0082)', tag_sym: :gps_map_datum, tag_ndm: '00160082', tag_ary: [0x0016,0x0082], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0083)', tag_name: "GPS Dest Latitude Ref", tag_key: 'GPSDestLatitudeRef', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0016,0083)', tag_sym: :gps_dest_latitude_ref, tag_ndm: '00160083', tag_ary: [0x0016,0x0083], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0084)', tag_name: "GPS Dest Latitude", tag_key: 'GPSDestLatitude', tag_vr: [:DS], tag_vm: ["3"], tag_str: '(0016,0084)', tag_sym: :gps_dest_latitude, tag_ndm: '00160084', tag_ary: [0x0016,0x0084], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0085)', tag_name: "GPS Dest Longitude Ref", tag_key: 'GPSDestLongitudeRef', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0016,0085)', tag_sym: :gps_dest_longitude_ref, tag_ndm: '00160085', tag_ary: [0x0016,0x0085], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0086)', tag_name: "GPS Dest Longitude", tag_key: 'GPSDestLongitude', tag_vr: [:DS], tag_vm: ["3"], tag_str: '(0016,0086)', tag_sym: :gps_dest_longitude, tag_ndm: '00160086', tag_ary: [0x0016,0x0086], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0087)', tag_name: "GPS Dest Bearing Ref", tag_key: 'GPSDestBearingRef', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0016,0087)', tag_sym: :gps_dest_bearing_ref, tag_ndm: '00160087', tag_ary: [0x0016,0x0087], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0088)', tag_name: "GPS Dest Bearing", tag_key: 'GPSDestBearing', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0016,0088)', tag_sym: :gps_dest_bearing, tag_ndm: '00160088', tag_ary: [0x0016,0x0088], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,0089)', tag_name: "GPS Dest Distance Ref", tag_key: 'GPSDestDistanceRef', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0016,0089)', tag_sym: :gps_dest_distance_ref, tag_ndm: '00160089', tag_ary: [0x0016,0x0089], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,008A)', tag_name: "GPS Dest Distance", tag_key: 'GPSDestDistance', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0016,008A)', tag_sym: :gps_dest_distance, tag_ndm: '0016008A', tag_ary: [0x0016,0x008A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,008B)', tag_name: "GPS Processing Method", tag_key: 'GPSProcessingMethod', tag_vr: [:OB], tag_vm: ["1"], tag_str: '(0016,008B)', tag_sym: :gps_processing_method, tag_ndm: '0016008B', tag_ary: [0x0016,0x008B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,008C)', tag_name: "GPS Area Information", tag_key: 'GPSAreaInformation', tag_vr: [:OB], tag_vm: ["1"], tag_str: '(0016,008C)', tag_sym: :gps_area_information, tag_ndm: '0016008C', tag_ary: [0x0016,0x008C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,008D)', tag_name: "GPS Date Stamp", tag_key: 'GPSDateStamp', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(0016,008D)', tag_sym: :gps_date_stamp, tag_ndm: '0016008D', tag_ary: [0x0016,0x008D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,008E)', tag_name: "GPS Differential", tag_key: 'GPSDifferential', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0016,008E)', tag_sym: :gps_differential, tag_ndm: '0016008E', tag_ary: [0x0016,0x008E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,1001)', tag_name: "Light Source Polarization", tag_key: 'LightSourcePolarization', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0016,1001)', tag_sym: :light_source_polarization, tag_ndm: '00161001', tag_ary: [0x0016,0x1001], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,1002)', tag_name: "Emitter Color Temperature", tag_key: 'EmitterColorTemperature', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0016,1002)', tag_sym: :emitter_color_temperature, tag_ndm: '00161002', tag_ary: [0x0016,0x1002], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,1003)', tag_name: "Contact Method", tag_key: 'ContactMethod', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0016,1003)', tag_sym: :contact_method, tag_ndm: '00161003', tag_ary: [0x0016,0x1003], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,1004)', tag_name: "Immersion Media", tag_key: 'ImmersionMedia', tag_vr: [:CS], tag_vm: ["1-n"], tag_str: '(0016,1004)', tag_sym: :immersion_media, tag_ndm: '00161004', tag_ary: [0x0016,0x1004], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0016,1005)', tag_name: "Optical Magnification Factor", tag_key: 'OpticalMagnificationFactor', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0016,1005)', tag_sym: :optical_magnification_factor, tag_ndm: '00161005', tag_ary: [0x0016,0x1005], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,0010)', tag_name: "Contrast/Bolus Agent", tag_key: 'ContrastBolusAgent', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0018,0010)', tag_sym: :contrast_bolus_agent, tag_ndm: '00180010', tag_ary: [0x0018,0x0010], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,0012)', tag_name: "Contrast/Bolus Agent Sequence", tag_key: 'ContrastBolusAgentSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,0012)', tag_sym: :contrast_bolus_agent_sequence, tag_ndm: '00180012', tag_ary: [0x0018,0x0012], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,0013)', tag_name: "Contrast/Bolus T1 Relaxivity", tag_key: 'ContrastBolusT1Relaxivity', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0018,0013)', tag_sym: :contrast_bolus_t1_relaxivity, tag_ndm: '00180013', tag_ary: [0x0018,0x0013], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,0014)', tag_name: "Contrast/Bolus Administration Route Sequence", tag_key: 'ContrastBolusAdministrationRouteSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,0014)', tag_sym: :contrast_bolus_administration_route_sequence, tag_ndm: '00180014', tag_ary: [0x0018,0x0014], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,0015)', tag_name: "Body Part Examined", tag_key: 'BodyPartExamined', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,0015)', tag_sym: :body_part_examined, tag_ndm: '00180015', tag_ary: [0x0018,0x0015], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,0020)', tag_name: "Scanning Sequence", tag_key: 'ScanningSequence', tag_vr: [:CS], tag_vm: ["1-n"], tag_str: '(0018,0020)', tag_sym: :scanning_sequence, tag_ndm: '00180020', tag_ary: [0x0018,0x0020], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,0021)', tag_name: "Sequence Variant", tag_key: 'SequenceVariant', tag_vr: [:CS], tag_vm: ["1-n"], tag_str: '(0018,0021)', tag_sym: :sequence_variant, tag_ndm: '00180021', tag_ary: [0x0018,0x0021], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,0022)', tag_name: "Scan Options", tag_key: 'ScanOptions', tag_vr: [:CS], tag_vm: ["1-n"], tag_str: '(0018,0022)', tag_sym: :scan_options, tag_ndm: '00180022', tag_ary: [0x0018,0x0022], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,0023)', tag_name: "MR Acquisition Type", tag_key: 'MRAcquisitionType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,0023)', tag_sym: :mr_acquisition_type, tag_ndm: '00180023', tag_ary: [0x0018,0x0023], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,0024)', tag_name: "Sequence Name", tag_key: 'SequenceName', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0018,0024)', tag_sym: :sequence_name, tag_ndm: '00180024', tag_ary: [0x0018,0x0024], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,0025)', tag_name: "Angio Flag", tag_key: 'AngioFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,0025)', tag_sym: :angio_flag, tag_ndm: '00180025', tag_ary: [0x0018,0x0025], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,0026)', tag_name: "Intervention Drug Information Sequence", tag_key: 'InterventionDrugInformationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,0026)', tag_sym: :intervention_drug_information_sequence, tag_ndm: '00180026', tag_ary: [0x0018,0x0026], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,0027)', tag_name: "Intervention Drug Stop Time", tag_key: 'InterventionDrugStopTime', tag_vr: [:TM], tag_vm: ["1"], tag_str: '(0018,0027)', tag_sym: :intervention_drug_stop_time, tag_ndm: '00180027', tag_ary: [0x0018,0x0027], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,0028)', tag_name: "Intervention Drug Dose", tag_key: 'InterventionDrugDose', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,0028)', tag_sym: :intervention_drug_dose, tag_ndm: '00180028', tag_ary: [0x0018,0x0028], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,0029)', tag_name: "Intervention Drug Code Sequence", tag_key: 'InterventionDrugCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,0029)', tag_sym: :intervention_drug_code_sequence, tag_ndm: '00180029', tag_ary: [0x0018,0x0029], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,002A)', tag_name: "Additional Drug Sequence", tag_key: 'AdditionalDrugSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,002A)', tag_sym: :additional_drug_sequence, tag_ndm: '0018002A', tag_ary: [0x0018,0x002A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,0030)', tag_name: "Radionuclide", tag_key: 'Radionuclide', tag_vr: [:LO], tag_vm: ["1-n"], tag_str: '(0018,0030)', tag_sym: :radionuclide, tag_ndm: '00180030', tag_ary: [0x0018,0x0030], tag_multiple: false, tag_note: 'RET (1993)'},
      { tag_ps: '(0018,0031)', tag_name: "Radiopharmaceutical", tag_key: 'Radiopharmaceutical', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0018,0031)', tag_sym: :radiopharmaceutical, tag_ndm: '00180031', tag_ary: [0x0018,0x0031], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,0032)', tag_name: "Energy Window Centerline", tag_key: 'EnergyWindowCenterline', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,0032)', tag_sym: :energy_window_centerline, tag_ndm: '00180032', tag_ary: [0x0018,0x0032], tag_multiple: false, tag_note: 'RET (1993)'},
      { tag_ps: '(0018,0033)', tag_name: "Energy Window Total Width", tag_key: 'EnergyWindowTotalWidth', tag_vr: [:DS], tag_vm: ["1-n"], tag_str: '(0018,0033)', tag_sym: :energy_window_total_width, tag_ndm: '00180033', tag_ary: [0x0018,0x0033], tag_multiple: false, tag_note: 'RET (1993)'},
      { tag_ps: '(0018,0034)', tag_name: "Intervention Drug Name", tag_key: 'InterventionDrugName', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0018,0034)', tag_sym: :intervention_drug_name, tag_ndm: '00180034', tag_ary: [0x0018,0x0034], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,0035)', tag_name: "Intervention Drug Start Time", tag_key: 'InterventionDrugStartTime', tag_vr: [:TM], tag_vm: ["1"], tag_str: '(0018,0035)', tag_sym: :intervention_drug_start_time, tag_ndm: '00180035', tag_ary: [0x0018,0x0035], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,0036)', tag_name: "Intervention Sequence", tag_key: 'InterventionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,0036)', tag_sym: :intervention_sequence, tag_ndm: '00180036', tag_ary: [0x0018,0x0036], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,0037)', tag_name: "Therapy Type", tag_key: 'TherapyType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,0037)', tag_sym: :therapy_type, tag_ndm: '00180037', tag_ary: [0x0018,0x0037], tag_multiple: false, tag_note: 'RET (2001)'},
      { tag_ps: '(0018,0038)', tag_name: "Intervention Status", tag_key: 'InterventionStatus', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,0038)', tag_sym: :intervention_status, tag_ndm: '00180038', tag_ary: [0x0018,0x0038], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,0039)', tag_name: "Therapy Description", tag_key: 'TherapyDescription', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,0039)', tag_sym: :therapy_description, tag_ndm: '00180039', tag_ary: [0x0018,0x0039], tag_multiple: false, tag_note: 'RET (2003)'},
      { tag_ps: '(0018,003A)', tag_name: "Intervention Description", tag_key: 'InterventionDescription', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0018,003A)', tag_sym: :intervention_description, tag_ndm: '0018003A', tag_ary: [0x0018,0x003A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,0040)', tag_name: "Cine Rate", tag_key: 'CineRate', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0018,0040)', tag_sym: :cine_rate, tag_ndm: '00180040', tag_ary: [0x0018,0x0040], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,0042)', tag_name: "Initial Cine Run State", tag_key: 'InitialCineRunState', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,0042)', tag_sym: :initial_cine_run_state, tag_ndm: '00180042', tag_ary: [0x0018,0x0042], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,0050)', tag_name: "Slice Thickness", tag_key: 'SliceThickness', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,0050)', tag_sym: :slice_thickness, tag_ndm: '00180050', tag_ary: [0x0018,0x0050], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,0060)', tag_name: "KVP", tag_key: 'KVP', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,0060)', tag_sym: :kvp, tag_ndm: '00180060', tag_ary: [0x0018,0x0060], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,0061)', tag_name: "Placeholder (0018,0061)", tag_key: 'Placeholder_0018_0061', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,0061)', tag_sym: :placeholder_0018_0061, tag_ndm: '00180061', tag_ary: [0x0018,0x0061], tag_multiple: false, tag_note: 'RET (2015c)'},
      { tag_ps: '(0018,0070)', tag_name: "Counts Accumulated", tag_key: 'CountsAccumulated', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0018,0070)', tag_sym: :counts_accumulated, tag_ndm: '00180070', tag_ary: [0x0018,0x0070], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,0071)', tag_name: "Acquisition Termination Condition", tag_key: 'AcquisitionTerminationCondition', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,0071)', tag_sym: :acquisition_termination_condition, tag_ndm: '00180071', tag_ary: [0x0018,0x0071], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,0072)', tag_name: "Effective Duration", tag_key: 'EffectiveDuration', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,0072)', tag_sym: :effective_duration, tag_ndm: '00180072', tag_ary: [0x0018,0x0072], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,0073)', tag_name: "Acquisition Start Condition", tag_key: 'AcquisitionStartCondition', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,0073)', tag_sym: :acquisition_start_condition, tag_ndm: '00180073', tag_ary: [0x0018,0x0073], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,0074)', tag_name: "Acquisition Start Condition Data", tag_key: 'AcquisitionStartConditionData', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0018,0074)', tag_sym: :acquisition_start_condition_data, tag_ndm: '00180074', tag_ary: [0x0018,0x0074], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,0075)', tag_name: "Acquisition Termination Condition Data", tag_key: 'AcquisitionTerminationConditionData', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0018,0075)', tag_sym: :acquisition_termination_condition_data, tag_ndm: '00180075', tag_ary: [0x0018,0x0075], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,0080)', tag_name: "Repetition Time", tag_key: 'RepetitionTime', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,0080)', tag_sym: :repetition_time, tag_ndm: '00180080', tag_ary: [0x0018,0x0080], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,0081)', tag_name: "Echo Time", tag_key: 'EchoTime', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,0081)', tag_sym: :echo_time, tag_ndm: '00180081', tag_ary: [0x0018,0x0081], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,0082)', tag_name: "Inversion Time", tag_key: 'InversionTime', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,0082)', tag_sym: :inversion_time, tag_ndm: '00180082', tag_ary: [0x0018,0x0082], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,0083)', tag_name: "Number of Averages", tag_key: 'NumberOfAverages', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,0083)', tag_sym: :number_of_averages, tag_ndm: '00180083', tag_ary: [0x0018,0x0083], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,0084)', tag_name: "Imaging Frequency", tag_key: 'ImagingFrequency', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,0084)', tag_sym: :imaging_frequency, tag_ndm: '00180084', tag_ary: [0x0018,0x0084], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,0085)', tag_name: "Imaged Nucleus", tag_key: 'ImagedNucleus', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0018,0085)', tag_sym: :imaged_nucleus, tag_ndm: '00180085', tag_ary: [0x0018,0x0085], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,0086)', tag_name: "Echo Number(s)", tag_key: 'EchoNumbers', tag_vr: [:IS], tag_vm: ["1-n"], tag_str: '(0018,0086)', tag_sym: :echo_numbers, tag_ndm: '00180086', tag_ary: [0x0018,0x0086], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,0087)', tag_name: "Magnetic Field Strength", tag_key: 'MagneticFieldStrength', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,0087)', tag_sym: :magnetic_field_strength, tag_ndm: '00180087', tag_ary: [0x0018,0x0087], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,0088)', tag_name: "Spacing Between Slices", tag_key: 'SpacingBetweenSlices', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,0088)', tag_sym: :spacing_between_slices, tag_ndm: '00180088', tag_ary: [0x0018,0x0088], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,0089)', tag_name: "Number of Phase Encoding Steps", tag_key: 'NumberOfPhaseEncodingSteps', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0018,0089)', tag_sym: :number_of_phase_encoding_steps, tag_ndm: '00180089', tag_ary: [0x0018,0x0089], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,0090)', tag_name: "Data Collection Diameter", tag_key: 'DataCollectionDiameter', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,0090)', tag_sym: :data_collection_diameter, tag_ndm: '00180090', tag_ary: [0x0018,0x0090], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,0091)', tag_name: "Echo Train Length", tag_key: 'EchoTrainLength', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0018,0091)', tag_sym: :echo_train_length, tag_ndm: '00180091', tag_ary: [0x0018,0x0091], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,0093)', tag_name: "Percent Sampling", tag_key: 'PercentSampling', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,0093)', tag_sym: :percent_sampling, tag_ndm: '00180093', tag_ary: [0x0018,0x0093], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,0094)', tag_name: "Percent Phase Field of View", tag_key: 'PercentPhaseFieldOfView', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,0094)', tag_sym: :percent_phase_field_of_view, tag_ndm: '00180094', tag_ary: [0x0018,0x0094], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,0095)', tag_name: "Pixel Bandwidth", tag_key: 'PixelBandwidth', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,0095)', tag_sym: :pixel_bandwidth, tag_ndm: '00180095', tag_ary: [0x0018,0x0095], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1000)', tag_name: "Device Serial Number", tag_key: 'DeviceSerialNumber', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0018,1000)', tag_sym: :device_serial_number, tag_ndm: '00181000', tag_ary: [0x0018,0x1000], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1002)', tag_name: "Device UID", tag_key: 'DeviceUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0018,1002)', tag_sym: :device_uid, tag_ndm: '00181002', tag_ary: [0x0018,0x1002], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1003)', tag_name: "Device ID", tag_key: 'DeviceID', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0018,1003)', tag_sym: :device_id, tag_ndm: '00181003', tag_ary: [0x0018,0x1003], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1004)', tag_name: "Plate ID", tag_key: 'PlateID', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0018,1004)', tag_sym: :plate_id, tag_ndm: '00181004', tag_ary: [0x0018,0x1004], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1005)', tag_name: "Generator ID", tag_key: 'GeneratorID', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0018,1005)', tag_sym: :generator_id, tag_ndm: '00181005', tag_ary: [0x0018,0x1005], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1006)', tag_name: "Grid ID", tag_key: 'GridID', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0018,1006)', tag_sym: :grid_id, tag_ndm: '00181006', tag_ary: [0x0018,0x1006], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1007)', tag_name: "Cassette ID", tag_key: 'CassetteID', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0018,1007)', tag_sym: :cassette_id, tag_ndm: '00181007', tag_ary: [0x0018,0x1007], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1008)', tag_name: "Gantry ID", tag_key: 'GantryID', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0018,1008)', tag_sym: :gantry_id, tag_ndm: '00181008', tag_ary: [0x0018,0x1008], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1009)', tag_name: "Unique Device Identifier", tag_key: 'UniqueDeviceIdentifier', tag_vr: [:UT], tag_vm: ["1"], tag_str: '(0018,1009)', tag_sym: :unique_device_identifier, tag_ndm: '00181009', tag_ary: [0x0018,0x1009], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,100A)', tag_name: "UDI Sequence", tag_key: 'UDISequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,100A)', tag_sym: :udi_sequence, tag_ndm: '0018100A', tag_ary: [0x0018,0x100A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,100B)', tag_name: "Manufacturer's Device Class UID", tag_key: 'ManufacturerDeviceClassUID', tag_vr: [:UI], tag_vm: ["1-n"], tag_str: '(0018,100B)', tag_sym: :manufacturer_device_class_uid, tag_ndm: '0018100B', tag_ary: [0x0018,0x100B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1010)', tag_name: "Secondary Capture Device ID", tag_key: 'SecondaryCaptureDeviceID', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0018,1010)', tag_sym: :secondary_capture_device_id, tag_ndm: '00181010', tag_ary: [0x0018,0x1010], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1011)', tag_name: "Hardcopy Creation Device ID", tag_key: 'HardcopyCreationDeviceID', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0018,1011)', tag_sym: :hardcopy_creation_device_id, tag_ndm: '00181011', tag_ary: [0x0018,0x1011], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0018,1012)', tag_name: "Date of Secondary Capture", tag_key: 'DateOfSecondaryCapture', tag_vr: [:DA], tag_vm: ["1"], tag_str: '(0018,1012)', tag_sym: :date_of_secondary_capture, tag_ndm: '00181012', tag_ary: [0x0018,0x1012], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1014)', tag_name: "Time of Secondary Capture", tag_key: 'TimeOfSecondaryCapture', tag_vr: [:TM], tag_vm: ["1"], tag_str: '(0018,1014)', tag_sym: :time_of_secondary_capture, tag_ndm: '00181014', tag_ary: [0x0018,0x1014], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1016)', tag_name: "Secondary Capture Device Manufacturer", tag_key: 'SecondaryCaptureDeviceManufacturer', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0018,1016)', tag_sym: :secondary_capture_device_manufacturer, tag_ndm: '00181016', tag_ary: [0x0018,0x1016], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1017)', tag_name: "Hardcopy Device Manufacturer", tag_key: 'HardcopyDeviceManufacturer', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0018,1017)', tag_sym: :hardcopy_device_manufacturer, tag_ndm: '00181017', tag_ary: [0x0018,0x1017], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0018,1018)', tag_name: "Secondary Capture Device Manufacturer's Model Name", tag_key: 'SecondaryCaptureDeviceManufacturerModelName', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0018,1018)', tag_sym: :secondary_capture_device_manufacturer_model_name, tag_ndm: '00181018', tag_ary: [0x0018,0x1018], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1019)', tag_name: "Secondary Capture Device Software Versions", tag_key: 'SecondaryCaptureDeviceSoftwareVersions', tag_vr: [:LO], tag_vm: ["1-n"], tag_str: '(0018,1019)', tag_sym: :secondary_capture_device_software_versions, tag_ndm: '00181019', tag_ary: [0x0018,0x1019], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,101A)', tag_name: "Hardcopy Device Software Version", tag_key: 'HardcopyDeviceSoftwareVersion', tag_vr: [:LO], tag_vm: ["1-n"], tag_str: '(0018,101A)', tag_sym: :hardcopy_device_software_version, tag_ndm: '0018101A', tag_ary: [0x0018,0x101A], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0018,101B)', tag_name: "Hardcopy Device Manufacturer's Model Name", tag_key: 'HardcopyDeviceManufacturerModelName', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0018,101B)', tag_sym: :hardcopy_device_manufacturer_model_name, tag_ndm: '0018101B', tag_ary: [0x0018,0x101B], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0018,1020)', tag_name: "Software Versions", tag_key: 'SoftwareVersions', tag_vr: [:LO], tag_vm: ["1-n"], tag_str: '(0018,1020)', tag_sym: :software_versions, tag_ndm: '00181020', tag_ary: [0x0018,0x1020], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1022)', tag_name: "Video Image Format Acquired", tag_key: 'VideoImageFormatAcquired', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0018,1022)', tag_sym: :video_image_format_acquired, tag_ndm: '00181022', tag_ary: [0x0018,0x1022], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1023)', tag_name: "Digital Image Format Acquired", tag_key: 'DigitalImageFormatAcquired', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0018,1023)', tag_sym: :digital_image_format_acquired, tag_ndm: '00181023', tag_ary: [0x0018,0x1023], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1030)', tag_name: "Protocol Name", tag_key: 'ProtocolName', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0018,1030)', tag_sym: :protocol_name, tag_ndm: '00181030', tag_ary: [0x0018,0x1030], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1040)', tag_name: "Contrast/Bolus Route", tag_key: 'ContrastBolusRoute', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0018,1040)', tag_sym: :contrast_bolus_route, tag_ndm: '00181040', tag_ary: [0x0018,0x1040], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1041)', tag_name: "Contrast/Bolus Volume", tag_key: 'ContrastBolusVolume', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,1041)', tag_sym: :contrast_bolus_volume, tag_ndm: '00181041', tag_ary: [0x0018,0x1041], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1042)', tag_name: "Contrast/Bolus Start Time", tag_key: 'ContrastBolusStartTime', tag_vr: [:TM], tag_vm: ["1"], tag_str: '(0018,1042)', tag_sym: :contrast_bolus_start_time, tag_ndm: '00181042', tag_ary: [0x0018,0x1042], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1043)', tag_name: "Contrast/Bolus Stop Time", tag_key: 'ContrastBolusStopTime', tag_vr: [:TM], tag_vm: ["1"], tag_str: '(0018,1043)', tag_sym: :contrast_bolus_stop_time, tag_ndm: '00181043', tag_ary: [0x0018,0x1043], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1044)', tag_name: "Contrast/Bolus Total Dose", tag_key: 'ContrastBolusTotalDose', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,1044)', tag_sym: :contrast_bolus_total_dose, tag_ndm: '00181044', tag_ary: [0x0018,0x1044], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1045)', tag_name: "Syringe Counts", tag_key: 'SyringeCounts', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0018,1045)', tag_sym: :syringe_counts, tag_ndm: '00181045', tag_ary: [0x0018,0x1045], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1046)', tag_name: "Contrast Flow Rate", tag_key: 'ContrastFlowRate', tag_vr: [:DS], tag_vm: ["1-n"], tag_str: '(0018,1046)', tag_sym: :contrast_flow_rate, tag_ndm: '00181046', tag_ary: [0x0018,0x1046], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1047)', tag_name: "Contrast Flow Duration", tag_key: 'ContrastFlowDuration', tag_vr: [:DS], tag_vm: ["1-n"], tag_str: '(0018,1047)', tag_sym: :contrast_flow_duration, tag_ndm: '00181047', tag_ary: [0x0018,0x1047], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1048)', tag_name: "Contrast/Bolus Ingredient", tag_key: 'ContrastBolusIngredient', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,1048)', tag_sym: :contrast_bolus_ingredient, tag_ndm: '00181048', tag_ary: [0x0018,0x1048], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1049)', tag_name: "Contrast/Bolus Ingredient Concentration", tag_key: 'ContrastBolusIngredientConcentration', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,1049)', tag_sym: :contrast_bolus_ingredient_concentration, tag_ndm: '00181049', tag_ary: [0x0018,0x1049], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1050)', tag_name: "Spatial Resolution", tag_key: 'SpatialResolution', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,1050)', tag_sym: :spatial_resolution, tag_ndm: '00181050', tag_ary: [0x0018,0x1050], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1060)', tag_name: "Trigger Time", tag_key: 'TriggerTime', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,1060)', tag_sym: :trigger_time, tag_ndm: '00181060', tag_ary: [0x0018,0x1060], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1061)', tag_name: "Trigger Source or Type", tag_key: 'TriggerSourceOrType', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0018,1061)', tag_sym: :trigger_source_or_type, tag_ndm: '00181061', tag_ary: [0x0018,0x1061], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1062)', tag_name: "Nominal Interval", tag_key: 'NominalInterval', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0018,1062)', tag_sym: :nominal_interval, tag_ndm: '00181062', tag_ary: [0x0018,0x1062], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1063)', tag_name: "Frame Time", tag_key: 'FrameTime', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,1063)', tag_sym: :frame_time, tag_ndm: '00181063', tag_ary: [0x0018,0x1063], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1064)', tag_name: "Cardiac Framing Type", tag_key: 'CardiacFramingType', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0018,1064)', tag_sym: :cardiac_framing_type, tag_ndm: '00181064', tag_ary: [0x0018,0x1064], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1065)', tag_name: "Frame Time Vector", tag_key: 'FrameTimeVector', tag_vr: [:DS], tag_vm: ["1-n"], tag_str: '(0018,1065)', tag_sym: :frame_time_vector, tag_ndm: '00181065', tag_ary: [0x0018,0x1065], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1066)', tag_name: "Frame Delay", tag_key: 'FrameDelay', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,1066)', tag_sym: :frame_delay, tag_ndm: '00181066', tag_ary: [0x0018,0x1066], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1067)', tag_name: "Image Trigger Delay", tag_key: 'ImageTriggerDelay', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,1067)', tag_sym: :image_trigger_delay, tag_ndm: '00181067', tag_ary: [0x0018,0x1067], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1068)', tag_name: "Multiplex Group Time Offset", tag_key: 'MultiplexGroupTimeOffset', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,1068)', tag_sym: :multiplex_group_time_offset, tag_ndm: '00181068', tag_ary: [0x0018,0x1068], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1069)', tag_name: "Trigger Time Offset", tag_key: 'TriggerTimeOffset', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,1069)', tag_sym: :trigger_time_offset, tag_ndm: '00181069', tag_ary: [0x0018,0x1069], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,106A)', tag_name: "Synchronization Trigger", tag_key: 'SynchronizationTrigger', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,106A)', tag_sym: :synchronization_trigger, tag_ndm: '0018106A', tag_ary: [0x0018,0x106A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,106C)', tag_name: "Synchronization Channel", tag_key: 'SynchronizationChannel', tag_vr: [:US], tag_vm: ["2"], tag_str: '(0018,106C)', tag_sym: :synchronization_channel, tag_ndm: '0018106C', tag_ary: [0x0018,0x106C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,106E)', tag_name: "Trigger Sample Position", tag_key: 'TriggerSamplePosition', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0018,106E)', tag_sym: :trigger_sample_position, tag_ndm: '0018106E', tag_ary: [0x0018,0x106E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1070)', tag_name: "Radiopharmaceutical Route", tag_key: 'RadiopharmaceuticalRoute', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0018,1070)', tag_sym: :radiopharmaceutical_route, tag_ndm: '00181070', tag_ary: [0x0018,0x1070], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1071)', tag_name: "Radiopharmaceutical Volume", tag_key: 'RadiopharmaceuticalVolume', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,1071)', tag_sym: :radiopharmaceutical_volume, tag_ndm: '00181071', tag_ary: [0x0018,0x1071], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1072)', tag_name: "Radiopharmaceutical Start Time", tag_key: 'RadiopharmaceuticalStartTime', tag_vr: [:TM], tag_vm: ["1"], tag_str: '(0018,1072)', tag_sym: :radiopharmaceutical_start_time, tag_ndm: '00181072', tag_ary: [0x0018,0x1072], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1073)', tag_name: "Radiopharmaceutical Stop Time", tag_key: 'RadiopharmaceuticalStopTime', tag_vr: [:TM], tag_vm: ["1"], tag_str: '(0018,1073)', tag_sym: :radiopharmaceutical_stop_time, tag_ndm: '00181073', tag_ary: [0x0018,0x1073], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1074)', tag_name: "Radionuclide Total Dose", tag_key: 'RadionuclideTotalDose', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,1074)', tag_sym: :radionuclide_total_dose, tag_ndm: '00181074', tag_ary: [0x0018,0x1074], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1075)', tag_name: "Radionuclide Half Life", tag_key: 'RadionuclideHalfLife', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,1075)', tag_sym: :radionuclide_half_life, tag_ndm: '00181075', tag_ary: [0x0018,0x1075], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1076)', tag_name: "Radionuclide Positron Fraction", tag_key: 'RadionuclidePositronFraction', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,1076)', tag_sym: :radionuclide_positron_fraction, tag_ndm: '00181076', tag_ary: [0x0018,0x1076], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1077)', tag_name: "Radiopharmaceutical Specific Activity", tag_key: 'RadiopharmaceuticalSpecificActivity', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,1077)', tag_sym: :radiopharmaceutical_specific_activity, tag_ndm: '00181077', tag_ary: [0x0018,0x1077], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1078)', tag_name: "Radiopharmaceutical Start DateTime", tag_key: 'RadiopharmaceuticalStartDateTime', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(0018,1078)', tag_sym: :radiopharmaceutical_start_date_time, tag_ndm: '00181078', tag_ary: [0x0018,0x1078], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1079)', tag_name: "Radiopharmaceutical Stop DateTime", tag_key: 'RadiopharmaceuticalStopDateTime', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(0018,1079)', tag_sym: :radiopharmaceutical_stop_date_time, tag_ndm: '00181079', tag_ary: [0x0018,0x1079], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1080)', tag_name: "Beat Rejection Flag", tag_key: 'BeatRejectionFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,1080)', tag_sym: :beat_rejection_flag, tag_ndm: '00181080', tag_ary: [0x0018,0x1080], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1081)', tag_name: "Low R-R Value", tag_key: 'LowRRValue', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0018,1081)', tag_sym: :low_rr_value, tag_ndm: '00181081', tag_ary: [0x0018,0x1081], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1082)', tag_name: "High R-R Value", tag_key: 'HighRRValue', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0018,1082)', tag_sym: :high_rr_value, tag_ndm: '00181082', tag_ary: [0x0018,0x1082], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1083)', tag_name: "Intervals Acquired", tag_key: 'IntervalsAcquired', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0018,1083)', tag_sym: :intervals_acquired, tag_ndm: '00181083', tag_ary: [0x0018,0x1083], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1084)', tag_name: "Intervals Rejected", tag_key: 'IntervalsRejected', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0018,1084)', tag_sym: :intervals_rejected, tag_ndm: '00181084', tag_ary: [0x0018,0x1084], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1085)', tag_name: "PVC Rejection", tag_key: 'PVCRejection', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0018,1085)', tag_sym: :pvc_rejection, tag_ndm: '00181085', tag_ary: [0x0018,0x1085], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1086)', tag_name: "Skip Beats", tag_key: 'SkipBeats', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0018,1086)', tag_sym: :skip_beats, tag_ndm: '00181086', tag_ary: [0x0018,0x1086], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1088)', tag_name: "Heart Rate", tag_key: 'HeartRate', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0018,1088)', tag_sym: :heart_rate, tag_ndm: '00181088', tag_ary: [0x0018,0x1088], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1090)', tag_name: "Cardiac Number of Images", tag_key: 'CardiacNumberOfImages', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0018,1090)', tag_sym: :cardiac_number_of_images, tag_ndm: '00181090', tag_ary: [0x0018,0x1090], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1094)', tag_name: "Trigger Window", tag_key: 'TriggerWindow', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0018,1094)', tag_sym: :trigger_window, tag_ndm: '00181094', tag_ary: [0x0018,0x1094], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1100)', tag_name: "Reconstruction Diameter", tag_key: 'ReconstructionDiameter', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,1100)', tag_sym: :reconstruction_diameter, tag_ndm: '00181100', tag_ary: [0x0018,0x1100], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1110)', tag_name: "Distance Source to Detector", tag_key: 'DistanceSourceToDetector', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,1110)', tag_sym: :distance_source_to_detector, tag_ndm: '00181110', tag_ary: [0x0018,0x1110], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1111)', tag_name: "Distance Source to Patient", tag_key: 'DistanceSourceToPatient', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,1111)', tag_sym: :distance_source_to_patient, tag_ndm: '00181111', tag_ary: [0x0018,0x1111], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1114)', tag_name: "Estimated Radiographic Magnification Factor", tag_key: 'EstimatedRadiographicMagnificationFactor', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,1114)', tag_sym: :estimated_radiographic_magnification_factor, tag_ndm: '00181114', tag_ary: [0x0018,0x1114], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1120)', tag_name: "Gantry/Detector Tilt", tag_key: 'GantryDetectorTilt', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,1120)', tag_sym: :gantry_detector_tilt, tag_ndm: '00181120', tag_ary: [0x0018,0x1120], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1121)', tag_name: "Gantry/Detector Slew", tag_key: 'GantryDetectorSlew', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,1121)', tag_sym: :gantry_detector_slew, tag_ndm: '00181121', tag_ary: [0x0018,0x1121], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1130)', tag_name: "Table Height", tag_key: 'TableHeight', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,1130)', tag_sym: :table_height, tag_ndm: '00181130', tag_ary: [0x0018,0x1130], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1131)', tag_name: "Table Traverse", tag_key: 'TableTraverse', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,1131)', tag_sym: :table_traverse, tag_ndm: '00181131', tag_ary: [0x0018,0x1131], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1134)', tag_name: "Table Motion", tag_key: 'TableMotion', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,1134)', tag_sym: :table_motion, tag_ndm: '00181134', tag_ary: [0x0018,0x1134], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1135)', tag_name: "Table Vertical Increment", tag_key: 'TableVerticalIncrement', tag_vr: [:DS], tag_vm: ["1-n"], tag_str: '(0018,1135)', tag_sym: :table_vertical_increment, tag_ndm: '00181135', tag_ary: [0x0018,0x1135], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1136)', tag_name: "Table Lateral Increment", tag_key: 'TableLateralIncrement', tag_vr: [:DS], tag_vm: ["1-n"], tag_str: '(0018,1136)', tag_sym: :table_lateral_increment, tag_ndm: '00181136', tag_ary: [0x0018,0x1136], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1137)', tag_name: "Table Longitudinal Increment", tag_key: 'TableLongitudinalIncrement', tag_vr: [:DS], tag_vm: ["1-n"], tag_str: '(0018,1137)', tag_sym: :table_longitudinal_increment, tag_ndm: '00181137', tag_ary: [0x0018,0x1137], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1138)', tag_name: "Table Angle", tag_key: 'TableAngle', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,1138)', tag_sym: :table_angle, tag_ndm: '00181138', tag_ary: [0x0018,0x1138], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,113A)', tag_name: "Table Type", tag_key: 'TableType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,113A)', tag_sym: :table_type, tag_ndm: '0018113A', tag_ary: [0x0018,0x113A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1140)', tag_name: "Rotation Direction", tag_key: 'RotationDirection', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,1140)', tag_sym: :rotation_direction, tag_ndm: '00181140', tag_ary: [0x0018,0x1140], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1141)', tag_name: "Angular Position", tag_key: 'AngularPosition', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,1141)', tag_sym: :angular_position, tag_ndm: '00181141', tag_ary: [0x0018,0x1141], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0018,1142)', tag_name: "Radial Position", tag_key: 'RadialPosition', tag_vr: [:DS], tag_vm: ["1-n"], tag_str: '(0018,1142)', tag_sym: :radial_position, tag_ndm: '00181142', tag_ary: [0x0018,0x1142], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1143)', tag_name: "Scan Arc", tag_key: 'ScanArc', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,1143)', tag_sym: :scan_arc, tag_ndm: '00181143', tag_ary: [0x0018,0x1143], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1144)', tag_name: "Angular Step", tag_key: 'AngularStep', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,1144)', tag_sym: :angular_step, tag_ndm: '00181144', tag_ary: [0x0018,0x1144], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1145)', tag_name: "Center of Rotation Offset", tag_key: 'CenterOfRotationOffset', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,1145)', tag_sym: :center_of_rotation_offset, tag_ndm: '00181145', tag_ary: [0x0018,0x1145], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1146)', tag_name: "Rotation Offset", tag_key: 'RotationOffset', tag_vr: [:DS], tag_vm: ["1-n"], tag_str: '(0018,1146)', tag_sym: :rotation_offset, tag_ndm: '00181146', tag_ary: [0x0018,0x1146], tag_multiple: false, tag_note: 'RET (1993)'},
      { tag_ps: '(0018,1147)', tag_name: "Field of View Shape", tag_key: 'FieldOfViewShape', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,1147)', tag_sym: :field_of_view_shape, tag_ndm: '00181147', tag_ary: [0x0018,0x1147], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1149)', tag_name: "Field of View Dimension(s)", tag_key: 'FieldOfViewDimensions', tag_vr: [:IS], tag_vm: ["1-2"], tag_str: '(0018,1149)', tag_sym: :field_of_view_dimensions, tag_ndm: '00181149', tag_ary: [0x0018,0x1149], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1150)', tag_name: "Exposure Time", tag_key: 'ExposureTime', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0018,1150)', tag_sym: :exposure_time, tag_ndm: '00181150', tag_ary: [0x0018,0x1150], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1151)', tag_name: "X-Ray Tube Current", tag_key: 'XRayTubeCurrent', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0018,1151)', tag_sym: :x_ray_tube_current, tag_ndm: '00181151', tag_ary: [0x0018,0x1151], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1152)', tag_name: "Exposure", tag_key: 'Exposure', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0018,1152)', tag_sym: :exposure, tag_ndm: '00181152', tag_ary: [0x0018,0x1152], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1153)', tag_name: "Exposure in µAs", tag_key: 'ExposureInuAs', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0018,1153)', tag_sym: :exposure_in_uas, tag_ndm: '00181153', tag_ary: [0x0018,0x1153], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1154)', tag_name: "Average Pulse Width", tag_key: 'AveragePulseWidth', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,1154)', tag_sym: :average_pulse_width, tag_ndm: '00181154', tag_ary: [0x0018,0x1154], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1155)', tag_name: "Radiation Setting", tag_key: 'RadiationSetting', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,1155)', tag_sym: :radiation_setting, tag_ndm: '00181155', tag_ary: [0x0018,0x1155], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1156)', tag_name: "Rectification Type", tag_key: 'RectificationType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,1156)', tag_sym: :rectification_type, tag_ndm: '00181156', tag_ary: [0x0018,0x1156], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,115A)', tag_name: "Radiation Mode", tag_key: 'RadiationMode', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,115A)', tag_sym: :radiation_mode, tag_ndm: '0018115A', tag_ary: [0x0018,0x115A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,115E)', tag_name: "Image and Fluoroscopy Area Dose Product", tag_key: 'ImageAndFluoroscopyAreaDoseProduct', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,115E)', tag_sym: :image_and_fluoroscopy_area_dose_product, tag_ndm: '0018115E', tag_ary: [0x0018,0x115E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1160)', tag_name: "Filter Type", tag_key: 'FilterType', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0018,1160)', tag_sym: :filter_type, tag_ndm: '00181160', tag_ary: [0x0018,0x1160], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1161)', tag_name: "Type of Filters", tag_key: 'TypeOfFilters', tag_vr: [:LO], tag_vm: ["1-n"], tag_str: '(0018,1161)', tag_sym: :type_of_filters, tag_ndm: '00181161', tag_ary: [0x0018,0x1161], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1162)', tag_name: "Intensifier Size", tag_key: 'IntensifierSize', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,1162)', tag_sym: :intensifier_size, tag_ndm: '00181162', tag_ary: [0x0018,0x1162], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1164)', tag_name: "Imager Pixel Spacing", tag_key: 'ImagerPixelSpacing', tag_vr: [:DS], tag_vm: ["2"], tag_str: '(0018,1164)', tag_sym: :imager_pixel_spacing, tag_ndm: '00181164', tag_ary: [0x0018,0x1164], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1166)', tag_name: "Grid", tag_key: 'Grid', tag_vr: [:CS], tag_vm: ["1-n"], tag_str: '(0018,1166)', tag_sym: :grid, tag_ndm: '00181166', tag_ary: [0x0018,0x1166], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1170)', tag_name: "Generator Power", tag_key: 'GeneratorPower', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0018,1170)', tag_sym: :generator_power, tag_ndm: '00181170', tag_ary: [0x0018,0x1170], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1180)', tag_name: "Collimator/grid Name", tag_key: 'CollimatorGridName', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0018,1180)', tag_sym: :collimator_grid_name, tag_ndm: '00181180', tag_ary: [0x0018,0x1180], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1181)', tag_name: "Collimator Type", tag_key: 'CollimatorType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,1181)', tag_sym: :collimator_type, tag_ndm: '00181181', tag_ary: [0x0018,0x1181], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1182)', tag_name: "Focal Distance", tag_key: 'FocalDistance', tag_vr: [:IS], tag_vm: ["1-2"], tag_str: '(0018,1182)', tag_sym: :focal_distance, tag_ndm: '00181182', tag_ary: [0x0018,0x1182], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1183)', tag_name: "X Focus Center", tag_key: 'XFocusCenter', tag_vr: [:DS], tag_vm: ["1-2"], tag_str: '(0018,1183)', tag_sym: :x_focus_center, tag_ndm: '00181183', tag_ary: [0x0018,0x1183], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1184)', tag_name: "Y Focus Center", tag_key: 'YFocusCenter', tag_vr: [:DS], tag_vm: ["1-2"], tag_str: '(0018,1184)', tag_sym: :y_focus_center, tag_ndm: '00181184', tag_ary: [0x0018,0x1184], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1190)', tag_name: "Focal Spot(s)", tag_key: 'FocalSpots', tag_vr: [:DS], tag_vm: ["1-n"], tag_str: '(0018,1190)', tag_sym: :focal_spots, tag_ndm: '00181190', tag_ary: [0x0018,0x1190], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1191)', tag_name: "Anode Target Material", tag_key: 'AnodeTargetMaterial', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,1191)', tag_sym: :anode_target_material, tag_ndm: '00181191', tag_ary: [0x0018,0x1191], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,11A0)', tag_name: "Body Part Thickness", tag_key: 'BodyPartThickness', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,11A0)', tag_sym: :body_part_thickness, tag_ndm: '001811A0', tag_ary: [0x0018,0x11A0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,11A2)', tag_name: "Compression Force", tag_key: 'CompressionForce', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,11A2)', tag_sym: :compression_force, tag_ndm: '001811A2', tag_ary: [0x0018,0x11A2], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,11A3)', tag_name: "Compression Pressure", tag_key: 'CompressionPressure', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,11A3)', tag_sym: :compression_pressure, tag_ndm: '001811A3', tag_ary: [0x0018,0x11A3], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,11A4)', tag_name: "Paddle Description", tag_key: 'PaddleDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0018,11A4)', tag_sym: :paddle_description, tag_ndm: '001811A4', tag_ary: [0x0018,0x11A4], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,11A5)', tag_name: "Compression Contact Area", tag_key: 'CompressionContactArea', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,11A5)', tag_sym: :compression_contact_area, tag_ndm: '001811A5', tag_ary: [0x0018,0x11A5], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,11B0)', tag_name: "Acquisition Mode", tag_key: 'AcquisitionMode', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0018,11B0)', tag_sym: :acquisition_mode, tag_ndm: '001811B0', tag_ary: [0x0018,0x11B0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,11B1)', tag_name: "Dose Mode Name", tag_key: 'DoseModeName', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0018,11B1)', tag_sym: :dose_mode_name, tag_ndm: '001811B1', tag_ary: [0x0018,0x11B1], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,11B2)', tag_name: "Acquired Subtraction Mask Flag", tag_key: 'AcquiredSubtractionMaskFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,11B2)', tag_sym: :acquired_subtraction_mask_flag, tag_ndm: '001811B2', tag_ary: [0x0018,0x11B2], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,11B3)', tag_name: "Fluoroscopy Persistence Flag", tag_key: 'FluoroscopyPersistenceFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,11B3)', tag_sym: :fluoroscopy_persistence_flag, tag_ndm: '001811B3', tag_ary: [0x0018,0x11B3], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,11B4)', tag_name: "Fluoroscopy Last Image Hold Persistence Flag", tag_key: 'FluoroscopyLastImageHoldPersistenceFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,11B4)', tag_sym: :fluoroscopy_last_image_hold_persistence_flag, tag_ndm: '001811B4', tag_ary: [0x0018,0x11B4], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,11B5)', tag_name: "Upper Limit Number Of Persistent Fluoroscopy Frames", tag_key: 'UpperLimitNumberOfPersistentFluoroscopyFrames', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0018,11B5)', tag_sym: :upper_limit_number_of_persistent_fluoroscopy_frames, tag_ndm: '001811B5', tag_ary: [0x0018,0x11B5], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,11B6)', tag_name: "Contrast/Bolus Auto Injection Trigger Flag", tag_key: 'ContrastBolusAutoInjectionTriggerFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,11B6)', tag_sym: :contrast_bolus_auto_injection_trigger_flag, tag_ndm: '001811B6', tag_ary: [0x0018,0x11B6], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,11B7)', tag_name: "Contrast/Bolus Injection Delay", tag_key: 'ContrastBolusInjectionDelay', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,11B7)', tag_sym: :contrast_bolus_injection_delay, tag_ndm: '001811B7', tag_ary: [0x0018,0x11B7], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,11B8)', tag_name: "XA Acquisition Phase Details Sequence", tag_key: 'XAAcquisitionPhaseDetailsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,11B8)', tag_sym: :xa_acquisition_phase_details_sequence, tag_ndm: '001811B8', tag_ary: [0x0018,0x11B8], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,11B9)', tag_name: "XA Acquisition Frame Rate", tag_key: 'XAAcquisitionFrameRate', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,11B9)', tag_sym: :xa_acquisition_frame_rate, tag_ndm: '001811B9', tag_ary: [0x0018,0x11B9], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,11BA)', tag_name: "XA Plane Details Sequence", tag_key: 'XAPlaneDetailsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,11BA)', tag_sym: :xa_plane_details_sequence, tag_ndm: '001811BA', tag_ary: [0x0018,0x11BA], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,11BB)', tag_name: "Acquisition Field of View Label", tag_key: 'AcquisitionFieldOfViewLabel', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0018,11BB)', tag_sym: :acquisition_field_of_view_label, tag_ndm: '001811BB', tag_ary: [0x0018,0x11BB], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,11BC)', tag_name: "X-Ray Filter Details Sequence", tag_key: 'XRayFilterDetailsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,11BC)', tag_sym: :x_ray_filter_details_sequence, tag_ndm: '001811BC', tag_ary: [0x0018,0x11BC], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,11BD)', tag_name: "XA Acquisition Duration", tag_key: 'XAAcquisitionDuration', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,11BD)', tag_sym: :xa_acquisition_duration, tag_ndm: '001811BD', tag_ary: [0x0018,0x11BD], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,11BE)', tag_name: "Reconstruction Pipeline Type", tag_key: 'ReconstructionPipelineType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,11BE)', tag_sym: :reconstruction_pipeline_type, tag_ndm: '001811BE', tag_ary: [0x0018,0x11BE], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,11BF)', tag_name: "Image Filter Details Sequence", tag_key: 'ImageFilterDetailsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,11BF)', tag_sym: :image_filter_details_sequence, tag_ndm: '001811BF', tag_ary: [0x0018,0x11BF], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,11C0)', tag_name: "Applied Mask Subtraction Flag", tag_key: 'AppliedMaskSubtractionFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,11C0)', tag_sym: :applied_mask_subtraction_flag, tag_ndm: '001811C0', tag_ary: [0x0018,0x11C0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,11C1)', tag_name: "Requested Series Description Code Sequence", tag_key: 'RequestedSeriesDescriptionCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,11C1)', tag_sym: :requested_series_description_code_sequence, tag_ndm: '001811C1', tag_ary: [0x0018,0x11C1], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1200)', tag_name: "Date of Last Calibration", tag_key: 'DateOfLastCalibration', tag_vr: [:DA], tag_vm: ["1-n"], tag_str: '(0018,1200)', tag_sym: :date_of_last_calibration, tag_ndm: '00181200', tag_ary: [0x0018,0x1200], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1201)', tag_name: "Time of Last Calibration", tag_key: 'TimeOfLastCalibration', tag_vr: [:TM], tag_vm: ["1-n"], tag_str: '(0018,1201)', tag_sym: :time_of_last_calibration, tag_ndm: '00181201', tag_ary: [0x0018,0x1201], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1202)', tag_name: "DateTime of Last Calibration", tag_key: 'DateTimeOfLastCalibration', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(0018,1202)', tag_sym: :date_time_of_last_calibration, tag_ndm: '00181202', tag_ary: [0x0018,0x1202], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1203)', tag_name: "Calibration DateTime", tag_key: 'CalibrationDateTime', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(0018,1203)', tag_sym: :calibration_date_time, tag_ndm: '00181203', tag_ary: [0x0018,0x1203], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1204)', tag_name: "Date of Manufacture", tag_key: 'DateOfManufacture', tag_vr: [:DA], tag_vm: ["1"], tag_str: '(0018,1204)', tag_sym: :date_of_manufacture, tag_ndm: '00181204', tag_ary: [0x0018,0x1204], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1205)', tag_name: "Date of Installation", tag_key: 'DateOfInstallation', tag_vr: [:DA], tag_vm: ["1"], tag_str: '(0018,1205)', tag_sym: :date_of_installation, tag_ndm: '00181205', tag_ary: [0x0018,0x1205], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1210)', tag_name: "Convolution Kernel", tag_key: 'ConvolutionKernel', tag_vr: [:SH], tag_vm: ["1-n"], tag_str: '(0018,1210)', tag_sym: :convolution_kernel, tag_ndm: '00181210', tag_ary: [0x0018,0x1210], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1240)', tag_name: "Upper/Lower Pixel Values", tag_key: 'UpperLowerPixelValues', tag_vr: [:IS], tag_vm: ["1-n"], tag_str: '(0018,1240)', tag_sym: :upper_lower_pixel_values, tag_ndm: '00181240', tag_ary: [0x0018,0x1240], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(0018,1242)', tag_name: "Actual Frame Duration", tag_key: 'ActualFrameDuration', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0018,1242)', tag_sym: :actual_frame_duration, tag_ndm: '00181242', tag_ary: [0x0018,0x1242], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1243)', tag_name: "Count Rate", tag_key: 'CountRate', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0018,1243)', tag_sym: :count_rate, tag_ndm: '00181243', tag_ary: [0x0018,0x1243], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1244)', tag_name: "Preferred Playback Sequencing", tag_key: 'PreferredPlaybackSequencing', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0018,1244)', tag_sym: :preferred_playback_sequencing, tag_ndm: '00181244', tag_ary: [0x0018,0x1244], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1250)', tag_name: "Receive Coil Name", tag_key: 'ReceiveCoilName', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0018,1250)', tag_sym: :receive_coil_name, tag_ndm: '00181250', tag_ary: [0x0018,0x1250], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1251)', tag_name: "Transmit Coil Name", tag_key: 'TransmitCoilName', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0018,1251)', tag_sym: :transmit_coil_name, tag_ndm: '00181251', tag_ary: [0x0018,0x1251], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1260)', tag_name: "Plate Type", tag_key: 'PlateType', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0018,1260)', tag_sym: :plate_type, tag_ndm: '00181260', tag_ary: [0x0018,0x1260], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1261)', tag_name: "Phosphor Type", tag_key: 'PhosphorType', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0018,1261)', tag_sym: :phosphor_type, tag_ndm: '00181261', tag_ary: [0x0018,0x1261], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1271)', tag_name: "Water Equivalent Diameter", tag_key: 'WaterEquivalentDiameter', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,1271)', tag_sym: :water_equivalent_diameter, tag_ndm: '00181271', tag_ary: [0x0018,0x1271], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1272)', tag_name: "Water Equivalent Diameter Calculation Method Code Sequence", tag_key: 'WaterEquivalentDiameterCalculationMethodCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,1272)', tag_sym: :water_equivalent_diameter_calculation_method_code_sequence, tag_ndm: '00181272', tag_ary: [0x0018,0x1272], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1300)', tag_name: "Scan Velocity", tag_key: 'ScanVelocity', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,1300)', tag_sym: :scan_velocity, tag_ndm: '00181300', tag_ary: [0x0018,0x1300], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1301)', tag_name: "Whole Body Technique", tag_key: 'WholeBodyTechnique', tag_vr: [:CS], tag_vm: ["1-n"], tag_str: '(0018,1301)', tag_sym: :whole_body_technique, tag_ndm: '00181301', tag_ary: [0x0018,0x1301], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1302)', tag_name: "Scan Length", tag_key: 'ScanLength', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0018,1302)', tag_sym: :scan_length, tag_ndm: '00181302', tag_ary: [0x0018,0x1302], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1310)', tag_name: "Acquisition Matrix", tag_key: 'AcquisitionMatrix', tag_vr: [:US], tag_vm: ["4"], tag_str: '(0018,1310)', tag_sym: :acquisition_matrix, tag_ndm: '00181310', tag_ary: [0x0018,0x1310], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1312)', tag_name: "In-plane Phase Encoding Direction", tag_key: 'InPlanePhaseEncodingDirection', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,1312)', tag_sym: :in_plane_phase_encoding_direction, tag_ndm: '00181312', tag_ary: [0x0018,0x1312], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1314)', tag_name: "Flip Angle", tag_key: 'FlipAngle', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,1314)', tag_sym: :flip_angle, tag_ndm: '00181314', tag_ary: [0x0018,0x1314], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1315)', tag_name: "Variable Flip Angle Flag", tag_key: 'VariableFlipAngleFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,1315)', tag_sym: :variable_flip_angle_flag, tag_ndm: '00181315', tag_ary: [0x0018,0x1315], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1316)', tag_name: "SAR", tag_key: 'SAR', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,1316)', tag_sym: :sar, tag_ndm: '00181316', tag_ary: [0x0018,0x1316], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1318)', tag_name: "dB/dt", tag_key: 'dBdt', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,1318)', tag_sym: :db_dt, tag_ndm: '00181318', tag_ary: [0x0018,0x1318], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1320)', tag_name: "B1rms", tag_key: 'B1rms', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0018,1320)', tag_sym: :b1rms, tag_ndm: '00181320', tag_ary: [0x0018,0x1320], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1400)', tag_name: "Acquisition Device Processing Description", tag_key: 'AcquisitionDeviceProcessingDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0018,1400)', tag_sym: :acquisition_device_processing_description, tag_ndm: '00181400', tag_ary: [0x0018,0x1400], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1401)', tag_name: "Acquisition Device Processing Code", tag_key: 'AcquisitionDeviceProcessingCode', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0018,1401)', tag_sym: :acquisition_device_processing_code, tag_ndm: '00181401', tag_ary: [0x0018,0x1401], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1402)', tag_name: "Cassette Orientation", tag_key: 'CassetteOrientation', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,1402)', tag_sym: :cassette_orientation, tag_ndm: '00181402', tag_ary: [0x0018,0x1402], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1403)', tag_name: "Cassette Size", tag_key: 'CassetteSize', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,1403)', tag_sym: :cassette_size, tag_ndm: '00181403', tag_ary: [0x0018,0x1403], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1404)', tag_name: "Exposures on Plate", tag_key: 'ExposuresOnPlate', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0018,1404)', tag_sym: :exposures_on_plate, tag_ndm: '00181404', tag_ary: [0x0018,0x1404], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1405)', tag_name: "Relative X-Ray Exposure", tag_key: 'RelativeXRayExposure', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0018,1405)', tag_sym: :relative_x_ray_exposure, tag_ndm: '00181405', tag_ary: [0x0018,0x1405], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1411)', tag_name: "Exposure Index", tag_key: 'ExposureIndex', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,1411)', tag_sym: :exposure_index, tag_ndm: '00181411', tag_ary: [0x0018,0x1411], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1412)', tag_name: "Target Exposure Index", tag_key: 'TargetExposureIndex', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,1412)', tag_sym: :target_exposure_index, tag_ndm: '00181412', tag_ary: [0x0018,0x1412], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1413)', tag_name: "Deviation Index", tag_key: 'DeviationIndex', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,1413)', tag_sym: :deviation_index, tag_ndm: '00181413', tag_ary: [0x0018,0x1413], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1450)', tag_name: "Column Angulation", tag_key: 'ColumnAngulation', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,1450)', tag_sym: :column_angulation, tag_ndm: '00181450', tag_ary: [0x0018,0x1450], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1460)', tag_name: "Tomo Layer Height", tag_key: 'TomoLayerHeight', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,1460)', tag_sym: :tomo_layer_height, tag_ndm: '00181460', tag_ary: [0x0018,0x1460], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1470)', tag_name: "Tomo Angle", tag_key: 'TomoAngle', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,1470)', tag_sym: :tomo_angle, tag_ndm: '00181470', tag_ary: [0x0018,0x1470], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1480)', tag_name: "Tomo Time", tag_key: 'TomoTime', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,1480)', tag_sym: :tomo_time, tag_ndm: '00181480', tag_ary: [0x0018,0x1480], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1490)', tag_name: "Tomo Type", tag_key: 'TomoType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,1490)', tag_sym: :tomo_type, tag_ndm: '00181490', tag_ary: [0x0018,0x1490], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1491)', tag_name: "Tomo Class", tag_key: 'TomoClass', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,1491)', tag_sym: :tomo_class, tag_ndm: '00181491', tag_ary: [0x0018,0x1491], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1495)', tag_name: "Number of Tomosynthesis Source Images", tag_key: 'NumberOfTomosynthesisSourceImages', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0018,1495)', tag_sym: :number_of_tomosynthesis_source_images, tag_ndm: '00181495', tag_ary: [0x0018,0x1495], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1500)', tag_name: "Positioner Motion", tag_key: 'PositionerMotion', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,1500)', tag_sym: :positioner_motion, tag_ndm: '00181500', tag_ary: [0x0018,0x1500], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1508)', tag_name: "Positioner Type", tag_key: 'PositionerType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,1508)', tag_sym: :positioner_type, tag_ndm: '00181508', tag_ary: [0x0018,0x1508], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1510)', tag_name: "Positioner Primary Angle", tag_key: 'PositionerPrimaryAngle', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,1510)', tag_sym: :positioner_primary_angle, tag_ndm: '00181510', tag_ary: [0x0018,0x1510], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1511)', tag_name: "Positioner Secondary Angle", tag_key: 'PositionerSecondaryAngle', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,1511)', tag_sym: :positioner_secondary_angle, tag_ndm: '00181511', tag_ary: [0x0018,0x1511], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1520)', tag_name: "Positioner Primary Angle Increment", tag_key: 'PositionerPrimaryAngleIncrement', tag_vr: [:DS], tag_vm: ["1-n"], tag_str: '(0018,1520)', tag_sym: :positioner_primary_angle_increment, tag_ndm: '00181520', tag_ary: [0x0018,0x1520], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1521)', tag_name: "Positioner Secondary Angle Increment", tag_key: 'PositionerSecondaryAngleIncrement', tag_vr: [:DS], tag_vm: ["1-n"], tag_str: '(0018,1521)', tag_sym: :positioner_secondary_angle_increment, tag_ndm: '00181521', tag_ary: [0x0018,0x1521], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1530)', tag_name: "Detector Primary Angle", tag_key: 'DetectorPrimaryAngle', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,1530)', tag_sym: :detector_primary_angle, tag_ndm: '00181530', tag_ary: [0x0018,0x1530], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1531)', tag_name: "Detector Secondary Angle", tag_key: 'DetectorSecondaryAngle', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,1531)', tag_sym: :detector_secondary_angle, tag_ndm: '00181531', tag_ary: [0x0018,0x1531], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1600)', tag_name: "Shutter Shape", tag_key: 'ShutterShape', tag_vr: [:CS], tag_vm: ["1-3"], tag_str: '(0018,1600)', tag_sym: :shutter_shape, tag_ndm: '00181600', tag_ary: [0x0018,0x1600], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1602)', tag_name: "Shutter Left Vertical Edge", tag_key: 'ShutterLeftVerticalEdge', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0018,1602)', tag_sym: :shutter_left_vertical_edge, tag_ndm: '00181602', tag_ary: [0x0018,0x1602], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1604)', tag_name: "Shutter Right Vertical Edge", tag_key: 'ShutterRightVerticalEdge', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0018,1604)', tag_sym: :shutter_right_vertical_edge, tag_ndm: '00181604', tag_ary: [0x0018,0x1604], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1606)', tag_name: "Shutter Upper Horizontal Edge", tag_key: 'ShutterUpperHorizontalEdge', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0018,1606)', tag_sym: :shutter_upper_horizontal_edge, tag_ndm: '00181606', tag_ary: [0x0018,0x1606], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1608)', tag_name: "Shutter Lower Horizontal Edge", tag_key: 'ShutterLowerHorizontalEdge', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0018,1608)', tag_sym: :shutter_lower_horizontal_edge, tag_ndm: '00181608', tag_ary: [0x0018,0x1608], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1610)', tag_name: "Center of Circular Shutter", tag_key: 'CenterOfCircularShutter', tag_vr: [:IS], tag_vm: ["2"], tag_str: '(0018,1610)', tag_sym: :center_of_circular_shutter, tag_ndm: '00181610', tag_ary: [0x0018,0x1610], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1612)', tag_name: "Radius of Circular Shutter", tag_key: 'RadiusOfCircularShutter', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0018,1612)', tag_sym: :radius_of_circular_shutter, tag_ndm: '00181612', tag_ary: [0x0018,0x1612], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1620)', tag_name: "Vertices of the Polygonal Shutter", tag_key: 'VerticesOfThePolygonalShutter', tag_vr: [:IS], tag_vm: ["2-2n"], tag_str: '(0018,1620)', tag_sym: :vertices_of_the_polygonal_shutter, tag_ndm: '00181620', tag_ary: [0x0018,0x1620], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1622)', tag_name: "Shutter Presentation Value", tag_key: 'ShutterPresentationValue', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0018,1622)', tag_sym: :shutter_presentation_value, tag_ndm: '00181622', tag_ary: [0x0018,0x1622], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1623)', tag_name: "Shutter Overlay Group", tag_key: 'ShutterOverlayGroup', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0018,1623)', tag_sym: :shutter_overlay_group, tag_ndm: '00181623', tag_ary: [0x0018,0x1623], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1624)', tag_name: "Shutter Presentation Color CIELab Value", tag_key: 'ShutterPresentationColorCIELabValue', tag_vr: [:US], tag_vm: ["3"], tag_str: '(0018,1624)', tag_sym: :shutter_presentation_color_cie_lab_value, tag_ndm: '00181624', tag_ary: [0x0018,0x1624], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1630)', tag_name: "Outline Shape Type", tag_key: 'OutlineShapeType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,1630)', tag_sym: :outline_shape_type, tag_ndm: '00181630', tag_ary: [0x0018,0x1630], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1631)', tag_name: "Outline Left Vertical Edge", tag_key: 'OutlineLeftVerticalEdge', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,1631)', tag_sym: :outline_left_vertical_edge, tag_ndm: '00181631', tag_ary: [0x0018,0x1631], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1632)', tag_name: "Outline Right Vertical Edge", tag_key: 'OutlineRightVerticalEdge', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,1632)', tag_sym: :outline_right_vertical_edge, tag_ndm: '00181632', tag_ary: [0x0018,0x1632], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1633)', tag_name: "Outline Upper Horizontal Edge", tag_key: 'OutlineUpperHorizontalEdge', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,1633)', tag_sym: :outline_upper_horizontal_edge, tag_ndm: '00181633', tag_ary: [0x0018,0x1633], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1634)', tag_name: "Outline Lower Horizontal Edge", tag_key: 'OutlineLowerHorizontalEdge', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,1634)', tag_sym: :outline_lower_horizontal_edge, tag_ndm: '00181634', tag_ary: [0x0018,0x1634], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1635)', tag_name: "Center of Circular Outline", tag_key: 'CenterOfCircularOutline', tag_vr: [:FD], tag_vm: ["2"], tag_str: '(0018,1635)', tag_sym: :center_of_circular_outline, tag_ndm: '00181635', tag_ary: [0x0018,0x1635], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1636)', tag_name: "Diameter of Circular Outline", tag_key: 'DiameterOfCircularOutline', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,1636)', tag_sym: :diameter_of_circular_outline, tag_ndm: '00181636', tag_ary: [0x0018,0x1636], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1637)', tag_name: "Number of Polygonal Vertices", tag_key: 'NumberOfPolygonalVertices', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0018,1637)', tag_sym: :number_of_polygonal_vertices, tag_ndm: '00181637', tag_ary: [0x0018,0x1637], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1638)', tag_name: "Vertices of the Polygonal Outline", tag_key: 'VerticesOfThePolygonalOutline', tag_vr: [:OF], tag_vm: ["1"], tag_str: '(0018,1638)', tag_sym: :vertices_of_the_polygonal_outline, tag_ndm: '00181638', tag_ary: [0x0018,0x1638], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1700)', tag_name: "Collimator Shape", tag_key: 'CollimatorShape', tag_vr: [:CS], tag_vm: ["1-3"], tag_str: '(0018,1700)', tag_sym: :collimator_shape, tag_ndm: '00181700', tag_ary: [0x0018,0x1700], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1702)', tag_name: "Collimator Left Vertical Edge", tag_key: 'CollimatorLeftVerticalEdge', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0018,1702)', tag_sym: :collimator_left_vertical_edge, tag_ndm: '00181702', tag_ary: [0x0018,0x1702], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1704)', tag_name: "Collimator Right Vertical Edge", tag_key: 'CollimatorRightVerticalEdge', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0018,1704)', tag_sym: :collimator_right_vertical_edge, tag_ndm: '00181704', tag_ary: [0x0018,0x1704], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1706)', tag_name: "Collimator Upper Horizontal Edge", tag_key: 'CollimatorUpperHorizontalEdge', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0018,1706)', tag_sym: :collimator_upper_horizontal_edge, tag_ndm: '00181706', tag_ary: [0x0018,0x1706], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1708)', tag_name: "Collimator Lower Horizontal Edge", tag_key: 'CollimatorLowerHorizontalEdge', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0018,1708)', tag_sym: :collimator_lower_horizontal_edge, tag_ndm: '00181708', tag_ary: [0x0018,0x1708], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1710)', tag_name: "Center of Circular Collimator", tag_key: 'CenterOfCircularCollimator', tag_vr: [:IS], tag_vm: ["2"], tag_str: '(0018,1710)', tag_sym: :center_of_circular_collimator, tag_ndm: '00181710', tag_ary: [0x0018,0x1710], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1712)', tag_name: "Radius of Circular Collimator", tag_key: 'RadiusOfCircularCollimator', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0018,1712)', tag_sym: :radius_of_circular_collimator, tag_ndm: '00181712', tag_ary: [0x0018,0x1712], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1720)', tag_name: "Vertices of the Polygonal Collimator", tag_key: 'VerticesOfThePolygonalCollimator', tag_vr: [:IS], tag_vm: ["2-2n"], tag_str: '(0018,1720)', tag_sym: :vertices_of_the_polygonal_collimator, tag_ndm: '00181720', tag_ary: [0x0018,0x1720], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1800)', tag_name: "Acquisition Time Synchronized", tag_key: 'AcquisitionTimeSynchronized', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,1800)', tag_sym: :acquisition_time_synchronized, tag_ndm: '00181800', tag_ary: [0x0018,0x1800], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1801)', tag_name: "Time Source", tag_key: 'TimeSource', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0018,1801)', tag_sym: :time_source, tag_ndm: '00181801', tag_ary: [0x0018,0x1801], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1802)', tag_name: "Time Distribution Protocol", tag_key: 'TimeDistributionProtocol', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,1802)', tag_sym: :time_distribution_protocol, tag_ndm: '00181802', tag_ary: [0x0018,0x1802], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,1803)', tag_name: "NTP Source Address", tag_key: 'NTPSourceAddress', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0018,1803)', tag_sym: :ntp_source_address, tag_ndm: '00181803', tag_ary: [0x0018,0x1803], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,2001)', tag_name: "Page Number Vector", tag_key: 'PageNumberVector', tag_vr: [:IS], tag_vm: ["1-n"], tag_str: '(0018,2001)', tag_sym: :page_number_vector, tag_ndm: '00182001', tag_ary: [0x0018,0x2001], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,2002)', tag_name: "Frame Label Vector", tag_key: 'FrameLabelVector', tag_vr: [:SH], tag_vm: ["1-n"], tag_str: '(0018,2002)', tag_sym: :frame_label_vector, tag_ndm: '00182002', tag_ary: [0x0018,0x2002], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,2003)', tag_name: "Frame Primary Angle Vector", tag_key: 'FramePrimaryAngleVector', tag_vr: [:DS], tag_vm: ["1-n"], tag_str: '(0018,2003)', tag_sym: :frame_primary_angle_vector, tag_ndm: '00182003', tag_ary: [0x0018,0x2003], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,2004)', tag_name: "Frame Secondary Angle Vector", tag_key: 'FrameSecondaryAngleVector', tag_vr: [:DS], tag_vm: ["1-n"], tag_str: '(0018,2004)', tag_sym: :frame_secondary_angle_vector, tag_ndm: '00182004', tag_ary: [0x0018,0x2004], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,2005)', tag_name: "Slice Location Vector", tag_key: 'SliceLocationVector', tag_vr: [:DS], tag_vm: ["1-n"], tag_str: '(0018,2005)', tag_sym: :slice_location_vector, tag_ndm: '00182005', tag_ary: [0x0018,0x2005], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,2006)', tag_name: "Display Window Label Vector", tag_key: 'DisplayWindowLabelVector', tag_vr: [:SH], tag_vm: ["1-n"], tag_str: '(0018,2006)', tag_sym: :display_window_label_vector, tag_ndm: '00182006', tag_ary: [0x0018,0x2006], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,2010)', tag_name: "Nominal Scanned Pixel Spacing", tag_key: 'NominalScannedPixelSpacing', tag_vr: [:DS], tag_vm: ["2"], tag_str: '(0018,2010)', tag_sym: :nominal_scanned_pixel_spacing, tag_ndm: '00182010', tag_ary: [0x0018,0x2010], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,2020)', tag_name: "Digitizing Device Transport Direction", tag_key: 'DigitizingDeviceTransportDirection', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,2020)', tag_sym: :digitizing_device_transport_direction, tag_ndm: '00182020', tag_ary: [0x0018,0x2020], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,2030)', tag_name: "Rotation of Scanned Film", tag_key: 'RotationOfScannedFilm', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,2030)', tag_sym: :rotation_of_scanned_film, tag_ndm: '00182030', tag_ary: [0x0018,0x2030], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,2041)', tag_name: "Biopsy Target Sequence", tag_key: 'BiopsyTargetSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,2041)', tag_sym: :biopsy_target_sequence, tag_ndm: '00182041', tag_ary: [0x0018,0x2041], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,2042)', tag_name: "Target UID", tag_key: 'TargetUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0018,2042)', tag_sym: :target_uid, tag_ndm: '00182042', tag_ary: [0x0018,0x2042], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,2043)', tag_name: "Localizing Cursor Position", tag_key: 'LocalizingCursorPosition', tag_vr: [:FL], tag_vm: ["2"], tag_str: '(0018,2043)', tag_sym: :localizing_cursor_position, tag_ndm: '00182043', tag_ary: [0x0018,0x2043], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,2044)', tag_name: "Calculated Target Position", tag_key: 'CalculatedTargetPosition', tag_vr: [:FL], tag_vm: ["3"], tag_str: '(0018,2044)', tag_sym: :calculated_target_position, tag_ndm: '00182044', tag_ary: [0x0018,0x2044], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,2045)', tag_name: "Target Label", tag_key: 'TargetLabel', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0018,2045)', tag_sym: :target_label, tag_ndm: '00182045', tag_ary: [0x0018,0x2045], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,2046)', tag_name: "Displayed Z Value", tag_key: 'DisplayedZValue', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0018,2046)', tag_sym: :displayed_z_value, tag_ndm: '00182046', tag_ary: [0x0018,0x2046], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,3100)', tag_name: "IVUS Acquisition", tag_key: 'IVUSAcquisition', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,3100)', tag_sym: :ivus_acquisition, tag_ndm: '00183100', tag_ary: [0x0018,0x3100], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,3101)', tag_name: "IVUS Pullback Rate", tag_key: 'IVUSPullbackRate', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,3101)', tag_sym: :ivus_pullback_rate, tag_ndm: '00183101', tag_ary: [0x0018,0x3101], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,3102)', tag_name: "IVUS Gated Rate", tag_key: 'IVUSGatedRate', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,3102)', tag_sym: :ivus_gated_rate, tag_ndm: '00183102', tag_ary: [0x0018,0x3102], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,3103)', tag_name: "IVUS Pullback Start Frame Number", tag_key: 'IVUSPullbackStartFrameNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0018,3103)', tag_sym: :ivus_pullback_start_frame_number, tag_ndm: '00183103', tag_ary: [0x0018,0x3103], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,3104)', tag_name: "IVUS Pullback Stop Frame Number", tag_key: 'IVUSPullbackStopFrameNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0018,3104)', tag_sym: :ivus_pullback_stop_frame_number, tag_ndm: '00183104', tag_ary: [0x0018,0x3104], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,3105)', tag_name: "Lesion Number", tag_key: 'LesionNumber', tag_vr: [:IS], tag_vm: ["1-n"], tag_str: '(0018,3105)', tag_sym: :lesion_number, tag_ndm: '00183105', tag_ary: [0x0018,0x3105], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,4000)', tag_name: "Acquisition Comments", tag_key: 'AcquisitionComments', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(0018,4000)', tag_sym: :acquisition_comments, tag_ndm: '00184000', tag_ary: [0x0018,0x4000], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(0018,5000)', tag_name: "Output Power", tag_key: 'OutputPower', tag_vr: [:SH], tag_vm: ["1-n"], tag_str: '(0018,5000)', tag_sym: :output_power, tag_ndm: '00185000', tag_ary: [0x0018,0x5000], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,5010)', tag_name: "Transducer Data", tag_key: 'TransducerData', tag_vr: [:LO], tag_vm: ["1-n"], tag_str: '(0018,5010)', tag_sym: :transducer_data, tag_ndm: '00185010', tag_ary: [0x0018,0x5010], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,5011)', tag_name: "Transducer Identification Sequence", tag_key: 'TransducerIdentificationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,5011)', tag_sym: :transducer_identification_sequence, tag_ndm: '00185011', tag_ary: [0x0018,0x5011], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,5012)', tag_name: "Focus Depth", tag_key: 'FocusDepth', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,5012)', tag_sym: :focus_depth, tag_ndm: '00185012', tag_ary: [0x0018,0x5012], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,5020)', tag_name: "Processing Function", tag_key: 'ProcessingFunction', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0018,5020)', tag_sym: :processing_function, tag_ndm: '00185020', tag_ary: [0x0018,0x5020], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,5021)', tag_name: "Postprocessing Function", tag_key: 'PostprocessingFunction', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0018,5021)', tag_sym: :postprocessing_function, tag_ndm: '00185021', tag_ary: [0x0018,0x5021], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0018,5022)', tag_name: "Mechanical Index", tag_key: 'MechanicalIndex', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,5022)', tag_sym: :mechanical_index, tag_ndm: '00185022', tag_ary: [0x0018,0x5022], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,5024)', tag_name: "Bone Thermal Index", tag_key: 'BoneThermalIndex', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,5024)', tag_sym: :bone_thermal_index, tag_ndm: '00185024', tag_ary: [0x0018,0x5024], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,5026)', tag_name: "Cranial Thermal Index", tag_key: 'CranialThermalIndex', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,5026)', tag_sym: :cranial_thermal_index, tag_ndm: '00185026', tag_ary: [0x0018,0x5026], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,5027)', tag_name: "Soft Tissue Thermal Index", tag_key: 'SoftTissueThermalIndex', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,5027)', tag_sym: :soft_tissue_thermal_index, tag_ndm: '00185027', tag_ary: [0x0018,0x5027], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,5028)', tag_name: "Soft Tissue-focus Thermal Index", tag_key: 'SoftTissueFocusThermalIndex', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,5028)', tag_sym: :soft_tissue_focus_thermal_index, tag_ndm: '00185028', tag_ary: [0x0018,0x5028], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,5029)', tag_name: "Soft Tissue-surface Thermal Index", tag_key: 'SoftTissueSurfaceThermalIndex', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,5029)', tag_sym: :soft_tissue_surface_thermal_index, tag_ndm: '00185029', tag_ary: [0x0018,0x5029], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,5030)', tag_name: "Dynamic Range", tag_key: 'DynamicRange', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,5030)', tag_sym: :dynamic_range, tag_ndm: '00185030', tag_ary: [0x0018,0x5030], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(0018,5040)', tag_name: "Total Gain", tag_key: 'TotalGain', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,5040)', tag_sym: :total_gain, tag_ndm: '00185040', tag_ary: [0x0018,0x5040], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(0018,5050)', tag_name: "Depth of Scan Field", tag_key: 'DepthOfScanField', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0018,5050)', tag_sym: :depth_of_scan_field, tag_ndm: '00185050', tag_ary: [0x0018,0x5050], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,5100)', tag_name: "Patient Position", tag_key: 'PatientPosition', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,5100)', tag_sym: :patient_position, tag_ndm: '00185100', tag_ary: [0x0018,0x5100], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,5101)', tag_name: "View Position", tag_key: 'ViewPosition', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,5101)', tag_sym: :view_position, tag_ndm: '00185101', tag_ary: [0x0018,0x5101], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,5104)', tag_name: "Projection Eponymous Name Code Sequence", tag_key: 'ProjectionEponymousNameCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,5104)', tag_sym: :projection_eponymous_name_code_sequence, tag_ndm: '00185104', tag_ary: [0x0018,0x5104], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,5210)', tag_name: "Image Transformation Matrix", tag_key: 'ImageTransformationMatrix', tag_vr: [:DS], tag_vm: ["6"], tag_str: '(0018,5210)', tag_sym: :image_transformation_matrix, tag_ndm: '00185210', tag_ary: [0x0018,0x5210], tag_multiple: false, tag_note: 'RET (2003)'},
      { tag_ps: '(0018,5212)', tag_name: "Image Translation Vector", tag_key: 'ImageTranslationVector', tag_vr: [:DS], tag_vm: ["3"], tag_str: '(0018,5212)', tag_sym: :image_translation_vector, tag_ndm: '00185212', tag_ary: [0x0018,0x5212], tag_multiple: false, tag_note: 'RET (2003)'},
      { tag_ps: '(0018,6000)', tag_name: "Sensitivity", tag_key: 'Sensitivity', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,6000)', tag_sym: :sensitivity, tag_ndm: '00186000', tag_ary: [0x0018,0x6000], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,6011)', tag_name: "Sequence of Ultrasound Regions", tag_key: 'SequenceOfUltrasoundRegions', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,6011)', tag_sym: :sequence_of_ultrasound_regions, tag_ndm: '00186011', tag_ary: [0x0018,0x6011], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,6012)', tag_name: "Region Spatial Format", tag_key: 'RegionSpatialFormat', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0018,6012)', tag_sym: :region_spatial_format, tag_ndm: '00186012', tag_ary: [0x0018,0x6012], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,6014)', tag_name: "Region Data Type", tag_key: 'RegionDataType', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0018,6014)', tag_sym: :region_data_type, tag_ndm: '00186014', tag_ary: [0x0018,0x6014], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,6016)', tag_name: "Region Flags", tag_key: 'RegionFlags', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0018,6016)', tag_sym: :region_flags, tag_ndm: '00186016', tag_ary: [0x0018,0x6016], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,6018)', tag_name: "Region Location Min X0", tag_key: 'RegionLocationMinX0', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0018,6018)', tag_sym: :region_location_min_x0, tag_ndm: '00186018', tag_ary: [0x0018,0x6018], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,601A)', tag_name: "Region Location Min Y0", tag_key: 'RegionLocationMinY0', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0018,601A)', tag_sym: :region_location_min_y0, tag_ndm: '0018601A', tag_ary: [0x0018,0x601A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,601C)', tag_name: "Region Location Max X1", tag_key: 'RegionLocationMaxX1', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0018,601C)', tag_sym: :region_location_max_x1, tag_ndm: '0018601C', tag_ary: [0x0018,0x601C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,601E)', tag_name: "Region Location Max Y1", tag_key: 'RegionLocationMaxY1', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0018,601E)', tag_sym: :region_location_max_y1, tag_ndm: '0018601E', tag_ary: [0x0018,0x601E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,6020)', tag_name: "Reference Pixel X0", tag_key: 'ReferencePixelX0', tag_vr: [:SL], tag_vm: ["1"], tag_str: '(0018,6020)', tag_sym: :reference_pixel_x0, tag_ndm: '00186020', tag_ary: [0x0018,0x6020], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,6022)', tag_name: "Reference Pixel Y0", tag_key: 'ReferencePixelY0', tag_vr: [:SL], tag_vm: ["1"], tag_str: '(0018,6022)', tag_sym: :reference_pixel_y0, tag_ndm: '00186022', tag_ary: [0x0018,0x6022], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,6024)', tag_name: "Physical Units X Direction", tag_key: 'PhysicalUnitsXDirection', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0018,6024)', tag_sym: :physical_units_x_direction, tag_ndm: '00186024', tag_ary: [0x0018,0x6024], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,6026)', tag_name: "Physical Units Y Direction", tag_key: 'PhysicalUnitsYDirection', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0018,6026)', tag_sym: :physical_units_y_direction, tag_ndm: '00186026', tag_ary: [0x0018,0x6026], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,6028)', tag_name: "Reference Pixel Physical Value X", tag_key: 'ReferencePixelPhysicalValueX', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,6028)', tag_sym: :reference_pixel_physical_value_x, tag_ndm: '00186028', tag_ary: [0x0018,0x6028], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,602A)', tag_name: "Reference Pixel Physical Value Y", tag_key: 'ReferencePixelPhysicalValueY', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,602A)', tag_sym: :reference_pixel_physical_value_y, tag_ndm: '0018602A', tag_ary: [0x0018,0x602A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,602C)', tag_name: "Physical Delta X", tag_key: 'PhysicalDeltaX', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,602C)', tag_sym: :physical_delta_x, tag_ndm: '0018602C', tag_ary: [0x0018,0x602C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,602E)', tag_name: "Physical Delta Y", tag_key: 'PhysicalDeltaY', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,602E)', tag_sym: :physical_delta_y, tag_ndm: '0018602E', tag_ary: [0x0018,0x602E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,6030)', tag_name: "Transducer Frequency", tag_key: 'TransducerFrequency', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0018,6030)', tag_sym: :transducer_frequency, tag_ndm: '00186030', tag_ary: [0x0018,0x6030], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,6031)', tag_name: "Transducer Type", tag_key: 'TransducerType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,6031)', tag_sym: :transducer_type, tag_ndm: '00186031', tag_ary: [0x0018,0x6031], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,6032)', tag_name: "Pulse Repetition Frequency", tag_key: 'PulseRepetitionFrequency', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0018,6032)', tag_sym: :pulse_repetition_frequency, tag_ndm: '00186032', tag_ary: [0x0018,0x6032], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,6034)', tag_name: "Doppler Correction Angle", tag_key: 'DopplerCorrectionAngle', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,6034)', tag_sym: :doppler_correction_angle, tag_ndm: '00186034', tag_ary: [0x0018,0x6034], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,6036)', tag_name: "Steering Angle", tag_key: 'SteeringAngle', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,6036)', tag_sym: :steering_angle, tag_ndm: '00186036', tag_ary: [0x0018,0x6036], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,6038)', tag_name: "Doppler Sample Volume X Position (Retired)", tag_key: 'DopplerSampleVolumeXPositionRetired', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0018,6038)', tag_sym: :doppler_sample_volume_x_position_retired, tag_ndm: '00186038', tag_ary: [0x0018,0x6038], tag_multiple: false, tag_note: 'RET (2001)'},
      { tag_ps: '(0018,6039)', tag_name: "Doppler Sample Volume X Position", tag_key: 'DopplerSampleVolumeXPosition', tag_vr: [:SL], tag_vm: ["1"], tag_str: '(0018,6039)', tag_sym: :doppler_sample_volume_x_position, tag_ndm: '00186039', tag_ary: [0x0018,0x6039], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,603A)', tag_name: "Doppler Sample Volume Y Position (Retired)", tag_key: 'DopplerSampleVolumeYPositionRetired', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0018,603A)', tag_sym: :doppler_sample_volume_y_position_retired, tag_ndm: '0018603A', tag_ary: [0x0018,0x603A], tag_multiple: false, tag_note: 'RET (2001)'},
      { tag_ps: '(0018,603B)', tag_name: "Doppler Sample Volume Y Position", tag_key: 'DopplerSampleVolumeYPosition', tag_vr: [:SL], tag_vm: ["1"], tag_str: '(0018,603B)', tag_sym: :doppler_sample_volume_y_position, tag_ndm: '0018603B', tag_ary: [0x0018,0x603B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,603C)', tag_name: "TM-Line Position X0 (Retired)", tag_key: 'TMLinePositionX0Retired', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0018,603C)', tag_sym: :tm_line_position_x0_retired, tag_ndm: '0018603C', tag_ary: [0x0018,0x603C], tag_multiple: false, tag_note: 'RET (2001)'},
      { tag_ps: '(0018,603D)', tag_name: "TM-Line Position X0", tag_key: 'TMLinePositionX0', tag_vr: [:SL], tag_vm: ["1"], tag_str: '(0018,603D)', tag_sym: :tm_line_position_x0, tag_ndm: '0018603D', tag_ary: [0x0018,0x603D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,603E)', tag_name: "TM-Line Position Y0 (Retired)", tag_key: 'TMLinePositionY0Retired', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0018,603E)', tag_sym: :tm_line_position_y0_retired, tag_ndm: '0018603E', tag_ary: [0x0018,0x603E], tag_multiple: false, tag_note: 'RET (2001)'},
      { tag_ps: '(0018,603F)', tag_name: "TM-Line Position Y0", tag_key: 'TMLinePositionY0', tag_vr: [:SL], tag_vm: ["1"], tag_str: '(0018,603F)', tag_sym: :tm_line_position_y0, tag_ndm: '0018603F', tag_ary: [0x0018,0x603F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,6040)', tag_name: "TM-Line Position X1 (Retired)", tag_key: 'TMLinePositionX1Retired', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0018,6040)', tag_sym: :tm_line_position_x1_retired, tag_ndm: '00186040', tag_ary: [0x0018,0x6040], tag_multiple: false, tag_note: 'RET (2001)'},
      { tag_ps: '(0018,6041)', tag_name: "TM-Line Position X1", tag_key: 'TMLinePositionX1', tag_vr: [:SL], tag_vm: ["1"], tag_str: '(0018,6041)', tag_sym: :tm_line_position_x1, tag_ndm: '00186041', tag_ary: [0x0018,0x6041], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,6042)', tag_name: "TM-Line Position Y1 (Retired)", tag_key: 'TMLinePositionY1Retired', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0018,6042)', tag_sym: :tm_line_position_y1_retired, tag_ndm: '00186042', tag_ary: [0x0018,0x6042], tag_multiple: false, tag_note: 'RET (2001)'},
      { tag_ps: '(0018,6043)', tag_name: "TM-Line Position Y1", tag_key: 'TMLinePositionY1', tag_vr: [:SL], tag_vm: ["1"], tag_str: '(0018,6043)', tag_sym: :tm_line_position_y1, tag_ndm: '00186043', tag_ary: [0x0018,0x6043], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,6044)', tag_name: "Pixel Component Organization", tag_key: 'PixelComponentOrganization', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0018,6044)', tag_sym: :pixel_component_organization, tag_ndm: '00186044', tag_ary: [0x0018,0x6044], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,6046)', tag_name: "Pixel Component Mask", tag_key: 'PixelComponentMask', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0018,6046)', tag_sym: :pixel_component_mask, tag_ndm: '00186046', tag_ary: [0x0018,0x6046], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,6048)', tag_name: "Pixel Component Range Start", tag_key: 'PixelComponentRangeStart', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0018,6048)', tag_sym: :pixel_component_range_start, tag_ndm: '00186048', tag_ary: [0x0018,0x6048], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,604A)', tag_name: "Pixel Component Range Stop", tag_key: 'PixelComponentRangeStop', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0018,604A)', tag_sym: :pixel_component_range_stop, tag_ndm: '0018604A', tag_ary: [0x0018,0x604A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,604C)', tag_name: "Pixel Component Physical Units", tag_key: 'PixelComponentPhysicalUnits', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0018,604C)', tag_sym: :pixel_component_physical_units, tag_ndm: '0018604C', tag_ary: [0x0018,0x604C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,604E)', tag_name: "Pixel Component Data Type", tag_key: 'PixelComponentDataType', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0018,604E)', tag_sym: :pixel_component_data_type, tag_ndm: '0018604E', tag_ary: [0x0018,0x604E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,6050)', tag_name: "Number of Table Break Points", tag_key: 'NumberOfTableBreakPoints', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0018,6050)', tag_sym: :number_of_table_break_points, tag_ndm: '00186050', tag_ary: [0x0018,0x6050], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,6052)', tag_name: "Table of X Break Points", tag_key: 'TableOfXBreakPoints', tag_vr: [:UL], tag_vm: ["1-n"], tag_str: '(0018,6052)', tag_sym: :table_of_x_break_points, tag_ndm: '00186052', tag_ary: [0x0018,0x6052], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,6054)', tag_name: "Table of Y Break Points", tag_key: 'TableOfYBreakPoints', tag_vr: [:FD], tag_vm: ["1-n"], tag_str: '(0018,6054)', tag_sym: :table_of_y_break_points, tag_ndm: '00186054', tag_ary: [0x0018,0x6054], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,6056)', tag_name: "Number of Table Entries", tag_key: 'NumberOfTableEntries', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0018,6056)', tag_sym: :number_of_table_entries, tag_ndm: '00186056', tag_ary: [0x0018,0x6056], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,6058)', tag_name: "Table of Pixel Values", tag_key: 'TableOfPixelValues', tag_vr: [:UL], tag_vm: ["1-n"], tag_str: '(0018,6058)', tag_sym: :table_of_pixel_values, tag_ndm: '00186058', tag_ary: [0x0018,0x6058], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,605A)', tag_name: "Table of Parameter Values", tag_key: 'TableOfParameterValues', tag_vr: [:FL], tag_vm: ["1-n"], tag_str: '(0018,605A)', tag_sym: :table_of_parameter_values, tag_ndm: '0018605A', tag_ary: [0x0018,0x605A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,6060)', tag_name: "R Wave Time Vector", tag_key: 'RWaveTimeVector', tag_vr: [:FL], tag_vm: ["1-n"], tag_str: '(0018,6060)', tag_sym: :r_wave_time_vector, tag_ndm: '00186060', tag_ary: [0x0018,0x6060], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,6070)', tag_name: "Active Image Area Overlay Group", tag_key: 'ActiveImageAreaOverlayGroup', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0018,6070)', tag_sym: :active_image_area_overlay_group, tag_ndm: '00186070', tag_ary: [0x0018,0x6070], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,7000)', tag_name: "Detector Conditions Nominal Flag", tag_key: 'DetectorConditionsNominalFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,7000)', tag_sym: :detector_conditions_nominal_flag, tag_ndm: '00187000', tag_ary: [0x0018,0x7000], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,7001)', tag_name: "Detector Temperature", tag_key: 'DetectorTemperature', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,7001)', tag_sym: :detector_temperature, tag_ndm: '00187001', tag_ary: [0x0018,0x7001], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,7004)', tag_name: "Detector Type", tag_key: 'DetectorType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,7004)', tag_sym: :detector_type, tag_ndm: '00187004', tag_ary: [0x0018,0x7004], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,7005)', tag_name: "Detector Configuration", tag_key: 'DetectorConfiguration', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,7005)', tag_sym: :detector_configuration, tag_ndm: '00187005', tag_ary: [0x0018,0x7005], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,7006)', tag_name: "Detector Description", tag_key: 'DetectorDescription', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(0018,7006)', tag_sym: :detector_description, tag_ndm: '00187006', tag_ary: [0x0018,0x7006], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,7008)', tag_name: "Detector Mode", tag_key: 'DetectorMode', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(0018,7008)', tag_sym: :detector_mode, tag_ndm: '00187008', tag_ary: [0x0018,0x7008], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,700A)', tag_name: "Detector ID", tag_key: 'DetectorID', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0018,700A)', tag_sym: :detector_id, tag_ndm: '0018700A', tag_ary: [0x0018,0x700A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,700C)', tag_name: "Date of Last Detector Calibration", tag_key: 'DateOfLastDetectorCalibration', tag_vr: [:DA], tag_vm: ["1"], tag_str: '(0018,700C)', tag_sym: :date_of_last_detector_calibration, tag_ndm: '0018700C', tag_ary: [0x0018,0x700C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,700E)', tag_name: "Time of Last Detector Calibration", tag_key: 'TimeOfLastDetectorCalibration', tag_vr: [:TM], tag_vm: ["1"], tag_str: '(0018,700E)', tag_sym: :time_of_last_detector_calibration, tag_ndm: '0018700E', tag_ary: [0x0018,0x700E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,7010)', tag_name: "Exposures on Detector Since Last Calibration", tag_key: 'ExposuresOnDetectorSinceLastCalibration', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0018,7010)', tag_sym: :exposures_on_detector_since_last_calibration, tag_ndm: '00187010', tag_ary: [0x0018,0x7010], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,7011)', tag_name: "Exposures on Detector Since Manufactured", tag_key: 'ExposuresOnDetectorSinceManufactured', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0018,7011)', tag_sym: :exposures_on_detector_since_manufactured, tag_ndm: '00187011', tag_ary: [0x0018,0x7011], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,7012)', tag_name: "Detector Time Since Last Exposure", tag_key: 'DetectorTimeSinceLastExposure', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,7012)', tag_sym: :detector_time_since_last_exposure, tag_ndm: '00187012', tag_ary: [0x0018,0x7012], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,7014)', tag_name: "Detector Active Time", tag_key: 'DetectorActiveTime', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,7014)', tag_sym: :detector_active_time, tag_ndm: '00187014', tag_ary: [0x0018,0x7014], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,7016)', tag_name: "Detector Activation Offset From Exposure", tag_key: 'DetectorActivationOffsetFromExposure', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,7016)', tag_sym: :detector_activation_offset_from_exposure, tag_ndm: '00187016', tag_ary: [0x0018,0x7016], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,701A)', tag_name: "Detector Binning", tag_key: 'DetectorBinning', tag_vr: [:DS], tag_vm: ["2"], tag_str: '(0018,701A)', tag_sym: :detector_binning, tag_ndm: '0018701A', tag_ary: [0x0018,0x701A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,7020)', tag_name: "Detector Element Physical Size", tag_key: 'DetectorElementPhysicalSize', tag_vr: [:DS], tag_vm: ["2"], tag_str: '(0018,7020)', tag_sym: :detector_element_physical_size, tag_ndm: '00187020', tag_ary: [0x0018,0x7020], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,7022)', tag_name: "Detector Element Spacing", tag_key: 'DetectorElementSpacing', tag_vr: [:DS], tag_vm: ["2"], tag_str: '(0018,7022)', tag_sym: :detector_element_spacing, tag_ndm: '00187022', tag_ary: [0x0018,0x7022], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,7024)', tag_name: "Detector Active Shape", tag_key: 'DetectorActiveShape', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,7024)', tag_sym: :detector_active_shape, tag_ndm: '00187024', tag_ary: [0x0018,0x7024], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,7026)', tag_name: "Detector Active Dimension(s)", tag_key: 'DetectorActiveDimensions', tag_vr: [:DS], tag_vm: ["1-2"], tag_str: '(0018,7026)', tag_sym: :detector_active_dimensions, tag_ndm: '00187026', tag_ary: [0x0018,0x7026], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,7028)', tag_name: "Detector Active Origin", tag_key: 'DetectorActiveOrigin', tag_vr: [:DS], tag_vm: ["2"], tag_str: '(0018,7028)', tag_sym: :detector_active_origin, tag_ndm: '00187028', tag_ary: [0x0018,0x7028], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,702A)', tag_name: "Detector Manufacturer Name", tag_key: 'DetectorManufacturerName', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0018,702A)', tag_sym: :detector_manufacturer_name, tag_ndm: '0018702A', tag_ary: [0x0018,0x702A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,702B)', tag_name: "Detector Manufacturer's Model Name", tag_key: 'DetectorManufacturerModelName', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0018,702B)', tag_sym: :detector_manufacturer_model_name, tag_ndm: '0018702B', tag_ary: [0x0018,0x702B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,7030)', tag_name: "Field of View Origin", tag_key: 'FieldOfViewOrigin', tag_vr: [:DS], tag_vm: ["2"], tag_str: '(0018,7030)', tag_sym: :field_of_view_origin, tag_ndm: '00187030', tag_ary: [0x0018,0x7030], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,7032)', tag_name: "Field of View Rotation", tag_key: 'FieldOfViewRotation', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,7032)', tag_sym: :field_of_view_rotation, tag_ndm: '00187032', tag_ary: [0x0018,0x7032], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,7034)', tag_name: "Field of View Horizontal Flip", tag_key: 'FieldOfViewHorizontalFlip', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,7034)', tag_sym: :field_of_view_horizontal_flip, tag_ndm: '00187034', tag_ary: [0x0018,0x7034], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,7036)', tag_name: "Pixel Data Area Origin Relative To FOV", tag_key: 'PixelDataAreaOriginRelativeToFOV', tag_vr: [:FL], tag_vm: ["2"], tag_str: '(0018,7036)', tag_sym: :pixel_data_area_origin_relative_to_fov, tag_ndm: '00187036', tag_ary: [0x0018,0x7036], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,7038)', tag_name: "Pixel Data Area Rotation Angle Relative To FOV", tag_key: 'PixelDataAreaRotationAngleRelativeToFOV', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0018,7038)', tag_sym: :pixel_data_area_rotation_angle_relative_to_fov, tag_ndm: '00187038', tag_ary: [0x0018,0x7038], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,7040)', tag_name: "Grid Absorbing Material", tag_key: 'GridAbsorbingMaterial', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(0018,7040)', tag_sym: :grid_absorbing_material, tag_ndm: '00187040', tag_ary: [0x0018,0x7040], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,7041)', tag_name: "Grid Spacing Material", tag_key: 'GridSpacingMaterial', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(0018,7041)', tag_sym: :grid_spacing_material, tag_ndm: '00187041', tag_ary: [0x0018,0x7041], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,7042)', tag_name: "Grid Thickness", tag_key: 'GridThickness', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,7042)', tag_sym: :grid_thickness, tag_ndm: '00187042', tag_ary: [0x0018,0x7042], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,7044)', tag_name: "Grid Pitch", tag_key: 'GridPitch', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,7044)', tag_sym: :grid_pitch, tag_ndm: '00187044', tag_ary: [0x0018,0x7044], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,7046)', tag_name: "Grid Aspect Ratio", tag_key: 'GridAspectRatio', tag_vr: [:IS], tag_vm: ["2"], tag_str: '(0018,7046)', tag_sym: :grid_aspect_ratio, tag_ndm: '00187046', tag_ary: [0x0018,0x7046], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,7048)', tag_name: "Grid Period", tag_key: 'GridPeriod', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,7048)', tag_sym: :grid_period, tag_ndm: '00187048', tag_ary: [0x0018,0x7048], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,704C)', tag_name: "Grid Focal Distance", tag_key: 'GridFocalDistance', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,704C)', tag_sym: :grid_focal_distance, tag_ndm: '0018704C', tag_ary: [0x0018,0x704C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,7050)', tag_name: "Filter Material", tag_key: 'FilterMaterial', tag_vr: [:CS], tag_vm: ["1-n"], tag_str: '(0018,7050)', tag_sym: :filter_material, tag_ndm: '00187050', tag_ary: [0x0018,0x7050], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,7052)', tag_name: "Filter Thickness Minimum", tag_key: 'FilterThicknessMinimum', tag_vr: [:DS], tag_vm: ["1-n"], tag_str: '(0018,7052)', tag_sym: :filter_thickness_minimum, tag_ndm: '00187052', tag_ary: [0x0018,0x7052], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,7054)', tag_name: "Filter Thickness Maximum", tag_key: 'FilterThicknessMaximum', tag_vr: [:DS], tag_vm: ["1-n"], tag_str: '(0018,7054)', tag_sym: :filter_thickness_maximum, tag_ndm: '00187054', tag_ary: [0x0018,0x7054], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,7056)', tag_name: "Filter Beam Path Length Minimum", tag_key: 'FilterBeamPathLengthMinimum', tag_vr: [:FL], tag_vm: ["1-n"], tag_str: '(0018,7056)', tag_sym: :filter_beam_path_length_minimum, tag_ndm: '00187056', tag_ary: [0x0018,0x7056], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,7058)', tag_name: "Filter Beam Path Length Maximum", tag_key: 'FilterBeamPathLengthMaximum', tag_vr: [:FL], tag_vm: ["1-n"], tag_str: '(0018,7058)', tag_sym: :filter_beam_path_length_maximum, tag_ndm: '00187058', tag_ary: [0x0018,0x7058], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,7060)', tag_name: "Exposure Control Mode", tag_key: 'ExposureControlMode', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,7060)', tag_sym: :exposure_control_mode, tag_ndm: '00187060', tag_ary: [0x0018,0x7060], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,7062)', tag_name: "Exposure Control Mode Description", tag_key: 'ExposureControlModeDescription', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(0018,7062)', tag_sym: :exposure_control_mode_description, tag_ndm: '00187062', tag_ary: [0x0018,0x7062], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,7064)', tag_name: "Exposure Status", tag_key: 'ExposureStatus', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,7064)', tag_sym: :exposure_status, tag_ndm: '00187064', tag_ary: [0x0018,0x7064], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,7065)', tag_name: "Phototimer Setting", tag_key: 'PhototimerSetting', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,7065)', tag_sym: :phototimer_setting, tag_ndm: '00187065', tag_ary: [0x0018,0x7065], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,8150)', tag_name: "Exposure Time in µS", tag_key: 'ExposureTimeInuS', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,8150)', tag_sym: :exposure_time_in_us, tag_ndm: '00188150', tag_ary: [0x0018,0x8150], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,8151)', tag_name: "X-Ray Tube Current in µA", tag_key: 'XRayTubeCurrentInuA', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,8151)', tag_sym: :x_ray_tube_current_in_ua, tag_ndm: '00188151', tag_ary: [0x0018,0x8151], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9004)', tag_name: "Content Qualification", tag_key: 'ContentQualification', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9004)', tag_sym: :content_qualification, tag_ndm: '00189004', tag_ary: [0x0018,0x9004], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9005)', tag_name: "Pulse Sequence Name", tag_key: 'PulseSequenceName', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0018,9005)', tag_sym: :pulse_sequence_name, tag_ndm: '00189005', tag_ary: [0x0018,0x9005], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9006)', tag_name: "MR Imaging Modifier Sequence", tag_key: 'MRImagingModifierSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9006)', tag_sym: :mr_imaging_modifier_sequence, tag_ndm: '00189006', tag_ary: [0x0018,0x9006], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9008)', tag_name: "Echo Pulse Sequence", tag_key: 'EchoPulseSequence', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9008)', tag_sym: :echo_pulse_sequence, tag_ndm: '00189008', tag_ary: [0x0018,0x9008], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9009)', tag_name: "Inversion Recovery", tag_key: 'InversionRecovery', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9009)', tag_sym: :inversion_recovery, tag_ndm: '00189009', tag_ary: [0x0018,0x9009], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9010)', tag_name: "Flow Compensation", tag_key: 'FlowCompensation', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9010)', tag_sym: :flow_compensation, tag_ndm: '00189010', tag_ary: [0x0018,0x9010], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9011)', tag_name: "Multiple Spin Echo", tag_key: 'MultipleSpinEcho', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9011)', tag_sym: :multiple_spin_echo, tag_ndm: '00189011', tag_ary: [0x0018,0x9011], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9012)', tag_name: "Multi-planar Excitation", tag_key: 'MultiPlanarExcitation', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9012)', tag_sym: :multi_planar_excitation, tag_ndm: '00189012', tag_ary: [0x0018,0x9012], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9014)', tag_name: "Phase Contrast", tag_key: 'PhaseContrast', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9014)', tag_sym: :phase_contrast, tag_ndm: '00189014', tag_ary: [0x0018,0x9014], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9015)', tag_name: "Time of Flight Contrast", tag_key: 'TimeOfFlightContrast', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9015)', tag_sym: :time_of_flight_contrast, tag_ndm: '00189015', tag_ary: [0x0018,0x9015], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9016)', tag_name: "Spoiling", tag_key: 'Spoiling', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9016)', tag_sym: :spoiling, tag_ndm: '00189016', tag_ary: [0x0018,0x9016], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9017)', tag_name: "Steady State Pulse Sequence", tag_key: 'SteadyStatePulseSequence', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9017)', tag_sym: :steady_state_pulse_sequence, tag_ndm: '00189017', tag_ary: [0x0018,0x9017], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9018)', tag_name: "Echo Planar Pulse Sequence", tag_key: 'EchoPlanarPulseSequence', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9018)', tag_sym: :echo_planar_pulse_sequence, tag_ndm: '00189018', tag_ary: [0x0018,0x9018], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9019)', tag_name: "Tag Angle First Axis", tag_key: 'TagAngleFirstAxis', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9019)', tag_sym: :tag_angle_first_axis, tag_ndm: '00189019', tag_ary: [0x0018,0x9019], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9020)', tag_name: "Magnetization Transfer", tag_key: 'MagnetizationTransfer', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9020)', tag_sym: :magnetization_transfer, tag_ndm: '00189020', tag_ary: [0x0018,0x9020], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9021)', tag_name: "T2 Preparation", tag_key: 'T2Preparation', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9021)', tag_sym: :t2_preparation, tag_ndm: '00189021', tag_ary: [0x0018,0x9021], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9022)', tag_name: "Blood Signal Nulling", tag_key: 'BloodSignalNulling', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9022)', tag_sym: :blood_signal_nulling, tag_ndm: '00189022', tag_ary: [0x0018,0x9022], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9024)', tag_name: "Saturation Recovery", tag_key: 'SaturationRecovery', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9024)', tag_sym: :saturation_recovery, tag_ndm: '00189024', tag_ary: [0x0018,0x9024], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9025)', tag_name: "Spectrally Selected Suppression", tag_key: 'SpectrallySelectedSuppression', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9025)', tag_sym: :spectrally_selected_suppression, tag_ndm: '00189025', tag_ary: [0x0018,0x9025], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9026)', tag_name: "Spectrally Selected Excitation", tag_key: 'SpectrallySelectedExcitation', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9026)', tag_sym: :spectrally_selected_excitation, tag_ndm: '00189026', tag_ary: [0x0018,0x9026], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9027)', tag_name: "Spatial Pre-saturation", tag_key: 'SpatialPresaturation', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9027)', tag_sym: :spatial_presaturation, tag_ndm: '00189027', tag_ary: [0x0018,0x9027], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9028)', tag_name: "Tagging", tag_key: 'Tagging', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9028)', tag_sym: :tagging, tag_ndm: '00189028', tag_ary: [0x0018,0x9028], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9029)', tag_name: "Oversampling Phase", tag_key: 'OversamplingPhase', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9029)', tag_sym: :oversampling_phase, tag_ndm: '00189029', tag_ary: [0x0018,0x9029], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9030)', tag_name: "Tag Spacing First Dimension", tag_key: 'TagSpacingFirstDimension', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9030)', tag_sym: :tag_spacing_first_dimension, tag_ndm: '00189030', tag_ary: [0x0018,0x9030], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9032)', tag_name: "Geometry of k-Space Traversal", tag_key: 'GeometryOfKSpaceTraversal', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9032)', tag_sym: :geometry_of_k_space_traversal, tag_ndm: '00189032', tag_ary: [0x0018,0x9032], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9033)', tag_name: "Segmented k-Space Traversal", tag_key: 'SegmentedKSpaceTraversal', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9033)', tag_sym: :segmented_k_space_traversal, tag_ndm: '00189033', tag_ary: [0x0018,0x9033], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9034)', tag_name: "Rectilinear Phase Encode Reordering", tag_key: 'RectilinearPhaseEncodeReordering', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9034)', tag_sym: :rectilinear_phase_encode_reordering, tag_ndm: '00189034', tag_ary: [0x0018,0x9034], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9035)', tag_name: "Tag Thickness", tag_key: 'TagThickness', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9035)', tag_sym: :tag_thickness, tag_ndm: '00189035', tag_ary: [0x0018,0x9035], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9036)', tag_name: "Partial Fourier Direction", tag_key: 'PartialFourierDirection', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9036)', tag_sym: :partial_fourier_direction, tag_ndm: '00189036', tag_ary: [0x0018,0x9036], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9037)', tag_name: "Cardiac Synchronization Technique", tag_key: 'CardiacSynchronizationTechnique', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9037)', tag_sym: :cardiac_synchronization_technique, tag_ndm: '00189037', tag_ary: [0x0018,0x9037], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9041)', tag_name: "Receive Coil Manufacturer Name", tag_key: 'ReceiveCoilManufacturerName', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0018,9041)', tag_sym: :receive_coil_manufacturer_name, tag_ndm: '00189041', tag_ary: [0x0018,0x9041], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9042)', tag_name: "MR Receive Coil Sequence", tag_key: 'MRReceiveCoilSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9042)', tag_sym: :mr_receive_coil_sequence, tag_ndm: '00189042', tag_ary: [0x0018,0x9042], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9043)', tag_name: "Receive Coil Type", tag_key: 'ReceiveCoilType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9043)', tag_sym: :receive_coil_type, tag_ndm: '00189043', tag_ary: [0x0018,0x9043], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9044)', tag_name: "Quadrature Receive Coil", tag_key: 'QuadratureReceiveCoil', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9044)', tag_sym: :quadrature_receive_coil, tag_ndm: '00189044', tag_ary: [0x0018,0x9044], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9045)', tag_name: "Multi-Coil Definition Sequence", tag_key: 'MultiCoilDefinitionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9045)', tag_sym: :multi_coil_definition_sequence, tag_ndm: '00189045', tag_ary: [0x0018,0x9045], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9046)', tag_name: "Multi-Coil Configuration", tag_key: 'MultiCoilConfiguration', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0018,9046)', tag_sym: :multi_coil_configuration, tag_ndm: '00189046', tag_ary: [0x0018,0x9046], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9047)', tag_name: "Multi-Coil Element Name", tag_key: 'MultiCoilElementName', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0018,9047)', tag_sym: :multi_coil_element_name, tag_ndm: '00189047', tag_ary: [0x0018,0x9047], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9048)', tag_name: "Multi-Coil Element Used", tag_key: 'MultiCoilElementUsed', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9048)', tag_sym: :multi_coil_element_used, tag_ndm: '00189048', tag_ary: [0x0018,0x9048], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9049)', tag_name: "MR Transmit Coil Sequence", tag_key: 'MRTransmitCoilSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9049)', tag_sym: :mr_transmit_coil_sequence, tag_ndm: '00189049', tag_ary: [0x0018,0x9049], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9050)', tag_name: "Transmit Coil Manufacturer Name", tag_key: 'TransmitCoilManufacturerName', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0018,9050)', tag_sym: :transmit_coil_manufacturer_name, tag_ndm: '00189050', tag_ary: [0x0018,0x9050], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9051)', tag_name: "Transmit Coil Type", tag_key: 'TransmitCoilType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9051)', tag_sym: :transmit_coil_type, tag_ndm: '00189051', tag_ary: [0x0018,0x9051], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9052)', tag_name: "Spectral Width", tag_key: 'SpectralWidth', tag_vr: [:FD], tag_vm: ["1-2"], tag_str: '(0018,9052)', tag_sym: :spectral_width, tag_ndm: '00189052', tag_ary: [0x0018,0x9052], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9053)', tag_name: "Chemical Shift Reference", tag_key: 'ChemicalShiftReference', tag_vr: [:FD], tag_vm: ["1-2"], tag_str: '(0018,9053)', tag_sym: :chemical_shift_reference, tag_ndm: '00189053', tag_ary: [0x0018,0x9053], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9054)', tag_name: "Volume Localization Technique", tag_key: 'VolumeLocalizationTechnique', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9054)', tag_sym: :volume_localization_technique, tag_ndm: '00189054', tag_ary: [0x0018,0x9054], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9058)', tag_name: "MR Acquisition Frequency Encoding Steps", tag_key: 'MRAcquisitionFrequencyEncodingSteps', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0018,9058)', tag_sym: :mr_acquisition_frequency_encoding_steps, tag_ndm: '00189058', tag_ary: [0x0018,0x9058], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9059)', tag_name: "De-coupling", tag_key: 'Decoupling', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9059)', tag_sym: :decoupling, tag_ndm: '00189059', tag_ary: [0x0018,0x9059], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9060)', tag_name: "De-coupled Nucleus", tag_key: 'DecoupledNucleus', tag_vr: [:CS], tag_vm: ["1-2"], tag_str: '(0018,9060)', tag_sym: :decoupled_nucleus, tag_ndm: '00189060', tag_ary: [0x0018,0x9060], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9061)', tag_name: "De-coupling Frequency", tag_key: 'DecouplingFrequency', tag_vr: [:FD], tag_vm: ["1-2"], tag_str: '(0018,9061)', tag_sym: :decoupling_frequency, tag_ndm: '00189061', tag_ary: [0x0018,0x9061], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9062)', tag_name: "De-coupling Method", tag_key: 'DecouplingMethod', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9062)', tag_sym: :decoupling_method, tag_ndm: '00189062', tag_ary: [0x0018,0x9062], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9063)', tag_name: "De-coupling Chemical Shift Reference", tag_key: 'DecouplingChemicalShiftReference', tag_vr: [:FD], tag_vm: ["1-2"], tag_str: '(0018,9063)', tag_sym: :decoupling_chemical_shift_reference, tag_ndm: '00189063', tag_ary: [0x0018,0x9063], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9064)', tag_name: "k-space Filtering", tag_key: 'KSpaceFiltering', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9064)', tag_sym: :k_space_filtering, tag_ndm: '00189064', tag_ary: [0x0018,0x9064], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9065)', tag_name: "Time Domain Filtering", tag_key: 'TimeDomainFiltering', tag_vr: [:CS], tag_vm: ["1-2"], tag_str: '(0018,9065)', tag_sym: :time_domain_filtering, tag_ndm: '00189065', tag_ary: [0x0018,0x9065], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9066)', tag_name: "Number of Zero Fills", tag_key: 'NumberOfZeroFills', tag_vr: [:US], tag_vm: ["1-2"], tag_str: '(0018,9066)', tag_sym: :number_of_zero_fills, tag_ndm: '00189066', tag_ary: [0x0018,0x9066], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9067)', tag_name: "Baseline Correction", tag_key: 'BaselineCorrection', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9067)', tag_sym: :baseline_correction, tag_ndm: '00189067', tag_ary: [0x0018,0x9067], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9069)', tag_name: "Parallel Reduction Factor In-plane", tag_key: 'ParallelReductionFactorInPlane', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9069)', tag_sym: :parallel_reduction_factor_in_plane, tag_ndm: '00189069', tag_ary: [0x0018,0x9069], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9070)', tag_name: "Cardiac R-R Interval Specified", tag_key: 'CardiacRRIntervalSpecified', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9070)', tag_sym: :cardiac_rr_interval_specified, tag_ndm: '00189070', tag_ary: [0x0018,0x9070], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9073)', tag_name: "Acquisition Duration", tag_key: 'AcquisitionDuration', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9073)', tag_sym: :acquisition_duration, tag_ndm: '00189073', tag_ary: [0x0018,0x9073], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9074)', tag_name: "Frame Acquisition DateTime", tag_key: 'FrameAcquisitionDateTime', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(0018,9074)', tag_sym: :frame_acquisition_date_time, tag_ndm: '00189074', tag_ary: [0x0018,0x9074], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9075)', tag_name: "Diffusion Directionality", tag_key: 'DiffusionDirectionality', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9075)', tag_sym: :diffusion_directionality, tag_ndm: '00189075', tag_ary: [0x0018,0x9075], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9076)', tag_name: "Diffusion Gradient Direction Sequence", tag_key: 'DiffusionGradientDirectionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9076)', tag_sym: :diffusion_gradient_direction_sequence, tag_ndm: '00189076', tag_ary: [0x0018,0x9076], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9077)', tag_name: "Parallel Acquisition", tag_key: 'ParallelAcquisition', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9077)', tag_sym: :parallel_acquisition, tag_ndm: '00189077', tag_ary: [0x0018,0x9077], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9078)', tag_name: "Parallel Acquisition Technique", tag_key: 'ParallelAcquisitionTechnique', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9078)', tag_sym: :parallel_acquisition_technique, tag_ndm: '00189078', tag_ary: [0x0018,0x9078], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9079)', tag_name: "Inversion Times", tag_key: 'InversionTimes', tag_vr: [:FD], tag_vm: ["1-n"], tag_str: '(0018,9079)', tag_sym: :inversion_times, tag_ndm: '00189079', tag_ary: [0x0018,0x9079], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9080)', tag_name: "Metabolite Map Description", tag_key: 'MetaboliteMapDescription', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0018,9080)', tag_sym: :metabolite_map_description, tag_ndm: '00189080', tag_ary: [0x0018,0x9080], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9081)', tag_name: "Partial Fourier", tag_key: 'PartialFourier', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9081)', tag_sym: :partial_fourier, tag_ndm: '00189081', tag_ary: [0x0018,0x9081], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9082)', tag_name: "Effective Echo Time", tag_key: 'EffectiveEchoTime', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9082)', tag_sym: :effective_echo_time, tag_ndm: '00189082', tag_ary: [0x0018,0x9082], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9083)', tag_name: "Metabolite Map Code Sequence", tag_key: 'MetaboliteMapCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9083)', tag_sym: :metabolite_map_code_sequence, tag_ndm: '00189083', tag_ary: [0x0018,0x9083], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9084)', tag_name: "Chemical Shift Sequence", tag_key: 'ChemicalShiftSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9084)', tag_sym: :chemical_shift_sequence, tag_ndm: '00189084', tag_ary: [0x0018,0x9084], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9085)', tag_name: "Cardiac Signal Source", tag_key: 'CardiacSignalSource', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9085)', tag_sym: :cardiac_signal_source, tag_ndm: '00189085', tag_ary: [0x0018,0x9085], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9087)', tag_name: "Diffusion b-value", tag_key: 'DiffusionBValue', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9087)', tag_sym: :diffusion_b_value, tag_ndm: '00189087', tag_ary: [0x0018,0x9087], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9089)', tag_name: "Diffusion Gradient Orientation", tag_key: 'DiffusionGradientOrientation', tag_vr: [:FD], tag_vm: ["3"], tag_str: '(0018,9089)', tag_sym: :diffusion_gradient_orientation, tag_ndm: '00189089', tag_ary: [0x0018,0x9089], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9090)', tag_name: "Velocity Encoding Direction", tag_key: 'VelocityEncodingDirection', tag_vr: [:FD], tag_vm: ["3"], tag_str: '(0018,9090)', tag_sym: :velocity_encoding_direction, tag_ndm: '00189090', tag_ary: [0x0018,0x9090], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9091)', tag_name: "Velocity Encoding Minimum Value", tag_key: 'VelocityEncodingMinimumValue', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9091)', tag_sym: :velocity_encoding_minimum_value, tag_ndm: '00189091', tag_ary: [0x0018,0x9091], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9092)', tag_name: "Velocity Encoding Acquisition Sequence", tag_key: 'VelocityEncodingAcquisitionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9092)', tag_sym: :velocity_encoding_acquisition_sequence, tag_ndm: '00189092', tag_ary: [0x0018,0x9092], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9093)', tag_name: "Number of k-Space Trajectories", tag_key: 'NumberOfKSpaceTrajectories', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0018,9093)', tag_sym: :number_of_k_space_trajectories, tag_ndm: '00189093', tag_ary: [0x0018,0x9093], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9094)', tag_name: "Coverage of k-Space", tag_key: 'CoverageOfKSpace', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9094)', tag_sym: :coverage_of_k_space, tag_ndm: '00189094', tag_ary: [0x0018,0x9094], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9095)', tag_name: "Spectroscopy Acquisition Phase Rows", tag_key: 'SpectroscopyAcquisitionPhaseRows', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0018,9095)', tag_sym: :spectroscopy_acquisition_phase_rows, tag_ndm: '00189095', tag_ary: [0x0018,0x9095], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9096)', tag_name: "Parallel Reduction Factor In-plane (Retired)", tag_key: 'ParallelReductionFactorInPlaneRetired', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9096)', tag_sym: :parallel_reduction_factor_in_plane_retired, tag_ndm: '00189096', tag_ary: [0x0018,0x9096], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0018,9098)', tag_name: "Transmitter Frequency", tag_key: 'TransmitterFrequency', tag_vr: [:FD], tag_vm: ["1-2"], tag_str: '(0018,9098)', tag_sym: :transmitter_frequency, tag_ndm: '00189098', tag_ary: [0x0018,0x9098], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9100)', tag_name: "Resonant Nucleus", tag_key: 'ResonantNucleus', tag_vr: [:CS], tag_vm: ["1-2"], tag_str: '(0018,9100)', tag_sym: :resonant_nucleus, tag_ndm: '00189100', tag_ary: [0x0018,0x9100], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9101)', tag_name: "Frequency Correction", tag_key: 'FrequencyCorrection', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9101)', tag_sym: :frequency_correction, tag_ndm: '00189101', tag_ary: [0x0018,0x9101], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9103)', tag_name: "MR Spectroscopy FOV/Geometry Sequence", tag_key: 'MRSpectroscopyFOVGeometrySequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9103)', tag_sym: :mr_spectroscopy_fov_geometry_sequence, tag_ndm: '00189103', tag_ary: [0x0018,0x9103], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9104)', tag_name: "Slab Thickness", tag_key: 'SlabThickness', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9104)', tag_sym: :slab_thickness, tag_ndm: '00189104', tag_ary: [0x0018,0x9104], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9105)', tag_name: "Slab Orientation", tag_key: 'SlabOrientation', tag_vr: [:FD], tag_vm: ["3"], tag_str: '(0018,9105)', tag_sym: :slab_orientation, tag_ndm: '00189105', tag_ary: [0x0018,0x9105], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9106)', tag_name: "Mid Slab Position", tag_key: 'MidSlabPosition', tag_vr: [:FD], tag_vm: ["3"], tag_str: '(0018,9106)', tag_sym: :mid_slab_position, tag_ndm: '00189106', tag_ary: [0x0018,0x9106], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9107)', tag_name: "MR Spatial Saturation Sequence", tag_key: 'MRSpatialSaturationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9107)', tag_sym: :mr_spatial_saturation_sequence, tag_ndm: '00189107', tag_ary: [0x0018,0x9107], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9112)', tag_name: "MR Timing and Related Parameters Sequence", tag_key: 'MRTimingAndRelatedParametersSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9112)', tag_sym: :mr_timing_and_related_parameters_sequence, tag_ndm: '00189112', tag_ary: [0x0018,0x9112], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9114)', tag_name: "MR Echo Sequence", tag_key: 'MREchoSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9114)', tag_sym: :mr_echo_sequence, tag_ndm: '00189114', tag_ary: [0x0018,0x9114], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9115)', tag_name: "MR Modifier Sequence", tag_key: 'MRModifierSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9115)', tag_sym: :mr_modifier_sequence, tag_ndm: '00189115', tag_ary: [0x0018,0x9115], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9117)', tag_name: "MR Diffusion Sequence", tag_key: 'MRDiffusionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9117)', tag_sym: :mr_diffusion_sequence, tag_ndm: '00189117', tag_ary: [0x0018,0x9117], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9118)', tag_name: "Cardiac Synchronization Sequence", tag_key: 'CardiacSynchronizationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9118)', tag_sym: :cardiac_synchronization_sequence, tag_ndm: '00189118', tag_ary: [0x0018,0x9118], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9119)', tag_name: "MR Averages Sequence", tag_key: 'MRAveragesSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9119)', tag_sym: :mr_averages_sequence, tag_ndm: '00189119', tag_ary: [0x0018,0x9119], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9125)', tag_name: "MR FOV/Geometry Sequence", tag_key: 'MRFOVGeometrySequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9125)', tag_sym: :mrfov_geometry_sequence, tag_ndm: '00189125', tag_ary: [0x0018,0x9125], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9126)', tag_name: "Volume Localization Sequence", tag_key: 'VolumeLocalizationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9126)', tag_sym: :volume_localization_sequence, tag_ndm: '00189126', tag_ary: [0x0018,0x9126], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9127)', tag_name: "Spectroscopy Acquisition Data Columns", tag_key: 'SpectroscopyAcquisitionDataColumns', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0018,9127)', tag_sym: :spectroscopy_acquisition_data_columns, tag_ndm: '00189127', tag_ary: [0x0018,0x9127], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9147)', tag_name: "Diffusion Anisotropy Type", tag_key: 'DiffusionAnisotropyType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9147)', tag_sym: :diffusion_anisotropy_type, tag_ndm: '00189147', tag_ary: [0x0018,0x9147], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9151)', tag_name: "Frame Reference DateTime", tag_key: 'FrameReferenceDateTime', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(0018,9151)', tag_sym: :frame_reference_date_time, tag_ndm: '00189151', tag_ary: [0x0018,0x9151], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9152)', tag_name: "MR Metabolite Map Sequence", tag_key: 'MRMetaboliteMapSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9152)', tag_sym: :mr_metabolite_map_sequence, tag_ndm: '00189152', tag_ary: [0x0018,0x9152], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9155)', tag_name: "Parallel Reduction Factor out-of-plane", tag_key: 'ParallelReductionFactorOutOfPlane', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9155)', tag_sym: :parallel_reduction_factor_out_of_plane, tag_ndm: '00189155', tag_ary: [0x0018,0x9155], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9159)', tag_name: "Spectroscopy Acquisition Out-of-plane Phase Steps", tag_key: 'SpectroscopyAcquisitionOutOfPlanePhaseSteps', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0018,9159)', tag_sym: :spectroscopy_acquisition_out_of_plane_phase_steps, tag_ndm: '00189159', tag_ary: [0x0018,0x9159], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9166)', tag_name: "Bulk Motion Status", tag_key: 'BulkMotionStatus', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9166)', tag_sym: :bulk_motion_status, tag_ndm: '00189166', tag_ary: [0x0018,0x9166], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0018,9168)', tag_name: "Parallel Reduction Factor Second In-plane", tag_key: 'ParallelReductionFactorSecondInPlane', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9168)', tag_sym: :parallel_reduction_factor_second_in_plane, tag_ndm: '00189168', tag_ary: [0x0018,0x9168], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9169)', tag_name: "Cardiac Beat Rejection Technique", tag_key: 'CardiacBeatRejectionTechnique', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9169)', tag_sym: :cardiac_beat_rejection_technique, tag_ndm: '00189169', tag_ary: [0x0018,0x9169], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9170)', tag_name: "Respiratory Motion Compensation Technique", tag_key: 'RespiratoryMotionCompensationTechnique', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9170)', tag_sym: :respiratory_motion_compensation_technique, tag_ndm: '00189170', tag_ary: [0x0018,0x9170], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9171)', tag_name: "Respiratory Signal Source", tag_key: 'RespiratorySignalSource', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9171)', tag_sym: :respiratory_signal_source, tag_ndm: '00189171', tag_ary: [0x0018,0x9171], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9172)', tag_name: "Bulk Motion Compensation Technique", tag_key: 'BulkMotionCompensationTechnique', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9172)', tag_sym: :bulk_motion_compensation_technique, tag_ndm: '00189172', tag_ary: [0x0018,0x9172], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9173)', tag_name: "Bulk Motion Signal Source", tag_key: 'BulkMotionSignalSource', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9173)', tag_sym: :bulk_motion_signal_source, tag_ndm: '00189173', tag_ary: [0x0018,0x9173], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9174)', tag_name: "Applicable Safety Standard Agency", tag_key: 'ApplicableSafetyStandardAgency', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9174)', tag_sym: :applicable_safety_standard_agency, tag_ndm: '00189174', tag_ary: [0x0018,0x9174], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9175)', tag_name: "Applicable Safety Standard Description", tag_key: 'ApplicableSafetyStandardDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0018,9175)', tag_sym: :applicable_safety_standard_description, tag_ndm: '00189175', tag_ary: [0x0018,0x9175], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9176)', tag_name: "Operating Mode Sequence", tag_key: 'OperatingModeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9176)', tag_sym: :operating_mode_sequence, tag_ndm: '00189176', tag_ary: [0x0018,0x9176], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9177)', tag_name: "Operating Mode Type", tag_key: 'OperatingModeType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9177)', tag_sym: :operating_mode_type, tag_ndm: '00189177', tag_ary: [0x0018,0x9177], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9178)', tag_name: "Operating Mode", tag_key: 'OperatingMode', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9178)', tag_sym: :operating_mode, tag_ndm: '00189178', tag_ary: [0x0018,0x9178], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9179)', tag_name: "Specific Absorption Rate Definition", tag_key: 'SpecificAbsorptionRateDefinition', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9179)', tag_sym: :specific_absorption_rate_definition, tag_ndm: '00189179', tag_ary: [0x0018,0x9179], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9180)', tag_name: "Gradient Output Type", tag_key: 'GradientOutputType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9180)', tag_sym: :gradient_output_type, tag_ndm: '00189180', tag_ary: [0x0018,0x9180], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9181)', tag_name: "Specific Absorption Rate Value", tag_key: 'SpecificAbsorptionRateValue', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9181)', tag_sym: :specific_absorption_rate_value, tag_ndm: '00189181', tag_ary: [0x0018,0x9181], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9182)', tag_name: "Gradient Output", tag_key: 'GradientOutput', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9182)', tag_sym: :gradient_output, tag_ndm: '00189182', tag_ary: [0x0018,0x9182], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9183)', tag_name: "Flow Compensation Direction", tag_key: 'FlowCompensationDirection', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9183)', tag_sym: :flow_compensation_direction, tag_ndm: '00189183', tag_ary: [0x0018,0x9183], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9184)', tag_name: "Tagging Delay", tag_key: 'TaggingDelay', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9184)', tag_sym: :tagging_delay, tag_ndm: '00189184', tag_ary: [0x0018,0x9184], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9185)', tag_name: "Respiratory Motion Compensation Technique Description", tag_key: 'RespiratoryMotionCompensationTechniqueDescription', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0018,9185)', tag_sym: :respiratory_motion_compensation_technique_description, tag_ndm: '00189185', tag_ary: [0x0018,0x9185], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9186)', tag_name: "Respiratory Signal Source ID", tag_key: 'RespiratorySignalSourceID', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0018,9186)', tag_sym: :respiratory_signal_source_id, tag_ndm: '00189186', tag_ary: [0x0018,0x9186], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9195)', tag_name: "Chemical Shift Minimum Integration Limit in Hz", tag_key: 'ChemicalShiftMinimumIntegrationLimitInHz', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9195)', tag_sym: :chemical_shift_minimum_integration_limit_in_hz, tag_ndm: '00189195', tag_ary: [0x0018,0x9195], tag_multiple: false, tag_note: 'RET (2003)'},
      { tag_ps: '(0018,9196)', tag_name: "Chemical Shift Maximum Integration Limit in Hz", tag_key: 'ChemicalShiftMaximumIntegrationLimitInHz', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9196)', tag_sym: :chemical_shift_maximum_integration_limit_in_hz, tag_ndm: '00189196', tag_ary: [0x0018,0x9196], tag_multiple: false, tag_note: 'RET (2003)'},
      { tag_ps: '(0018,9197)', tag_name: "MR Velocity Encoding Sequence", tag_key: 'MRVelocityEncodingSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9197)', tag_sym: :mr_velocity_encoding_sequence, tag_ndm: '00189197', tag_ary: [0x0018,0x9197], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9198)', tag_name: "First Order Phase Correction", tag_key: 'FirstOrderPhaseCorrection', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9198)', tag_sym: :first_order_phase_correction, tag_ndm: '00189198', tag_ary: [0x0018,0x9198], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9199)', tag_name: "Water Referenced Phase Correction", tag_key: 'WaterReferencedPhaseCorrection', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9199)', tag_sym: :water_referenced_phase_correction, tag_ndm: '00189199', tag_ary: [0x0018,0x9199], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9200)', tag_name: "MR Spectroscopy Acquisition Type", tag_key: 'MRSpectroscopyAcquisitionType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9200)', tag_sym: :mr_spectroscopy_acquisition_type, tag_ndm: '00189200', tag_ary: [0x0018,0x9200], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9214)', tag_name: "Respiratory Cycle Position", tag_key: 'RespiratoryCyclePosition', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9214)', tag_sym: :respiratory_cycle_position, tag_ndm: '00189214', tag_ary: [0x0018,0x9214], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9217)', tag_name: "Velocity Encoding Maximum Value", tag_key: 'VelocityEncodingMaximumValue', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9217)', tag_sym: :velocity_encoding_maximum_value, tag_ndm: '00189217', tag_ary: [0x0018,0x9217], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9218)', tag_name: "Tag Spacing Second Dimension", tag_key: 'TagSpacingSecondDimension', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9218)', tag_sym: :tag_spacing_second_dimension, tag_ndm: '00189218', tag_ary: [0x0018,0x9218], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9219)', tag_name: "Tag Angle Second Axis", tag_key: 'TagAngleSecondAxis', tag_vr: [:SS], tag_vm: ["1"], tag_str: '(0018,9219)', tag_sym: :tag_angle_second_axis, tag_ndm: '00189219', tag_ary: [0x0018,0x9219], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9220)', tag_name: "Frame Acquisition Duration", tag_key: 'FrameAcquisitionDuration', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9220)', tag_sym: :frame_acquisition_duration, tag_ndm: '00189220', tag_ary: [0x0018,0x9220], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9226)', tag_name: "MR Image Frame Type Sequence", tag_key: 'MRImageFrameTypeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9226)', tag_sym: :mr_image_frame_type_sequence, tag_ndm: '00189226', tag_ary: [0x0018,0x9226], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9227)', tag_name: "MR Spectroscopy Frame Type Sequence", tag_key: 'MRSpectroscopyFrameTypeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9227)', tag_sym: :mr_spectroscopy_frame_type_sequence, tag_ndm: '00189227', tag_ary: [0x0018,0x9227], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9231)', tag_name: "MR Acquisition Phase Encoding Steps in-plane", tag_key: 'MRAcquisitionPhaseEncodingStepsInPlane', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0018,9231)', tag_sym: :mr_acquisition_phase_encoding_steps_in_plane, tag_ndm: '00189231', tag_ary: [0x0018,0x9231], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9232)', tag_name: "MR Acquisition Phase Encoding Steps out-of-plane", tag_key: 'MRAcquisitionPhaseEncodingStepsOutOfPlane', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0018,9232)', tag_sym: :mr_acquisition_phase_encoding_steps_out_of_plane, tag_ndm: '00189232', tag_ary: [0x0018,0x9232], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9234)', tag_name: "Spectroscopy Acquisition Phase Columns", tag_key: 'SpectroscopyAcquisitionPhaseColumns', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0018,9234)', tag_sym: :spectroscopy_acquisition_phase_columns, tag_ndm: '00189234', tag_ary: [0x0018,0x9234], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9236)', tag_name: "Cardiac Cycle Position", tag_key: 'CardiacCyclePosition', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9236)', tag_sym: :cardiac_cycle_position, tag_ndm: '00189236', tag_ary: [0x0018,0x9236], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9239)', tag_name: "Specific Absorption Rate Sequence", tag_key: 'SpecificAbsorptionRateSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9239)', tag_sym: :specific_absorption_rate_sequence, tag_ndm: '00189239', tag_ary: [0x0018,0x9239], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9240)', tag_name: "RF Echo Train Length", tag_key: 'RFEchoTrainLength', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0018,9240)', tag_sym: :rf_echo_train_length, tag_ndm: '00189240', tag_ary: [0x0018,0x9240], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9241)', tag_name: "Gradient Echo Train Length", tag_key: 'GradientEchoTrainLength', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0018,9241)', tag_sym: :gradient_echo_train_length, tag_ndm: '00189241', tag_ary: [0x0018,0x9241], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9250)', tag_name: "Arterial Spin Labeling Contrast", tag_key: 'ArterialSpinLabelingContrast', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9250)', tag_sym: :arterial_spin_labeling_contrast, tag_ndm: '00189250', tag_ary: [0x0018,0x9250], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9251)', tag_name: "MR Arterial Spin Labeling Sequence", tag_key: 'MRArterialSpinLabelingSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9251)', tag_sym: :mr_arterial_spin_labeling_sequence, tag_ndm: '00189251', tag_ary: [0x0018,0x9251], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9252)', tag_name: "ASL Technique Description", tag_key: 'ASLTechniqueDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0018,9252)', tag_sym: :asl_technique_description, tag_ndm: '00189252', tag_ary: [0x0018,0x9252], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9253)', tag_name: "ASL Slab Number", tag_key: 'ASLSlabNumber', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0018,9253)', tag_sym: :asl_slab_number, tag_ndm: '00189253', tag_ary: [0x0018,0x9253], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9254)', tag_name: "ASL Slab Thickness", tag_key: 'ASLSlabThickness', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9254)', tag_sym: :asl_slab_thickness, tag_ndm: '00189254', tag_ary: [0x0018,0x9254], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9255)', tag_name: "ASL Slab Orientation", tag_key: 'ASLSlabOrientation', tag_vr: [:FD], tag_vm: ["3"], tag_str: '(0018,9255)', tag_sym: :asl_slab_orientation, tag_ndm: '00189255', tag_ary: [0x0018,0x9255], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9256)', tag_name: "ASL Mid Slab Position", tag_key: 'ASLMidSlabPosition', tag_vr: [:FD], tag_vm: ["3"], tag_str: '(0018,9256)', tag_sym: :asl_mid_slab_position, tag_ndm: '00189256', tag_ary: [0x0018,0x9256], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9257)', tag_name: "ASL Context", tag_key: 'ASLContext', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9257)', tag_sym: :asl_context, tag_ndm: '00189257', tag_ary: [0x0018,0x9257], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9258)', tag_name: "ASL Pulse Train Duration", tag_key: 'ASLPulseTrainDuration', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0018,9258)', tag_sym: :asl_pulse_train_duration, tag_ndm: '00189258', tag_ary: [0x0018,0x9258], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9259)', tag_name: "ASL Crusher Flag", tag_key: 'ASLCrusherFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9259)', tag_sym: :asl_crusher_flag, tag_ndm: '00189259', tag_ary: [0x0018,0x9259], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,925A)', tag_name: "ASL Crusher Flow Limit", tag_key: 'ASLCrusherFlowLimit', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,925A)', tag_sym: :asl_crusher_flow_limit, tag_ndm: '0018925A', tag_ary: [0x0018,0x925A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,925B)', tag_name: "ASL Crusher Description", tag_key: 'ASLCrusherDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0018,925B)', tag_sym: :asl_crusher_description, tag_ndm: '0018925B', tag_ary: [0x0018,0x925B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,925C)', tag_name: "ASL Bolus Cut-off Flag", tag_key: 'ASLBolusCutoffFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,925C)', tag_sym: :asl_bolus_cutoff_flag, tag_ndm: '0018925C', tag_ary: [0x0018,0x925C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,925D)', tag_name: "ASL Bolus Cut-off Timing Sequence", tag_key: 'ASLBolusCutoffTimingSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,925D)', tag_sym: :asl_bolus_cutoff_timing_sequence, tag_ndm: '0018925D', tag_ary: [0x0018,0x925D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,925E)', tag_name: "ASL Bolus Cut-off Technique", tag_key: 'ASLBolusCutoffTechnique', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0018,925E)', tag_sym: :asl_bolus_cutoff_technique, tag_ndm: '0018925E', tag_ary: [0x0018,0x925E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,925F)', tag_name: "ASL Bolus Cut-off Delay Time", tag_key: 'ASLBolusCutoffDelayTime', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0018,925F)', tag_sym: :asl_bolus_cutoff_delay_time, tag_ndm: '0018925F', tag_ary: [0x0018,0x925F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9260)', tag_name: "ASL Slab Sequence", tag_key: 'ASLSlabSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9260)', tag_sym: :asl_slab_sequence, tag_ndm: '00189260', tag_ary: [0x0018,0x9260], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9295)', tag_name: "Chemical Shift Minimum Integration Limit in ppm", tag_key: 'ChemicalShiftMinimumIntegrationLimitInppm', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9295)', tag_sym: :chemical_shift_minimum_integration_limit_inppm, tag_ndm: '00189295', tag_ary: [0x0018,0x9295], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9296)', tag_name: "Chemical Shift Maximum Integration Limit in ppm", tag_key: 'ChemicalShiftMaximumIntegrationLimitInppm', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9296)', tag_sym: :chemical_shift_maximum_integration_limit_inppm, tag_ndm: '00189296', tag_ary: [0x0018,0x9296], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9297)', tag_name: "Water Reference Acquisition", tag_key: 'WaterReferenceAcquisition', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9297)', tag_sym: :water_reference_acquisition, tag_ndm: '00189297', tag_ary: [0x0018,0x9297], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9298)', tag_name: "Echo Peak Position", tag_key: 'EchoPeakPosition', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0018,9298)', tag_sym: :echo_peak_position, tag_ndm: '00189298', tag_ary: [0x0018,0x9298], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9301)', tag_name: "CT Acquisition Type Sequence", tag_key: 'CTAcquisitionTypeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9301)', tag_sym: :ct_acquisition_type_sequence, tag_ndm: '00189301', tag_ary: [0x0018,0x9301], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9302)', tag_name: "Acquisition Type", tag_key: 'AcquisitionType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9302)', tag_sym: :acquisition_type, tag_ndm: '00189302', tag_ary: [0x0018,0x9302], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9303)', tag_name: "Tube Angle", tag_key: 'TubeAngle', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9303)', tag_sym: :tube_angle, tag_ndm: '00189303', tag_ary: [0x0018,0x9303], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9304)', tag_name: "CT Acquisition Details Sequence", tag_key: 'CTAcquisitionDetailsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9304)', tag_sym: :ct_acquisition_details_sequence, tag_ndm: '00189304', tag_ary: [0x0018,0x9304], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9305)', tag_name: "Revolution Time", tag_key: 'RevolutionTime', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9305)', tag_sym: :revolution_time, tag_ndm: '00189305', tag_ary: [0x0018,0x9305], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9306)', tag_name: "Single Collimation Width", tag_key: 'SingleCollimationWidth', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9306)', tag_sym: :single_collimation_width, tag_ndm: '00189306', tag_ary: [0x0018,0x9306], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9307)', tag_name: "Total Collimation Width", tag_key: 'TotalCollimationWidth', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9307)', tag_sym: :total_collimation_width, tag_ndm: '00189307', tag_ary: [0x0018,0x9307], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9308)', tag_name: "CT Table Dynamics Sequence", tag_key: 'CTTableDynamicsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9308)', tag_sym: :ct_table_dynamics_sequence, tag_ndm: '00189308', tag_ary: [0x0018,0x9308], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9309)', tag_name: "Table Speed", tag_key: 'TableSpeed', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9309)', tag_sym: :table_speed, tag_ndm: '00189309', tag_ary: [0x0018,0x9309], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9310)', tag_name: "Table Feed per Rotation", tag_key: 'TableFeedPerRotation', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9310)', tag_sym: :table_feed_per_rotation, tag_ndm: '00189310', tag_ary: [0x0018,0x9310], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9311)', tag_name: "Spiral Pitch Factor", tag_key: 'SpiralPitchFactor', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9311)', tag_sym: :spiral_pitch_factor, tag_ndm: '00189311', tag_ary: [0x0018,0x9311], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9312)', tag_name: "CT Geometry Sequence", tag_key: 'CTGeometrySequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9312)', tag_sym: :ct_geometry_sequence, tag_ndm: '00189312', tag_ary: [0x0018,0x9312], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9313)', tag_name: "Data Collection Center (Patient)", tag_key: 'DataCollectionCenterPatient', tag_vr: [:FD], tag_vm: ["3"], tag_str: '(0018,9313)', tag_sym: :data_collection_center_patient, tag_ndm: '00189313', tag_ary: [0x0018,0x9313], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9314)', tag_name: "CT Reconstruction Sequence", tag_key: 'CTReconstructionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9314)', tag_sym: :ct_reconstruction_sequence, tag_ndm: '00189314', tag_ary: [0x0018,0x9314], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9315)', tag_name: "Reconstruction Algorithm", tag_key: 'ReconstructionAlgorithm', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9315)', tag_sym: :reconstruction_algorithm, tag_ndm: '00189315', tag_ary: [0x0018,0x9315], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9316)', tag_name: "Convolution Kernel Group", tag_key: 'ConvolutionKernelGroup', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9316)', tag_sym: :convolution_kernel_group, tag_ndm: '00189316', tag_ary: [0x0018,0x9316], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9317)', tag_name: "Reconstruction Field of View", tag_key: 'ReconstructionFieldOfView', tag_vr: [:FD], tag_vm: ["2"], tag_str: '(0018,9317)', tag_sym: :reconstruction_field_of_view, tag_ndm: '00189317', tag_ary: [0x0018,0x9317], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9318)', tag_name: "Reconstruction Target Center (Patient)", tag_key: 'ReconstructionTargetCenterPatient', tag_vr: [:FD], tag_vm: ["3"], tag_str: '(0018,9318)', tag_sym: :reconstruction_target_center_patient, tag_ndm: '00189318', tag_ary: [0x0018,0x9318], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9319)', tag_name: "Reconstruction Angle", tag_key: 'ReconstructionAngle', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9319)', tag_sym: :reconstruction_angle, tag_ndm: '00189319', tag_ary: [0x0018,0x9319], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9320)', tag_name: "Image Filter", tag_key: 'ImageFilter', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0018,9320)', tag_sym: :image_filter, tag_ndm: '00189320', tag_ary: [0x0018,0x9320], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9321)', tag_name: "CT Exposure Sequence", tag_key: 'CTExposureSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9321)', tag_sym: :ct_exposure_sequence, tag_ndm: '00189321', tag_ary: [0x0018,0x9321], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9322)', tag_name: "Reconstruction Pixel Spacing", tag_key: 'ReconstructionPixelSpacing', tag_vr: [:FD], tag_vm: ["2"], tag_str: '(0018,9322)', tag_sym: :reconstruction_pixel_spacing, tag_ndm: '00189322', tag_ary: [0x0018,0x9322], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9323)', tag_name: "Exposure Modulation Type", tag_key: 'ExposureModulationType', tag_vr: [:CS], tag_vm: ["1-n"], tag_str: '(0018,9323)', tag_sym: :exposure_modulation_type, tag_ndm: '00189323', tag_ary: [0x0018,0x9323], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9324)', tag_name: "Estimated Dose Saving", tag_key: 'EstimatedDoseSaving', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9324)', tag_sym: :estimated_dose_saving, tag_ndm: '00189324', tag_ary: [0x0018,0x9324], tag_multiple: false, tag_note: 'RET (2020a)'},
      { tag_ps: '(0018,9325)', tag_name: "CT X-Ray Details Sequence", tag_key: 'CTXRayDetailsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9325)', tag_sym: :ctx_ray_details_sequence, tag_ndm: '00189325', tag_ary: [0x0018,0x9325], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9326)', tag_name: "CT Position Sequence", tag_key: 'CTPositionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9326)', tag_sym: :ct_position_sequence, tag_ndm: '00189326', tag_ary: [0x0018,0x9326], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9327)', tag_name: "Table Position", tag_key: 'TablePosition', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9327)', tag_sym: :table_position, tag_ndm: '00189327', tag_ary: [0x0018,0x9327], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9328)', tag_name: "Exposure Time in ms", tag_key: 'ExposureTimeInms', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9328)', tag_sym: :exposure_time_inms, tag_ndm: '00189328', tag_ary: [0x0018,0x9328], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9329)', tag_name: "CT Image Frame Type Sequence", tag_key: 'CTImageFrameTypeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9329)', tag_sym: :ct_image_frame_type_sequence, tag_ndm: '00189329', tag_ary: [0x0018,0x9329], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9330)', tag_name: "X-Ray Tube Current in mA", tag_key: 'XRayTubeCurrentInmA', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9330)', tag_sym: :x_ray_tube_current_inm_a, tag_ndm: '00189330', tag_ary: [0x0018,0x9330], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9332)', tag_name: "Exposure in mAs", tag_key: 'ExposureInmAs', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9332)', tag_sym: :exposure_inm_as, tag_ndm: '00189332', tag_ary: [0x0018,0x9332], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9333)', tag_name: "Constant Volume Flag", tag_key: 'ConstantVolumeFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9333)', tag_sym: :constant_volume_flag, tag_ndm: '00189333', tag_ary: [0x0018,0x9333], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9334)', tag_name: "Fluoroscopy Flag", tag_key: 'FluoroscopyFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9334)', tag_sym: :fluoroscopy_flag, tag_ndm: '00189334', tag_ary: [0x0018,0x9334], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9335)', tag_name: "Distance Source to Data Collection Center", tag_key: 'DistanceSourceToDataCollectionCenter', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9335)', tag_sym: :distance_source_to_data_collection_center, tag_ndm: '00189335', tag_ary: [0x0018,0x9335], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9337)', tag_name: "Contrast/Bolus Agent Number", tag_key: 'ContrastBolusAgentNumber', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0018,9337)', tag_sym: :contrast_bolus_agent_number, tag_ndm: '00189337', tag_ary: [0x0018,0x9337], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9338)', tag_name: "Contrast/Bolus Ingredient Code Sequence", tag_key: 'ContrastBolusIngredientCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9338)', tag_sym: :contrast_bolus_ingredient_code_sequence, tag_ndm: '00189338', tag_ary: [0x0018,0x9338], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9340)', tag_name: "Contrast Administration Profile Sequence", tag_key: 'ContrastAdministrationProfileSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9340)', tag_sym: :contrast_administration_profile_sequence, tag_ndm: '00189340', tag_ary: [0x0018,0x9340], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9341)', tag_name: "Contrast/Bolus Usage Sequence", tag_key: 'ContrastBolusUsageSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9341)', tag_sym: :contrast_bolus_usage_sequence, tag_ndm: '00189341', tag_ary: [0x0018,0x9341], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9342)', tag_name: "Contrast/Bolus Agent Administered", tag_key: 'ContrastBolusAgentAdministered', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9342)', tag_sym: :contrast_bolus_agent_administered, tag_ndm: '00189342', tag_ary: [0x0018,0x9342], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9343)', tag_name: "Contrast/Bolus Agent Detected", tag_key: 'ContrastBolusAgentDetected', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9343)', tag_sym: :contrast_bolus_agent_detected, tag_ndm: '00189343', tag_ary: [0x0018,0x9343], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9344)', tag_name: "Contrast/Bolus Agent Phase", tag_key: 'ContrastBolusAgentPhase', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9344)', tag_sym: :contrast_bolus_agent_phase, tag_ndm: '00189344', tag_ary: [0x0018,0x9344], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9345)', tag_name: "CTDIvol", tag_key: 'CTDIvol', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9345)', tag_sym: :ctdi_vol, tag_ndm: '00189345', tag_ary: [0x0018,0x9345], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9346)', tag_name: "CTDI Phantom Type Code Sequence", tag_key: 'CTDIPhantomTypeCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9346)', tag_sym: :ctdi_phantom_type_code_sequence, tag_ndm: '00189346', tag_ary: [0x0018,0x9346], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9351)', tag_name: "Calcium Scoring Mass Factor Patient", tag_key: 'CalciumScoringMassFactorPatient', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0018,9351)', tag_sym: :calcium_scoring_mass_factor_patient, tag_ndm: '00189351', tag_ary: [0x0018,0x9351], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9352)', tag_name: "Calcium Scoring Mass Factor Device", tag_key: 'CalciumScoringMassFactorDevice', tag_vr: [:FL], tag_vm: ["3"], tag_str: '(0018,9352)', tag_sym: :calcium_scoring_mass_factor_device, tag_ndm: '00189352', tag_ary: [0x0018,0x9352], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9353)', tag_name: "Energy Weighting Factor", tag_key: 'EnergyWeightingFactor', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0018,9353)', tag_sym: :energy_weighting_factor, tag_ndm: '00189353', tag_ary: [0x0018,0x9353], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9360)', tag_name: "CT Additional X-Ray Source Sequence", tag_key: 'CTAdditionalXRaySourceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9360)', tag_sym: :ct_additional_x_ray_source_sequence, tag_ndm: '00189360', tag_ary: [0x0018,0x9360], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9361)', tag_name: "Multi-energy CT Acquisition", tag_key: 'MultienergyCTAcquisition', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9361)', tag_sym: :multienergy_ct_acquisition, tag_ndm: '00189361', tag_ary: [0x0018,0x9361], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9362)', tag_name: "Multi-energy CT Acquisition Sequence", tag_key: 'MultienergyCTAcquisitionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9362)', tag_sym: :multienergy_ct_acquisition_sequence, tag_ndm: '00189362', tag_ary: [0x0018,0x9362], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9363)', tag_name: "Multi-energy CT Processing Sequence", tag_key: 'MultienergyCTProcessingSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9363)', tag_sym: :multienergy_ct_processing_sequence, tag_ndm: '00189363', tag_ary: [0x0018,0x9363], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9364)', tag_name: "Multi-energy CT Characteristics Sequence", tag_key: 'MultienergyCTCharacteristicsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9364)', tag_sym: :multienergy_ct_characteristics_sequence, tag_ndm: '00189364', tag_ary: [0x0018,0x9364], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9365)', tag_name: "Multi-energy CT X-Ray Source Sequence", tag_key: 'MultienergyCTXRaySourceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9365)', tag_sym: :multienergy_ctx_ray_source_sequence, tag_ndm: '00189365', tag_ary: [0x0018,0x9365], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9366)', tag_name: "X-Ray Source Index", tag_key: 'XRaySourceIndex', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0018,9366)', tag_sym: :x_ray_source_index, tag_ndm: '00189366', tag_ary: [0x0018,0x9366], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9367)', tag_name: "X-Ray Source ID", tag_key: 'XRaySourceID', tag_vr: [:UC], tag_vm: ["1"], tag_str: '(0018,9367)', tag_sym: :x_ray_source_id, tag_ndm: '00189367', tag_ary: [0x0018,0x9367], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9368)', tag_name: "Multi-energy Source Technique", tag_key: 'MultienergySourceTechnique', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9368)', tag_sym: :multienergy_source_technique, tag_ndm: '00189368', tag_ary: [0x0018,0x9368], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9369)', tag_name: "Source Start DateTime", tag_key: 'SourceStartDateTime', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(0018,9369)', tag_sym: :source_start_date_time, tag_ndm: '00189369', tag_ary: [0x0018,0x9369], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,936A)', tag_name: "Source End DateTime", tag_key: 'SourceEndDateTime', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(0018,936A)', tag_sym: :source_end_date_time, tag_ndm: '0018936A', tag_ary: [0x0018,0x936A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,936B)', tag_name: "Switching Phase Number", tag_key: 'SwitchingPhaseNumber', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0018,936B)', tag_sym: :switching_phase_number, tag_ndm: '0018936B', tag_ary: [0x0018,0x936B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,936C)', tag_name: "Switching Phase Nominal Duration", tag_key: 'SwitchingPhaseNominalDuration', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,936C)', tag_sym: :switching_phase_nominal_duration, tag_ndm: '0018936C', tag_ary: [0x0018,0x936C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,936D)', tag_name: "Switching Phase Transition Duration", tag_key: 'SwitchingPhaseTransitionDuration', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,936D)', tag_sym: :switching_phase_transition_duration, tag_ndm: '0018936D', tag_ary: [0x0018,0x936D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,936E)', tag_name: "Effective Bin Energy", tag_key: 'EffectiveBinEnergy', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,936E)', tag_sym: :effective_bin_energy, tag_ndm: '0018936E', tag_ary: [0x0018,0x936E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,936F)', tag_name: "Multi-energy CT X-Ray Detector Sequence", tag_key: 'MultienergyCTXRayDetectorSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,936F)', tag_sym: :multienergy_ctx_ray_detector_sequence, tag_ndm: '0018936F', tag_ary: [0x0018,0x936F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9370)', tag_name: "X-Ray Detector Index", tag_key: 'XRayDetectorIndex', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0018,9370)', tag_sym: :x_ray_detector_index, tag_ndm: '00189370', tag_ary: [0x0018,0x9370], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9371)', tag_name: "X-Ray Detector ID", tag_key: 'XRayDetectorID', tag_vr: [:UC], tag_vm: ["1"], tag_str: '(0018,9371)', tag_sym: :x_ray_detector_id, tag_ndm: '00189371', tag_ary: [0x0018,0x9371], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9372)', tag_name: "Multi-energy Detector Type", tag_key: 'MultienergyDetectorType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9372)', tag_sym: :multienergy_detector_type, tag_ndm: '00189372', tag_ary: [0x0018,0x9372], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9373)', tag_name: "X-Ray Detector Label", tag_key: 'XRayDetectorLabel', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0018,9373)', tag_sym: :x_ray_detector_label, tag_ndm: '00189373', tag_ary: [0x0018,0x9373], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9374)', tag_name: "Nominal Max Energy", tag_key: 'NominalMaxEnergy', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,9374)', tag_sym: :nominal_max_energy, tag_ndm: '00189374', tag_ary: [0x0018,0x9374], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9375)', tag_name: "Nominal Min Energy", tag_key: 'NominalMinEnergy', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,9375)', tag_sym: :nominal_min_energy, tag_ndm: '00189375', tag_ary: [0x0018,0x9375], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9376)', tag_name: "Referenced X-Ray Detector Index", tag_key: 'ReferencedXRayDetectorIndex', tag_vr: [:US], tag_vm: ["1-n"], tag_str: '(0018,9376)', tag_sym: :referenced_x_ray_detector_index, tag_ndm: '00189376', tag_ary: [0x0018,0x9376], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9377)', tag_name: "Referenced X-Ray Source Index", tag_key: 'ReferencedXRaySourceIndex', tag_vr: [:US], tag_vm: ["1-n"], tag_str: '(0018,9377)', tag_sym: :referenced_x_ray_source_index, tag_ndm: '00189377', tag_ary: [0x0018,0x9377], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9378)', tag_name: "Referenced Path Index", tag_key: 'ReferencedPathIndex', tag_vr: [:US], tag_vm: ["1-n"], tag_str: '(0018,9378)', tag_sym: :referenced_path_index, tag_ndm: '00189378', tag_ary: [0x0018,0x9378], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9379)', tag_name: "Multi-energy CT Path Sequence", tag_key: 'MultienergyCTPathSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9379)', tag_sym: :multienergy_ct_path_sequence, tag_ndm: '00189379', tag_ary: [0x0018,0x9379], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,937A)', tag_name: "Multi-energy CT Path Index", tag_key: 'MultienergyCTPathIndex', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0018,937A)', tag_sym: :multienergy_ct_path_index, tag_ndm: '0018937A', tag_ary: [0x0018,0x937A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,937B)', tag_name: "Multi-energy Acquisition Description", tag_key: 'MultienergyAcquisitionDescription', tag_vr: [:UT], tag_vm: ["1"], tag_str: '(0018,937B)', tag_sym: :multienergy_acquisition_description, tag_ndm: '0018937B', tag_ary: [0x0018,0x937B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,937C)', tag_name: "Monoenergetic Energy Equivalent", tag_key: 'MonoenergeticEnergyEquivalent', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,937C)', tag_sym: :monoenergetic_energy_equivalent, tag_ndm: '0018937C', tag_ary: [0x0018,0x937C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,937D)', tag_name: "Material Code Sequence", tag_key: 'MaterialCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,937D)', tag_sym: :material_code_sequence, tag_ndm: '0018937D', tag_ary: [0x0018,0x937D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,937E)', tag_name: "Decomposition Method", tag_key: 'DecompositionMethod', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,937E)', tag_sym: :decomposition_method, tag_ndm: '0018937E', tag_ary: [0x0018,0x937E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,937F)', tag_name: "Decomposition Description", tag_key: 'DecompositionDescription', tag_vr: [:UT], tag_vm: ["1"], tag_str: '(0018,937F)', tag_sym: :decomposition_description, tag_ndm: '0018937F', tag_ary: [0x0018,0x937F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9380)', tag_name: "Decomposition Algorithm Identification Sequence", tag_key: 'DecompositionAlgorithmIdentificationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9380)', tag_sym: :decomposition_algorithm_identification_sequence, tag_ndm: '00189380', tag_ary: [0x0018,0x9380], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9381)', tag_name: "Decomposition Material Sequence", tag_key: 'DecompositionMaterialSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9381)', tag_sym: :decomposition_material_sequence, tag_ndm: '00189381', tag_ary: [0x0018,0x9381], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9382)', tag_name: "Material Attenuation Sequence", tag_key: 'MaterialAttenuationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9382)', tag_sym: :material_attenuation_sequence, tag_ndm: '00189382', tag_ary: [0x0018,0x9382], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9383)', tag_name: "Photon Energy", tag_key: 'PhotonEnergy', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,9383)', tag_sym: :photon_energy, tag_ndm: '00189383', tag_ary: [0x0018,0x9383], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9384)', tag_name: "X-Ray Mass Attenuation Coefficient", tag_key: 'XRayMassAttenuationCoefficient', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,9384)', tag_sym: :x_ray_mass_attenuation_coefficient, tag_ndm: '00189384', tag_ary: [0x0018,0x9384], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9401)', tag_name: "Projection Pixel Calibration Sequence", tag_key: 'ProjectionPixelCalibrationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9401)', tag_sym: :projection_pixel_calibration_sequence, tag_ndm: '00189401', tag_ary: [0x0018,0x9401], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9402)', tag_name: "Distance Source to Isocenter", tag_key: 'DistanceSourceToIsocenter', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0018,9402)', tag_sym: :distance_source_to_isocenter, tag_ndm: '00189402', tag_ary: [0x0018,0x9402], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9403)', tag_name: "Distance Object to Table Top", tag_key: 'DistanceObjectToTableTop', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0018,9403)', tag_sym: :distance_object_to_table_top, tag_ndm: '00189403', tag_ary: [0x0018,0x9403], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9404)', tag_name: "Object Pixel Spacing in Center of Beam", tag_key: 'ObjectPixelSpacingInCenterOfBeam', tag_vr: [:FL], tag_vm: ["2"], tag_str: '(0018,9404)', tag_sym: :object_pixel_spacing_in_center_of_beam, tag_ndm: '00189404', tag_ary: [0x0018,0x9404], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9405)', tag_name: "Positioner Position Sequence", tag_key: 'PositionerPositionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9405)', tag_sym: :positioner_position_sequence, tag_ndm: '00189405', tag_ary: [0x0018,0x9405], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9406)', tag_name: "Table Position Sequence", tag_key: 'TablePositionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9406)', tag_sym: :table_position_sequence, tag_ndm: '00189406', tag_ary: [0x0018,0x9406], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9407)', tag_name: "Collimator Shape Sequence", tag_key: 'CollimatorShapeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9407)', tag_sym: :collimator_shape_sequence, tag_ndm: '00189407', tag_ary: [0x0018,0x9407], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9410)', tag_name: "Planes in Acquisition", tag_key: 'PlanesInAcquisition', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9410)', tag_sym: :planes_in_acquisition, tag_ndm: '00189410', tag_ary: [0x0018,0x9410], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9412)', tag_name: "XA/XRF Frame Characteristics Sequence", tag_key: 'XAXRFFrameCharacteristicsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9412)', tag_sym: :xa_xrf_frame_characteristics_sequence, tag_ndm: '00189412', tag_ary: [0x0018,0x9412], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9417)', tag_name: "Frame Acquisition Sequence", tag_key: 'FrameAcquisitionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9417)', tag_sym: :frame_acquisition_sequence, tag_ndm: '00189417', tag_ary: [0x0018,0x9417], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9420)', tag_name: "X-Ray Receptor Type", tag_key: 'XRayReceptorType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9420)', tag_sym: :x_ray_receptor_type, tag_ndm: '00189420', tag_ary: [0x0018,0x9420], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9423)', tag_name: "Acquisition Protocol Name", tag_key: 'AcquisitionProtocolName', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0018,9423)', tag_sym: :acquisition_protocol_name, tag_ndm: '00189423', tag_ary: [0x0018,0x9423], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9424)', tag_name: "Acquisition Protocol Description", tag_key: 'AcquisitionProtocolDescription', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(0018,9424)', tag_sym: :acquisition_protocol_description, tag_ndm: '00189424', tag_ary: [0x0018,0x9424], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9425)', tag_name: "Contrast/Bolus Ingredient Opaque", tag_key: 'ContrastBolusIngredientOpaque', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9425)', tag_sym: :contrast_bolus_ingredient_opaque, tag_ndm: '00189425', tag_ary: [0x0018,0x9425], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9426)', tag_name: "Distance Receptor Plane to Detector Housing", tag_key: 'DistanceReceptorPlaneToDetectorHousing', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0018,9426)', tag_sym: :distance_receptor_plane_to_detector_housing, tag_ndm: '00189426', tag_ary: [0x0018,0x9426], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9427)', tag_name: "Intensifier Active Shape", tag_key: 'IntensifierActiveShape', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9427)', tag_sym: :intensifier_active_shape, tag_ndm: '00189427', tag_ary: [0x0018,0x9427], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9428)', tag_name: "Intensifier Active Dimension(s)", tag_key: 'IntensifierActiveDimensions', tag_vr: [:FL], tag_vm: ["1-2"], tag_str: '(0018,9428)', tag_sym: :intensifier_active_dimensions, tag_ndm: '00189428', tag_ary: [0x0018,0x9428], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9429)', tag_name: "Physical Detector Size", tag_key: 'PhysicalDetectorSize', tag_vr: [:FL], tag_vm: ["2"], tag_str: '(0018,9429)', tag_sym: :physical_detector_size, tag_ndm: '00189429', tag_ary: [0x0018,0x9429], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9430)', tag_name: "Position of Isocenter Projection", tag_key: 'PositionOfIsocenterProjection', tag_vr: [:FL], tag_vm: ["2"], tag_str: '(0018,9430)', tag_sym: :position_of_isocenter_projection, tag_ndm: '00189430', tag_ary: [0x0018,0x9430], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9432)', tag_name: "Field of View Sequence", tag_key: 'FieldOfViewSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9432)', tag_sym: :field_of_view_sequence, tag_ndm: '00189432', tag_ary: [0x0018,0x9432], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9433)', tag_name: "Field of View Description", tag_key: 'FieldOfViewDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0018,9433)', tag_sym: :field_of_view_description, tag_ndm: '00189433', tag_ary: [0x0018,0x9433], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9434)', tag_name: "Exposure Control Sensing Regions Sequence", tag_key: 'ExposureControlSensingRegionsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9434)', tag_sym: :exposure_control_sensing_regions_sequence, tag_ndm: '00189434', tag_ary: [0x0018,0x9434], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9435)', tag_name: "Exposure Control Sensing Region Shape", tag_key: 'ExposureControlSensingRegionShape', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9435)', tag_sym: :exposure_control_sensing_region_shape, tag_ndm: '00189435', tag_ary: [0x0018,0x9435], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9436)', tag_name: "Exposure Control Sensing Region Left Vertical Edge", tag_key: 'ExposureControlSensingRegionLeftVerticalEdge', tag_vr: [:SS], tag_vm: ["1"], tag_str: '(0018,9436)', tag_sym: :exposure_control_sensing_region_left_vertical_edge, tag_ndm: '00189436', tag_ary: [0x0018,0x9436], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9437)', tag_name: "Exposure Control Sensing Region Right Vertical Edge", tag_key: 'ExposureControlSensingRegionRightVerticalEdge', tag_vr: [:SS], tag_vm: ["1"], tag_str: '(0018,9437)', tag_sym: :exposure_control_sensing_region_right_vertical_edge, tag_ndm: '00189437', tag_ary: [0x0018,0x9437], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9438)', tag_name: "Exposure Control Sensing Region Upper Horizontal Edge", tag_key: 'ExposureControlSensingRegionUpperHorizontalEdge', tag_vr: [:SS], tag_vm: ["1"], tag_str: '(0018,9438)', tag_sym: :exposure_control_sensing_region_upper_horizontal_edge, tag_ndm: '00189438', tag_ary: [0x0018,0x9438], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9439)', tag_name: "Exposure Control Sensing Region Lower Horizontal Edge", tag_key: 'ExposureControlSensingRegionLowerHorizontalEdge', tag_vr: [:SS], tag_vm: ["1"], tag_str: '(0018,9439)', tag_sym: :exposure_control_sensing_region_lower_horizontal_edge, tag_ndm: '00189439', tag_ary: [0x0018,0x9439], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9440)', tag_name: "Center of Circular Exposure Control Sensing Region", tag_key: 'CenterOfCircularExposureControlSensingRegion', tag_vr: [:SS], tag_vm: ["2"], tag_str: '(0018,9440)', tag_sym: :center_of_circular_exposure_control_sensing_region, tag_ndm: '00189440', tag_ary: [0x0018,0x9440], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9441)', tag_name: "Radius of Circular Exposure Control Sensing Region", tag_key: 'RadiusOfCircularExposureControlSensingRegion', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0018,9441)', tag_sym: :radius_of_circular_exposure_control_sensing_region, tag_ndm: '00189441', tag_ary: [0x0018,0x9441], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9442)', tag_name: "Vertices of the Polygonal Exposure Control Sensing Region", tag_key: 'VerticesOfThePolygonalExposureControlSensingRegion', tag_vr: [:SS], tag_vm: ["2-n"], tag_str: '(0018,9442)', tag_sym: :vertices_of_the_polygonal_exposure_control_sensing_region, tag_ndm: '00189442', tag_ary: [0x0018,0x9442], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9445)', tag_name: "Placeholder (0018,9445)", tag_key: 'Placeholder_0018_9445', tag_vr: [:UN], tag_vm: ["1"], tag_str: '(0018,9445)', tag_sym: :placeholder_0018_9445, tag_ndm: '00189445', tag_ary: [0x0018,0x9445], tag_multiple: false, tag_note: 'RET (2004) - See Note'},
      { tag_ps: '(0018,9447)', tag_name: "Column Angulation (Patient)", tag_key: 'ColumnAngulationPatient', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0018,9447)', tag_sym: :column_angulation_patient, tag_ndm: '00189447', tag_ary: [0x0018,0x9447], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9449)', tag_name: "Beam Angle", tag_key: 'BeamAngle', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0018,9449)', tag_sym: :beam_angle, tag_ndm: '00189449', tag_ary: [0x0018,0x9449], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9451)', tag_name: "Frame Detector Parameters Sequence", tag_key: 'FrameDetectorParametersSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9451)', tag_sym: :frame_detector_parameters_sequence, tag_ndm: '00189451', tag_ary: [0x0018,0x9451], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9452)', tag_name: "Calculated Anatomy Thickness", tag_key: 'CalculatedAnatomyThickness', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0018,9452)', tag_sym: :calculated_anatomy_thickness, tag_ndm: '00189452', tag_ary: [0x0018,0x9452], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9455)', tag_name: "Calibration Sequence", tag_key: 'CalibrationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9455)', tag_sym: :calibration_sequence, tag_ndm: '00189455', tag_ary: [0x0018,0x9455], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9456)', tag_name: "Object Thickness Sequence", tag_key: 'ObjectThicknessSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9456)', tag_sym: :object_thickness_sequence, tag_ndm: '00189456', tag_ary: [0x0018,0x9456], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9457)', tag_name: "Plane Identification", tag_key: 'PlaneIdentification', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9457)', tag_sym: :plane_identification, tag_ndm: '00189457', tag_ary: [0x0018,0x9457], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9461)', tag_name: "Field of View Dimension(s) in Float", tag_key: 'FieldOfViewDimensionsInFloat', tag_vr: [:FL], tag_vm: ["1-2"], tag_str: '(0018,9461)', tag_sym: :field_of_view_dimensions_in_float, tag_ndm: '00189461', tag_ary: [0x0018,0x9461], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9462)', tag_name: "Isocenter Reference System Sequence", tag_key: 'IsocenterReferenceSystemSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9462)', tag_sym: :isocenter_reference_system_sequence, tag_ndm: '00189462', tag_ary: [0x0018,0x9462], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9463)', tag_name: "Positioner Isocenter Primary Angle", tag_key: 'PositionerIsocenterPrimaryAngle', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0018,9463)', tag_sym: :positioner_isocenter_primary_angle, tag_ndm: '00189463', tag_ary: [0x0018,0x9463], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9464)', tag_name: "Positioner Isocenter Secondary Angle", tag_key: 'PositionerIsocenterSecondaryAngle', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0018,9464)', tag_sym: :positioner_isocenter_secondary_angle, tag_ndm: '00189464', tag_ary: [0x0018,0x9464], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9465)', tag_name: "Positioner Isocenter Detector Rotation Angle", tag_key: 'PositionerIsocenterDetectorRotationAngle', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0018,9465)', tag_sym: :positioner_isocenter_detector_rotation_angle, tag_ndm: '00189465', tag_ary: [0x0018,0x9465], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9466)', tag_name: "Table X Position to Isocenter", tag_key: 'TableXPositionToIsocenter', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0018,9466)', tag_sym: :table_x_position_to_isocenter, tag_ndm: '00189466', tag_ary: [0x0018,0x9466], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9467)', tag_name: "Table Y Position to Isocenter", tag_key: 'TableYPositionToIsocenter', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0018,9467)', tag_sym: :table_y_position_to_isocenter, tag_ndm: '00189467', tag_ary: [0x0018,0x9467], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9468)', tag_name: "Table Z Position to Isocenter", tag_key: 'TableZPositionToIsocenter', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0018,9468)', tag_sym: :table_z_position_to_isocenter, tag_ndm: '00189468', tag_ary: [0x0018,0x9468], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9469)', tag_name: "Table Horizontal Rotation Angle", tag_key: 'TableHorizontalRotationAngle', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0018,9469)', tag_sym: :table_horizontal_rotation_angle, tag_ndm: '00189469', tag_ary: [0x0018,0x9469], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9470)', tag_name: "Table Head Tilt Angle", tag_key: 'TableHeadTiltAngle', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0018,9470)', tag_sym: :table_head_tilt_angle, tag_ndm: '00189470', tag_ary: [0x0018,0x9470], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9471)', tag_name: "Table Cradle Tilt Angle", tag_key: 'TableCradleTiltAngle', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0018,9471)', tag_sym: :table_cradle_tilt_angle, tag_ndm: '00189471', tag_ary: [0x0018,0x9471], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9472)', tag_name: "Frame Display Shutter Sequence", tag_key: 'FrameDisplayShutterSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9472)', tag_sym: :frame_display_shutter_sequence, tag_ndm: '00189472', tag_ary: [0x0018,0x9472], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9473)', tag_name: "Acquired Image Area Dose Product", tag_key: 'AcquiredImageAreaDoseProduct', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0018,9473)', tag_sym: :acquired_image_area_dose_product, tag_ndm: '00189473', tag_ary: [0x0018,0x9473], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9474)', tag_name: "C-arm Positioner Tabletop Relationship", tag_key: 'CArmPositionerTabletopRelationship', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9474)', tag_sym: :c_arm_positioner_tabletop_relationship, tag_ndm: '00189474', tag_ary: [0x0018,0x9474], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9476)', tag_name: "X-Ray Geometry Sequence", tag_key: 'XRayGeometrySequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9476)', tag_sym: :x_ray_geometry_sequence, tag_ndm: '00189476', tag_ary: [0x0018,0x9476], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9477)', tag_name: "Irradiation Event Identification Sequence", tag_key: 'IrradiationEventIdentificationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9477)', tag_sym: :irradiation_event_identification_sequence, tag_ndm: '00189477', tag_ary: [0x0018,0x9477], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9504)', tag_name: "X-Ray 3D Frame Type Sequence", tag_key: 'XRay3DFrameTypeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9504)', tag_sym: :x_ray_3d_frame_type_sequence, tag_ndm: '00189504', tag_ary: [0x0018,0x9504], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9506)', tag_name: "Contributing Sources Sequence", tag_key: 'ContributingSourcesSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9506)', tag_sym: :contributing_sources_sequence, tag_ndm: '00189506', tag_ary: [0x0018,0x9506], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9507)', tag_name: "X-Ray 3D Acquisition Sequence", tag_key: 'XRay3DAcquisitionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9507)', tag_sym: :x_ray_3d_acquisition_sequence, tag_ndm: '00189507', tag_ary: [0x0018,0x9507], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9508)', tag_name: "Primary Positioner Scan Arc", tag_key: 'PrimaryPositionerScanArc', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0018,9508)', tag_sym: :primary_positioner_scan_arc, tag_ndm: '00189508', tag_ary: [0x0018,0x9508], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9509)', tag_name: "Secondary Positioner Scan Arc", tag_key: 'SecondaryPositionerScanArc', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0018,9509)', tag_sym: :secondary_positioner_scan_arc, tag_ndm: '00189509', tag_ary: [0x0018,0x9509], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9510)', tag_name: "Primary Positioner Scan Start Angle", tag_key: 'PrimaryPositionerScanStartAngle', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0018,9510)', tag_sym: :primary_positioner_scan_start_angle, tag_ndm: '00189510', tag_ary: [0x0018,0x9510], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9511)', tag_name: "Secondary Positioner Scan Start Angle", tag_key: 'SecondaryPositionerScanStartAngle', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0018,9511)', tag_sym: :secondary_positioner_scan_start_angle, tag_ndm: '00189511', tag_ary: [0x0018,0x9511], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9514)', tag_name: "Primary Positioner Increment", tag_key: 'PrimaryPositionerIncrement', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0018,9514)', tag_sym: :primary_positioner_increment, tag_ndm: '00189514', tag_ary: [0x0018,0x9514], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9515)', tag_name: "Secondary Positioner Increment", tag_key: 'SecondaryPositionerIncrement', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0018,9515)', tag_sym: :secondary_positioner_increment, tag_ndm: '00189515', tag_ary: [0x0018,0x9515], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9516)', tag_name: "Start Acquisition DateTime", tag_key: 'StartAcquisitionDateTime', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(0018,9516)', tag_sym: :start_acquisition_date_time, tag_ndm: '00189516', tag_ary: [0x0018,0x9516], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9517)', tag_name: "End Acquisition DateTime", tag_key: 'EndAcquisitionDateTime', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(0018,9517)', tag_sym: :end_acquisition_date_time, tag_ndm: '00189517', tag_ary: [0x0018,0x9517], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9518)', tag_name: "Primary Positioner Increment Sign", tag_key: 'PrimaryPositionerIncrementSign', tag_vr: [:SS], tag_vm: ["1"], tag_str: '(0018,9518)', tag_sym: :primary_positioner_increment_sign, tag_ndm: '00189518', tag_ary: [0x0018,0x9518], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9519)', tag_name: "Secondary Positioner Increment Sign", tag_key: 'SecondaryPositionerIncrementSign', tag_vr: [:SS], tag_vm: ["1"], tag_str: '(0018,9519)', tag_sym: :secondary_positioner_increment_sign, tag_ndm: '00189519', tag_ary: [0x0018,0x9519], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9524)', tag_name: "Application Name", tag_key: 'ApplicationName', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0018,9524)', tag_sym: :application_name, tag_ndm: '00189524', tag_ary: [0x0018,0x9524], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9525)', tag_name: "Application Version", tag_key: 'ApplicationVersion', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0018,9525)', tag_sym: :application_version, tag_ndm: '00189525', tag_ary: [0x0018,0x9525], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9526)', tag_name: "Application Manufacturer", tag_key: 'ApplicationManufacturer', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0018,9526)', tag_sym: :application_manufacturer, tag_ndm: '00189526', tag_ary: [0x0018,0x9526], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9527)', tag_name: "Algorithm Type", tag_key: 'AlgorithmType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9527)', tag_sym: :algorithm_type, tag_ndm: '00189527', tag_ary: [0x0018,0x9527], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9528)', tag_name: "Algorithm Description", tag_key: 'AlgorithmDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0018,9528)', tag_sym: :algorithm_description, tag_ndm: '00189528', tag_ary: [0x0018,0x9528], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9530)', tag_name: "X-Ray 3D Reconstruction Sequence", tag_key: 'XRay3DReconstructionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9530)', tag_sym: :x_ray_3d_reconstruction_sequence, tag_ndm: '00189530', tag_ary: [0x0018,0x9530], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9531)', tag_name: "Reconstruction Description", tag_key: 'ReconstructionDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0018,9531)', tag_sym: :reconstruction_description, tag_ndm: '00189531', tag_ary: [0x0018,0x9531], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9538)', tag_name: "Per Projection Acquisition Sequence", tag_key: 'PerProjectionAcquisitionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9538)', tag_sym: :per_projection_acquisition_sequence, tag_ndm: '00189538', tag_ary: [0x0018,0x9538], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9541)', tag_name: "Detector Position Sequence", tag_key: 'DetectorPositionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9541)', tag_sym: :detector_position_sequence, tag_ndm: '00189541', tag_ary: [0x0018,0x9541], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9542)', tag_name: "X-Ray Acquisition Dose Sequence", tag_key: 'XRayAcquisitionDoseSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9542)', tag_sym: :x_ray_acquisition_dose_sequence, tag_ndm: '00189542', tag_ary: [0x0018,0x9542], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9543)', tag_name: "X-Ray Source Isocenter Primary Angle", tag_key: 'XRaySourceIsocenterPrimaryAngle', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9543)', tag_sym: :x_ray_source_isocenter_primary_angle, tag_ndm: '00189543', tag_ary: [0x0018,0x9543], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9544)', tag_name: "X-Ray Source Isocenter Secondary Angle", tag_key: 'XRaySourceIsocenterSecondaryAngle', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9544)', tag_sym: :x_ray_source_isocenter_secondary_angle, tag_ndm: '00189544', tag_ary: [0x0018,0x9544], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9545)', tag_name: "Breast Support Isocenter Primary Angle", tag_key: 'BreastSupportIsocenterPrimaryAngle', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9545)', tag_sym: :breast_support_isocenter_primary_angle, tag_ndm: '00189545', tag_ary: [0x0018,0x9545], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9546)', tag_name: "Breast Support Isocenter Secondary Angle", tag_key: 'BreastSupportIsocenterSecondaryAngle', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9546)', tag_sym: :breast_support_isocenter_secondary_angle, tag_ndm: '00189546', tag_ary: [0x0018,0x9546], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9547)', tag_name: "Breast Support X Position to Isocenter", tag_key: 'BreastSupportXPositionToIsocenter', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9547)', tag_sym: :breast_support_x_position_to_isocenter, tag_ndm: '00189547', tag_ary: [0x0018,0x9547], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9548)', tag_name: "Breast Support Y Position to Isocenter", tag_key: 'BreastSupportYPositionToIsocenter', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9548)', tag_sym: :breast_support_y_position_to_isocenter, tag_ndm: '00189548', tag_ary: [0x0018,0x9548], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9549)', tag_name: "Breast Support Z Position to Isocenter", tag_key: 'BreastSupportZPositionToIsocenter', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9549)', tag_sym: :breast_support_z_position_to_isocenter, tag_ndm: '00189549', tag_ary: [0x0018,0x9549], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9550)', tag_name: "Detector Isocenter Primary Angle", tag_key: 'DetectorIsocenterPrimaryAngle', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9550)', tag_sym: :detector_isocenter_primary_angle, tag_ndm: '00189550', tag_ary: [0x0018,0x9550], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9551)', tag_name: "Detector Isocenter Secondary Angle", tag_key: 'DetectorIsocenterSecondaryAngle', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9551)', tag_sym: :detector_isocenter_secondary_angle, tag_ndm: '00189551', tag_ary: [0x0018,0x9551], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9552)', tag_name: "Detector X Position to Isocenter", tag_key: 'DetectorXPositionToIsocenter', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9552)', tag_sym: :detector_x_position_to_isocenter, tag_ndm: '00189552', tag_ary: [0x0018,0x9552], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9553)', tag_name: "Detector Y Position to Isocenter", tag_key: 'DetectorYPositionToIsocenter', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9553)', tag_sym: :detector_y_position_to_isocenter, tag_ndm: '00189553', tag_ary: [0x0018,0x9553], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9554)', tag_name: "Detector Z Position to Isocenter", tag_key: 'DetectorZPositionToIsocenter', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9554)', tag_sym: :detector_z_position_to_isocenter, tag_ndm: '00189554', tag_ary: [0x0018,0x9554], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9555)', tag_name: "X-Ray Grid Sequence", tag_key: 'XRayGridSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9555)', tag_sym: :x_ray_grid_sequence, tag_ndm: '00189555', tag_ary: [0x0018,0x9555], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9556)', tag_name: "X-Ray Filter Sequence", tag_key: 'XRayFilterSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9556)', tag_sym: :x_ray_filter_sequence, tag_ndm: '00189556', tag_ary: [0x0018,0x9556], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9557)', tag_name: "Detector Active Area TLHC Position", tag_key: 'DetectorActiveAreaTLHCPosition', tag_vr: [:FD], tag_vm: ["3"], tag_str: '(0018,9557)', tag_sym: :detector_active_area_tlhc_position, tag_ndm: '00189557', tag_ary: [0x0018,0x9557], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9558)', tag_name: "Detector Active Area Orientation", tag_key: 'DetectorActiveAreaOrientation', tag_vr: [:FD], tag_vm: ["6"], tag_str: '(0018,9558)', tag_sym: :detector_active_area_orientation, tag_ndm: '00189558', tag_ary: [0x0018,0x9558], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9559)', tag_name: "Positioner Primary Angle Direction", tag_key: 'PositionerPrimaryAngleDirection', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9559)', tag_sym: :positioner_primary_angle_direction, tag_ndm: '00189559', tag_ary: [0x0018,0x9559], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9601)', tag_name: "Diffusion b-matrix Sequence", tag_key: 'DiffusionBMatrixSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9601)', tag_sym: :diffusion_b_matrix_sequence, tag_ndm: '00189601', tag_ary: [0x0018,0x9601], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9602)', tag_name: "Diffusion b-value XX", tag_key: 'DiffusionBValueXX', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9602)', tag_sym: :diffusion_b_value_xx, tag_ndm: '00189602', tag_ary: [0x0018,0x9602], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9603)', tag_name: "Diffusion b-value XY", tag_key: 'DiffusionBValueXY', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9603)', tag_sym: :diffusion_b_value_xy, tag_ndm: '00189603', tag_ary: [0x0018,0x9603], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9604)', tag_name: "Diffusion b-value XZ", tag_key: 'DiffusionBValueXZ', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9604)', tag_sym: :diffusion_b_value_xz, tag_ndm: '00189604', tag_ary: [0x0018,0x9604], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9605)', tag_name: "Diffusion b-value YY", tag_key: 'DiffusionBValueYY', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9605)', tag_sym: :diffusion_b_value_yy, tag_ndm: '00189605', tag_ary: [0x0018,0x9605], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9606)', tag_name: "Diffusion b-value YZ", tag_key: 'DiffusionBValueYZ', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9606)', tag_sym: :diffusion_b_value_yz, tag_ndm: '00189606', tag_ary: [0x0018,0x9606], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9607)', tag_name: "Diffusion b-value ZZ", tag_key: 'DiffusionBValueZZ', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9607)', tag_sym: :diffusion_b_value_zz, tag_ndm: '00189607', tag_ary: [0x0018,0x9607], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9621)', tag_name: "Functional MR Sequence", tag_key: 'FunctionalMRSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9621)', tag_sym: :functional_mr_sequence, tag_ndm: '00189621', tag_ary: [0x0018,0x9621], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9622)', tag_name: "Functional Settling Phase Frames Present", tag_key: 'FunctionalSettlingPhaseFramesPresent', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9622)', tag_sym: :functional_settling_phase_frames_present, tag_ndm: '00189622', tag_ary: [0x0018,0x9622], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9623)', tag_name: "Functional Sync Pulse", tag_key: 'FunctionalSyncPulse', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(0018,9623)', tag_sym: :functional_sync_pulse, tag_ndm: '00189623', tag_ary: [0x0018,0x9623], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9624)', tag_name: "Settling Phase Frame", tag_key: 'SettlingPhaseFrame', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9624)', tag_sym: :settling_phase_frame, tag_ndm: '00189624', tag_ary: [0x0018,0x9624], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9701)', tag_name: "Decay Correction DateTime", tag_key: 'DecayCorrectionDateTime', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(0018,9701)', tag_sym: :decay_correction_date_time, tag_ndm: '00189701', tag_ary: [0x0018,0x9701], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9715)', tag_name: "Start Density Threshold", tag_key: 'StartDensityThreshold', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9715)', tag_sym: :start_density_threshold, tag_ndm: '00189715', tag_ary: [0x0018,0x9715], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9716)', tag_name: "Start Relative Density Difference Threshold", tag_key: 'StartRelativeDensityDifferenceThreshold', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9716)', tag_sym: :start_relative_density_difference_threshold, tag_ndm: '00189716', tag_ary: [0x0018,0x9716], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9717)', tag_name: "Start Cardiac Trigger Count Threshold", tag_key: 'StartCardiacTriggerCountThreshold', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9717)', tag_sym: :start_cardiac_trigger_count_threshold, tag_ndm: '00189717', tag_ary: [0x0018,0x9717], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9718)', tag_name: "Start Respiratory Trigger Count Threshold", tag_key: 'StartRespiratoryTriggerCountThreshold', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9718)', tag_sym: :start_respiratory_trigger_count_threshold, tag_ndm: '00189718', tag_ary: [0x0018,0x9718], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9719)', tag_name: "Termination Counts Threshold", tag_key: 'TerminationCountsThreshold', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9719)', tag_sym: :termination_counts_threshold, tag_ndm: '00189719', tag_ary: [0x0018,0x9719], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9720)', tag_name: "Termination Density Threshold", tag_key: 'TerminationDensityThreshold', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9720)', tag_sym: :termination_density_threshold, tag_ndm: '00189720', tag_ary: [0x0018,0x9720], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9721)', tag_name: "Termination Relative Density Threshold", tag_key: 'TerminationRelativeDensityThreshold', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9721)', tag_sym: :termination_relative_density_threshold, tag_ndm: '00189721', tag_ary: [0x0018,0x9721], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9722)', tag_name: "Termination Time Threshold", tag_key: 'TerminationTimeThreshold', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9722)', tag_sym: :termination_time_threshold, tag_ndm: '00189722', tag_ary: [0x0018,0x9722], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9723)', tag_name: "Termination Cardiac Trigger Count Threshold", tag_key: 'TerminationCardiacTriggerCountThreshold', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9723)', tag_sym: :termination_cardiac_trigger_count_threshold, tag_ndm: '00189723', tag_ary: [0x0018,0x9723], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9724)', tag_name: "Termination Respiratory Trigger Count Threshold", tag_key: 'TerminationRespiratoryTriggerCountThreshold', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9724)', tag_sym: :termination_respiratory_trigger_count_threshold, tag_ndm: '00189724', tag_ary: [0x0018,0x9724], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9725)', tag_name: "Detector Geometry", tag_key: 'DetectorGeometry', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9725)', tag_sym: :detector_geometry, tag_ndm: '00189725', tag_ary: [0x0018,0x9725], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9726)', tag_name: "Transverse Detector Separation", tag_key: 'TransverseDetectorSeparation', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9726)', tag_sym: :transverse_detector_separation, tag_ndm: '00189726', tag_ary: [0x0018,0x9726], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9727)', tag_name: "Axial Detector Dimension", tag_key: 'AxialDetectorDimension', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9727)', tag_sym: :axial_detector_dimension, tag_ndm: '00189727', tag_ary: [0x0018,0x9727], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9729)', tag_name: "Radiopharmaceutical Agent Number", tag_key: 'RadiopharmaceuticalAgentNumber', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0018,9729)', tag_sym: :radiopharmaceutical_agent_number, tag_ndm: '00189729', tag_ary: [0x0018,0x9729], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9732)', tag_name: "PET Frame Acquisition Sequence", tag_key: 'PETFrameAcquisitionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9732)', tag_sym: :pet_frame_acquisition_sequence, tag_ndm: '00189732', tag_ary: [0x0018,0x9732], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9733)', tag_name: "PET Detector Motion Details Sequence", tag_key: 'PETDetectorMotionDetailsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9733)', tag_sym: :pet_detector_motion_details_sequence, tag_ndm: '00189733', tag_ary: [0x0018,0x9733], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9734)', tag_name: "PET Table Dynamics Sequence", tag_key: 'PETTableDynamicsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9734)', tag_sym: :pet_table_dynamics_sequence, tag_ndm: '00189734', tag_ary: [0x0018,0x9734], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9735)', tag_name: "PET Position Sequence", tag_key: 'PETPositionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9735)', tag_sym: :pet_position_sequence, tag_ndm: '00189735', tag_ary: [0x0018,0x9735], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9736)', tag_name: "PET Frame Correction Factors Sequence", tag_key: 'PETFrameCorrectionFactorsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9736)', tag_sym: :pet_frame_correction_factors_sequence, tag_ndm: '00189736', tag_ary: [0x0018,0x9736], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9737)', tag_name: "Radiopharmaceutical Usage Sequence", tag_key: 'RadiopharmaceuticalUsageSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9737)', tag_sym: :radiopharmaceutical_usage_sequence, tag_ndm: '00189737', tag_ary: [0x0018,0x9737], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9738)', tag_name: "Attenuation Correction Source", tag_key: 'AttenuationCorrectionSource', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9738)', tag_sym: :attenuation_correction_source, tag_ndm: '00189738', tag_ary: [0x0018,0x9738], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9739)', tag_name: "Number of Iterations", tag_key: 'NumberOfIterations', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0018,9739)', tag_sym: :number_of_iterations, tag_ndm: '00189739', tag_ary: [0x0018,0x9739], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9740)', tag_name: "Number of Subsets", tag_key: 'NumberOfSubsets', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0018,9740)', tag_sym: :number_of_subsets, tag_ndm: '00189740', tag_ary: [0x0018,0x9740], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9749)', tag_name: "PET Reconstruction Sequence", tag_key: 'PETReconstructionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9749)', tag_sym: :pet_reconstruction_sequence, tag_ndm: '00189749', tag_ary: [0x0018,0x9749], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9751)', tag_name: "PET Frame Type Sequence", tag_key: 'PETFrameTypeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9751)', tag_sym: :pet_frame_type_sequence, tag_ndm: '00189751', tag_ary: [0x0018,0x9751], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9755)', tag_name: "Time of Flight Information Used", tag_key: 'TimeOfFlightInformationUsed', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9755)', tag_sym: :time_of_flight_information_used, tag_ndm: '00189755', tag_ary: [0x0018,0x9755], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9756)', tag_name: "Reconstruction Type", tag_key: 'ReconstructionType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9756)', tag_sym: :reconstruction_type, tag_ndm: '00189756', tag_ary: [0x0018,0x9756], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9758)', tag_name: "Decay Corrected", tag_key: 'DecayCorrected', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9758)', tag_sym: :decay_corrected, tag_ndm: '00189758', tag_ary: [0x0018,0x9758], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9759)', tag_name: "Attenuation Corrected", tag_key: 'AttenuationCorrected', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9759)', tag_sym: :attenuation_corrected, tag_ndm: '00189759', tag_ary: [0x0018,0x9759], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9760)', tag_name: "Scatter Corrected", tag_key: 'ScatterCorrected', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9760)', tag_sym: :scatter_corrected, tag_ndm: '00189760', tag_ary: [0x0018,0x9760], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9761)', tag_name: "Dead Time Corrected", tag_key: 'DeadTimeCorrected', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9761)', tag_sym: :dead_time_corrected, tag_ndm: '00189761', tag_ary: [0x0018,0x9761], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9762)', tag_name: "Gantry Motion Corrected", tag_key: 'GantryMotionCorrected', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9762)', tag_sym: :gantry_motion_corrected, tag_ndm: '00189762', tag_ary: [0x0018,0x9762], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9763)', tag_name: "Patient Motion Corrected", tag_key: 'PatientMotionCorrected', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9763)', tag_sym: :patient_motion_corrected, tag_ndm: '00189763', tag_ary: [0x0018,0x9763], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9764)', tag_name: "Count Loss Normalization Corrected", tag_key: 'CountLossNormalizationCorrected', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9764)', tag_sym: :count_loss_normalization_corrected, tag_ndm: '00189764', tag_ary: [0x0018,0x9764], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9765)', tag_name: "Randoms Corrected", tag_key: 'RandomsCorrected', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9765)', tag_sym: :randoms_corrected, tag_ndm: '00189765', tag_ary: [0x0018,0x9765], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9766)', tag_name: "Non-uniform Radial Sampling Corrected", tag_key: 'NonUniformRadialSamplingCorrected', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9766)', tag_sym: :non_uniform_radial_sampling_corrected, tag_ndm: '00189766', tag_ary: [0x0018,0x9766], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9767)', tag_name: "Sensitivity Calibrated", tag_key: 'SensitivityCalibrated', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9767)', tag_sym: :sensitivity_calibrated, tag_ndm: '00189767', tag_ary: [0x0018,0x9767], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9768)', tag_name: "Detector Normalization Correction", tag_key: 'DetectorNormalizationCorrection', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9768)', tag_sym: :detector_normalization_correction, tag_ndm: '00189768', tag_ary: [0x0018,0x9768], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9769)', tag_name: "Iterative Reconstruction Method", tag_key: 'IterativeReconstructionMethod', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9769)', tag_sym: :iterative_reconstruction_method, tag_ndm: '00189769', tag_ary: [0x0018,0x9769], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9770)', tag_name: "Attenuation Correction Temporal Relationship", tag_key: 'AttenuationCorrectionTemporalRelationship', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9770)', tag_sym: :attenuation_correction_temporal_relationship, tag_ndm: '00189770', tag_ary: [0x0018,0x9770], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9771)', tag_name: "Patient Physiological State Sequence", tag_key: 'PatientPhysiologicalStateSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9771)', tag_sym: :patient_physiological_state_sequence, tag_ndm: '00189771', tag_ary: [0x0018,0x9771], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9772)', tag_name: "Patient Physiological State Code Sequence", tag_key: 'PatientPhysiologicalStateCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9772)', tag_sym: :patient_physiological_state_code_sequence, tag_ndm: '00189772', tag_ary: [0x0018,0x9772], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9801)', tag_name: "Depth(s) of Focus", tag_key: 'DepthsOfFocus', tag_vr: [:FD], tag_vm: ["1-n"], tag_str: '(0018,9801)', tag_sym: :depths_of_focus, tag_ndm: '00189801', tag_ary: [0x0018,0x9801], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9803)', tag_name: "Excluded Intervals Sequence", tag_key: 'ExcludedIntervalsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9803)', tag_sym: :excluded_intervals_sequence, tag_ndm: '00189803', tag_ary: [0x0018,0x9803], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9804)', tag_name: "Exclusion Start DateTime", tag_key: 'ExclusionStartDateTime', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(0018,9804)', tag_sym: :exclusion_start_date_time, tag_ndm: '00189804', tag_ary: [0x0018,0x9804], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9805)', tag_name: "Exclusion Duration", tag_key: 'ExclusionDuration', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9805)', tag_sym: :exclusion_duration, tag_ndm: '00189805', tag_ary: [0x0018,0x9805], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9806)', tag_name: "US Image Description Sequence", tag_key: 'USImageDescriptionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9806)', tag_sym: :us_image_description_sequence, tag_ndm: '00189806', tag_ary: [0x0018,0x9806], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9807)', tag_name: "Image Data Type Sequence", tag_key: 'ImageDataTypeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9807)', tag_sym: :image_data_type_sequence, tag_ndm: '00189807', tag_ary: [0x0018,0x9807], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9808)', tag_name: "Data Type", tag_key: 'DataType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9808)', tag_sym: :data_type, tag_ndm: '00189808', tag_ary: [0x0018,0x9808], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9809)', tag_name: "Transducer Scan Pattern Code Sequence", tag_key: 'TransducerScanPatternCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9809)', tag_sym: :transducer_scan_pattern_code_sequence, tag_ndm: '00189809', tag_ary: [0x0018,0x9809], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,980B)', tag_name: "Aliased Data Type", tag_key: 'AliasedDataType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,980B)', tag_sym: :aliased_data_type, tag_ndm: '0018980B', tag_ary: [0x0018,0x980B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,980C)', tag_name: "Position Measuring Device Used", tag_key: 'PositionMeasuringDeviceUsed', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,980C)', tag_sym: :position_measuring_device_used, tag_ndm: '0018980C', tag_ary: [0x0018,0x980C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,980D)', tag_name: "Transducer Geometry Code Sequence", tag_key: 'TransducerGeometryCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,980D)', tag_sym: :transducer_geometry_code_sequence, tag_ndm: '0018980D', tag_ary: [0x0018,0x980D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,980E)', tag_name: "Transducer Beam Steering Code Sequence", tag_key: 'TransducerBeamSteeringCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,980E)', tag_sym: :transducer_beam_steering_code_sequence, tag_ndm: '0018980E', tag_ary: [0x0018,0x980E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,980F)', tag_name: "Transducer Application Code Sequence", tag_key: 'TransducerApplicationCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,980F)', tag_sym: :transducer_application_code_sequence, tag_ndm: '0018980F', tag_ary: [0x0018,0x980F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9810)', tag_name: "Zero Velocity Pixel Value", tag_key: 'ZeroVelocityPixelValue', tag_vr: [:US, :SS], tag_vm: ["1"], tag_str: '(0018,9810)', tag_sym: :zero_velocity_pixel_value, tag_ndm: '00189810', tag_ary: [0x0018,0x9810], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9821)', tag_name: "Photoacoustic Excitation Characteristics Sequence", tag_key: 'PhotoacousticExcitationCharacteristicsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9821)', tag_sym: :photoacoustic_excitation_characteristics_sequence, tag_ndm: '00189821', tag_ary: [0x0018,0x9821], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9822)', tag_name: "Excitation Spectral Width", tag_key: 'ExcitationSpectralWidth', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9822)', tag_sym: :excitation_spectral_width, tag_ndm: '00189822', tag_ary: [0x0018,0x9822], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9823)', tag_name: "Excitation Energy", tag_key: 'ExcitationEnergy', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9823)', tag_sym: :excitation_energy, tag_ndm: '00189823', tag_ary: [0x0018,0x9823], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9824)', tag_name: "Excitation Pulse Duration", tag_key: 'ExcitationPulseDuration', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9824)', tag_sym: :excitation_pulse_duration, tag_ndm: '00189824', tag_ary: [0x0018,0x9824], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9825)', tag_name: "Excitation Wavelength Sequence", tag_key: 'ExcitationWavelengthSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9825)', tag_sym: :excitation_wavelength_sequence, tag_ndm: '00189825', tag_ary: [0x0018,0x9825], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9826)', tag_name: "Excitation Wavelength", tag_key: 'ExcitationWavelength', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9826)', tag_sym: :excitation_wavelength, tag_ndm: '00189826', tag_ary: [0x0018,0x9826], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9828)', tag_name: "Illumination Translation Flag", tag_key: 'IlluminationTranslationFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9828)', tag_sym: :illumination_translation_flag, tag_ndm: '00189828', tag_ary: [0x0018,0x9828], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9829)', tag_name: "Acoustic Coupling Medium Flag", tag_key: 'AcousticCouplingMediumFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9829)', tag_sym: :acoustic_coupling_medium_flag, tag_ndm: '00189829', tag_ary: [0x0018,0x9829], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,982A)', tag_name: "Acoustic Coupling Medium Code Sequence", tag_key: 'AcousticCouplingMediumCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,982A)', tag_sym: :acoustic_coupling_medium_code_sequence, tag_ndm: '0018982A', tag_ary: [0x0018,0x982A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,982B)', tag_name: "Acoustic Coupling Medium Temperature", tag_key: 'AcousticCouplingMediumTemperature', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,982B)', tag_sym: :acoustic_coupling_medium_temperature, tag_ndm: '0018982B', tag_ary: [0x0018,0x982B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,982C)', tag_name: "Transducer Response Sequence", tag_key: 'TransducerResponseSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,982C)', tag_sym: :transducer_response_sequence, tag_ndm: '0018982C', tag_ary: [0x0018,0x982C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,982D)', tag_name: "Center Frequency", tag_key: 'CenterFrequency', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,982D)', tag_sym: :center_frequency, tag_ndm: '0018982D', tag_ary: [0x0018,0x982D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,982E)', tag_name: "Fractional Bandwidth", tag_key: 'FractionalBandwidth', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,982E)', tag_sym: :fractional_bandwidth, tag_ndm: '0018982E', tag_ary: [0x0018,0x982E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,982F)', tag_name: "Lower Cutoff Frequency", tag_key: 'LowerCutoffFrequency', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,982F)', tag_sym: :lower_cutoff_frequency, tag_ndm: '0018982F', tag_ary: [0x0018,0x982F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9830)', tag_name: "Upper Cutoff Frequency", tag_key: 'UpperCutoffFrequency', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9830)', tag_sym: :upper_cutoff_frequency, tag_ndm: '00189830', tag_ary: [0x0018,0x9830], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9831)', tag_name: "Transducer Technology Sequence", tag_key: 'TransducerTechnologySequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9831)', tag_sym: :transducer_technology_sequence, tag_ndm: '00189831', tag_ary: [0x0018,0x9831], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9832)', tag_name: "Sound Speed Correction Mechanism Code Sequence", tag_key: 'SoundSpeedCorrectionMechanismCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9832)', tag_sym: :sound_speed_correction_mechanism_code_sequence, tag_ndm: '00189832', tag_ary: [0x0018,0x9832], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9833)', tag_name: "Object Sound Speed", tag_key: 'ObjectSoundSpeed', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9833)', tag_sym: :object_sound_speed, tag_ndm: '00189833', tag_ary: [0x0018,0x9833], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9834)', tag_name: "Acoustic Coupling Medium Sound Speed", tag_key: 'AcousticCouplingMediumSoundSpeed', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9834)', tag_sym: :acoustic_coupling_medium_sound_speed, tag_ndm: '00189834', tag_ary: [0x0018,0x9834], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9835)', tag_name: "Photoacoustic Image Frame Type Sequence", tag_key: 'PhotoacousticImageFrameTypeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9835)', tag_sym: :photoacoustic_image_frame_type_sequence, tag_ndm: '00189835', tag_ary: [0x0018,0x9835], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9836)', tag_name: "Image Data Type Code Sequence", tag_key: 'ImageDataTypeCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9836)', tag_sym: :image_data_type_code_sequence, tag_ndm: '00189836', tag_ary: [0x0018,0x9836], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9900)', tag_name: "Reference Location Label", tag_key: 'ReferenceLocationLabel', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0018,9900)', tag_sym: :reference_location_label, tag_ndm: '00189900', tag_ary: [0x0018,0x9900], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9901)', tag_name: "Reference Location Description", tag_key: 'ReferenceLocationDescription', tag_vr: [:UT], tag_vm: ["1"], tag_str: '(0018,9901)', tag_sym: :reference_location_description, tag_ndm: '00189901', tag_ary: [0x0018,0x9901], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9902)', tag_name: "Reference Basis Code Sequence", tag_key: 'ReferenceBasisCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9902)', tag_sym: :reference_basis_code_sequence, tag_ndm: '00189902', tag_ary: [0x0018,0x9902], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9903)', tag_name: "Reference Geometry Code Sequence", tag_key: 'ReferenceGeometryCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9903)', tag_sym: :reference_geometry_code_sequence, tag_ndm: '00189903', tag_ary: [0x0018,0x9903], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9904)', tag_name: "Offset Distance", tag_key: 'OffsetDistance', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0018,9904)', tag_sym: :offset_distance, tag_ndm: '00189904', tag_ary: [0x0018,0x9904], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9905)', tag_name: "Offset Direction", tag_key: 'OffsetDirection', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9905)', tag_sym: :offset_direction, tag_ndm: '00189905', tag_ary: [0x0018,0x9905], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9906)', tag_name: "Potential Scheduled Protocol Code Sequence", tag_key: 'PotentialScheduledProtocolCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9906)', tag_sym: :potential_scheduled_protocol_code_sequence, tag_ndm: '00189906', tag_ary: [0x0018,0x9906], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9907)', tag_name: "Potential Requested Procedure Code Sequence", tag_key: 'PotentialRequestedProcedureCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9907)', tag_sym: :potential_requested_procedure_code_sequence, tag_ndm: '00189907', tag_ary: [0x0018,0x9907], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9908)', tag_name: "Potential Reasons for Procedure", tag_key: 'PotentialReasonsForProcedure', tag_vr: [:UC], tag_vm: ["1-n"], tag_str: '(0018,9908)', tag_sym: :potential_reasons_for_procedure, tag_ndm: '00189908', tag_ary: [0x0018,0x9908], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9909)', tag_name: "Potential Reasons for Procedure Code Sequence", tag_key: 'PotentialReasonsForProcedureCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9909)', tag_sym: :potential_reasons_for_procedure_code_sequence, tag_ndm: '00189909', tag_ary: [0x0018,0x9909], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,990A)', tag_name: "Potential Diagnostic Tasks", tag_key: 'PotentialDiagnosticTasks', tag_vr: [:UC], tag_vm: ["1-n"], tag_str: '(0018,990A)', tag_sym: :potential_diagnostic_tasks, tag_ndm: '0018990A', tag_ary: [0x0018,0x990A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,990B)', tag_name: "Contraindications Code Sequence", tag_key: 'ContraindicationsCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,990B)', tag_sym: :contraindications_code_sequence, tag_ndm: '0018990B', tag_ary: [0x0018,0x990B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,990C)', tag_name: "Referenced Defined Protocol Sequence", tag_key: 'ReferencedDefinedProtocolSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,990C)', tag_sym: :referenced_defined_protocol_sequence, tag_ndm: '0018990C', tag_ary: [0x0018,0x990C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,990D)', tag_name: "Referenced Performed Protocol Sequence", tag_key: 'ReferencedPerformedProtocolSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,990D)', tag_sym: :referenced_performed_protocol_sequence, tag_ndm: '0018990D', tag_ary: [0x0018,0x990D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,990E)', tag_name: "Predecessor Protocol Sequence", tag_key: 'PredecessorProtocolSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,990E)', tag_sym: :predecessor_protocol_sequence, tag_ndm: '0018990E', tag_ary: [0x0018,0x990E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,990F)', tag_name: "Protocol Planning Information", tag_key: 'ProtocolPlanningInformation', tag_vr: [:UT], tag_vm: ["1"], tag_str: '(0018,990F)', tag_sym: :protocol_planning_information, tag_ndm: '0018990F', tag_ary: [0x0018,0x990F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9910)', tag_name: "Protocol Design Rationale", tag_key: 'ProtocolDesignRationale', tag_vr: [:UT], tag_vm: ["1"], tag_str: '(0018,9910)', tag_sym: :protocol_design_rationale, tag_ndm: '00189910', tag_ary: [0x0018,0x9910], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9911)', tag_name: "Patient Specification Sequence", tag_key: 'PatientSpecificationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9911)', tag_sym: :patient_specification_sequence, tag_ndm: '00189911', tag_ary: [0x0018,0x9911], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9912)', tag_name: "Model Specification Sequence", tag_key: 'ModelSpecificationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9912)', tag_sym: :model_specification_sequence, tag_ndm: '00189912', tag_ary: [0x0018,0x9912], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9913)', tag_name: "Parameters Specification Sequence", tag_key: 'ParametersSpecificationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9913)', tag_sym: :parameters_specification_sequence, tag_ndm: '00189913', tag_ary: [0x0018,0x9913], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9914)', tag_name: "Instruction Sequence", tag_key: 'InstructionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9914)', tag_sym: :instruction_sequence, tag_ndm: '00189914', tag_ary: [0x0018,0x9914], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9915)', tag_name: "Instruction Index", tag_key: 'InstructionIndex', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0018,9915)', tag_sym: :instruction_index, tag_ndm: '00189915', tag_ary: [0x0018,0x9915], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9916)', tag_name: "Instruction Text", tag_key: 'InstructionText', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0018,9916)', tag_sym: :instruction_text, tag_ndm: '00189916', tag_ary: [0x0018,0x9916], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9917)', tag_name: "Instruction Description", tag_key: 'InstructionDescription', tag_vr: [:UT], tag_vm: ["1"], tag_str: '(0018,9917)', tag_sym: :instruction_description, tag_ndm: '00189917', tag_ary: [0x0018,0x9917], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9918)', tag_name: "Instruction Performed Flag", tag_key: 'InstructionPerformedFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9918)', tag_sym: :instruction_performed_flag, tag_ndm: '00189918', tag_ary: [0x0018,0x9918], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9919)', tag_name: "Instruction Performed DateTime", tag_key: 'InstructionPerformedDateTime', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(0018,9919)', tag_sym: :instruction_performed_date_time, tag_ndm: '00189919', tag_ary: [0x0018,0x9919], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,991A)', tag_name: "Instruction Performance Comment", tag_key: 'InstructionPerformanceComment', tag_vr: [:UT], tag_vm: ["1"], tag_str: '(0018,991A)', tag_sym: :instruction_performance_comment, tag_ndm: '0018991A', tag_ary: [0x0018,0x991A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,991B)', tag_name: "Patient Positioning Instruction Sequence", tag_key: 'PatientPositioningInstructionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,991B)', tag_sym: :patient_positioning_instruction_sequence, tag_ndm: '0018991B', tag_ary: [0x0018,0x991B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,991C)', tag_name: "Positioning Method Code Sequence", tag_key: 'PositioningMethodCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,991C)', tag_sym: :positioning_method_code_sequence, tag_ndm: '0018991C', tag_ary: [0x0018,0x991C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,991D)', tag_name: "Positioning Landmark Sequence", tag_key: 'PositioningLandmarkSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,991D)', tag_sym: :positioning_landmark_sequence, tag_ndm: '0018991D', tag_ary: [0x0018,0x991D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,991E)', tag_name: "Target Frame of Reference UID", tag_key: 'TargetFrameOfReferenceUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0018,991E)', tag_sym: :target_frame_of_reference_uid, tag_ndm: '0018991E', tag_ary: [0x0018,0x991E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,991F)', tag_name: "Acquisition Protocol Element Specification Sequence", tag_key: 'AcquisitionProtocolElementSpecificationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,991F)', tag_sym: :acquisition_protocol_element_specification_sequence, tag_ndm: '0018991F', tag_ary: [0x0018,0x991F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9920)', tag_name: "Acquisition Protocol Element Sequence", tag_key: 'AcquisitionProtocolElementSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9920)', tag_sym: :acquisition_protocol_element_sequence, tag_ndm: '00189920', tag_ary: [0x0018,0x9920], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9921)', tag_name: "Protocol Element Number", tag_key: 'ProtocolElementNumber', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0018,9921)', tag_sym: :protocol_element_number, tag_ndm: '00189921', tag_ary: [0x0018,0x9921], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9922)', tag_name: "Protocol Element Name", tag_key: 'ProtocolElementName', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0018,9922)', tag_sym: :protocol_element_name, tag_ndm: '00189922', tag_ary: [0x0018,0x9922], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9923)', tag_name: "Protocol Element Characteristics Summary", tag_key: 'ProtocolElementCharacteristicsSummary', tag_vr: [:UT], tag_vm: ["1"], tag_str: '(0018,9923)', tag_sym: :protocol_element_characteristics_summary, tag_ndm: '00189923', tag_ary: [0x0018,0x9923], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9924)', tag_name: "Protocol Element Purpose", tag_key: 'ProtocolElementPurpose', tag_vr: [:UT], tag_vm: ["1"], tag_str: '(0018,9924)', tag_sym: :protocol_element_purpose, tag_ndm: '00189924', tag_ary: [0x0018,0x9924], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9930)', tag_name: "Acquisition Motion", tag_key: 'AcquisitionMotion', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9930)', tag_sym: :acquisition_motion, tag_ndm: '00189930', tag_ary: [0x0018,0x9930], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9931)', tag_name: "Acquisition Start Location Sequence", tag_key: 'AcquisitionStartLocationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9931)', tag_sym: :acquisition_start_location_sequence, tag_ndm: '00189931', tag_ary: [0x0018,0x9931], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9932)', tag_name: "Acquisition End Location Sequence", tag_key: 'AcquisitionEndLocationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9932)', tag_sym: :acquisition_end_location_sequence, tag_ndm: '00189932', tag_ary: [0x0018,0x9932], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9933)', tag_name: "Reconstruction Protocol Element Specification Sequence", tag_key: 'ReconstructionProtocolElementSpecificationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9933)', tag_sym: :reconstruction_protocol_element_specification_sequence, tag_ndm: '00189933', tag_ary: [0x0018,0x9933], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9934)', tag_name: "Reconstruction Protocol Element Sequence", tag_key: 'ReconstructionProtocolElementSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9934)', tag_sym: :reconstruction_protocol_element_sequence, tag_ndm: '00189934', tag_ary: [0x0018,0x9934], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9935)', tag_name: "Storage Protocol Element Specification Sequence", tag_key: 'StorageProtocolElementSpecificationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9935)', tag_sym: :storage_protocol_element_specification_sequence, tag_ndm: '00189935', tag_ary: [0x0018,0x9935], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9936)', tag_name: "Storage Protocol Element Sequence", tag_key: 'StorageProtocolElementSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,9936)', tag_sym: :storage_protocol_element_sequence, tag_ndm: '00189936', tag_ary: [0x0018,0x9936], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9937)', tag_name: "Requested Series Description", tag_key: 'RequestedSeriesDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0018,9937)', tag_sym: :requested_series_description, tag_ndm: '00189937', tag_ary: [0x0018,0x9937], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9938)', tag_name: "Source Acquisition Protocol Element Number", tag_key: 'SourceAcquisitionProtocolElementNumber', tag_vr: [:US], tag_vm: ["1-n"], tag_str: '(0018,9938)', tag_sym: :source_acquisition_protocol_element_number, tag_ndm: '00189938', tag_ary: [0x0018,0x9938], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9939)', tag_name: "Source Acquisition Beam Number", tag_key: 'SourceAcquisitionBeamNumber', tag_vr: [:US], tag_vm: ["1-n"], tag_str: '(0018,9939)', tag_sym: :source_acquisition_beam_number, tag_ndm: '00189939', tag_ary: [0x0018,0x9939], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,993A)', tag_name: "Source Reconstruction Protocol Element Number", tag_key: 'SourceReconstructionProtocolElementNumber', tag_vr: [:US], tag_vm: ["1-n"], tag_str: '(0018,993A)', tag_sym: :source_reconstruction_protocol_element_number, tag_ndm: '0018993A', tag_ary: [0x0018,0x993A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,993B)', tag_name: "Reconstruction Start Location Sequence", tag_key: 'ReconstructionStartLocationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,993B)', tag_sym: :reconstruction_start_location_sequence, tag_ndm: '0018993B', tag_ary: [0x0018,0x993B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,993C)', tag_name: "Reconstruction End Location Sequence", tag_key: 'ReconstructionEndLocationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,993C)', tag_sym: :reconstruction_end_location_sequence, tag_ndm: '0018993C', tag_ary: [0x0018,0x993C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,993D)', tag_name: "Reconstruction Algorithm Sequence", tag_key: 'ReconstructionAlgorithmSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,993D)', tag_sym: :reconstruction_algorithm_sequence, tag_ndm: '0018993D', tag_ary: [0x0018,0x993D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,993E)', tag_name: "Reconstruction Target Center Location Sequence", tag_key: 'ReconstructionTargetCenterLocationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,993E)', tag_sym: :reconstruction_target_center_location_sequence, tag_ndm: '0018993E', tag_ary: [0x0018,0x993E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9941)', tag_name: "Image Filter Description", tag_key: 'ImageFilterDescription', tag_vr: [:UT], tag_vm: ["1"], tag_str: '(0018,9941)', tag_sym: :image_filter_description, tag_ndm: '00189941', tag_ary: [0x0018,0x9941], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9942)', tag_name: "CTDIvol Notification Trigger", tag_key: 'CTDIvolNotificationTrigger', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9942)', tag_sym: :ctdi_vol_notification_trigger, tag_ndm: '00189942', tag_ary: [0x0018,0x9942], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9943)', tag_name: "DLP Notification Trigger", tag_key: 'DLPNotificationTrigger', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9943)', tag_sym: :dlp_notification_trigger, tag_ndm: '00189943', tag_ary: [0x0018,0x9943], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9944)', tag_name: "Auto KVP Selection Type", tag_key: 'AutoKVPSelectionType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9944)', tag_sym: :auto_kvp_selection_type, tag_ndm: '00189944', tag_ary: [0x0018,0x9944], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9945)', tag_name: "Auto KVP Upper Bound", tag_key: 'AutoKVPUpperBound', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9945)', tag_sym: :auto_kvp_upper_bound, tag_ndm: '00189945', tag_ary: [0x0018,0x9945], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9946)', tag_name: "Auto KVP Lower Bound", tag_key: 'AutoKVPLowerBound', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0018,9946)', tag_sym: :auto_kvp_lower_bound, tag_ndm: '00189946', tag_ary: [0x0018,0x9946], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,9947)', tag_name: "Protocol Defined Patient Position", tag_key: 'ProtocolDefinedPatientPosition', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0018,9947)', tag_sym: :protocol_defined_patient_position, tag_ndm: '00189947', tag_ary: [0x0018,0x9947], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,A001)', tag_name: "Contributing Equipment Sequence", tag_key: 'ContributingEquipmentSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0018,A001)', tag_sym: :contributing_equipment_sequence, tag_ndm: '0018A001', tag_ary: [0x0018,0xA001], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,A002)', tag_name: "Contribution DateTime", tag_key: 'ContributionDateTime', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(0018,A002)', tag_sym: :contribution_date_time, tag_ndm: '0018A002', tag_ary: [0x0018,0xA002], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0018,A003)', tag_name: "Contribution Description", tag_key: 'ContributionDescription', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0018,A003)', tag_sym: :contribution_description, tag_ndm: '0018A003', tag_ary: [0x0018,0xA003], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,000D)', tag_name: "Study Instance UID", tag_key: 'StudyInstanceUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0020,000D)', tag_sym: :study_instance_uid, tag_ndm: '0020000D', tag_ary: [0x0020,0x000D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,000E)', tag_name: "Series Instance UID", tag_key: 'SeriesInstanceUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0020,000E)', tag_sym: :series_instance_uid, tag_ndm: '0020000E', tag_ary: [0x0020,0x000E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,0010)', tag_name: "Study ID", tag_key: 'StudyID', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0020,0010)', tag_sym: :study_id, tag_ndm: '00200010', tag_ary: [0x0020,0x0010], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,0011)', tag_name: "Series Number", tag_key: 'SeriesNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0020,0011)', tag_sym: :series_number, tag_ndm: '00200011', tag_ary: [0x0020,0x0011], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,0012)', tag_name: "Acquisition Number", tag_key: 'AcquisitionNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0020,0012)', tag_sym: :acquisition_number, tag_ndm: '00200012', tag_ary: [0x0020,0x0012], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,0013)', tag_name: "Instance Number", tag_key: 'InstanceNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0020,0013)', tag_sym: :instance_number, tag_ndm: '00200013', tag_ary: [0x0020,0x0013], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,0014)', tag_name: "Isotope Number", tag_key: 'IsotopeNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0020,0014)', tag_sym: :isotope_number, tag_ndm: '00200014', tag_ary: [0x0020,0x0014], tag_multiple: false, tag_note: 'RET (1993)'},
      { tag_ps: '(0020,0015)', tag_name: "Phase Number", tag_key: 'PhaseNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0020,0015)', tag_sym: :phase_number, tag_ndm: '00200015', tag_ary: [0x0020,0x0015], tag_multiple: false, tag_note: 'RET (1993)'},
      { tag_ps: '(0020,0016)', tag_name: "Interval Number", tag_key: 'IntervalNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0020,0016)', tag_sym: :interval_number, tag_ndm: '00200016', tag_ary: [0x0020,0x0016], tag_multiple: false, tag_note: 'RET (1993)'},
      { tag_ps: '(0020,0017)', tag_name: "Time Slot Number", tag_key: 'TimeSlotNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0020,0017)', tag_sym: :time_slot_number, tag_ndm: '00200017', tag_ary: [0x0020,0x0017], tag_multiple: false, tag_note: 'RET (1993)'},
      { tag_ps: '(0020,0018)', tag_name: "Angle Number", tag_key: 'AngleNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0020,0018)', tag_sym: :angle_number, tag_ndm: '00200018', tag_ary: [0x0020,0x0018], tag_multiple: false, tag_note: 'RET (1993)'},
      { tag_ps: '(0020,0019)', tag_name: "Item Number", tag_key: 'ItemNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0020,0019)', tag_sym: :item_number, tag_ndm: '00200019', tag_ary: [0x0020,0x0019], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,0020)', tag_name: "Patient Orientation", tag_key: 'PatientOrientation', tag_vr: [:CS], tag_vm: ["2"], tag_str: '(0020,0020)', tag_sym: :patient_orientation, tag_ndm: '00200020', tag_ary: [0x0020,0x0020], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,0022)', tag_name: "Overlay Number", tag_key: 'OverlayNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0020,0022)', tag_sym: :overlay_number, tag_ndm: '00200022', tag_ary: [0x0020,0x0022], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(0020,0024)', tag_name: "Curve Number", tag_key: 'CurveNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0020,0024)', tag_sym: :curve_number, tag_ndm: '00200024', tag_ary: [0x0020,0x0024], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(0020,0026)', tag_name: "LUT Number", tag_key: 'LUTNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0020,0026)', tag_sym: :lut_number, tag_ndm: '00200026', tag_ary: [0x0020,0x0026], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(0020,0027)', tag_name: "Pyramid Label", tag_key: 'PyramidLabel', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0020,0027)', tag_sym: :pyramid_label, tag_ndm: '00200027', tag_ary: [0x0020,0x0027], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,0030)', tag_name: "Image Position", tag_key: 'ImagePosition', tag_vr: [:DS], tag_vm: ["3"], tag_str: '(0020,0030)', tag_sym: :image_position, tag_ndm: '00200030', tag_ary: [0x0020,0x0030], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(0020,0032)', tag_name: "Image Position (Patient)", tag_key: 'ImagePositionPatient', tag_vr: [:DS], tag_vm: ["3"], tag_str: '(0020,0032)', tag_sym: :image_position_patient, tag_ndm: '00200032', tag_ary: [0x0020,0x0032], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,0035)', tag_name: "Image Orientation", tag_key: 'ImageOrientation', tag_vr: [:DS], tag_vm: ["6"], tag_str: '(0020,0035)', tag_sym: :image_orientation, tag_ndm: '00200035', tag_ary: [0x0020,0x0035], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(0020,0037)', tag_name: "Image Orientation (Patient)", tag_key: 'ImageOrientationPatient', tag_vr: [:DS], tag_vm: ["6"], tag_str: '(0020,0037)', tag_sym: :image_orientation_patient, tag_ndm: '00200037', tag_ary: [0x0020,0x0037], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,0050)', tag_name: "Location", tag_key: 'Location', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0020,0050)', tag_sym: :location, tag_ndm: '00200050', tag_ary: [0x0020,0x0050], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(0020,0052)', tag_name: "Frame of Reference UID", tag_key: 'FrameOfReferenceUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0020,0052)', tag_sym: :frame_of_reference_uid, tag_ndm: '00200052', tag_ary: [0x0020,0x0052], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,0060)', tag_name: "Laterality", tag_key: 'Laterality', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0020,0060)', tag_sym: :laterality, tag_ndm: '00200060', tag_ary: [0x0020,0x0060], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,0062)', tag_name: "Image Laterality", tag_key: 'ImageLaterality', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0020,0062)', tag_sym: :image_laterality, tag_ndm: '00200062', tag_ary: [0x0020,0x0062], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,0070)', tag_name: "Image Geometry Type", tag_key: 'ImageGeometryType', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0020,0070)', tag_sym: :image_geometry_type, tag_ndm: '00200070', tag_ary: [0x0020,0x0070], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(0020,0080)', tag_name: "Masking Image", tag_key: 'MaskingImage', tag_vr: [:CS], tag_vm: ["1-n"], tag_str: '(0020,0080)', tag_sym: :masking_image, tag_ndm: '00200080', tag_ary: [0x0020,0x0080], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(0020,00AA)', tag_name: "Report Number", tag_key: 'ReportNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0020,00AA)', tag_sym: :report_number, tag_ndm: '002000AA', tag_ary: [0x0020,0x00AA], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0020,0100)', tag_name: "Temporal Position Identifier", tag_key: 'TemporalPositionIdentifier', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0020,0100)', tag_sym: :temporal_position_identifier, tag_ndm: '00200100', tag_ary: [0x0020,0x0100], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,0105)', tag_name: "Number of Temporal Positions", tag_key: 'NumberOfTemporalPositions', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0020,0105)', tag_sym: :number_of_temporal_positions, tag_ndm: '00200105', tag_ary: [0x0020,0x0105], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,0110)', tag_name: "Temporal Resolution", tag_key: 'TemporalResolution', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0020,0110)', tag_sym: :temporal_resolution, tag_ndm: '00200110', tag_ary: [0x0020,0x0110], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,0200)', tag_name: "Synchronization Frame of Reference UID", tag_key: 'SynchronizationFrameOfReferenceUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0020,0200)', tag_sym: :synchronization_frame_of_reference_uid, tag_ndm: '00200200', tag_ary: [0x0020,0x0200], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,0242)', tag_name: "SOP Instance UID of Concatenation Source", tag_key: 'SOPInstanceUIDOfConcatenationSource', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0020,0242)', tag_sym: :sop_instance_uid_of_concatenation_source, tag_ndm: '00200242', tag_ary: [0x0020,0x0242], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,1000)', tag_name: "Series in Study", tag_key: 'SeriesInStudy', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0020,1000)', tag_sym: :series_in_study, tag_ndm: '00201000', tag_ary: [0x0020,0x1000], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(0020,1001)', tag_name: "Acquisitions in Series", tag_key: 'AcquisitionsInSeries', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0020,1001)', tag_sym: :acquisitions_in_series, tag_ndm: '00201001', tag_ary: [0x0020,0x1001], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(0020,1002)', tag_name: "Images in Acquisition", tag_key: 'ImagesInAcquisition', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0020,1002)', tag_sym: :images_in_acquisition, tag_ndm: '00201002', tag_ary: [0x0020,0x1002], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,1003)', tag_name: "Images in Series", tag_key: 'ImagesInSeries', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0020,1003)', tag_sym: :images_in_series, tag_ndm: '00201003', tag_ary: [0x0020,0x1003], tag_multiple: false, tag_note: 'RET (2006)'},
      { tag_ps: '(0020,1004)', tag_name: "Acquisitions in Study", tag_key: 'AcquisitionsInStudy', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0020,1004)', tag_sym: :acquisitions_in_study, tag_ndm: '00201004', tag_ary: [0x0020,0x1004], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(0020,1005)', tag_name: "Images in Study", tag_key: 'ImagesInStudy', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0020,1005)', tag_sym: :images_in_study, tag_ndm: '00201005', tag_ary: [0x0020,0x1005], tag_multiple: false, tag_note: 'RET (2006)'},
      { tag_ps: '(0020,1020)', tag_name: "Reference", tag_key: 'Reference', tag_vr: [:LO], tag_vm: ["1-n"], tag_str: '(0020,1020)', tag_sym: :reference, tag_ndm: '00201020', tag_ary: [0x0020,0x1020], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(0020,103F)', tag_name: "Target Position Reference Indicator", tag_key: 'TargetPositionReferenceIndicator', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0020,103F)', tag_sym: :target_position_reference_indicator, tag_ndm: '0020103F', tag_ary: [0x0020,0x103F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,1040)', tag_name: "Position Reference Indicator", tag_key: 'PositionReferenceIndicator', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0020,1040)', tag_sym: :position_reference_indicator, tag_ndm: '00201040', tag_ary: [0x0020,0x1040], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,1041)', tag_name: "Slice Location", tag_key: 'SliceLocation', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0020,1041)', tag_sym: :slice_location, tag_ndm: '00201041', tag_ary: [0x0020,0x1041], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,1070)', tag_name: "Other Study Numbers", tag_key: 'OtherStudyNumbers', tag_vr: [:IS], tag_vm: ["1-n"], tag_str: '(0020,1070)', tag_sym: :other_study_numbers, tag_ndm: '00201070', tag_ary: [0x0020,0x1070], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(0020,1200)', tag_name: "Number of Patient Related Studies", tag_key: 'NumberOfPatientRelatedStudies', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0020,1200)', tag_sym: :number_of_patient_related_studies, tag_ndm: '00201200', tag_ary: [0x0020,0x1200], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,1202)', tag_name: "Number of Patient Related Series", tag_key: 'NumberOfPatientRelatedSeries', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0020,1202)', tag_sym: :number_of_patient_related_series, tag_ndm: '00201202', tag_ary: [0x0020,0x1202], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,1204)', tag_name: "Number of Patient Related Instances", tag_key: 'NumberOfPatientRelatedInstances', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0020,1204)', tag_sym: :number_of_patient_related_instances, tag_ndm: '00201204', tag_ary: [0x0020,0x1204], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,1206)', tag_name: "Number of Study Related Series", tag_key: 'NumberOfStudyRelatedSeries', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0020,1206)', tag_sym: :number_of_study_related_series, tag_ndm: '00201206', tag_ary: [0x0020,0x1206], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,1208)', tag_name: "Number of Study Related Instances", tag_key: 'NumberOfStudyRelatedInstances', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0020,1208)', tag_sym: :number_of_study_related_instances, tag_ndm: '00201208', tag_ary: [0x0020,0x1208], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,1209)', tag_name: "Number of Series Related Instances", tag_key: 'NumberOfSeriesRelatedInstances', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0020,1209)', tag_sym: :number_of_series_related_instances, tag_ndm: '00201209', tag_ary: [0x0020,0x1209], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,31XX)', tag_name: "Source Image IDs", tag_key: 'SourceImageIDs', tag_vr: [:CS], tag_vm: ["1-n"], tag_str: '(0020,3122)', tag_sym: :source_image_ids, tag_ndm: '00203122', tag_ary: [0x0020,0x3122], tag_multiple: true, tag_note: 'RET'},
      { tag_ps: '(0020,3401)', tag_name: "Modifying Device ID", tag_key: 'ModifyingDeviceID', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0020,3401)', tag_sym: :modifying_device_id, tag_ndm: '00203401', tag_ary: [0x0020,0x3401], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(0020,3402)', tag_name: "Modified Image ID", tag_key: 'ModifiedImageID', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0020,3402)', tag_sym: :modified_image_id, tag_ndm: '00203402', tag_ary: [0x0020,0x3402], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(0020,3403)', tag_name: "Modified Image Date", tag_key: 'ModifiedImageDate', tag_vr: [:DA], tag_vm: ["1"], tag_str: '(0020,3403)', tag_sym: :modified_image_date, tag_ndm: '00203403', tag_ary: [0x0020,0x3403], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(0020,3404)', tag_name: "Modifying Device Manufacturer", tag_key: 'ModifyingDeviceManufacturer', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0020,3404)', tag_sym: :modifying_device_manufacturer, tag_ndm: '00203404', tag_ary: [0x0020,0x3404], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(0020,3405)', tag_name: "Modified Image Time", tag_key: 'ModifiedImageTime', tag_vr: [:TM], tag_vm: ["1"], tag_str: '(0020,3405)', tag_sym: :modified_image_time, tag_ndm: '00203405', tag_ary: [0x0020,0x3405], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(0020,3406)', tag_name: "Modified Image Description", tag_key: 'ModifiedImageDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0020,3406)', tag_sym: :modified_image_description, tag_ndm: '00203406', tag_ary: [0x0020,0x3406], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(0020,4000)', tag_name: "Image Comments", tag_key: 'ImageComments', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(0020,4000)', tag_sym: :image_comments, tag_ndm: '00204000', tag_ary: [0x0020,0x4000], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,5000)', tag_name: "Original Image Identification", tag_key: 'OriginalImageIdentification', tag_vr: [:AT], tag_vm: ["1-n"], tag_str: '(0020,5000)', tag_sym: :original_image_identification, tag_ndm: '00205000', tag_ary: [0x0020,0x5000], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(0020,5002)', tag_name: "Original Image Identification Nomenclature", tag_key: 'OriginalImageIdentificationNomenclature', tag_vr: [:LO], tag_vm: ["1-n"], tag_str: '(0020,5002)', tag_sym: :original_image_identification_nomenclature, tag_ndm: '00205002', tag_ary: [0x0020,0x5002], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(0020,9056)', tag_name: "Stack ID", tag_key: 'StackID', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0020,9056)', tag_sym: :stack_id, tag_ndm: '00209056', tag_ary: [0x0020,0x9056], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,9057)', tag_name: "In-Stack Position Number", tag_key: 'InStackPositionNumber', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0020,9057)', tag_sym: :in_stack_position_number, tag_ndm: '00209057', tag_ary: [0x0020,0x9057], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,9071)', tag_name: "Frame Anatomy Sequence", tag_key: 'FrameAnatomySequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0020,9071)', tag_sym: :frame_anatomy_sequence, tag_ndm: '00209071', tag_ary: [0x0020,0x9071], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,9072)', tag_name: "Frame Laterality", tag_key: 'FrameLaterality', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0020,9072)', tag_sym: :frame_laterality, tag_ndm: '00209072', tag_ary: [0x0020,0x9072], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,9111)', tag_name: "Frame Content Sequence", tag_key: 'FrameContentSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0020,9111)', tag_sym: :frame_content_sequence, tag_ndm: '00209111', tag_ary: [0x0020,0x9111], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,9113)', tag_name: "Plane Position Sequence", tag_key: 'PlanePositionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0020,9113)', tag_sym: :plane_position_sequence, tag_ndm: '00209113', tag_ary: [0x0020,0x9113], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,9116)', tag_name: "Plane Orientation Sequence", tag_key: 'PlaneOrientationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0020,9116)', tag_sym: :plane_orientation_sequence, tag_ndm: '00209116', tag_ary: [0x0020,0x9116], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,9128)', tag_name: "Temporal Position Index", tag_key: 'TemporalPositionIndex', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0020,9128)', tag_sym: :temporal_position_index, tag_ndm: '00209128', tag_ary: [0x0020,0x9128], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,9153)', tag_name: "Nominal Cardiac Trigger Delay Time", tag_key: 'NominalCardiacTriggerDelayTime', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0020,9153)', tag_sym: :nominal_cardiac_trigger_delay_time, tag_ndm: '00209153', tag_ary: [0x0020,0x9153], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,9154)', tag_name: "Nominal Cardiac Trigger Time Prior To R-Peak", tag_key: 'NominalCardiacTriggerTimePriorToRPeak', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0020,9154)', tag_sym: :nominal_cardiac_trigger_time_prior_to_r_peak, tag_ndm: '00209154', tag_ary: [0x0020,0x9154], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,9155)', tag_name: "Actual Cardiac Trigger Time Prior To R-Peak", tag_key: 'ActualCardiacTriggerTimePriorToRPeak', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0020,9155)', tag_sym: :actual_cardiac_trigger_time_prior_to_r_peak, tag_ndm: '00209155', tag_ary: [0x0020,0x9155], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,9156)', tag_name: "Frame Acquisition Number", tag_key: 'FrameAcquisitionNumber', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0020,9156)', tag_sym: :frame_acquisition_number, tag_ndm: '00209156', tag_ary: [0x0020,0x9156], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,9157)', tag_name: "Dimension Index Values", tag_key: 'DimensionIndexValues', tag_vr: [:UL], tag_vm: ["1-n"], tag_str: '(0020,9157)', tag_sym: :dimension_index_values, tag_ndm: '00209157', tag_ary: [0x0020,0x9157], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,9158)', tag_name: "Frame Comments", tag_key: 'FrameComments', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(0020,9158)', tag_sym: :frame_comments, tag_ndm: '00209158', tag_ary: [0x0020,0x9158], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,9161)', tag_name: "Concatenation UID", tag_key: 'ConcatenationUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0020,9161)', tag_sym: :concatenation_uid, tag_ndm: '00209161', tag_ary: [0x0020,0x9161], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,9162)', tag_name: "In-concatenation Number", tag_key: 'InConcatenationNumber', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0020,9162)', tag_sym: :in_concatenation_number, tag_ndm: '00209162', tag_ary: [0x0020,0x9162], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,9163)', tag_name: "In-concatenation Total Number", tag_key: 'InConcatenationTotalNumber', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0020,9163)', tag_sym: :in_concatenation_total_number, tag_ndm: '00209163', tag_ary: [0x0020,0x9163], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,9164)', tag_name: "Dimension Organization UID", tag_key: 'DimensionOrganizationUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0020,9164)', tag_sym: :dimension_organization_uid, tag_ndm: '00209164', tag_ary: [0x0020,0x9164], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,9165)', tag_name: "Dimension Index Pointer", tag_key: 'DimensionIndexPointer', tag_vr: [:AT], tag_vm: ["1"], tag_str: '(0020,9165)', tag_sym: :dimension_index_pointer, tag_ndm: '00209165', tag_ary: [0x0020,0x9165], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,9167)', tag_name: "Functional Group Pointer", tag_key: 'FunctionalGroupPointer', tag_vr: [:AT], tag_vm: ["1"], tag_str: '(0020,9167)', tag_sym: :functional_group_pointer, tag_ndm: '00209167', tag_ary: [0x0020,0x9167], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,9170)', tag_name: "Unassigned Shared Converted Attributes Sequence", tag_key: 'UnassignedSharedConvertedAttributesSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0020,9170)', tag_sym: :unassigned_shared_converted_attributes_sequence, tag_ndm: '00209170', tag_ary: [0x0020,0x9170], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,9171)', tag_name: "Unassigned Per-Frame Converted Attributes Sequence", tag_key: 'UnassignedPerFrameConvertedAttributesSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0020,9171)', tag_sym: :unassigned_per_frame_converted_attributes_sequence, tag_ndm: '00209171', tag_ary: [0x0020,0x9171], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,9172)', tag_name: "Conversion Source Attributes Sequence", tag_key: 'ConversionSourceAttributesSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0020,9172)', tag_sym: :conversion_source_attributes_sequence, tag_ndm: '00209172', tag_ary: [0x0020,0x9172], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,9213)', tag_name: "Dimension Index Private Creator", tag_key: 'DimensionIndexPrivateCreator', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0020,9213)', tag_sym: :dimension_index_private_creator, tag_ndm: '00209213', tag_ary: [0x0020,0x9213], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,9221)', tag_name: "Dimension Organization Sequence", tag_key: 'DimensionOrganizationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0020,9221)', tag_sym: :dimension_organization_sequence, tag_ndm: '00209221', tag_ary: [0x0020,0x9221], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,9222)', tag_name: "Dimension Index Sequence", tag_key: 'DimensionIndexSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0020,9222)', tag_sym: :dimension_index_sequence, tag_ndm: '00209222', tag_ary: [0x0020,0x9222], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,9228)', tag_name: "Concatenation Frame Offset Number", tag_key: 'ConcatenationFrameOffsetNumber', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0020,9228)', tag_sym: :concatenation_frame_offset_number, tag_ndm: '00209228', tag_ary: [0x0020,0x9228], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,9238)', tag_name: "Functional Group Private Creator", tag_key: 'FunctionalGroupPrivateCreator', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0020,9238)', tag_sym: :functional_group_private_creator, tag_ndm: '00209238', tag_ary: [0x0020,0x9238], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,9241)', tag_name: "Nominal Percentage of Cardiac Phase", tag_key: 'NominalPercentageOfCardiacPhase', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0020,9241)', tag_sym: :nominal_percentage_of_cardiac_phase, tag_ndm: '00209241', tag_ary: [0x0020,0x9241], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,9245)', tag_name: "Nominal Percentage of Respiratory Phase", tag_key: 'NominalPercentageOfRespiratoryPhase', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0020,9245)', tag_sym: :nominal_percentage_of_respiratory_phase, tag_ndm: '00209245', tag_ary: [0x0020,0x9245], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,9246)', tag_name: "Starting Respiratory Amplitude", tag_key: 'StartingRespiratoryAmplitude', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0020,9246)', tag_sym: :starting_respiratory_amplitude, tag_ndm: '00209246', tag_ary: [0x0020,0x9246], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,9247)', tag_name: "Starting Respiratory Phase", tag_key: 'StartingRespiratoryPhase', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0020,9247)', tag_sym: :starting_respiratory_phase, tag_ndm: '00209247', tag_ary: [0x0020,0x9247], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,9248)', tag_name: "Ending Respiratory Amplitude", tag_key: 'EndingRespiratoryAmplitude', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0020,9248)', tag_sym: :ending_respiratory_amplitude, tag_ndm: '00209248', tag_ary: [0x0020,0x9248], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,9249)', tag_name: "Ending Respiratory Phase", tag_key: 'EndingRespiratoryPhase', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0020,9249)', tag_sym: :ending_respiratory_phase, tag_ndm: '00209249', tag_ary: [0x0020,0x9249], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,9250)', tag_name: "Respiratory Trigger Type", tag_key: 'RespiratoryTriggerType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0020,9250)', tag_sym: :respiratory_trigger_type, tag_ndm: '00209250', tag_ary: [0x0020,0x9250], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,9251)', tag_name: "R-R Interval Time Nominal", tag_key: 'RRIntervalTimeNominal', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0020,9251)', tag_sym: :rr_interval_time_nominal, tag_ndm: '00209251', tag_ary: [0x0020,0x9251], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,9252)', tag_name: "Actual Cardiac Trigger Delay Time", tag_key: 'ActualCardiacTriggerDelayTime', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0020,9252)', tag_sym: :actual_cardiac_trigger_delay_time, tag_ndm: '00209252', tag_ary: [0x0020,0x9252], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,9253)', tag_name: "Respiratory Synchronization Sequence", tag_key: 'RespiratorySynchronizationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0020,9253)', tag_sym: :respiratory_synchronization_sequence, tag_ndm: '00209253', tag_ary: [0x0020,0x9253], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,9254)', tag_name: "Respiratory Interval Time", tag_key: 'RespiratoryIntervalTime', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0020,9254)', tag_sym: :respiratory_interval_time, tag_ndm: '00209254', tag_ary: [0x0020,0x9254], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,9255)', tag_name: "Nominal Respiratory Trigger Delay Time", tag_key: 'NominalRespiratoryTriggerDelayTime', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0020,9255)', tag_sym: :nominal_respiratory_trigger_delay_time, tag_ndm: '00209255', tag_ary: [0x0020,0x9255], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,9256)', tag_name: "Respiratory Trigger Delay Threshold", tag_key: 'RespiratoryTriggerDelayThreshold', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0020,9256)', tag_sym: :respiratory_trigger_delay_threshold, tag_ndm: '00209256', tag_ary: [0x0020,0x9256], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,9257)', tag_name: "Actual Respiratory Trigger Delay Time", tag_key: 'ActualRespiratoryTriggerDelayTime', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0020,9257)', tag_sym: :actual_respiratory_trigger_delay_time, tag_ndm: '00209257', tag_ary: [0x0020,0x9257], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,9301)', tag_name: "Image Position (Volume)", tag_key: 'ImagePositionVolume', tag_vr: [:FD], tag_vm: ["3"], tag_str: '(0020,9301)', tag_sym: :image_position_volume, tag_ndm: '00209301', tag_ary: [0x0020,0x9301], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,9302)', tag_name: "Image Orientation (Volume)", tag_key: 'ImageOrientationVolume', tag_vr: [:FD], tag_vm: ["6"], tag_str: '(0020,9302)', tag_sym: :image_orientation_volume, tag_ndm: '00209302', tag_ary: [0x0020,0x9302], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,9307)', tag_name: "Ultrasound Acquisition Geometry", tag_key: 'UltrasoundAcquisitionGeometry', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0020,9307)', tag_sym: :ultrasound_acquisition_geometry, tag_ndm: '00209307', tag_ary: [0x0020,0x9307], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,9308)', tag_name: "Apex Position", tag_key: 'ApexPosition', tag_vr: [:FD], tag_vm: ["3"], tag_str: '(0020,9308)', tag_sym: :apex_position, tag_ndm: '00209308', tag_ary: [0x0020,0x9308], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,9309)', tag_name: "Volume to Transducer Mapping Matrix", tag_key: 'VolumeToTransducerMappingMatrix', tag_vr: [:FD], tag_vm: ["16"], tag_str: '(0020,9309)', tag_sym: :volume_to_transducer_mapping_matrix, tag_ndm: '00209309', tag_ary: [0x0020,0x9309], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,930A)', tag_name: "Volume to Table Mapping Matrix", tag_key: 'VolumeToTableMappingMatrix', tag_vr: [:FD], tag_vm: ["16"], tag_str: '(0020,930A)', tag_sym: :volume_to_table_mapping_matrix, tag_ndm: '0020930A', tag_ary: [0x0020,0x930A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,930B)', tag_name: "Volume to Transducer Relationship", tag_key: 'VolumeToTransducerRelationship', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0020,930B)', tag_sym: :volume_to_transducer_relationship, tag_ndm: '0020930B', tag_ary: [0x0020,0x930B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,930C)', tag_name: "Patient Frame of Reference Source", tag_key: 'PatientFrameOfReferenceSource', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0020,930C)', tag_sym: :patient_frame_of_reference_source, tag_ndm: '0020930C', tag_ary: [0x0020,0x930C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,930D)', tag_name: "Temporal Position Time Offset", tag_key: 'TemporalPositionTimeOffset', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0020,930D)', tag_sym: :temporal_position_time_offset, tag_ndm: '0020930D', tag_ary: [0x0020,0x930D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,930E)', tag_name: "Plane Position (Volume) Sequence", tag_key: 'PlanePositionVolumeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0020,930E)', tag_sym: :plane_position_volume_sequence, tag_ndm: '0020930E', tag_ary: [0x0020,0x930E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,930F)', tag_name: "Plane Orientation (Volume) Sequence", tag_key: 'PlaneOrientationVolumeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0020,930F)', tag_sym: :plane_orientation_volume_sequence, tag_ndm: '0020930F', tag_ary: [0x0020,0x930F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,9310)', tag_name: "Temporal Position Sequence", tag_key: 'TemporalPositionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0020,9310)', tag_sym: :temporal_position_sequence, tag_ndm: '00209310', tag_ary: [0x0020,0x9310], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,9311)', tag_name: "Dimension Organization Type", tag_key: 'DimensionOrganizationType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0020,9311)', tag_sym: :dimension_organization_type, tag_ndm: '00209311', tag_ary: [0x0020,0x9311], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,9312)', tag_name: "Volume Frame of Reference UID", tag_key: 'VolumeFrameOfReferenceUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0020,9312)', tag_sym: :volume_frame_of_reference_uid, tag_ndm: '00209312', tag_ary: [0x0020,0x9312], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,9313)', tag_name: "Table Frame of Reference UID", tag_key: 'TableFrameOfReferenceUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0020,9313)', tag_sym: :table_frame_of_reference_uid, tag_ndm: '00209313', tag_ary: [0x0020,0x9313], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,9421)', tag_name: "Dimension Description Label", tag_key: 'DimensionDescriptionLabel', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0020,9421)', tag_sym: :dimension_description_label, tag_ndm: '00209421', tag_ary: [0x0020,0x9421], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,9450)', tag_name: "Patient Orientation in Frame Sequence", tag_key: 'PatientOrientationInFrameSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0020,9450)', tag_sym: :patient_orientation_in_frame_sequence, tag_ndm: '00209450', tag_ary: [0x0020,0x9450], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,9453)', tag_name: "Frame Label", tag_key: 'FrameLabel', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0020,9453)', tag_sym: :frame_label, tag_ndm: '00209453', tag_ary: [0x0020,0x9453], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,9518)', tag_name: "Acquisition Index", tag_key: 'AcquisitionIndex', tag_vr: [:US], tag_vm: ["1-n"], tag_str: '(0020,9518)', tag_sym: :acquisition_index, tag_ndm: '00209518', tag_ary: [0x0020,0x9518], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,9529)', tag_name: "Contributing SOP Instances Reference Sequence", tag_key: 'ContributingSOPInstancesReferenceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0020,9529)', tag_sym: :contributing_sop_instances_reference_sequence, tag_ndm: '00209529', tag_ary: [0x0020,0x9529], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0020,9536)', tag_name: "Reconstruction Index", tag_key: 'ReconstructionIndex', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0020,9536)', tag_sym: :reconstruction_index, tag_ndm: '00209536', tag_ary: [0x0020,0x9536], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,0001)', tag_name: "Light Path Filter Pass-Through Wavelength", tag_key: 'LightPathFilterPassThroughWavelength', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0022,0001)', tag_sym: :light_path_filter_pass_through_wavelength, tag_ndm: '00220001', tag_ary: [0x0022,0x0001], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,0002)', tag_name: "Light Path Filter Pass Band", tag_key: 'LightPathFilterPassBand', tag_vr: [:US], tag_vm: ["2"], tag_str: '(0022,0002)', tag_sym: :light_path_filter_pass_band, tag_ndm: '00220002', tag_ary: [0x0022,0x0002], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,0003)', tag_name: "Image Path Filter Pass-Through Wavelength", tag_key: 'ImagePathFilterPassThroughWavelength', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0022,0003)', tag_sym: :image_path_filter_pass_through_wavelength, tag_ndm: '00220003', tag_ary: [0x0022,0x0003], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,0004)', tag_name: "Image Path Filter Pass Band", tag_key: 'ImagePathFilterPassBand', tag_vr: [:US], tag_vm: ["2"], tag_str: '(0022,0004)', tag_sym: :image_path_filter_pass_band, tag_ndm: '00220004', tag_ary: [0x0022,0x0004], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,0005)', tag_name: "Patient Eye Movement Commanded", tag_key: 'PatientEyeMovementCommanded', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0022,0005)', tag_sym: :patient_eye_movement_commanded, tag_ndm: '00220005', tag_ary: [0x0022,0x0005], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,0006)', tag_name: "Patient Eye Movement Command Code Sequence", tag_key: 'PatientEyeMovementCommandCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,0006)', tag_sym: :patient_eye_movement_command_code_sequence, tag_ndm: '00220006', tag_ary: [0x0022,0x0006], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,0007)', tag_name: "Spherical Lens Power", tag_key: 'SphericalLensPower', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0022,0007)', tag_sym: :spherical_lens_power, tag_ndm: '00220007', tag_ary: [0x0022,0x0007], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,0008)', tag_name: "Cylinder Lens Power", tag_key: 'CylinderLensPower', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0022,0008)', tag_sym: :cylinder_lens_power, tag_ndm: '00220008', tag_ary: [0x0022,0x0008], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,0009)', tag_name: "Cylinder Axis", tag_key: 'CylinderAxis', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0022,0009)', tag_sym: :cylinder_axis, tag_ndm: '00220009', tag_ary: [0x0022,0x0009], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,000A)', tag_name: "Emmetropic Magnification", tag_key: 'EmmetropicMagnification', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0022,000A)', tag_sym: :emmetropic_magnification, tag_ndm: '0022000A', tag_ary: [0x0022,0x000A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,000B)', tag_name: "Intra Ocular Pressure", tag_key: 'IntraOcularPressure', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0022,000B)', tag_sym: :intra_ocular_pressure, tag_ndm: '0022000B', tag_ary: [0x0022,0x000B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,000C)', tag_name: "Horizontal Field of View", tag_key: 'HorizontalFieldOfView', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0022,000C)', tag_sym: :horizontal_field_of_view, tag_ndm: '0022000C', tag_ary: [0x0022,0x000C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,000D)', tag_name: "Pupil Dilated", tag_key: 'PupilDilated', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0022,000D)', tag_sym: :pupil_dilated, tag_ndm: '0022000D', tag_ary: [0x0022,0x000D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,000E)', tag_name: "Degree of Dilation", tag_key: 'DegreeOfDilation', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0022,000E)', tag_sym: :degree_of_dilation, tag_ndm: '0022000E', tag_ary: [0x0022,0x000E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,000F)', tag_name: "Vertex Distance", tag_key: 'VertexDistance', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0022,000F)', tag_sym: :vertex_distance, tag_ndm: '0022000F', tag_ary: [0x0022,0x000F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,0010)', tag_name: "Stereo Baseline Angle", tag_key: 'StereoBaselineAngle', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0022,0010)', tag_sym: :stereo_baseline_angle, tag_ndm: '00220010', tag_ary: [0x0022,0x0010], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,0011)', tag_name: "Stereo Baseline Displacement", tag_key: 'StereoBaselineDisplacement', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0022,0011)', tag_sym: :stereo_baseline_displacement, tag_ndm: '00220011', tag_ary: [0x0022,0x0011], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,0012)', tag_name: "Stereo Horizontal Pixel Offset", tag_key: 'StereoHorizontalPixelOffset', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0022,0012)', tag_sym: :stereo_horizontal_pixel_offset, tag_ndm: '00220012', tag_ary: [0x0022,0x0012], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,0013)', tag_name: "Stereo Vertical Pixel Offset", tag_key: 'StereoVerticalPixelOffset', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0022,0013)', tag_sym: :stereo_vertical_pixel_offset, tag_ndm: '00220013', tag_ary: [0x0022,0x0013], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,0014)', tag_name: "Stereo Rotation", tag_key: 'StereoRotation', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0022,0014)', tag_sym: :stereo_rotation, tag_ndm: '00220014', tag_ary: [0x0022,0x0014], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,0015)', tag_name: "Acquisition Device Type Code Sequence", tag_key: 'AcquisitionDeviceTypeCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,0015)', tag_sym: :acquisition_device_type_code_sequence, tag_ndm: '00220015', tag_ary: [0x0022,0x0015], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,0016)', tag_name: "Illumination Type Code Sequence", tag_key: 'IlluminationTypeCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,0016)', tag_sym: :illumination_type_code_sequence, tag_ndm: '00220016', tag_ary: [0x0022,0x0016], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,0017)', tag_name: "Light Path Filter Type Stack Code Sequence", tag_key: 'LightPathFilterTypeStackCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,0017)', tag_sym: :light_path_filter_type_stack_code_sequence, tag_ndm: '00220017', tag_ary: [0x0022,0x0017], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,0018)', tag_name: "Image Path Filter Type Stack Code Sequence", tag_key: 'ImagePathFilterTypeStackCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,0018)', tag_sym: :image_path_filter_type_stack_code_sequence, tag_ndm: '00220018', tag_ary: [0x0022,0x0018], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,0019)', tag_name: "Lenses Code Sequence", tag_key: 'LensesCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,0019)', tag_sym: :lenses_code_sequence, tag_ndm: '00220019', tag_ary: [0x0022,0x0019], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,001A)', tag_name: "Channel Description Code Sequence", tag_key: 'ChannelDescriptionCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,001A)', tag_sym: :channel_description_code_sequence, tag_ndm: '0022001A', tag_ary: [0x0022,0x001A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,001B)', tag_name: "Refractive State Sequence", tag_key: 'RefractiveStateSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,001B)', tag_sym: :refractive_state_sequence, tag_ndm: '0022001B', tag_ary: [0x0022,0x001B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,001C)', tag_name: "Mydriatic Agent Code Sequence", tag_key: 'MydriaticAgentCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,001C)', tag_sym: :mydriatic_agent_code_sequence, tag_ndm: '0022001C', tag_ary: [0x0022,0x001C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,001D)', tag_name: "Relative Image Position Code Sequence", tag_key: 'RelativeImagePositionCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,001D)', tag_sym: :relative_image_position_code_sequence, tag_ndm: '0022001D', tag_ary: [0x0022,0x001D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,001E)', tag_name: "Camera Angle of View", tag_key: 'CameraAngleOfView', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0022,001E)', tag_sym: :camera_angle_of_view, tag_ndm: '0022001E', tag_ary: [0x0022,0x001E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,0020)', tag_name: "Stereo Pairs Sequence", tag_key: 'StereoPairsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,0020)', tag_sym: :stereo_pairs_sequence, tag_ndm: '00220020', tag_ary: [0x0022,0x0020], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,0021)', tag_name: "Left Image Sequence", tag_key: 'LeftImageSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,0021)', tag_sym: :left_image_sequence, tag_ndm: '00220021', tag_ary: [0x0022,0x0021], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,0022)', tag_name: "Right Image Sequence", tag_key: 'RightImageSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,0022)', tag_sym: :right_image_sequence, tag_ndm: '00220022', tag_ary: [0x0022,0x0022], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,0028)', tag_name: "Stereo Pairs Present", tag_key: 'StereoPairsPresent', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0022,0028)', tag_sym: :stereo_pairs_present, tag_ndm: '00220028', tag_ary: [0x0022,0x0028], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,0030)', tag_name: "Axial Length of the Eye", tag_key: 'AxialLengthOfTheEye', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0022,0030)', tag_sym: :axial_length_of_the_eye, tag_ndm: '00220030', tag_ary: [0x0022,0x0030], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,0031)', tag_name: "Ophthalmic Frame Location Sequence", tag_key: 'OphthalmicFrameLocationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,0031)', tag_sym: :ophthalmic_frame_location_sequence, tag_ndm: '00220031', tag_ary: [0x0022,0x0031], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,0032)', tag_name: "Reference Coordinates", tag_key: 'ReferenceCoordinates', tag_vr: [:FL], tag_vm: ["2-2n"], tag_str: '(0022,0032)', tag_sym: :reference_coordinates, tag_ndm: '00220032', tag_ary: [0x0022,0x0032], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,0035)', tag_name: "Depth Spatial Resolution", tag_key: 'DepthSpatialResolution', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0022,0035)', tag_sym: :depth_spatial_resolution, tag_ndm: '00220035', tag_ary: [0x0022,0x0035], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,0036)', tag_name: "Maximum Depth Distortion", tag_key: 'MaximumDepthDistortion', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0022,0036)', tag_sym: :maximum_depth_distortion, tag_ndm: '00220036', tag_ary: [0x0022,0x0036], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,0037)', tag_name: "Along-scan Spatial Resolution", tag_key: 'AlongScanSpatialResolution', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0022,0037)', tag_sym: :along_scan_spatial_resolution, tag_ndm: '00220037', tag_ary: [0x0022,0x0037], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,0038)', tag_name: "Maximum Along-scan Distortion", tag_key: 'MaximumAlongScanDistortion', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0022,0038)', tag_sym: :maximum_along_scan_distortion, tag_ndm: '00220038', tag_ary: [0x0022,0x0038], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,0039)', tag_name: "Ophthalmic Image Orientation", tag_key: 'OphthalmicImageOrientation', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0022,0039)', tag_sym: :ophthalmic_image_orientation, tag_ndm: '00220039', tag_ary: [0x0022,0x0039], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,0041)', tag_name: "Depth of Transverse Image", tag_key: 'DepthOfTransverseImage', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0022,0041)', tag_sym: :depth_of_transverse_image, tag_ndm: '00220041', tag_ary: [0x0022,0x0041], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,0042)', tag_name: "Mydriatic Agent Concentration Units Sequence", tag_key: 'MydriaticAgentConcentrationUnitsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,0042)', tag_sym: :mydriatic_agent_concentration_units_sequence, tag_ndm: '00220042', tag_ary: [0x0022,0x0042], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,0048)', tag_name: "Across-scan Spatial Resolution", tag_key: 'AcrossScanSpatialResolution', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0022,0048)', tag_sym: :across_scan_spatial_resolution, tag_ndm: '00220048', tag_ary: [0x0022,0x0048], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,0049)', tag_name: "Maximum Across-scan Distortion", tag_key: 'MaximumAcrossScanDistortion', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0022,0049)', tag_sym: :maximum_across_scan_distortion, tag_ndm: '00220049', tag_ary: [0x0022,0x0049], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,004E)', tag_name: "Mydriatic Agent Concentration", tag_key: 'MydriaticAgentConcentration', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0022,004E)', tag_sym: :mydriatic_agent_concentration, tag_ndm: '0022004E', tag_ary: [0x0022,0x004E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,0055)', tag_name: "Illumination Wave Length", tag_key: 'IlluminationWaveLength', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0022,0055)', tag_sym: :illumination_wave_length, tag_ndm: '00220055', tag_ary: [0x0022,0x0055], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,0056)', tag_name: "Illumination Power", tag_key: 'IlluminationPower', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0022,0056)', tag_sym: :illumination_power, tag_ndm: '00220056', tag_ary: [0x0022,0x0056], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,0057)', tag_name: "Illumination Bandwidth", tag_key: 'IlluminationBandwidth', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0022,0057)', tag_sym: :illumination_bandwidth, tag_ndm: '00220057', tag_ary: [0x0022,0x0057], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,0058)', tag_name: "Mydriatic Agent Sequence", tag_key: 'MydriaticAgentSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,0058)', tag_sym: :mydriatic_agent_sequence, tag_ndm: '00220058', tag_ary: [0x0022,0x0058], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1007)', tag_name: "Ophthalmic Axial Measurements Right Eye Sequence", tag_key: 'OphthalmicAxialMeasurementsRightEyeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1007)', tag_sym: :ophthalmic_axial_measurements_right_eye_sequence, tag_ndm: '00221007', tag_ary: [0x0022,0x1007], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1008)', tag_name: "Ophthalmic Axial Measurements Left Eye Sequence", tag_key: 'OphthalmicAxialMeasurementsLeftEyeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1008)', tag_sym: :ophthalmic_axial_measurements_left_eye_sequence, tag_ndm: '00221008', tag_ary: [0x0022,0x1008], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1009)', tag_name: "Ophthalmic Axial Measurements Device Type", tag_key: 'OphthalmicAxialMeasurementsDeviceType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0022,1009)', tag_sym: :ophthalmic_axial_measurements_device_type, tag_ndm: '00221009', tag_ary: [0x0022,0x1009], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1010)', tag_name: "Ophthalmic Axial Length Measurements Type", tag_key: 'OphthalmicAxialLengthMeasurementsType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0022,1010)', tag_sym: :ophthalmic_axial_length_measurements_type, tag_ndm: '00221010', tag_ary: [0x0022,0x1010], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1012)', tag_name: "Ophthalmic Axial Length Sequence", tag_key: 'OphthalmicAxialLengthSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1012)', tag_sym: :ophthalmic_axial_length_sequence, tag_ndm: '00221012', tag_ary: [0x0022,0x1012], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1019)', tag_name: "Ophthalmic Axial Length", tag_key: 'OphthalmicAxialLength', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0022,1019)', tag_sym: :ophthalmic_axial_length, tag_ndm: '00221019', tag_ary: [0x0022,0x1019], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1024)', tag_name: "Lens Status Code Sequence", tag_key: 'LensStatusCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1024)', tag_sym: :lens_status_code_sequence, tag_ndm: '00221024', tag_ary: [0x0022,0x1024], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1025)', tag_name: "Vitreous Status Code Sequence", tag_key: 'VitreousStatusCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1025)', tag_sym: :vitreous_status_code_sequence, tag_ndm: '00221025', tag_ary: [0x0022,0x1025], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1028)', tag_name: "IOL Formula Code Sequence", tag_key: 'IOLFormulaCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1028)', tag_sym: :iol_formula_code_sequence, tag_ndm: '00221028', tag_ary: [0x0022,0x1028], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1029)', tag_name: "IOL Formula Detail", tag_key: 'IOLFormulaDetail', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0022,1029)', tag_sym: :iol_formula_detail, tag_ndm: '00221029', tag_ary: [0x0022,0x1029], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1033)', tag_name: "Keratometer Index", tag_key: 'KeratometerIndex', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0022,1033)', tag_sym: :keratometer_index, tag_ndm: '00221033', tag_ary: [0x0022,0x1033], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1035)', tag_name: "Source of Ophthalmic Axial Length Code Sequence", tag_key: 'SourceOfOphthalmicAxialLengthCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1035)', tag_sym: :source_of_ophthalmic_axial_length_code_sequence, tag_ndm: '00221035', tag_ary: [0x0022,0x1035], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1036)', tag_name: "Source of Corneal Size Data Code Sequence", tag_key: 'SourceOfCornealSizeDataCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1036)', tag_sym: :source_of_corneal_size_data_code_sequence, tag_ndm: '00221036', tag_ary: [0x0022,0x1036], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1037)', tag_name: "Target Refraction", tag_key: 'TargetRefraction', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0022,1037)', tag_sym: :target_refraction, tag_ndm: '00221037', tag_ary: [0x0022,0x1037], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1039)', tag_name: "Refractive Procedure Occurred", tag_key: 'RefractiveProcedureOccurred', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0022,1039)', tag_sym: :refractive_procedure_occurred, tag_ndm: '00221039', tag_ary: [0x0022,0x1039], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1040)', tag_name: "Refractive Surgery Type Code Sequence", tag_key: 'RefractiveSurgeryTypeCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1040)', tag_sym: :refractive_surgery_type_code_sequence, tag_ndm: '00221040', tag_ary: [0x0022,0x1040], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1044)', tag_name: "Ophthalmic Ultrasound Method Code Sequence", tag_key: 'OphthalmicUltrasoundMethodCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1044)', tag_sym: :ophthalmic_ultrasound_method_code_sequence, tag_ndm: '00221044', tag_ary: [0x0022,0x1044], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1045)', tag_name: "Surgically Induced Astigmatism Sequence", tag_key: 'SurgicallyInducedAstigmatismSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1045)', tag_sym: :surgically_induced_astigmatism_sequence, tag_ndm: '00221045', tag_ary: [0x0022,0x1045], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1046)', tag_name: "Type of Optical Correction", tag_key: 'TypeOfOpticalCorrection', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0022,1046)', tag_sym: :type_of_optical_correction, tag_ndm: '00221046', tag_ary: [0x0022,0x1046], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1047)', tag_name: "Toric IOL Power Sequence", tag_key: 'ToricIOLPowerSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1047)', tag_sym: :toric_iol_power_sequence, tag_ndm: '00221047', tag_ary: [0x0022,0x1047], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1048)', tag_name: "Predicted Toric Error Sequence", tag_key: 'PredictedToricErrorSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1048)', tag_sym: :predicted_toric_error_sequence, tag_ndm: '00221048', tag_ary: [0x0022,0x1048], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1049)', tag_name: "Pre-Selected for Implantation", tag_key: 'PreSelectedForImplantation', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0022,1049)', tag_sym: :pre_selected_for_implantation, tag_ndm: '00221049', tag_ary: [0x0022,0x1049], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,104A)', tag_name: "Toric IOL Power for Exact Emmetropia Sequence", tag_key: 'ToricIOLPowerForExactEmmetropiaSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,104A)', tag_sym: :toric_iol_power_for_exact_emmetropia_sequence, tag_ndm: '0022104A', tag_ary: [0x0022,0x104A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,104B)', tag_name: "Toric IOL Power for Exact Target Refraction Sequence", tag_key: 'ToricIOLPowerForExactTargetRefractionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,104B)', tag_sym: :toric_iol_power_for_exact_target_refraction_sequence, tag_ndm: '0022104B', tag_ary: [0x0022,0x104B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1050)', tag_name: "Ophthalmic Axial Length Measurements Sequence", tag_key: 'OphthalmicAxialLengthMeasurementsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1050)', tag_sym: :ophthalmic_axial_length_measurements_sequence, tag_ndm: '00221050', tag_ary: [0x0022,0x1050], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1053)', tag_name: "IOL Power", tag_key: 'IOLPower', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0022,1053)', tag_sym: :iol_power, tag_ndm: '00221053', tag_ary: [0x0022,0x1053], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1054)', tag_name: "Predicted Refractive Error", tag_key: 'PredictedRefractiveError', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0022,1054)', tag_sym: :predicted_refractive_error, tag_ndm: '00221054', tag_ary: [0x0022,0x1054], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1059)', tag_name: "Ophthalmic Axial Length Velocity", tag_key: 'OphthalmicAxialLengthVelocity', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0022,1059)', tag_sym: :ophthalmic_axial_length_velocity, tag_ndm: '00221059', tag_ary: [0x0022,0x1059], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1065)', tag_name: "Lens Status Description", tag_key: 'LensStatusDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0022,1065)', tag_sym: :lens_status_description, tag_ndm: '00221065', tag_ary: [0x0022,0x1065], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1066)', tag_name: "Vitreous Status Description", tag_key: 'VitreousStatusDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0022,1066)', tag_sym: :vitreous_status_description, tag_ndm: '00221066', tag_ary: [0x0022,0x1066], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1090)', tag_name: "IOL Power Sequence", tag_key: 'IOLPowerSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1090)', tag_sym: :iol_power_sequence, tag_ndm: '00221090', tag_ary: [0x0022,0x1090], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1092)', tag_name: "Lens Constant Sequence", tag_key: 'LensConstantSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1092)', tag_sym: :lens_constant_sequence, tag_ndm: '00221092', tag_ary: [0x0022,0x1092], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1093)', tag_name: "IOL Manufacturer", tag_key: 'IOLManufacturer', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0022,1093)', tag_sym: :iol_manufacturer, tag_ndm: '00221093', tag_ary: [0x0022,0x1093], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1094)', tag_name: "Lens Constant Description", tag_key: 'LensConstantDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0022,1094)', tag_sym: :lens_constant_description, tag_ndm: '00221094', tag_ary: [0x0022,0x1094], tag_multiple: false, tag_note: 'RET (2011)'},
      { tag_ps: '(0022,1095)', tag_name: "Implant Name", tag_key: 'ImplantName', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0022,1095)', tag_sym: :implant_name, tag_ndm: '00221095', tag_ary: [0x0022,0x1095], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1096)', tag_name: "Keratometry Measurement Type Code Sequence", tag_key: 'KeratometryMeasurementTypeCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1096)', tag_sym: :keratometry_measurement_type_code_sequence, tag_ndm: '00221096', tag_ary: [0x0022,0x1096], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1097)', tag_name: "Implant Part Number", tag_key: 'ImplantPartNumber', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0022,1097)', tag_sym: :implant_part_number, tag_ndm: '00221097', tag_ary: [0x0022,0x1097], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1100)', tag_name: "Referenced Ophthalmic Axial Measurements Sequence", tag_key: 'ReferencedOphthalmicAxialMeasurementsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1100)', tag_sym: :referenced_ophthalmic_axial_measurements_sequence, tag_ndm: '00221100', tag_ary: [0x0022,0x1100], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1101)', tag_name: "Ophthalmic Axial Length Measurements Segment Name Code Sequence", tag_key: 'OphthalmicAxialLengthMeasurementsSegmentNameCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1101)', tag_sym: :ophthalmic_axial_length_measurements_segment_name_code_sequence, tag_ndm: '00221101', tag_ary: [0x0022,0x1101], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1103)', tag_name: "Refractive Error Before Refractive Surgery Code Sequence", tag_key: 'RefractiveErrorBeforeRefractiveSurgeryCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1103)', tag_sym: :refractive_error_before_refractive_surgery_code_sequence, tag_ndm: '00221103', tag_ary: [0x0022,0x1103], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1121)', tag_name: "IOL Power For Exact Emmetropia", tag_key: 'IOLPowerForExactEmmetropia', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0022,1121)', tag_sym: :iol_power_for_exact_emmetropia, tag_ndm: '00221121', tag_ary: [0x0022,0x1121], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1122)', tag_name: "IOL Power For Exact Target Refraction", tag_key: 'IOLPowerForExactTargetRefraction', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0022,1122)', tag_sym: :iol_power_for_exact_target_refraction, tag_ndm: '00221122', tag_ary: [0x0022,0x1122], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1125)', tag_name: "Anterior Chamber Depth Definition Code Sequence", tag_key: 'AnteriorChamberDepthDefinitionCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1125)', tag_sym: :anterior_chamber_depth_definition_code_sequence, tag_ndm: '00221125', tag_ary: [0x0022,0x1125], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1127)', tag_name: "Lens Thickness Sequence", tag_key: 'LensThicknessSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1127)', tag_sym: :lens_thickness_sequence, tag_ndm: '00221127', tag_ary: [0x0022,0x1127], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1128)', tag_name: "Anterior Chamber Depth Sequence", tag_key: 'AnteriorChamberDepthSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1128)', tag_sym: :anterior_chamber_depth_sequence, tag_ndm: '00221128', tag_ary: [0x0022,0x1128], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,112A)', tag_name: "Calculation Comment Sequence", tag_key: 'CalculationCommentSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,112A)', tag_sym: :calculation_comment_sequence, tag_ndm: '0022112A', tag_ary: [0x0022,0x112A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,112B)', tag_name: "Calculation Comment Type", tag_key: 'CalculationCommentType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0022,112B)', tag_sym: :calculation_comment_type, tag_ndm: '0022112B', tag_ary: [0x0022,0x112B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,112C)', tag_name: "Calculation Comment", tag_key: 'CalculationComment', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(0022,112C)', tag_sym: :calculation_comment, tag_ndm: '0022112C', tag_ary: [0x0022,0x112C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1130)', tag_name: "Lens Thickness", tag_key: 'LensThickness', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0022,1130)', tag_sym: :lens_thickness, tag_ndm: '00221130', tag_ary: [0x0022,0x1130], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1131)', tag_name: "Anterior Chamber Depth", tag_key: 'AnteriorChamberDepth', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0022,1131)', tag_sym: :anterior_chamber_depth, tag_ndm: '00221131', tag_ary: [0x0022,0x1131], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1132)', tag_name: "Source of Lens Thickness Data Code Sequence", tag_key: 'SourceOfLensThicknessDataCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1132)', tag_sym: :source_of_lens_thickness_data_code_sequence, tag_ndm: '00221132', tag_ary: [0x0022,0x1132], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1133)', tag_name: "Source of Anterior Chamber Depth Data Code Sequence", tag_key: 'SourceOfAnteriorChamberDepthDataCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1133)', tag_sym: :source_of_anterior_chamber_depth_data_code_sequence, tag_ndm: '00221133', tag_ary: [0x0022,0x1133], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1134)', tag_name: "Source of Refractive Measurements Sequence", tag_key: 'SourceOfRefractiveMeasurementsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1134)', tag_sym: :source_of_refractive_measurements_sequence, tag_ndm: '00221134', tag_ary: [0x0022,0x1134], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1135)', tag_name: "Source of Refractive Measurements Code Sequence", tag_key: 'SourceOfRefractiveMeasurementsCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1135)', tag_sym: :source_of_refractive_measurements_code_sequence, tag_ndm: '00221135', tag_ary: [0x0022,0x1135], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1140)', tag_name: "Ophthalmic Axial Length Measurement Modified", tag_key: 'OphthalmicAxialLengthMeasurementModified', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0022,1140)', tag_sym: :ophthalmic_axial_length_measurement_modified, tag_ndm: '00221140', tag_ary: [0x0022,0x1140], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1150)', tag_name: "Ophthalmic Axial Length Data Source Code Sequence", tag_key: 'OphthalmicAxialLengthDataSourceCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1150)', tag_sym: :ophthalmic_axial_length_data_source_code_sequence, tag_ndm: '00221150', tag_ary: [0x0022,0x1150], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1153)', tag_name: "Ophthalmic Axial Length Acquisition Method Code Sequence", tag_key: 'OphthalmicAxialLengthAcquisitionMethodCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1153)', tag_sym: :ophthalmic_axial_length_acquisition_method_code_sequence, tag_ndm: '00221153', tag_ary: [0x0022,0x1153], tag_multiple: false, tag_note: 'RET (2011)'},
      { tag_ps: '(0022,1155)', tag_name: "Signal to Noise Ratio", tag_key: 'SignalToNoiseRatio', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0022,1155)', tag_sym: :signal_to_noise_ratio, tag_ndm: '00221155', tag_ary: [0x0022,0x1155], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1159)', tag_name: "Ophthalmic Axial Length Data Source Description", tag_key: 'OphthalmicAxialLengthDataSourceDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0022,1159)', tag_sym: :ophthalmic_axial_length_data_source_description, tag_ndm: '00221159', tag_ary: [0x0022,0x1159], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1210)', tag_name: "Ophthalmic Axial Length Measurements Total Length Sequence", tag_key: 'OphthalmicAxialLengthMeasurementsTotalLengthSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1210)', tag_sym: :ophthalmic_axial_length_measurements_total_length_sequence, tag_ndm: '00221210', tag_ary: [0x0022,0x1210], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1211)', tag_name: "Ophthalmic Axial Length Measurements Segmental Length Sequence", tag_key: 'OphthalmicAxialLengthMeasurementsSegmentalLengthSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1211)', tag_sym: :ophthalmic_axial_length_measurements_segmental_length_sequence, tag_ndm: '00221211', tag_ary: [0x0022,0x1211], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1212)', tag_name: "Ophthalmic Axial Length Measurements Length Summation Sequence", tag_key: 'OphthalmicAxialLengthMeasurementsLengthSummationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1212)', tag_sym: :ophthalmic_axial_length_measurements_length_summation_sequence, tag_ndm: '00221212', tag_ary: [0x0022,0x1212], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1220)', tag_name: "Ultrasound Ophthalmic Axial Length Measurements Sequence", tag_key: 'UltrasoundOphthalmicAxialLengthMeasurementsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1220)', tag_sym: :ultrasound_ophthalmic_axial_length_measurements_sequence, tag_ndm: '00221220', tag_ary: [0x0022,0x1220], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1225)', tag_name: "Optical Ophthalmic Axial Length Measurements Sequence", tag_key: 'OpticalOphthalmicAxialLengthMeasurementsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1225)', tag_sym: :optical_ophthalmic_axial_length_measurements_sequence, tag_ndm: '00221225', tag_ary: [0x0022,0x1225], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1230)', tag_name: "Ultrasound Selected Ophthalmic Axial Length Sequence", tag_key: 'UltrasoundSelectedOphthalmicAxialLengthSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1230)', tag_sym: :ultrasound_selected_ophthalmic_axial_length_sequence, tag_ndm: '00221230', tag_ary: [0x0022,0x1230], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1250)', tag_name: "Ophthalmic Axial Length Selection Method Code Sequence", tag_key: 'OphthalmicAxialLengthSelectionMethodCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1250)', tag_sym: :ophthalmic_axial_length_selection_method_code_sequence, tag_ndm: '00221250', tag_ary: [0x0022,0x1250], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1255)', tag_name: "Optical Selected Ophthalmic Axial Length Sequence", tag_key: 'OpticalSelectedOphthalmicAxialLengthSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1255)', tag_sym: :optical_selected_ophthalmic_axial_length_sequence, tag_ndm: '00221255', tag_ary: [0x0022,0x1255], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1257)', tag_name: "Selected Segmental Ophthalmic Axial Length Sequence", tag_key: 'SelectedSegmentalOphthalmicAxialLengthSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1257)', tag_sym: :selected_segmental_ophthalmic_axial_length_sequence, tag_ndm: '00221257', tag_ary: [0x0022,0x1257], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1260)', tag_name: "Selected Total Ophthalmic Axial Length Sequence", tag_key: 'SelectedTotalOphthalmicAxialLengthSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1260)', tag_sym: :selected_total_ophthalmic_axial_length_sequence, tag_ndm: '00221260', tag_ary: [0x0022,0x1260], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1262)', tag_name: "Ophthalmic Axial Length Quality Metric Sequence", tag_key: 'OphthalmicAxialLengthQualityMetricSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1262)', tag_sym: :ophthalmic_axial_length_quality_metric_sequence, tag_ndm: '00221262', tag_ary: [0x0022,0x1262], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1265)', tag_name: "Ophthalmic Axial Length Quality Metric Type Code Sequence", tag_key: 'OphthalmicAxialLengthQualityMetricTypeCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1265)', tag_sym: :ophthalmic_axial_length_quality_metric_type_code_sequence, tag_ndm: '00221265', tag_ary: [0x0022,0x1265], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(0022,1273)', tag_name: "Ophthalmic Axial Length Quality Metric Type Description", tag_key: 'OphthalmicAxialLengthQualityMetricTypeDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0022,1273)', tag_sym: :ophthalmic_axial_length_quality_metric_type_description, tag_ndm: '00221273', tag_ary: [0x0022,0x1273], tag_multiple: false, tag_note: 'RET (2011)'},
      { tag_ps: '(0022,1300)', tag_name: "Intraocular Lens Calculations Right Eye Sequence", tag_key: 'IntraocularLensCalculationsRightEyeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1300)', tag_sym: :intraocular_lens_calculations_right_eye_sequence, tag_ndm: '00221300', tag_ary: [0x0022,0x1300], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1310)', tag_name: "Intraocular Lens Calculations Left Eye Sequence", tag_key: 'IntraocularLensCalculationsLeftEyeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1310)', tag_sym: :intraocular_lens_calculations_left_eye_sequence, tag_ndm: '00221310', tag_ary: [0x0022,0x1310], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1330)', tag_name: "Referenced Ophthalmic Axial Length Measurement QC Image Sequence", tag_key: 'ReferencedOphthalmicAxialLengthMeasurementQCImageSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1330)', tag_sym: :referenced_ophthalmic_axial_length_measurement_qc_image_sequence, tag_ndm: '00221330', tag_ary: [0x0022,0x1330], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1415)', tag_name: "Ophthalmic Mapping Device Type", tag_key: 'OphthalmicMappingDeviceType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0022,1415)', tag_sym: :ophthalmic_mapping_device_type, tag_ndm: '00221415', tag_ary: [0x0022,0x1415], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1420)', tag_name: "Acquisition Method Code Sequence", tag_key: 'AcquisitionMethodCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1420)', tag_sym: :acquisition_method_code_sequence, tag_ndm: '00221420', tag_ary: [0x0022,0x1420], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1423)', tag_name: "Acquisition Method Algorithm Sequence", tag_key: 'AcquisitionMethodAlgorithmSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1423)', tag_sym: :acquisition_method_algorithm_sequence, tag_ndm: '00221423', tag_ary: [0x0022,0x1423], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1436)', tag_name: "Ophthalmic Thickness Map Type Code Sequence", tag_key: 'OphthalmicThicknessMapTypeCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1436)', tag_sym: :ophthalmic_thickness_map_type_code_sequence, tag_ndm: '00221436', tag_ary: [0x0022,0x1436], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1443)', tag_name: "Ophthalmic Thickness Mapping Normals Sequence", tag_key: 'OphthalmicThicknessMappingNormalsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1443)', tag_sym: :ophthalmic_thickness_mapping_normals_sequence, tag_ndm: '00221443', tag_ary: [0x0022,0x1443], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1445)', tag_name: "Retinal Thickness Definition Code Sequence", tag_key: 'RetinalThicknessDefinitionCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1445)', tag_sym: :retinal_thickness_definition_code_sequence, tag_ndm: '00221445', tag_ary: [0x0022,0x1445], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1450)', tag_name: "Pixel Value Mapping to Coded Concept Sequence", tag_key: 'PixelValueMappingToCodedConceptSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1450)', tag_sym: :pixel_value_mapping_to_coded_concept_sequence, tag_ndm: '00221450', tag_ary: [0x0022,0x1450], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1452)', tag_name: "Mapped Pixel Value", tag_key: 'MappedPixelValue', tag_vr: [:US, :SS], tag_vm: ["1"], tag_str: '(0022,1452)', tag_sym: :mapped_pixel_value, tag_ndm: '00221452', tag_ary: [0x0022,0x1452], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1454)', tag_name: "Pixel Value Mapping Explanation", tag_key: 'PixelValueMappingExplanation', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0022,1454)', tag_sym: :pixel_value_mapping_explanation, tag_ndm: '00221454', tag_ary: [0x0022,0x1454], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1458)', tag_name: "Ophthalmic Thickness Map Quality Threshold Sequence", tag_key: 'OphthalmicThicknessMapQualityThresholdSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1458)', tag_sym: :ophthalmic_thickness_map_quality_threshold_sequence, tag_ndm: '00221458', tag_ary: [0x0022,0x1458], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1460)', tag_name: "Ophthalmic Thickness Map Threshold Quality Rating", tag_key: 'OphthalmicThicknessMapThresholdQualityRating', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0022,1460)', tag_sym: :ophthalmic_thickness_map_threshold_quality_rating, tag_ndm: '00221460', tag_ary: [0x0022,0x1460], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1463)', tag_name: "Anatomic Structure Reference Point", tag_key: 'AnatomicStructureReferencePoint', tag_vr: [:FL], tag_vm: ["2"], tag_str: '(0022,1463)', tag_sym: :anatomic_structure_reference_point, tag_ndm: '00221463', tag_ary: [0x0022,0x1463], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1465)', tag_name: "Registration to Localizer Sequence", tag_key: 'RegistrationToLocalizerSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1465)', tag_sym: :registration_to_localizer_sequence, tag_ndm: '00221465', tag_ary: [0x0022,0x1465], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1466)', tag_name: "Registered Localizer Units", tag_key: 'RegisteredLocalizerUnits', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0022,1466)', tag_sym: :registered_localizer_units, tag_ndm: '00221466', tag_ary: [0x0022,0x1466], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1467)', tag_name: "Registered Localizer Top Left Hand Corner", tag_key: 'RegisteredLocalizerTopLeftHandCorner', tag_vr: [:FL], tag_vm: ["2"], tag_str: '(0022,1467)', tag_sym: :registered_localizer_top_left_hand_corner, tag_ndm: '00221467', tag_ary: [0x0022,0x1467], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1468)', tag_name: "Registered Localizer Bottom Right Hand Corner", tag_key: 'RegisteredLocalizerBottomRightHandCorner', tag_vr: [:FL], tag_vm: ["2"], tag_str: '(0022,1468)', tag_sym: :registered_localizer_bottom_right_hand_corner, tag_ndm: '00221468', tag_ary: [0x0022,0x1468], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1470)', tag_name: "Ophthalmic Thickness Map Quality Rating Sequence", tag_key: 'OphthalmicThicknessMapQualityRatingSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1470)', tag_sym: :ophthalmic_thickness_map_quality_rating_sequence, tag_ndm: '00221470', tag_ary: [0x0022,0x1470], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1472)', tag_name: "Relevant OPT Attributes Sequence", tag_key: 'RelevantOPTAttributesSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1472)', tag_sym: :relevant_opt_attributes_sequence, tag_ndm: '00221472', tag_ary: [0x0022,0x1472], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1512)', tag_name: "Transformation Method Code Sequence", tag_key: 'TransformationMethodCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1512)', tag_sym: :transformation_method_code_sequence, tag_ndm: '00221512', tag_ary: [0x0022,0x1512], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1513)', tag_name: "Transformation Algorithm Sequence", tag_key: 'TransformationAlgorithmSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1513)', tag_sym: :transformation_algorithm_sequence, tag_ndm: '00221513', tag_ary: [0x0022,0x1513], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1515)', tag_name: "Ophthalmic Axial Length Method", tag_key: 'OphthalmicAxialLengthMethod', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0022,1515)', tag_sym: :ophthalmic_axial_length_method, tag_ndm: '00221515', tag_ary: [0x0022,0x1515], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1517)', tag_name: "Ophthalmic FOV", tag_key: 'OphthalmicFOV', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0022,1517)', tag_sym: :ophthalmic_fov, tag_ndm: '00221517', tag_ary: [0x0022,0x1517], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1518)', tag_name: "Two Dimensional to Three Dimensional Map Sequence", tag_key: 'TwoDimensionalToThreeDimensionalMapSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1518)', tag_sym: :two_dimensional_to_three_dimensional_map_sequence, tag_ndm: '00221518', tag_ary: [0x0022,0x1518], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1525)', tag_name: "Wide Field Ophthalmic Photography Quality Rating Sequence", tag_key: 'WideFieldOphthalmicPhotographyQualityRatingSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1525)', tag_sym: :wide_field_ophthalmic_photography_quality_rating_sequence, tag_ndm: '00221525', tag_ary: [0x0022,0x1525], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1526)', tag_name: "Wide Field Ophthalmic Photography Quality Threshold Sequence", tag_key: 'WideFieldOphthalmicPhotographyQualityThresholdSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1526)', tag_sym: :wide_field_ophthalmic_photography_quality_threshold_sequence, tag_ndm: '00221526', tag_ary: [0x0022,0x1526], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1527)', tag_name: "Wide Field Ophthalmic Photography Threshold Quality Rating", tag_key: 'WideFieldOphthalmicPhotographyThresholdQualityRating', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0022,1527)', tag_sym: :wide_field_ophthalmic_photography_threshold_quality_rating, tag_ndm: '00221527', tag_ary: [0x0022,0x1527], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1528)', tag_name: "X Coordinates Center Pixel View Angle", tag_key: 'XCoordinatesCenterPixelViewAngle', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0022,1528)', tag_sym: :x_coordinates_center_pixel_view_angle, tag_ndm: '00221528', tag_ary: [0x0022,0x1528], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1529)', tag_name: "Y Coordinates Center Pixel View Angle", tag_key: 'YCoordinatesCenterPixelViewAngle', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0022,1529)', tag_sym: :y_coordinates_center_pixel_view_angle, tag_ndm: '00221529', tag_ary: [0x0022,0x1529], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1530)', tag_name: "Number of Map Points", tag_key: 'NumberOfMapPoints', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0022,1530)', tag_sym: :number_of_map_points, tag_ndm: '00221530', tag_ary: [0x0022,0x1530], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1531)', tag_name: "Two Dimensional to Three Dimensional Map Data", tag_key: 'TwoDimensionalToThreeDimensionalMapData', tag_vr: [:OF], tag_vm: ["1"], tag_str: '(0022,1531)', tag_sym: :two_dimensional_to_three_dimensional_map_data, tag_ndm: '00221531', tag_ary: [0x0022,0x1531], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1612)', tag_name: "Derivation Algorithm Sequence", tag_key: 'DerivationAlgorithmSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1612)', tag_sym: :derivation_algorithm_sequence, tag_ndm: '00221612', tag_ary: [0x0022,0x1612], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1615)', tag_name: "Ophthalmic Image Type Code Sequence", tag_key: 'OphthalmicImageTypeCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1615)', tag_sym: :ophthalmic_image_type_code_sequence, tag_ndm: '00221615', tag_ary: [0x0022,0x1615], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1616)', tag_name: "Ophthalmic Image Type Description", tag_key: 'OphthalmicImageTypeDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0022,1616)', tag_sym: :ophthalmic_image_type_description, tag_ndm: '00221616', tag_ary: [0x0022,0x1616], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1618)', tag_name: "Scan Pattern Type Code Sequence", tag_key: 'ScanPatternTypeCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1618)', tag_sym: :scan_pattern_type_code_sequence, tag_ndm: '00221618', tag_ary: [0x0022,0x1618], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1620)', tag_name: "Referenced Surface Mesh Identification Sequence", tag_key: 'ReferencedSurfaceMeshIdentificationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1620)', tag_sym: :referenced_surface_mesh_identification_sequence, tag_ndm: '00221620', tag_ary: [0x0022,0x1620], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1622)', tag_name: "Ophthalmic Volumetric Properties Flag", tag_key: 'OphthalmicVolumetricPropertiesFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0022,1622)', tag_sym: :ophthalmic_volumetric_properties_flag, tag_ndm: '00221622', tag_ary: [0x0022,0x1622], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1623)', tag_name: "Ophthalmic Anatomic Reference Point Frame Coordinate", tag_key: 'OphthalmicAnatomicReferencePointFrameCoordinate', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0022,1623)', tag_sym: :ophthalmic_anatomic_reference_point_frame_coordinate, tag_ndm: '00221623', tag_ary: [0x0022,0x1623], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1624)', tag_name: "Ophthalmic Anatomic Reference Point X-Coordinate", tag_key: 'OphthalmicAnatomicReferencePointXCoordinate', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0022,1624)', tag_sym: :ophthalmic_anatomic_reference_point_x_coordinate, tag_ndm: '00221624', tag_ary: [0x0022,0x1624], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1626)', tag_name: "Ophthalmic Anatomic Reference Point Y-Coordinate", tag_key: 'OphthalmicAnatomicReferencePointYCoordinate', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0022,1626)', tag_sym: :ophthalmic_anatomic_reference_point_y_coordinate, tag_ndm: '00221626', tag_ary: [0x0022,0x1626], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1627)', tag_name: "Ophthalmic En Face Volume Descriptor Sequence", tag_key: 'OphthalmicEnFaceVolumeDescriptorSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1627)', tag_sym: :ophthalmic_en_face_volume_descriptor_sequence, tag_ndm: '00221627', tag_ary: [0x0022,0x1627], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1628)', tag_name: "Ophthalmic En Face Image Quality Rating Sequence", tag_key: 'OphthalmicEnFaceImageQualityRatingSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1628)', tag_sym: :ophthalmic_en_face_image_quality_rating_sequence, tag_ndm: '00221628', tag_ary: [0x0022,0x1628], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1629)', tag_name: "Ophthalmic En Face Volume Descriptor Scope", tag_key: 'OphthalmicEnFaceVolumeDescriptorScope', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0022,1629)', tag_sym: :ophthalmic_en_face_volume_descriptor_scope, tag_ndm: '00221629', tag_ary: [0x0022,0x1629], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1630)', tag_name: "Quality Threshold", tag_key: 'QualityThreshold', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0022,1630)', tag_sym: :quality_threshold, tag_ndm: '00221630', tag_ary: [0x0022,0x1630], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1632)', tag_name: "Ophthalmic Anatomic Reference Point Sequence", tag_key: 'OphthalmicAnatomicReferencePointSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1632)', tag_sym: :ophthalmic_anatomic_reference_point_sequence, tag_ndm: '00221632', tag_ary: [0x0022,0x1632], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1633)', tag_name: "Ophthalmic Anatomic Reference Point Localization Type", tag_key: 'OphthalmicAnatomicReferencePointLocalizationType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0022,1633)', tag_sym: :ophthalmic_anatomic_reference_point_localization_type, tag_ndm: '00221633', tag_ary: [0x0022,0x1633], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1634)', tag_name: "Primary Anatomic Structure Item Index", tag_key: 'PrimaryAnatomicStructureItemIndex', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0022,1634)', tag_sym: :primary_anatomic_structure_item_index, tag_ndm: '00221634', tag_ary: [0x0022,0x1634], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1640)', tag_name: "OCT B-scan Analysis Acquisition Parameters Sequence", tag_key: 'OCTBscanAnalysisAcquisitionParametersSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0022,1640)', tag_sym: :oct_bscan_analysis_acquisition_parameters_sequence, tag_ndm: '00221640', tag_ary: [0x0022,0x1640], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1642)', tag_name: "Number of B-scans Per Frame", tag_key: 'NumberOfBscansPerFrame', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0022,1642)', tag_sym: :number_of_bscans_per_frame, tag_ndm: '00221642', tag_ary: [0x0022,0x1642], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1643)', tag_name: "B-scan Slab Thickness", tag_key: 'BscanSlabThickness', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0022,1643)', tag_sym: :bscan_slab_thickness, tag_ndm: '00221643', tag_ary: [0x0022,0x1643], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1644)', tag_name: "Distance Between B-scan Slabs", tag_key: 'DistanceBetweenBscanSlabs', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0022,1644)', tag_sym: :distance_between_bscan_slabs, tag_ndm: '00221644', tag_ary: [0x0022,0x1644], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1645)', tag_name: "B-scan Cycle Time", tag_key: 'BscanCycleTime', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0022,1645)', tag_sym: :bscan_cycle_time, tag_ndm: '00221645', tag_ary: [0x0022,0x1645], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1646)', tag_name: "B-scan Cycle Time Vector", tag_key: 'BscanCycleTimeVector', tag_vr: [:FL], tag_vm: ["1-n"], tag_str: '(0022,1646)', tag_sym: :bscan_cycle_time_vector, tag_ndm: '00221646', tag_ary: [0x0022,0x1646], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1649)', tag_name: "A-scan Rate", tag_key: 'AscanRate', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0022,1649)', tag_sym: :ascan_rate, tag_ndm: '00221649', tag_ary: [0x0022,0x1649], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1650)', tag_name: "B-scan Rate", tag_key: 'BscanRate', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0022,1650)', tag_sym: :bscan_rate, tag_ndm: '00221650', tag_ary: [0x0022,0x1650], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0022,1658)', tag_name: "Surface Mesh Z-Pixel Offset", tag_key: 'SurfaceMeshZPixelOffset', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0022,1658)', tag_sym: :surface_mesh_z_pixel_offset, tag_ndm: '00221658', tag_ary: [0x0022,0x1658], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0010)', tag_name: "Visual Field Horizontal Extent", tag_key: 'VisualFieldHorizontalExtent', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0024,0010)', tag_sym: :visual_field_horizontal_extent, tag_ndm: '00240010', tag_ary: [0x0024,0x0010], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0011)', tag_name: "Visual Field Vertical Extent", tag_key: 'VisualFieldVerticalExtent', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0024,0011)', tag_sym: :visual_field_vertical_extent, tag_ndm: '00240011', tag_ary: [0x0024,0x0011], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0012)', tag_name: "Visual Field Shape", tag_key: 'VisualFieldShape', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0024,0012)', tag_sym: :visual_field_shape, tag_ndm: '00240012', tag_ary: [0x0024,0x0012], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0016)', tag_name: "Screening Test Mode Code Sequence", tag_key: 'ScreeningTestModeCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0024,0016)', tag_sym: :screening_test_mode_code_sequence, tag_ndm: '00240016', tag_ary: [0x0024,0x0016], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0018)', tag_name: "Maximum Stimulus Luminance", tag_key: 'MaximumStimulusLuminance', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0024,0018)', tag_sym: :maximum_stimulus_luminance, tag_ndm: '00240018', tag_ary: [0x0024,0x0018], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0020)', tag_name: "Background Luminance", tag_key: 'BackgroundLuminance', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0024,0020)', tag_sym: :background_luminance, tag_ndm: '00240020', tag_ary: [0x0024,0x0020], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0021)', tag_name: "Stimulus Color Code Sequence", tag_key: 'StimulusColorCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0024,0021)', tag_sym: :stimulus_color_code_sequence, tag_ndm: '00240021', tag_ary: [0x0024,0x0021], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0024)', tag_name: "Background Illumination Color Code Sequence", tag_key: 'BackgroundIlluminationColorCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0024,0024)', tag_sym: :background_illumination_color_code_sequence, tag_ndm: '00240024', tag_ary: [0x0024,0x0024], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0025)', tag_name: "Stimulus Area", tag_key: 'StimulusArea', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0024,0025)', tag_sym: :stimulus_area, tag_ndm: '00240025', tag_ary: [0x0024,0x0025], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0028)', tag_name: "Stimulus Presentation Time", tag_key: 'StimulusPresentationTime', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0024,0028)', tag_sym: :stimulus_presentation_time, tag_ndm: '00240028', tag_ary: [0x0024,0x0028], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0032)', tag_name: "Fixation Sequence", tag_key: 'FixationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0024,0032)', tag_sym: :fixation_sequence, tag_ndm: '00240032', tag_ary: [0x0024,0x0032], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0033)', tag_name: "Fixation Monitoring Code Sequence", tag_key: 'FixationMonitoringCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0024,0033)', tag_sym: :fixation_monitoring_code_sequence, tag_ndm: '00240033', tag_ary: [0x0024,0x0033], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0034)', tag_name: "Visual Field Catch Trial Sequence", tag_key: 'VisualFieldCatchTrialSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0024,0034)', tag_sym: :visual_field_catch_trial_sequence, tag_ndm: '00240034', tag_ary: [0x0024,0x0034], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0035)', tag_name: "Fixation Checked Quantity", tag_key: 'FixationCheckedQuantity', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0024,0035)', tag_sym: :fixation_checked_quantity, tag_ndm: '00240035', tag_ary: [0x0024,0x0035], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0036)', tag_name: "Patient Not Properly Fixated Quantity", tag_key: 'PatientNotProperlyFixatedQuantity', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0024,0036)', tag_sym: :patient_not_properly_fixated_quantity, tag_ndm: '00240036', tag_ary: [0x0024,0x0036], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0037)', tag_name: "Presented Visual Stimuli Data Flag", tag_key: 'PresentedVisualStimuliDataFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0024,0037)', tag_sym: :presented_visual_stimuli_data_flag, tag_ndm: '00240037', tag_ary: [0x0024,0x0037], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0038)', tag_name: "Number of Visual Stimuli", tag_key: 'NumberOfVisualStimuli', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0024,0038)', tag_sym: :number_of_visual_stimuli, tag_ndm: '00240038', tag_ary: [0x0024,0x0038], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0039)', tag_name: "Excessive Fixation Losses Data Flag", tag_key: 'ExcessiveFixationLossesDataFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0024,0039)', tag_sym: :excessive_fixation_losses_data_flag, tag_ndm: '00240039', tag_ary: [0x0024,0x0039], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0040)', tag_name: "Excessive Fixation Losses", tag_key: 'ExcessiveFixationLosses', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0024,0040)', tag_sym: :excessive_fixation_losses, tag_ndm: '00240040', tag_ary: [0x0024,0x0040], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0042)', tag_name: "Stimuli Retesting Quantity", tag_key: 'StimuliRetestingQuantity', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0024,0042)', tag_sym: :stimuli_retesting_quantity, tag_ndm: '00240042', tag_ary: [0x0024,0x0042], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0044)', tag_name: "Comments on Patient's Performance of Visual Field", tag_key: 'CommentsOnPatientPerformanceOfVisualField', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(0024,0044)', tag_sym: :comments_on_patient_performance_of_visual_field, tag_ndm: '00240044', tag_ary: [0x0024,0x0044], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0045)', tag_name: "False Negatives Estimate Flag", tag_key: 'FalseNegativesEstimateFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0024,0045)', tag_sym: :false_negatives_estimate_flag, tag_ndm: '00240045', tag_ary: [0x0024,0x0045], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0046)', tag_name: "False Negatives Estimate", tag_key: 'FalseNegativesEstimate', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0024,0046)', tag_sym: :false_negatives_estimate, tag_ndm: '00240046', tag_ary: [0x0024,0x0046], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0048)', tag_name: "Negative Catch Trials Quantity", tag_key: 'NegativeCatchTrialsQuantity', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0024,0048)', tag_sym: :negative_catch_trials_quantity, tag_ndm: '00240048', tag_ary: [0x0024,0x0048], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0050)', tag_name: "False Negatives Quantity", tag_key: 'FalseNegativesQuantity', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0024,0050)', tag_sym: :false_negatives_quantity, tag_ndm: '00240050', tag_ary: [0x0024,0x0050], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0051)', tag_name: "Excessive False Negatives Data Flag", tag_key: 'ExcessiveFalseNegativesDataFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0024,0051)', tag_sym: :excessive_false_negatives_data_flag, tag_ndm: '00240051', tag_ary: [0x0024,0x0051], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0052)', tag_name: "Excessive False Negatives", tag_key: 'ExcessiveFalseNegatives', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0024,0052)', tag_sym: :excessive_false_negatives, tag_ndm: '00240052', tag_ary: [0x0024,0x0052], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0053)', tag_name: "False Positives Estimate Flag", tag_key: 'FalsePositivesEstimateFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0024,0053)', tag_sym: :false_positives_estimate_flag, tag_ndm: '00240053', tag_ary: [0x0024,0x0053], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0054)', tag_name: "False Positives Estimate", tag_key: 'FalsePositivesEstimate', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0024,0054)', tag_sym: :false_positives_estimate, tag_ndm: '00240054', tag_ary: [0x0024,0x0054], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0055)', tag_name: "Catch Trials Data Flag", tag_key: 'CatchTrialsDataFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0024,0055)', tag_sym: :catch_trials_data_flag, tag_ndm: '00240055', tag_ary: [0x0024,0x0055], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0056)', tag_name: "Positive Catch Trials Quantity", tag_key: 'PositiveCatchTrialsQuantity', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0024,0056)', tag_sym: :positive_catch_trials_quantity, tag_ndm: '00240056', tag_ary: [0x0024,0x0056], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0057)', tag_name: "Test Point Normals Data Flag", tag_key: 'TestPointNormalsDataFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0024,0057)', tag_sym: :test_point_normals_data_flag, tag_ndm: '00240057', tag_ary: [0x0024,0x0057], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0058)', tag_name: "Test Point Normals Sequence", tag_key: 'TestPointNormalsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0024,0058)', tag_sym: :test_point_normals_sequence, tag_ndm: '00240058', tag_ary: [0x0024,0x0058], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0059)', tag_name: "Global Deviation Probability Normals Flag", tag_key: 'GlobalDeviationProbabilityNormalsFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0024,0059)', tag_sym: :global_deviation_probability_normals_flag, tag_ndm: '00240059', tag_ary: [0x0024,0x0059], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0060)', tag_name: "False Positives Quantity", tag_key: 'FalsePositivesQuantity', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0024,0060)', tag_sym: :false_positives_quantity, tag_ndm: '00240060', tag_ary: [0x0024,0x0060], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0061)', tag_name: "Excessive False Positives Data Flag", tag_key: 'ExcessiveFalsePositivesDataFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0024,0061)', tag_sym: :excessive_false_positives_data_flag, tag_ndm: '00240061', tag_ary: [0x0024,0x0061], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0062)', tag_name: "Excessive False Positives", tag_key: 'ExcessiveFalsePositives', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0024,0062)', tag_sym: :excessive_false_positives, tag_ndm: '00240062', tag_ary: [0x0024,0x0062], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0063)', tag_name: "Visual Field Test Normals Flag", tag_key: 'VisualFieldTestNormalsFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0024,0063)', tag_sym: :visual_field_test_normals_flag, tag_ndm: '00240063', tag_ary: [0x0024,0x0063], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0064)', tag_name: "Results Normals Sequence", tag_key: 'ResultsNormalsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0024,0064)', tag_sym: :results_normals_sequence, tag_ndm: '00240064', tag_ary: [0x0024,0x0064], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0065)', tag_name: "Age Corrected Sensitivity Deviation Algorithm Sequence", tag_key: 'AgeCorrectedSensitivityDeviationAlgorithmSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0024,0065)', tag_sym: :age_corrected_sensitivity_deviation_algorithm_sequence, tag_ndm: '00240065', tag_ary: [0x0024,0x0065], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0066)', tag_name: "Global Deviation From Normal", tag_key: 'GlobalDeviationFromNormal', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0024,0066)', tag_sym: :global_deviation_from_normal, tag_ndm: '00240066', tag_ary: [0x0024,0x0066], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0067)', tag_name: "Generalized Defect Sensitivity Deviation Algorithm Sequence", tag_key: 'GeneralizedDefectSensitivityDeviationAlgorithmSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0024,0067)', tag_sym: :generalized_defect_sensitivity_deviation_algorithm_sequence, tag_ndm: '00240067', tag_ary: [0x0024,0x0067], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0068)', tag_name: "Localized Deviation From Normal", tag_key: 'LocalizedDeviationFromNormal', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0024,0068)', tag_sym: :localized_deviation_from_normal, tag_ndm: '00240068', tag_ary: [0x0024,0x0068], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0069)', tag_name: "Patient Reliability Indicator", tag_key: 'PatientReliabilityIndicator', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0024,0069)', tag_sym: :patient_reliability_indicator, tag_ndm: '00240069', tag_ary: [0x0024,0x0069], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0070)', tag_name: "Visual Field Mean Sensitivity", tag_key: 'VisualFieldMeanSensitivity', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0024,0070)', tag_sym: :visual_field_mean_sensitivity, tag_ndm: '00240070', tag_ary: [0x0024,0x0070], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0071)', tag_name: "Global Deviation Probability", tag_key: 'GlobalDeviationProbability', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0024,0071)', tag_sym: :global_deviation_probability, tag_ndm: '00240071', tag_ary: [0x0024,0x0071], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0072)', tag_name: "Local Deviation Probability Normals Flag", tag_key: 'LocalDeviationProbabilityNormalsFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0024,0072)', tag_sym: :local_deviation_probability_normals_flag, tag_ndm: '00240072', tag_ary: [0x0024,0x0072], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0073)', tag_name: "Localized Deviation Probability", tag_key: 'LocalizedDeviationProbability', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0024,0073)', tag_sym: :localized_deviation_probability, tag_ndm: '00240073', tag_ary: [0x0024,0x0073], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0074)', tag_name: "Short Term Fluctuation Calculated", tag_key: 'ShortTermFluctuationCalculated', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0024,0074)', tag_sym: :short_term_fluctuation_calculated, tag_ndm: '00240074', tag_ary: [0x0024,0x0074], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0075)', tag_name: "Short Term Fluctuation", tag_key: 'ShortTermFluctuation', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0024,0075)', tag_sym: :short_term_fluctuation, tag_ndm: '00240075', tag_ary: [0x0024,0x0075], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0076)', tag_name: "Short Term Fluctuation Probability Calculated", tag_key: 'ShortTermFluctuationProbabilityCalculated', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0024,0076)', tag_sym: :short_term_fluctuation_probability_calculated, tag_ndm: '00240076', tag_ary: [0x0024,0x0076], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0077)', tag_name: "Short Term Fluctuation Probability", tag_key: 'ShortTermFluctuationProbability', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0024,0077)', tag_sym: :short_term_fluctuation_probability, tag_ndm: '00240077', tag_ary: [0x0024,0x0077], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0078)', tag_name: "Corrected Localized Deviation From Normal Calculated", tag_key: 'CorrectedLocalizedDeviationFromNormalCalculated', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0024,0078)', tag_sym: :corrected_localized_deviation_from_normal_calculated, tag_ndm: '00240078', tag_ary: [0x0024,0x0078], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0079)', tag_name: "Corrected Localized Deviation From Normal", tag_key: 'CorrectedLocalizedDeviationFromNormal', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0024,0079)', tag_sym: :corrected_localized_deviation_from_normal, tag_ndm: '00240079', tag_ary: [0x0024,0x0079], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0080)', tag_name: "Corrected Localized Deviation From Normal Probability Calculated", tag_key: 'CorrectedLocalizedDeviationFromNormalProbabilityCalculated', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0024,0080)', tag_sym: :corrected_localized_deviation_from_normal_probability_calculated, tag_ndm: '00240080', tag_ary: [0x0024,0x0080], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0081)', tag_name: "Corrected Localized Deviation From Normal Probability", tag_key: 'CorrectedLocalizedDeviationFromNormalProbability', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0024,0081)', tag_sym: :corrected_localized_deviation_from_normal_probability, tag_ndm: '00240081', tag_ary: [0x0024,0x0081], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0083)', tag_name: "Global Deviation Probability Sequence", tag_key: 'GlobalDeviationProbabilitySequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0024,0083)', tag_sym: :global_deviation_probability_sequence, tag_ndm: '00240083', tag_ary: [0x0024,0x0083], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0085)', tag_name: "Localized Deviation Probability Sequence", tag_key: 'LocalizedDeviationProbabilitySequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0024,0085)', tag_sym: :localized_deviation_probability_sequence, tag_ndm: '00240085', tag_ary: [0x0024,0x0085], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0086)', tag_name: "Foveal Sensitivity Measured", tag_key: 'FovealSensitivityMeasured', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0024,0086)', tag_sym: :foveal_sensitivity_measured, tag_ndm: '00240086', tag_ary: [0x0024,0x0086], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0087)', tag_name: "Foveal Sensitivity", tag_key: 'FovealSensitivity', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0024,0087)', tag_sym: :foveal_sensitivity, tag_ndm: '00240087', tag_ary: [0x0024,0x0087], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0088)', tag_name: "Visual Field Test Duration", tag_key: 'VisualFieldTestDuration', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0024,0088)', tag_sym: :visual_field_test_duration, tag_ndm: '00240088', tag_ary: [0x0024,0x0088], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0089)', tag_name: "Visual Field Test Point Sequence", tag_key: 'VisualFieldTestPointSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0024,0089)', tag_sym: :visual_field_test_point_sequence, tag_ndm: '00240089', tag_ary: [0x0024,0x0089], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0090)', tag_name: "Visual Field Test Point X-Coordinate", tag_key: 'VisualFieldTestPointXCoordinate', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0024,0090)', tag_sym: :visual_field_test_point_x_coordinate, tag_ndm: '00240090', tag_ary: [0x0024,0x0090], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0091)', tag_name: "Visual Field Test Point Y-Coordinate", tag_key: 'VisualFieldTestPointYCoordinate', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0024,0091)', tag_sym: :visual_field_test_point_y_coordinate, tag_ndm: '00240091', tag_ary: [0x0024,0x0091], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0092)', tag_name: "Age Corrected Sensitivity Deviation Value", tag_key: 'AgeCorrectedSensitivityDeviationValue', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0024,0092)', tag_sym: :age_corrected_sensitivity_deviation_value, tag_ndm: '00240092', tag_ary: [0x0024,0x0092], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0093)', tag_name: "Stimulus Results", tag_key: 'StimulusResults', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0024,0093)', tag_sym: :stimulus_results, tag_ndm: '00240093', tag_ary: [0x0024,0x0093], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0094)', tag_name: "Sensitivity Value", tag_key: 'SensitivityValue', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0024,0094)', tag_sym: :sensitivity_value, tag_ndm: '00240094', tag_ary: [0x0024,0x0094], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0095)', tag_name: "Retest Stimulus Seen", tag_key: 'RetestStimulusSeen', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0024,0095)', tag_sym: :retest_stimulus_seen, tag_ndm: '00240095', tag_ary: [0x0024,0x0095], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0096)', tag_name: "Retest Sensitivity Value", tag_key: 'RetestSensitivityValue', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0024,0096)', tag_sym: :retest_sensitivity_value, tag_ndm: '00240096', tag_ary: [0x0024,0x0096], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0097)', tag_name: "Visual Field Test Point Normals Sequence", tag_key: 'VisualFieldTestPointNormalsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0024,0097)', tag_sym: :visual_field_test_point_normals_sequence, tag_ndm: '00240097', tag_ary: [0x0024,0x0097], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0098)', tag_name: "Quantified Defect", tag_key: 'QuantifiedDefect', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0024,0098)', tag_sym: :quantified_defect, tag_ndm: '00240098', tag_ary: [0x0024,0x0098], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0100)', tag_name: "Age Corrected Sensitivity Deviation Probability Value", tag_key: 'AgeCorrectedSensitivityDeviationProbabilityValue', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0024,0100)', tag_sym: :age_corrected_sensitivity_deviation_probability_value, tag_ndm: '00240100', tag_ary: [0x0024,0x0100], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0102)', tag_name: "Generalized Defect Corrected Sensitivity Deviation Flag", tag_key: 'GeneralizedDefectCorrectedSensitivityDeviationFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0024,0102)', tag_sym: :generalized_defect_corrected_sensitivity_deviation_flag, tag_ndm: '00240102', tag_ary: [0x0024,0x0102], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0103)', tag_name: "Generalized Defect Corrected Sensitivity Deviation Value", tag_key: 'GeneralizedDefectCorrectedSensitivityDeviationValue', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0024,0103)', tag_sym: :generalized_defect_corrected_sensitivity_deviation_value, tag_ndm: '00240103', tag_ary: [0x0024,0x0103], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0104)', tag_name: "Generalized Defect Corrected Sensitivity Deviation Probability Value", tag_key: 'GeneralizedDefectCorrectedSensitivityDeviationProbabilityValue', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0024,0104)', tag_sym: :generalized_defect_corrected_sensitivity_deviation_probability_value, tag_ndm: '00240104', tag_ary: [0x0024,0x0104], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0105)', tag_name: "Minimum Sensitivity Value", tag_key: 'MinimumSensitivityValue', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0024,0105)', tag_sym: :minimum_sensitivity_value, tag_ndm: '00240105', tag_ary: [0x0024,0x0105], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0106)', tag_name: "Blind Spot Localized", tag_key: 'BlindSpotLocalized', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0024,0106)', tag_sym: :blind_spot_localized, tag_ndm: '00240106', tag_ary: [0x0024,0x0106], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0107)', tag_name: "Blind Spot X-Coordinate", tag_key: 'BlindSpotXCoordinate', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0024,0107)', tag_sym: :blind_spot_x_coordinate, tag_ndm: '00240107', tag_ary: [0x0024,0x0107], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0108)', tag_name: "Blind Spot Y-Coordinate", tag_key: 'BlindSpotYCoordinate', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0024,0108)', tag_sym: :blind_spot_y_coordinate, tag_ndm: '00240108', tag_ary: [0x0024,0x0108], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0110)', tag_name: "Visual Acuity Measurement Sequence", tag_key: 'VisualAcuityMeasurementSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0024,0110)', tag_sym: :visual_acuity_measurement_sequence, tag_ndm: '00240110', tag_ary: [0x0024,0x0110], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0112)', tag_name: "Refractive Parameters Used on Patient Sequence", tag_key: 'RefractiveParametersUsedOnPatientSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0024,0112)', tag_sym: :refractive_parameters_used_on_patient_sequence, tag_ndm: '00240112', tag_ary: [0x0024,0x0112], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0113)', tag_name: "Measurement Laterality", tag_key: 'MeasurementLaterality', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0024,0113)', tag_sym: :measurement_laterality, tag_ndm: '00240113', tag_ary: [0x0024,0x0113], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0114)', tag_name: "Ophthalmic Patient Clinical Information Left Eye Sequence", tag_key: 'OphthalmicPatientClinicalInformationLeftEyeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0024,0114)', tag_sym: :ophthalmic_patient_clinical_information_left_eye_sequence, tag_ndm: '00240114', tag_ary: [0x0024,0x0114], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0115)', tag_name: "Ophthalmic Patient Clinical Information Right Eye Sequence", tag_key: 'OphthalmicPatientClinicalInformationRightEyeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0024,0115)', tag_sym: :ophthalmic_patient_clinical_information_right_eye_sequence, tag_ndm: '00240115', tag_ary: [0x0024,0x0115], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0117)', tag_name: "Foveal Point Normative Data Flag", tag_key: 'FovealPointNormativeDataFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0024,0117)', tag_sym: :foveal_point_normative_data_flag, tag_ndm: '00240117', tag_ary: [0x0024,0x0117], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0118)', tag_name: "Foveal Point Probability Value", tag_key: 'FovealPointProbabilityValue', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0024,0118)', tag_sym: :foveal_point_probability_value, tag_ndm: '00240118', tag_ary: [0x0024,0x0118], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0120)', tag_name: "Screening Baseline Measured", tag_key: 'ScreeningBaselineMeasured', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0024,0120)', tag_sym: :screening_baseline_measured, tag_ndm: '00240120', tag_ary: [0x0024,0x0120], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0122)', tag_name: "Screening Baseline Measured Sequence", tag_key: 'ScreeningBaselineMeasuredSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0024,0122)', tag_sym: :screening_baseline_measured_sequence, tag_ndm: '00240122', tag_ary: [0x0024,0x0122], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0124)', tag_name: "Screening Baseline Type", tag_key: 'ScreeningBaselineType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0024,0124)', tag_sym: :screening_baseline_type, tag_ndm: '00240124', tag_ary: [0x0024,0x0124], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0126)', tag_name: "Screening Baseline Value", tag_key: 'ScreeningBaselineValue', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0024,0126)', tag_sym: :screening_baseline_value, tag_ndm: '00240126', tag_ary: [0x0024,0x0126], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0202)', tag_name: "Algorithm Source", tag_key: 'AlgorithmSource', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0024,0202)', tag_sym: :algorithm_source, tag_ndm: '00240202', tag_ary: [0x0024,0x0202], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0306)', tag_name: "Data Set Name", tag_key: 'DataSetName', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0024,0306)', tag_sym: :data_set_name, tag_ndm: '00240306', tag_ary: [0x0024,0x0306], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0307)', tag_name: "Data Set Version", tag_key: 'DataSetVersion', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0024,0307)', tag_sym: :data_set_version, tag_ndm: '00240307', tag_ary: [0x0024,0x0307], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0308)', tag_name: "Data Set Source", tag_key: 'DataSetSource', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0024,0308)', tag_sym: :data_set_source, tag_ndm: '00240308', tag_ary: [0x0024,0x0308], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0309)', tag_name: "Data Set Description", tag_key: 'DataSetDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0024,0309)', tag_sym: :data_set_description, tag_ndm: '00240309', tag_ary: [0x0024,0x0309], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0317)', tag_name: "Visual Field Test Reliability Global Index Sequence", tag_key: 'VisualFieldTestReliabilityGlobalIndexSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0024,0317)', tag_sym: :visual_field_test_reliability_global_index_sequence, tag_ndm: '00240317', tag_ary: [0x0024,0x0317], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0320)', tag_name: "Visual Field Global Results Index Sequence", tag_key: 'VisualFieldGlobalResultsIndexSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0024,0320)', tag_sym: :visual_field_global_results_index_sequence, tag_ndm: '00240320', tag_ary: [0x0024,0x0320], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0325)', tag_name: "Data Observation Sequence", tag_key: 'DataObservationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0024,0325)', tag_sym: :data_observation_sequence, tag_ndm: '00240325', tag_ary: [0x0024,0x0325], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0338)', tag_name: "Index Normals Flag", tag_key: 'IndexNormalsFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0024,0338)', tag_sym: :index_normals_flag, tag_ndm: '00240338', tag_ary: [0x0024,0x0338], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0341)', tag_name: "Index Probability", tag_key: 'IndexProbability', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0024,0341)', tag_sym: :index_probability, tag_ndm: '00240341', tag_ary: [0x0024,0x0341], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0024,0344)', tag_name: "Index Probability Sequence", tag_key: 'IndexProbabilitySequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0024,0344)', tag_sym: :index_probability_sequence, tag_ndm: '00240344', tag_ary: [0x0024,0x0344], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,0002)', tag_name: "Samples per Pixel", tag_key: 'SamplesPerPixel', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0028,0002)', tag_sym: :samples_per_pixel, tag_ndm: '00280002', tag_ary: [0x0028,0x0002], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,0003)', tag_name: "Samples per Pixel Used", tag_key: 'SamplesPerPixelUsed', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0028,0003)', tag_sym: :samples_per_pixel_used, tag_ndm: '00280003', tag_ary: [0x0028,0x0003], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,0004)', tag_name: "Photometric Interpretation", tag_key: 'PhotometricInterpretation', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0028,0004)', tag_sym: :photometric_interpretation, tag_ndm: '00280004', tag_ary: [0x0028,0x0004], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,0005)', tag_name: "Image Dimensions", tag_key: 'ImageDimensions', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0028,0005)', tag_sym: :image_dimensions, tag_ndm: '00280005', tag_ary: [0x0028,0x0005], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(0028,0006)', tag_name: "Planar Configuration", tag_key: 'PlanarConfiguration', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0028,0006)', tag_sym: :planar_configuration, tag_ndm: '00280006', tag_ary: [0x0028,0x0006], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,0008)', tag_name: "Number of Frames", tag_key: 'NumberOfFrames', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0028,0008)', tag_sym: :number_of_frames, tag_ndm: '00280008', tag_ary: [0x0028,0x0008], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,0009)', tag_name: "Frame Increment Pointer", tag_key: 'FrameIncrementPointer', tag_vr: [:AT], tag_vm: ["1-n"], tag_str: '(0028,0009)', tag_sym: :frame_increment_pointer, tag_ndm: '00280009', tag_ary: [0x0028,0x0009], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,000A)', tag_name: "Frame Dimension Pointer", tag_key: 'FrameDimensionPointer', tag_vr: [:AT], tag_vm: ["1-n"], tag_str: '(0028,000A)', tag_sym: :frame_dimension_pointer, tag_ndm: '0028000A', tag_ary: [0x0028,0x000A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,0010)', tag_name: "Rows", tag_key: 'Rows', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0028,0010)', tag_sym: :rows, tag_ndm: '00280010', tag_ary: [0x0028,0x0010], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,0011)', tag_name: "Columns", tag_key: 'Columns', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0028,0011)', tag_sym: :columns, tag_ndm: '00280011', tag_ary: [0x0028,0x0011], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,0012)', tag_name: "Planes", tag_key: 'Planes', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0028,0012)', tag_sym: :planes, tag_ndm: '00280012', tag_ary: [0x0028,0x0012], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0028,0014)', tag_name: "Ultrasound Color Data Present", tag_key: 'UltrasoundColorDataPresent', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0028,0014)', tag_sym: :ultrasound_color_data_present, tag_ndm: '00280014', tag_ary: [0x0028,0x0014], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,0020)', tag_name: "Placeholder (0028,0020)", tag_key: 'Placeholder_0028_0020', tag_vr: [:UN], tag_vm: ["1"], tag_str: '(0028,0020)', tag_sym: :placeholder_0028_0020, tag_ndm: '00280020', tag_ary: [0x0028,0x0020], tag_multiple: false, tag_note: 'RET (2007) - See Note'},
      { tag_ps: '(0028,0030)', tag_name: "Pixel Spacing", tag_key: 'PixelSpacing', tag_vr: [:DS], tag_vm: ["2"], tag_str: '(0028,0030)', tag_sym: :pixel_spacing, tag_ndm: '00280030', tag_ary: [0x0028,0x0030], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,0031)', tag_name: "Zoom Factor", tag_key: 'ZoomFactor', tag_vr: [:DS], tag_vm: ["2"], tag_str: '(0028,0031)', tag_sym: :zoom_factor, tag_ndm: '00280031', tag_ary: [0x0028,0x0031], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,0032)', tag_name: "Zoom Center", tag_key: 'ZoomCenter', tag_vr: [:DS], tag_vm: ["2"], tag_str: '(0028,0032)', tag_sym: :zoom_center, tag_ndm: '00280032', tag_ary: [0x0028,0x0032], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,0034)', tag_name: "Pixel Aspect Ratio", tag_key: 'PixelAspectRatio', tag_vr: [:IS], tag_vm: ["2"], tag_str: '(0028,0034)', tag_sym: :pixel_aspect_ratio, tag_ndm: '00280034', tag_ary: [0x0028,0x0034], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,0040)', tag_name: "Image Format", tag_key: 'ImageFormat', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0028,0040)', tag_sym: :image_format, tag_ndm: '00280040', tag_ary: [0x0028,0x0040], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(0028,0050)', tag_name: "Manipulated Image", tag_key: 'ManipulatedImage', tag_vr: [:LO], tag_vm: ["1-n"], tag_str: '(0028,0050)', tag_sym: :manipulated_image, tag_ndm: '00280050', tag_ary: [0x0028,0x0050], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(0028,0051)', tag_name: "Corrected Image", tag_key: 'CorrectedImage', tag_vr: [:CS], tag_vm: ["1-n"], tag_str: '(0028,0051)', tag_sym: :corrected_image, tag_ndm: '00280051', tag_ary: [0x0028,0x0051], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,005F)', tag_name: "Compression Recognition Code", tag_key: 'CompressionRecognitionCode', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0028,005F)', tag_sym: :compression_recognition_code, tag_ndm: '0028005F', tag_ary: [0x0028,0x005F], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0028,0060)', tag_name: "Compression Code", tag_key: 'CompressionCode', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0028,0060)', tag_sym: :compression_code, tag_ndm: '00280060', tag_ary: [0x0028,0x0060], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(0028,0061)', tag_name: "Compression Originator", tag_key: 'CompressionOriginator', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0028,0061)', tag_sym: :compression_originator, tag_ndm: '00280061', tag_ary: [0x0028,0x0061], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0028,0062)', tag_name: "Compression Label", tag_key: 'CompressionLabel', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0028,0062)', tag_sym: :compression_label, tag_ndm: '00280062', tag_ary: [0x0028,0x0062], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0028,0063)', tag_name: "Compression Description", tag_key: 'CompressionDescription', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0028,0063)', tag_sym: :compression_description, tag_ndm: '00280063', tag_ary: [0x0028,0x0063], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0028,0065)', tag_name: "Compression Sequence", tag_key: 'CompressionSequence', tag_vr: [:CS], tag_vm: ["1-n"], tag_str: '(0028,0065)', tag_sym: :compression_sequence, tag_ndm: '00280065', tag_ary: [0x0028,0x0065], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0028,0066)', tag_name: "Compression Step Pointers", tag_key: 'CompressionStepPointers', tag_vr: [:AT], tag_vm: ["1-n"], tag_str: '(0028,0066)', tag_sym: :compression_step_pointers, tag_ndm: '00280066', tag_ary: [0x0028,0x0066], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0028,0068)', tag_name: "Repeat Interval", tag_key: 'RepeatInterval', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0028,0068)', tag_sym: :repeat_interval, tag_ndm: '00280068', tag_ary: [0x0028,0x0068], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0028,0069)', tag_name: "Bits Grouped", tag_key: 'BitsGrouped', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0028,0069)', tag_sym: :bits_grouped, tag_ndm: '00280069', tag_ary: [0x0028,0x0069], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0028,0070)', tag_name: "Perimeter Table", tag_key: 'PerimeterTable', tag_vr: [:US], tag_vm: ["1-n"], tag_str: '(0028,0070)', tag_sym: :perimeter_table, tag_ndm: '00280070', tag_ary: [0x0028,0x0070], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0028,0071)', tag_name: "Perimeter Value", tag_key: 'PerimeterValue', tag_vr: [:US, :SS], tag_vm: ["1"], tag_str: '(0028,0071)', tag_sym: :perimeter_value, tag_ndm: '00280071', tag_ary: [0x0028,0x0071], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0028,0080)', tag_name: "Predictor Rows", tag_key: 'PredictorRows', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0028,0080)', tag_sym: :predictor_rows, tag_ndm: '00280080', tag_ary: [0x0028,0x0080], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0028,0081)', tag_name: "Predictor Columns", tag_key: 'PredictorColumns', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0028,0081)', tag_sym: :predictor_columns, tag_ndm: '00280081', tag_ary: [0x0028,0x0081], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0028,0082)', tag_name: "Predictor Constants", tag_key: 'PredictorConstants', tag_vr: [:US], tag_vm: ["1-n"], tag_str: '(0028,0082)', tag_sym: :predictor_constants, tag_ndm: '00280082', tag_ary: [0x0028,0x0082], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0028,0090)', tag_name: "Blocked Pixels", tag_key: 'BlockedPixels', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0028,0090)', tag_sym: :blocked_pixels, tag_ndm: '00280090', tag_ary: [0x0028,0x0090], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0028,0091)', tag_name: "Block Rows", tag_key: 'BlockRows', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0028,0091)', tag_sym: :block_rows, tag_ndm: '00280091', tag_ary: [0x0028,0x0091], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0028,0092)', tag_name: "Block Columns", tag_key: 'BlockColumns', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0028,0092)', tag_sym: :block_columns, tag_ndm: '00280092', tag_ary: [0x0028,0x0092], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0028,0093)', tag_name: "Row Overlap", tag_key: 'RowOverlap', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0028,0093)', tag_sym: :row_overlap, tag_ndm: '00280093', tag_ary: [0x0028,0x0093], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0028,0094)', tag_name: "Column Overlap", tag_key: 'ColumnOverlap', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0028,0094)', tag_sym: :column_overlap, tag_ndm: '00280094', tag_ary: [0x0028,0x0094], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0028,0100)', tag_name: "Bits Allocated", tag_key: 'BitsAllocated', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0028,0100)', tag_sym: :bits_allocated, tag_ndm: '00280100', tag_ary: [0x0028,0x0100], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,0101)', tag_name: "Bits Stored", tag_key: 'BitsStored', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0028,0101)', tag_sym: :bits_stored, tag_ndm: '00280101', tag_ary: [0x0028,0x0101], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,0102)', tag_name: "High Bit", tag_key: 'HighBit', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0028,0102)', tag_sym: :high_bit, tag_ndm: '00280102', tag_ary: [0x0028,0x0102], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,0103)', tag_name: "Pixel Representation", tag_key: 'PixelRepresentation', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0028,0103)', tag_sym: :pixel_representation, tag_ndm: '00280103', tag_ary: [0x0028,0x0103], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,0104)', tag_name: "Smallest Valid Pixel Value", tag_key: 'SmallestValidPixelValue', tag_vr: [:US, :SS], tag_vm: ["1"], tag_str: '(0028,0104)', tag_sym: :smallest_valid_pixel_value, tag_ndm: '00280104', tag_ary: [0x0028,0x0104], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(0028,0105)', tag_name: "Largest Valid Pixel Value", tag_key: 'LargestValidPixelValue', tag_vr: [:US, :SS], tag_vm: ["1"], tag_str: '(0028,0105)', tag_sym: :largest_valid_pixel_value, tag_ndm: '00280105', tag_ary: [0x0028,0x0105], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(0028,0106)', tag_name: "Smallest Image Pixel Value", tag_key: 'SmallestImagePixelValue', tag_vr: [:US, :SS], tag_vm: ["1"], tag_str: '(0028,0106)', tag_sym: :smallest_image_pixel_value, tag_ndm: '00280106', tag_ary: [0x0028,0x0106], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,0107)', tag_name: "Largest Image Pixel Value", tag_key: 'LargestImagePixelValue', tag_vr: [:US, :SS], tag_vm: ["1"], tag_str: '(0028,0107)', tag_sym: :largest_image_pixel_value, tag_ndm: '00280107', tag_ary: [0x0028,0x0107], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,0108)', tag_name: "Smallest Pixel Value in Series", tag_key: 'SmallestPixelValueInSeries', tag_vr: [:US, :SS], tag_vm: ["1"], tag_str: '(0028,0108)', tag_sym: :smallest_pixel_value_in_series, tag_ndm: '00280108', tag_ary: [0x0028,0x0108], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,0109)', tag_name: "Largest Pixel Value in Series", tag_key: 'LargestPixelValueInSeries', tag_vr: [:US, :SS], tag_vm: ["1"], tag_str: '(0028,0109)', tag_sym: :largest_pixel_value_in_series, tag_ndm: '00280109', tag_ary: [0x0028,0x0109], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,0110)', tag_name: "Smallest Image Pixel Value in Plane", tag_key: 'SmallestImagePixelValueInPlane', tag_vr: [:US, :SS], tag_vm: ["1"], tag_str: '(0028,0110)', tag_sym: :smallest_image_pixel_value_in_plane, tag_ndm: '00280110', tag_ary: [0x0028,0x0110], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0028,0111)', tag_name: "Largest Image Pixel Value in Plane", tag_key: 'LargestImagePixelValueInPlane', tag_vr: [:US, :SS], tag_vm: ["1"], tag_str: '(0028,0111)', tag_sym: :largest_image_pixel_value_in_plane, tag_ndm: '00280111', tag_ary: [0x0028,0x0111], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0028,0120)', tag_name: "Pixel Padding Value", tag_key: 'PixelPaddingValue', tag_vr: [:US, :SS], tag_vm: ["1"], tag_str: '(0028,0120)', tag_sym: :pixel_padding_value, tag_ndm: '00280120', tag_ary: [0x0028,0x0120], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,0121)', tag_name: "Pixel Padding Range Limit", tag_key: 'PixelPaddingRangeLimit', tag_vr: [:US, :SS], tag_vm: ["1"], tag_str: '(0028,0121)', tag_sym: :pixel_padding_range_limit, tag_ndm: '00280121', tag_ary: [0x0028,0x0121], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,0122)', tag_name: "Float Pixel Padding Value", tag_key: 'FloatPixelPaddingValue', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0028,0122)', tag_sym: :float_pixel_padding_value, tag_ndm: '00280122', tag_ary: [0x0028,0x0122], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,0123)', tag_name: "Double Float Pixel Padding Value", tag_key: 'DoubleFloatPixelPaddingValue', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0028,0123)', tag_sym: :double_float_pixel_padding_value, tag_ndm: '00280123', tag_ary: [0x0028,0x0123], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,0124)', tag_name: "Float Pixel Padding Range Limit", tag_key: 'FloatPixelPaddingRangeLimit', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0028,0124)', tag_sym: :float_pixel_padding_range_limit, tag_ndm: '00280124', tag_ary: [0x0028,0x0124], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,0125)', tag_name: "Double Float Pixel Padding Range Limit", tag_key: 'DoubleFloatPixelPaddingRangeLimit', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0028,0125)', tag_sym: :double_float_pixel_padding_range_limit, tag_ndm: '00280125', tag_ary: [0x0028,0x0125], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,0200)', tag_name: "Image Location", tag_key: 'ImageLocation', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0028,0200)', tag_sym: :image_location, tag_ndm: '00280200', tag_ary: [0x0028,0x0200], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(0028,0300)', tag_name: "Quality Control Image", tag_key: 'QualityControlImage', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0028,0300)', tag_sym: :quality_control_image, tag_ndm: '00280300', tag_ary: [0x0028,0x0300], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,0301)', tag_name: "Burned In Annotation", tag_key: 'BurnedInAnnotation', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0028,0301)', tag_sym: :burned_in_annotation, tag_ndm: '00280301', tag_ary: [0x0028,0x0301], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,0302)', tag_name: "Recognizable Visual Features", tag_key: 'RecognizableVisualFeatures', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0028,0302)', tag_sym: :recognizable_visual_features, tag_ndm: '00280302', tag_ary: [0x0028,0x0302], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,0303)', tag_name: "Longitudinal Temporal Information Modified", tag_key: 'LongitudinalTemporalInformationModified', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0028,0303)', tag_sym: :longitudinal_temporal_information_modified, tag_ndm: '00280303', tag_ary: [0x0028,0x0303], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,0304)', tag_name: "Referenced Color Palette Instance UID", tag_key: 'ReferencedColorPaletteInstanceUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0028,0304)', tag_sym: :referenced_color_palette_instance_uid, tag_ndm: '00280304', tag_ary: [0x0028,0x0304], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,0400)', tag_name: "Transform Label", tag_key: 'TransformLabel', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0028,0400)', tag_sym: :transform_label, tag_ndm: '00280400', tag_ary: [0x0028,0x0400], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0028,0401)', tag_name: "Transform Version Number", tag_key: 'TransformVersionNumber', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0028,0401)', tag_sym: :transform_version_number, tag_ndm: '00280401', tag_ary: [0x0028,0x0401], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0028,0402)', tag_name: "Number of Transform Steps", tag_key: 'NumberOfTransformSteps', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0028,0402)', tag_sym: :number_of_transform_steps, tag_ndm: '00280402', tag_ary: [0x0028,0x0402], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0028,0403)', tag_name: "Sequence of Compressed Data", tag_key: 'SequenceOfCompressedData', tag_vr: [:LO], tag_vm: ["1-n"], tag_str: '(0028,0403)', tag_sym: :sequence_of_compressed_data, tag_ndm: '00280403', tag_ary: [0x0028,0x0403], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0028,0404)', tag_name: "Details of Coefficients", tag_key: 'DetailsOfCoefficients', tag_vr: [:AT], tag_vm: ["1-n"], tag_str: '(0028,0404)', tag_sym: :details_of_coefficients, tag_ndm: '00280404', tag_ary: [0x0028,0x0404], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0028,04X0)', tag_name: "Rows For Nth Order Coefficients", tag_key: 'RowsForNthOrderCoefficients', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0028,0420)', tag_sym: :rows_for_nth_order_coefficients, tag_ndm: '00280420', tag_ary: [0x0028,0x0420], tag_multiple: true, tag_note: 'RET (2007)'},
      { tag_ps: '(0028,04X1)', tag_name: "Columns For Nth Order Coefficients", tag_key: 'ColumnsForNthOrderCoefficients', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0028,0421)', tag_sym: :columns_for_nth_order_coefficients, tag_ndm: '00280421', tag_ary: [0x0028,0x0421], tag_multiple: true, tag_note: 'RET (2007)'},
      { tag_ps: '(0028,04X2)', tag_name: "Coefficient Coding", tag_key: 'CoefficientCoding', tag_vr: [:LO], tag_vm: ["1-n"], tag_str: '(0028,0422)', tag_sym: :coefficient_coding, tag_ndm: '00280422', tag_ary: [0x0028,0x0422], tag_multiple: true, tag_note: 'RET (2007)'},
      { tag_ps: '(0028,04X3)', tag_name: "Coefficient Coding Pointers", tag_key: 'CoefficientCodingPointers', tag_vr: [:AT], tag_vm: ["1-n"], tag_str: '(0028,0423)', tag_sym: :coefficient_coding_pointers, tag_ndm: '00280423', tag_ary: [0x0028,0x0423], tag_multiple: true, tag_note: 'RET (2007)'},
      { tag_ps: '(0028,0700)', tag_name: "DCT Label", tag_key: 'DCTLabel', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0028,0700)', tag_sym: :dct_label, tag_ndm: '00280700', tag_ary: [0x0028,0x0700], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0028,0701)', tag_name: "Data Block Description", tag_key: 'DataBlockDescription', tag_vr: [:CS], tag_vm: ["1-n"], tag_str: '(0028,0701)', tag_sym: :data_block_description, tag_ndm: '00280701', tag_ary: [0x0028,0x0701], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0028,0702)', tag_name: "Data Block", tag_key: 'DataBlock', tag_vr: [:AT], tag_vm: ["1-n"], tag_str: '(0028,0702)', tag_sym: :data_block, tag_ndm: '00280702', tag_ary: [0x0028,0x0702], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0028,0710)', tag_name: "Normalization Factor Format", tag_key: 'NormalizationFactorFormat', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0028,0710)', tag_sym: :normalization_factor_format, tag_ndm: '00280710', tag_ary: [0x0028,0x0710], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0028,0720)', tag_name: "Zonal Map Number Format", tag_key: 'ZonalMapNumberFormat', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0028,0720)', tag_sym: :zonal_map_number_format, tag_ndm: '00280720', tag_ary: [0x0028,0x0720], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0028,0721)', tag_name: "Zonal Map Location", tag_key: 'ZonalMapLocation', tag_vr: [:AT], tag_vm: ["1-n"], tag_str: '(0028,0721)', tag_sym: :zonal_map_location, tag_ndm: '00280721', tag_ary: [0x0028,0x0721], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0028,0722)', tag_name: "Zonal Map Format", tag_key: 'ZonalMapFormat', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0028,0722)', tag_sym: :zonal_map_format, tag_ndm: '00280722', tag_ary: [0x0028,0x0722], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0028,0730)', tag_name: "Adaptive Map Format", tag_key: 'AdaptiveMapFormat', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0028,0730)', tag_sym: :adaptive_map_format, tag_ndm: '00280730', tag_ary: [0x0028,0x0730], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0028,0740)', tag_name: "Code Number Format", tag_key: 'CodeNumberFormat', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0028,0740)', tag_sym: :code_number_format, tag_ndm: '00280740', tag_ary: [0x0028,0x0740], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0028,08X0)', tag_name: "Code Label", tag_key: 'CodeLabel', tag_vr: [:CS], tag_vm: ["1-n"], tag_str: '(0028,0820)', tag_sym: :code_label, tag_ndm: '00280820', tag_ary: [0x0028,0x0820], tag_multiple: true, tag_note: 'RET (2007)'},
      { tag_ps: '(0028,08X2)', tag_name: "Number of Tables", tag_key: 'NumberOfTables', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0028,0822)', tag_sym: :number_of_tables, tag_ndm: '00280822', tag_ary: [0x0028,0x0822], tag_multiple: true, tag_note: 'RET (2007)'},
      { tag_ps: '(0028,08X3)', tag_name: "Code Table Location", tag_key: 'CodeTableLocation', tag_vr: [:AT], tag_vm: ["1-n"], tag_str: '(0028,0823)', tag_sym: :code_table_location, tag_ndm: '00280823', tag_ary: [0x0028,0x0823], tag_multiple: true, tag_note: 'RET (2007)'},
      { tag_ps: '(0028,08X4)', tag_name: "Bits For Code Word", tag_key: 'BitsForCodeWord', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0028,0824)', tag_sym: :bits_for_code_word, tag_ndm: '00280824', tag_ary: [0x0028,0x0824], tag_multiple: true, tag_note: 'RET (2007)'},
      { tag_ps: '(0028,08X8)', tag_name: "Image Data Location", tag_key: 'ImageDataLocation', tag_vr: [:AT], tag_vm: ["1-n"], tag_str: '(0028,0828)', tag_sym: :image_data_location, tag_ndm: '00280828', tag_ary: [0x0028,0x0828], tag_multiple: true, tag_note: 'RET (2007)'},
      { tag_ps: '(0028,0A02)', tag_name: "Pixel Spacing Calibration Type", tag_key: 'PixelSpacingCalibrationType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0028,0A02)', tag_sym: :pixel_spacing_calibration_type, tag_ndm: '00280A02', tag_ary: [0x0028,0x0A02], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,0A04)', tag_name: "Pixel Spacing Calibration Description", tag_key: 'PixelSpacingCalibrationDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0028,0A04)', tag_sym: :pixel_spacing_calibration_description, tag_ndm: '00280A04', tag_ary: [0x0028,0x0A04], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,1040)', tag_name: "Pixel Intensity Relationship", tag_key: 'PixelIntensityRelationship', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0028,1040)', tag_sym: :pixel_intensity_relationship, tag_ndm: '00281040', tag_ary: [0x0028,0x1040], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,1041)', tag_name: "Pixel Intensity Relationship Sign", tag_key: 'PixelIntensityRelationshipSign', tag_vr: [:SS], tag_vm: ["1"], tag_str: '(0028,1041)', tag_sym: :pixel_intensity_relationship_sign, tag_ndm: '00281041', tag_ary: [0x0028,0x1041], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,1050)', tag_name: "Window Center", tag_key: 'WindowCenter', tag_vr: [:DS], tag_vm: ["1-n"], tag_str: '(0028,1050)', tag_sym: :window_center, tag_ndm: '00281050', tag_ary: [0x0028,0x1050], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,1051)', tag_name: "Window Width", tag_key: 'WindowWidth', tag_vr: [:DS], tag_vm: ["1-n"], tag_str: '(0028,1051)', tag_sym: :window_width, tag_ndm: '00281051', tag_ary: [0x0028,0x1051], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,1052)', tag_name: "Rescale Intercept", tag_key: 'RescaleIntercept', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0028,1052)', tag_sym: :rescale_intercept, tag_ndm: '00281052', tag_ary: [0x0028,0x1052], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,1053)', tag_name: "Rescale Slope", tag_key: 'RescaleSlope', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0028,1053)', tag_sym: :rescale_slope, tag_ndm: '00281053', tag_ary: [0x0028,0x1053], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,1054)', tag_name: "Rescale Type", tag_key: 'RescaleType', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0028,1054)', tag_sym: :rescale_type, tag_ndm: '00281054', tag_ary: [0x0028,0x1054], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,1055)', tag_name: "Window Center & Width Explanation", tag_key: 'WindowCenterWidthExplanation', tag_vr: [:LO], tag_vm: ["1-n"], tag_str: '(0028,1055)', tag_sym: :window_center_width_explanation, tag_ndm: '00281055', tag_ary: [0x0028,0x1055], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,1056)', tag_name: "VOI LUT Function", tag_key: 'VOILUTFunction', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0028,1056)', tag_sym: :voi_lut_function, tag_ndm: '00281056', tag_ary: [0x0028,0x1056], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,1080)', tag_name: "Gray Scale", tag_key: 'GrayScale', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0028,1080)', tag_sym: :gray_scale, tag_ndm: '00281080', tag_ary: [0x0028,0x1080], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(0028,1090)', tag_name: "Recommended Viewing Mode", tag_key: 'RecommendedViewingMode', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0028,1090)', tag_sym: :recommended_viewing_mode, tag_ndm: '00281090', tag_ary: [0x0028,0x1090], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,1100)', tag_name: "Gray Lookup Table Descriptor", tag_key: 'GrayLookupTableDescriptor', tag_vr: [:US, :SS], tag_vm: ["3"], tag_str: '(0028,1100)', tag_sym: :gray_lookup_table_descriptor, tag_ndm: '00281100', tag_ary: [0x0028,0x1100], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(0028,1101)', tag_name: "Red Palette Color Lookup Table Descriptor", tag_key: 'RedPaletteColorLookupTableDescriptor', tag_vr: [:US, :SS], tag_vm: ["3"], tag_str: '(0028,1101)', tag_sym: :red_palette_color_lookup_table_descriptor, tag_ndm: '00281101', tag_ary: [0x0028,0x1101], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,1102)', tag_name: "Green Palette Color Lookup Table Descriptor", tag_key: 'GreenPaletteColorLookupTableDescriptor', tag_vr: [:US, :SS], tag_vm: ["3"], tag_str: '(0028,1102)', tag_sym: :green_palette_color_lookup_table_descriptor, tag_ndm: '00281102', tag_ary: [0x0028,0x1102], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,1103)', tag_name: "Blue Palette Color Lookup Table Descriptor", tag_key: 'BluePaletteColorLookupTableDescriptor', tag_vr: [:US, :SS], tag_vm: ["3"], tag_str: '(0028,1103)', tag_sym: :blue_palette_color_lookup_table_descriptor, tag_ndm: '00281103', tag_ary: [0x0028,0x1103], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,1104)', tag_name: "Alpha Palette Color Lookup Table Descriptor", tag_key: 'AlphaPaletteColorLookupTableDescriptor', tag_vr: [:US], tag_vm: ["3"], tag_str: '(0028,1104)', tag_sym: :alpha_palette_color_lookup_table_descriptor, tag_ndm: '00281104', tag_ary: [0x0028,0x1104], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,1111)', tag_name: "Large Red Palette Color Lookup Table Descriptor", tag_key: 'LargeRedPaletteColorLookupTableDescriptor', tag_vr: [:US, :SS], tag_vm: ["4"], tag_str: '(0028,1111)', tag_sym: :large_red_palette_color_lookup_table_descriptor, tag_ndm: '00281111', tag_ary: [0x0028,0x1111], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0028,1112)', tag_name: "Large Green Palette Color Lookup Table Descriptor", tag_key: 'LargeGreenPaletteColorLookupTableDescriptor', tag_vr: [:US, :SS], tag_vm: ["4"], tag_str: '(0028,1112)', tag_sym: :large_green_palette_color_lookup_table_descriptor, tag_ndm: '00281112', tag_ary: [0x0028,0x1112], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0028,1113)', tag_name: "Large Blue Palette Color Lookup Table Descriptor", tag_key: 'LargeBluePaletteColorLookupTableDescriptor', tag_vr: [:US, :SS], tag_vm: ["4"], tag_str: '(0028,1113)', tag_sym: :large_blue_palette_color_lookup_table_descriptor, tag_ndm: '00281113', tag_ary: [0x0028,0x1113], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0028,1199)', tag_name: "Palette Color Lookup Table UID", tag_key: 'PaletteColorLookupTableUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0028,1199)', tag_sym: :palette_color_lookup_table_uid, tag_ndm: '00281199', tag_ary: [0x0028,0x1199], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,1200)', tag_name: "Gray Lookup Table Data", tag_key: 'GrayLookupTableData', tag_vr: [:US, :SS, :OW], tag_vm: ["1-n", "1"], tag_str: '(0028,1200)', tag_sym: :gray_lookup_table_data, tag_ndm: '00281200', tag_ary: [0x0028,0x1200], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(0028,1201)', tag_name: "Red Palette Color Lookup Table Data", tag_key: 'RedPaletteColorLookupTableData', tag_vr: [:OW], tag_vm: ["1"], tag_str: '(0028,1201)', tag_sym: :red_palette_color_lookup_table_data, tag_ndm: '00281201', tag_ary: [0x0028,0x1201], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,1202)', tag_name: "Green Palette Color Lookup Table Data", tag_key: 'GreenPaletteColorLookupTableData', tag_vr: [:OW], tag_vm: ["1"], tag_str: '(0028,1202)', tag_sym: :green_palette_color_lookup_table_data, tag_ndm: '00281202', tag_ary: [0x0028,0x1202], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,1203)', tag_name: "Blue Palette Color Lookup Table Data", tag_key: 'BluePaletteColorLookupTableData', tag_vr: [:OW], tag_vm: ["1"], tag_str: '(0028,1203)', tag_sym: :blue_palette_color_lookup_table_data, tag_ndm: '00281203', tag_ary: [0x0028,0x1203], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,1204)', tag_name: "Alpha Palette Color Lookup Table Data", tag_key: 'AlphaPaletteColorLookupTableData', tag_vr: [:OW], tag_vm: ["1"], tag_str: '(0028,1204)', tag_sym: :alpha_palette_color_lookup_table_data, tag_ndm: '00281204', tag_ary: [0x0028,0x1204], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,1211)', tag_name: "Large Red Palette Color Lookup Table Data", tag_key: 'LargeRedPaletteColorLookupTableData', tag_vr: [:OW], tag_vm: ["1"], tag_str: '(0028,1211)', tag_sym: :large_red_palette_color_lookup_table_data, tag_ndm: '00281211', tag_ary: [0x0028,0x1211], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0028,1212)', tag_name: "Large Green Palette Color Lookup Table Data", tag_key: 'LargeGreenPaletteColorLookupTableData', tag_vr: [:OW], tag_vm: ["1"], tag_str: '(0028,1212)', tag_sym: :large_green_palette_color_lookup_table_data, tag_ndm: '00281212', tag_ary: [0x0028,0x1212], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0028,1213)', tag_name: "Large Blue Palette Color Lookup Table Data", tag_key: 'LargeBluePaletteColorLookupTableData', tag_vr: [:OW], tag_vm: ["1"], tag_str: '(0028,1213)', tag_sym: :large_blue_palette_color_lookup_table_data, tag_ndm: '00281213', tag_ary: [0x0028,0x1213], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0028,1214)', tag_name: "Large Palette Color Lookup Table UID", tag_key: 'LargePaletteColorLookupTableUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0028,1214)', tag_sym: :large_palette_color_lookup_table_uid, tag_ndm: '00281214', tag_ary: [0x0028,0x1214], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0028,1221)', tag_name: "Segmented Red Palette Color Lookup Table Data", tag_key: 'SegmentedRedPaletteColorLookupTableData', tag_vr: [:OW], tag_vm: ["1"], tag_str: '(0028,1221)', tag_sym: :segmented_red_palette_color_lookup_table_data, tag_ndm: '00281221', tag_ary: [0x0028,0x1221], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,1222)', tag_name: "Segmented Green Palette Color Lookup Table Data", tag_key: 'SegmentedGreenPaletteColorLookupTableData', tag_vr: [:OW], tag_vm: ["1"], tag_str: '(0028,1222)', tag_sym: :segmented_green_palette_color_lookup_table_data, tag_ndm: '00281222', tag_ary: [0x0028,0x1222], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,1223)', tag_name: "Segmented Blue Palette Color Lookup Table Data", tag_key: 'SegmentedBluePaletteColorLookupTableData', tag_vr: [:OW], tag_vm: ["1"], tag_str: '(0028,1223)', tag_sym: :segmented_blue_palette_color_lookup_table_data, tag_ndm: '00281223', tag_ary: [0x0028,0x1223], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,1224)', tag_name: "Segmented Alpha Palette Color Lookup Table Data", tag_key: 'SegmentedAlphaPaletteColorLookupTableData', tag_vr: [:OW], tag_vm: ["1"], tag_str: '(0028,1224)', tag_sym: :segmented_alpha_palette_color_lookup_table_data, tag_ndm: '00281224', tag_ary: [0x0028,0x1224], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,1230)', tag_name: "Stored Value Color Range Sequence", tag_key: 'StoredValueColorRangeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0028,1230)', tag_sym: :stored_value_color_range_sequence, tag_ndm: '00281230', tag_ary: [0x0028,0x1230], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,1231)', tag_name: "Minimum Stored Value Mapped", tag_key: 'MinimumStoredValueMapped', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0028,1231)', tag_sym: :minimum_stored_value_mapped, tag_ndm: '00281231', tag_ary: [0x0028,0x1231], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,1232)', tag_name: "Maximum Stored Value Mapped", tag_key: 'MaximumStoredValueMapped', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0028,1232)', tag_sym: :maximum_stored_value_mapped, tag_ndm: '00281232', tag_ary: [0x0028,0x1232], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,1300)', tag_name: "Breast Implant Present", tag_key: 'BreastImplantPresent', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0028,1300)', tag_sym: :breast_implant_present, tag_ndm: '00281300', tag_ary: [0x0028,0x1300], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,1350)', tag_name: "Partial View", tag_key: 'PartialView', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0028,1350)', tag_sym: :partial_view, tag_ndm: '00281350', tag_ary: [0x0028,0x1350], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,1351)', tag_name: "Partial View Description", tag_key: 'PartialViewDescription', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0028,1351)', tag_sym: :partial_view_description, tag_ndm: '00281351', tag_ary: [0x0028,0x1351], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,1352)', tag_name: "Partial View Code Sequence", tag_key: 'PartialViewCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0028,1352)', tag_sym: :partial_view_code_sequence, tag_ndm: '00281352', tag_ary: [0x0028,0x1352], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,135A)', tag_name: "Spatial Locations Preserved", tag_key: 'SpatialLocationsPreserved', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0028,135A)', tag_sym: :spatial_locations_preserved, tag_ndm: '0028135A', tag_ary: [0x0028,0x135A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,1401)', tag_name: "Data Frame Assignment Sequence", tag_key: 'DataFrameAssignmentSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0028,1401)', tag_sym: :data_frame_assignment_sequence, tag_ndm: '00281401', tag_ary: [0x0028,0x1401], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,1402)', tag_name: "Data Path Assignment", tag_key: 'DataPathAssignment', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0028,1402)', tag_sym: :data_path_assignment, tag_ndm: '00281402', tag_ary: [0x0028,0x1402], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,1403)', tag_name: "Bits Mapped to Color Lookup Table", tag_key: 'BitsMappedToColorLookupTable', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0028,1403)', tag_sym: :bits_mapped_to_color_lookup_table, tag_ndm: '00281403', tag_ary: [0x0028,0x1403], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,1404)', tag_name: "Blending LUT 1 Sequence", tag_key: 'BlendingLUT1Sequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0028,1404)', tag_sym: :blending_lut1_sequence, tag_ndm: '00281404', tag_ary: [0x0028,0x1404], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,1405)', tag_name: "Blending LUT 1 Transfer Function", tag_key: 'BlendingLUT1TransferFunction', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0028,1405)', tag_sym: :blending_lut1_transfer_function, tag_ndm: '00281405', tag_ary: [0x0028,0x1405], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,1406)', tag_name: "Blending Weight Constant", tag_key: 'BlendingWeightConstant', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0028,1406)', tag_sym: :blending_weight_constant, tag_ndm: '00281406', tag_ary: [0x0028,0x1406], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,1407)', tag_name: "Blending Lookup Table Descriptor", tag_key: 'BlendingLookupTableDescriptor', tag_vr: [:US], tag_vm: ["3"], tag_str: '(0028,1407)', tag_sym: :blending_lookup_table_descriptor, tag_ndm: '00281407', tag_ary: [0x0028,0x1407], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,1408)', tag_name: "Blending Lookup Table Data", tag_key: 'BlendingLookupTableData', tag_vr: [:OW], tag_vm: ["1"], tag_str: '(0028,1408)', tag_sym: :blending_lookup_table_data, tag_ndm: '00281408', tag_ary: [0x0028,0x1408], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,140B)', tag_name: "Enhanced Palette Color Lookup Table Sequence", tag_key: 'EnhancedPaletteColorLookupTableSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0028,140B)', tag_sym: :enhanced_palette_color_lookup_table_sequence, tag_ndm: '0028140B', tag_ary: [0x0028,0x140B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,140C)', tag_name: "Blending LUT 2 Sequence", tag_key: 'BlendingLUT2Sequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0028,140C)', tag_sym: :blending_lut2_sequence, tag_ndm: '0028140C', tag_ary: [0x0028,0x140C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,140D)', tag_name: "Blending LUT 2 Transfer Function", tag_key: 'BlendingLUT2TransferFunction', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0028,140D)', tag_sym: :blending_lut2_transfer_function, tag_ndm: '0028140D', tag_ary: [0x0028,0x140D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,140E)', tag_name: "Data Path ID", tag_key: 'DataPathID', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0028,140E)', tag_sym: :data_path_id, tag_ndm: '0028140E', tag_ary: [0x0028,0x140E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,140F)', tag_name: "RGB LUT Transfer Function", tag_key: 'RGBLUTTransferFunction', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0028,140F)', tag_sym: :rgb_lut_transfer_function, tag_ndm: '0028140F', tag_ary: [0x0028,0x140F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,1410)', tag_name: "Alpha LUT Transfer Function", tag_key: 'AlphaLUTTransferFunction', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0028,1410)', tag_sym: :alpha_lut_transfer_function, tag_ndm: '00281410', tag_ary: [0x0028,0x1410], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,2000)', tag_name: "ICC Profile", tag_key: 'ICCProfile', tag_vr: [:OB], tag_vm: ["1"], tag_str: '(0028,2000)', tag_sym: :icc_profile, tag_ndm: '00282000', tag_ary: [0x0028,0x2000], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,2002)', tag_name: "Color Space", tag_key: 'ColorSpace', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0028,2002)', tag_sym: :color_space, tag_ndm: '00282002', tag_ary: [0x0028,0x2002], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,2110)', tag_name: "Lossy Image Compression", tag_key: 'LossyImageCompression', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0028,2110)', tag_sym: :lossy_image_compression, tag_ndm: '00282110', tag_ary: [0x0028,0x2110], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,2112)', tag_name: "Lossy Image Compression Ratio", tag_key: 'LossyImageCompressionRatio', tag_vr: [:DS], tag_vm: ["1-n"], tag_str: '(0028,2112)', tag_sym: :lossy_image_compression_ratio, tag_ndm: '00282112', tag_ary: [0x0028,0x2112], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,2114)', tag_name: "Lossy Image Compression Method", tag_key: 'LossyImageCompressionMethod', tag_vr: [:CS], tag_vm: ["1-n"], tag_str: '(0028,2114)', tag_sym: :lossy_image_compression_method, tag_ndm: '00282114', tag_ary: [0x0028,0x2114], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,3000)', tag_name: "Modality LUT Sequence", tag_key: 'ModalityLUTSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0028,3000)', tag_sym: :modality_lut_sequence, tag_ndm: '00283000', tag_ary: [0x0028,0x3000], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,3001)', tag_name: "Variable Modality LUT Sequence", tag_key: 'VariableModalityLUTSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0028,3001)', tag_sym: :variable_modality_lut_sequence, tag_ndm: '00283001', tag_ary: [0x0028,0x3001], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,3002)', tag_name: "LUT Descriptor", tag_key: 'LUTDescriptor', tag_vr: [:US, :SS], tag_vm: ["3"], tag_str: '(0028,3002)', tag_sym: :lut_descriptor, tag_ndm: '00283002', tag_ary: [0x0028,0x3002], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,3003)', tag_name: "LUT Explanation", tag_key: 'LUTExplanation', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0028,3003)', tag_sym: :lut_explanation, tag_ndm: '00283003', tag_ary: [0x0028,0x3003], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,3004)', tag_name: "Modality LUT Type", tag_key: 'ModalityLUTType', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0028,3004)', tag_sym: :modality_lut_type, tag_ndm: '00283004', tag_ary: [0x0028,0x3004], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,3006)', tag_name: "LUT Data", tag_key: 'LUTData', tag_vr: [:US, :OW], tag_vm: ["1-n", "1"], tag_str: '(0028,3006)', tag_sym: :lut_data, tag_ndm: '00283006', tag_ary: [0x0028,0x3006], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,3010)', tag_name: "VOI LUT Sequence", tag_key: 'VOILUTSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0028,3010)', tag_sym: :voi_lut_sequence, tag_ndm: '00283010', tag_ary: [0x0028,0x3010], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,3110)', tag_name: "Softcopy VOI LUT Sequence", tag_key: 'SoftcopyVOILUTSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0028,3110)', tag_sym: :softcopy_voi_lut_sequence, tag_ndm: '00283110', tag_ary: [0x0028,0x3110], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,4000)', tag_name: "Image Presentation Comments", tag_key: 'ImagePresentationComments', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(0028,4000)', tag_sym: :image_presentation_comments, tag_ndm: '00284000', tag_ary: [0x0028,0x4000], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(0028,5000)', tag_name: "Bi-Plane Acquisition Sequence", tag_key: 'BiPlaneAcquisitionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0028,5000)', tag_sym: :bi_plane_acquisition_sequence, tag_ndm: '00285000', tag_ary: [0x0028,0x5000], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0028,6010)', tag_name: "Representative Frame Number", tag_key: 'RepresentativeFrameNumber', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0028,6010)', tag_sym: :representative_frame_number, tag_ndm: '00286010', tag_ary: [0x0028,0x6010], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,6020)', tag_name: "Frame Numbers of Interest (FOI)", tag_key: 'FrameNumbersOfInterest', tag_vr: [:US], tag_vm: ["1-n"], tag_str: '(0028,6020)', tag_sym: :frame_numbers_of_interest, tag_ndm: '00286020', tag_ary: [0x0028,0x6020], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,6022)', tag_name: "Frame of Interest Description", tag_key: 'FrameOfInterestDescription', tag_vr: [:LO], tag_vm: ["1-n"], tag_str: '(0028,6022)', tag_sym: :frame_of_interest_description, tag_ndm: '00286022', tag_ary: [0x0028,0x6022], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,6023)', tag_name: "Frame of Interest Type", tag_key: 'FrameOfInterestType', tag_vr: [:CS], tag_vm: ["1-n"], tag_str: '(0028,6023)', tag_sym: :frame_of_interest_type, tag_ndm: '00286023', tag_ary: [0x0028,0x6023], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,6030)', tag_name: "Mask Pointer(s)", tag_key: 'MaskPointers', tag_vr: [:US], tag_vm: ["1-n"], tag_str: '(0028,6030)', tag_sym: :mask_pointers, tag_ndm: '00286030', tag_ary: [0x0028,0x6030], tag_multiple: false, tag_note: 'RET (2001)'},
      { tag_ps: '(0028,6040)', tag_name: "R Wave Pointer", tag_key: 'RWavePointer', tag_vr: [:US], tag_vm: ["1-n"], tag_str: '(0028,6040)', tag_sym: :r_wave_pointer, tag_ndm: '00286040', tag_ary: [0x0028,0x6040], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,6100)', tag_name: "Mask Subtraction Sequence", tag_key: 'MaskSubtractionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0028,6100)', tag_sym: :mask_subtraction_sequence, tag_ndm: '00286100', tag_ary: [0x0028,0x6100], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,6101)', tag_name: "Mask Operation", tag_key: 'MaskOperation', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0028,6101)', tag_sym: :mask_operation, tag_ndm: '00286101', tag_ary: [0x0028,0x6101], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,6102)', tag_name: "Applicable Frame Range", tag_key: 'ApplicableFrameRange', tag_vr: [:US], tag_vm: ["2-2n"], tag_str: '(0028,6102)', tag_sym: :applicable_frame_range, tag_ndm: '00286102', tag_ary: [0x0028,0x6102], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,6110)', tag_name: "Mask Frame Numbers", tag_key: 'MaskFrameNumbers', tag_vr: [:US], tag_vm: ["1-n"], tag_str: '(0028,6110)', tag_sym: :mask_frame_numbers, tag_ndm: '00286110', tag_ary: [0x0028,0x6110], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,6112)', tag_name: "Contrast Frame Averaging", tag_key: 'ContrastFrameAveraging', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0028,6112)', tag_sym: :contrast_frame_averaging, tag_ndm: '00286112', tag_ary: [0x0028,0x6112], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,6114)', tag_name: "Mask Sub-pixel Shift", tag_key: 'MaskSubPixelShift', tag_vr: [:FL], tag_vm: ["2"], tag_str: '(0028,6114)', tag_sym: :mask_sub_pixel_shift, tag_ndm: '00286114', tag_ary: [0x0028,0x6114], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,6120)', tag_name: "TID Offset", tag_key: 'TIDOffset', tag_vr: [:SS], tag_vm: ["1"], tag_str: '(0028,6120)', tag_sym: :tid_offset, tag_ndm: '00286120', tag_ary: [0x0028,0x6120], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,6190)', tag_name: "Mask Operation Explanation", tag_key: 'MaskOperationExplanation', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0028,6190)', tag_sym: :mask_operation_explanation, tag_ndm: '00286190', tag_ary: [0x0028,0x6190], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,7000)', tag_name: "Equipment Administrator Sequence", tag_key: 'EquipmentAdministratorSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0028,7000)', tag_sym: :equipment_administrator_sequence, tag_ndm: '00287000', tag_ary: [0x0028,0x7000], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,7001)', tag_name: "Number of Display Subsystems", tag_key: 'NumberOfDisplaySubsystems', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0028,7001)', tag_sym: :number_of_display_subsystems, tag_ndm: '00287001', tag_ary: [0x0028,0x7001], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,7002)', tag_name: "Current Configuration ID", tag_key: 'CurrentConfigurationID', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0028,7002)', tag_sym: :current_configuration_id, tag_ndm: '00287002', tag_ary: [0x0028,0x7002], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,7003)', tag_name: "Display Subsystem ID", tag_key: 'DisplaySubsystemID', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0028,7003)', tag_sym: :display_subsystem_id, tag_ndm: '00287003', tag_ary: [0x0028,0x7003], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,7004)', tag_name: "Display Subsystem Name", tag_key: 'DisplaySubsystemName', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0028,7004)', tag_sym: :display_subsystem_name, tag_ndm: '00287004', tag_ary: [0x0028,0x7004], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,7005)', tag_name: "Display Subsystem Description", tag_key: 'DisplaySubsystemDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0028,7005)', tag_sym: :display_subsystem_description, tag_ndm: '00287005', tag_ary: [0x0028,0x7005], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,7006)', tag_name: "System Status", tag_key: 'SystemStatus', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0028,7006)', tag_sym: :system_status, tag_ndm: '00287006', tag_ary: [0x0028,0x7006], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,7007)', tag_name: "System Status Comment", tag_key: 'SystemStatusComment', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0028,7007)', tag_sym: :system_status_comment, tag_ndm: '00287007', tag_ary: [0x0028,0x7007], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,7008)', tag_name: "Target Luminance Characteristics Sequence", tag_key: 'TargetLuminanceCharacteristicsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0028,7008)', tag_sym: :target_luminance_characteristics_sequence, tag_ndm: '00287008', tag_ary: [0x0028,0x7008], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,7009)', tag_name: "Luminance Characteristics ID", tag_key: 'LuminanceCharacteristicsID', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0028,7009)', tag_sym: :luminance_characteristics_id, tag_ndm: '00287009', tag_ary: [0x0028,0x7009], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,700A)', tag_name: "Display Subsystem Configuration Sequence", tag_key: 'DisplaySubsystemConfigurationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0028,700A)', tag_sym: :display_subsystem_configuration_sequence, tag_ndm: '0028700A', tag_ary: [0x0028,0x700A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,700B)', tag_name: "Configuration ID", tag_key: 'ConfigurationID', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0028,700B)', tag_sym: :configuration_id, tag_ndm: '0028700B', tag_ary: [0x0028,0x700B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,700C)', tag_name: "Configuration Name", tag_key: 'ConfigurationName', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0028,700C)', tag_sym: :configuration_name, tag_ndm: '0028700C', tag_ary: [0x0028,0x700C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,700D)', tag_name: "Configuration Description", tag_key: 'ConfigurationDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0028,700D)', tag_sym: :configuration_description, tag_ndm: '0028700D', tag_ary: [0x0028,0x700D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,700E)', tag_name: "Referenced Target Luminance Characteristics ID", tag_key: 'ReferencedTargetLuminanceCharacteristicsID', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0028,700E)', tag_sym: :referenced_target_luminance_characteristics_id, tag_ndm: '0028700E', tag_ary: [0x0028,0x700E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,700F)', tag_name: "QA Results Sequence", tag_key: 'QAResultsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0028,700F)', tag_sym: :qa_results_sequence, tag_ndm: '0028700F', tag_ary: [0x0028,0x700F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,7010)', tag_name: "Display Subsystem QA Results Sequence", tag_key: 'DisplaySubsystemQAResultsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0028,7010)', tag_sym: :display_subsystem_qa_results_sequence, tag_ndm: '00287010', tag_ary: [0x0028,0x7010], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,7011)', tag_name: "Configuration QA Results Sequence", tag_key: 'ConfigurationQAResultsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0028,7011)', tag_sym: :configuration_qa_results_sequence, tag_ndm: '00287011', tag_ary: [0x0028,0x7011], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,7012)', tag_name: "Measurement Equipment Sequence", tag_key: 'MeasurementEquipmentSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0028,7012)', tag_sym: :measurement_equipment_sequence, tag_ndm: '00287012', tag_ary: [0x0028,0x7012], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,7013)', tag_name: "Measurement Functions", tag_key: 'MeasurementFunctions', tag_vr: [:CS], tag_vm: ["1-n"], tag_str: '(0028,7013)', tag_sym: :measurement_functions, tag_ndm: '00287013', tag_ary: [0x0028,0x7013], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,7014)', tag_name: "Measurement Equipment Type", tag_key: 'MeasurementEquipmentType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0028,7014)', tag_sym: :measurement_equipment_type, tag_ndm: '00287014', tag_ary: [0x0028,0x7014], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,7015)', tag_name: "Visual Evaluation Result Sequence", tag_key: 'VisualEvaluationResultSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0028,7015)', tag_sym: :visual_evaluation_result_sequence, tag_ndm: '00287015', tag_ary: [0x0028,0x7015], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,7016)', tag_name: "Display Calibration Result Sequence", tag_key: 'DisplayCalibrationResultSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0028,7016)', tag_sym: :display_calibration_result_sequence, tag_ndm: '00287016', tag_ary: [0x0028,0x7016], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,7017)', tag_name: "DDL Value", tag_key: 'DDLValue', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0028,7017)', tag_sym: :ddl_value, tag_ndm: '00287017', tag_ary: [0x0028,0x7017], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,7018)', tag_name: "CIExy White Point", tag_key: 'CIExyWhitePoint', tag_vr: [:FL], tag_vm: ["2"], tag_str: '(0028,7018)', tag_sym: :ciexy_white_point, tag_ndm: '00287018', tag_ary: [0x0028,0x7018], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,7019)', tag_name: "Display Function Type", tag_key: 'DisplayFunctionType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0028,7019)', tag_sym: :display_function_type, tag_ndm: '00287019', tag_ary: [0x0028,0x7019], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,701A)', tag_name: "Gamma Value", tag_key: 'GammaValue', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0028,701A)', tag_sym: :gamma_value, tag_ndm: '0028701A', tag_ary: [0x0028,0x701A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,701B)', tag_name: "Number of Luminance Points", tag_key: 'NumberOfLuminancePoints', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0028,701B)', tag_sym: :number_of_luminance_points, tag_ndm: '0028701B', tag_ary: [0x0028,0x701B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,701C)', tag_name: "Luminance Response Sequence", tag_key: 'LuminanceResponseSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0028,701C)', tag_sym: :luminance_response_sequence, tag_ndm: '0028701C', tag_ary: [0x0028,0x701C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,701D)', tag_name: "Target Minimum Luminance", tag_key: 'TargetMinimumLuminance', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0028,701D)', tag_sym: :target_minimum_luminance, tag_ndm: '0028701D', tag_ary: [0x0028,0x701D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,701E)', tag_name: "Target Maximum Luminance", tag_key: 'TargetMaximumLuminance', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0028,701E)', tag_sym: :target_maximum_luminance, tag_ndm: '0028701E', tag_ary: [0x0028,0x701E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,701F)', tag_name: "Luminance Value", tag_key: 'LuminanceValue', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0028,701F)', tag_sym: :luminance_value, tag_ndm: '0028701F', tag_ary: [0x0028,0x701F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,7020)', tag_name: "Luminance Response Description", tag_key: 'LuminanceResponseDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0028,7020)', tag_sym: :luminance_response_description, tag_ndm: '00287020', tag_ary: [0x0028,0x7020], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,7021)', tag_name: "White Point Flag", tag_key: 'WhitePointFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0028,7021)', tag_sym: :white_point_flag, tag_ndm: '00287021', tag_ary: [0x0028,0x7021], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,7022)', tag_name: "Display Device Type Code Sequence", tag_key: 'DisplayDeviceTypeCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0028,7022)', tag_sym: :display_device_type_code_sequence, tag_ndm: '00287022', tag_ary: [0x0028,0x7022], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,7023)', tag_name: "Display Subsystem Sequence", tag_key: 'DisplaySubsystemSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0028,7023)', tag_sym: :display_subsystem_sequence, tag_ndm: '00287023', tag_ary: [0x0028,0x7023], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,7024)', tag_name: "Luminance Result Sequence", tag_key: 'LuminanceResultSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0028,7024)', tag_sym: :luminance_result_sequence, tag_ndm: '00287024', tag_ary: [0x0028,0x7024], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,7025)', tag_name: "Ambient Light Value Source", tag_key: 'AmbientLightValueSource', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0028,7025)', tag_sym: :ambient_light_value_source, tag_ndm: '00287025', tag_ary: [0x0028,0x7025], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,7026)', tag_name: "Measured Characteristics", tag_key: 'MeasuredCharacteristics', tag_vr: [:CS], tag_vm: ["1-n"], tag_str: '(0028,7026)', tag_sym: :measured_characteristics, tag_ndm: '00287026', tag_ary: [0x0028,0x7026], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,7027)', tag_name: "Luminance Uniformity Result Sequence", tag_key: 'LuminanceUniformityResultSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0028,7027)', tag_sym: :luminance_uniformity_result_sequence, tag_ndm: '00287027', tag_ary: [0x0028,0x7027], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,7028)', tag_name: "Visual Evaluation Test Sequence", tag_key: 'VisualEvaluationTestSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0028,7028)', tag_sym: :visual_evaluation_test_sequence, tag_ndm: '00287028', tag_ary: [0x0028,0x7028], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,7029)', tag_name: "Test Result", tag_key: 'TestResult', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0028,7029)', tag_sym: :test_result, tag_ndm: '00287029', tag_ary: [0x0028,0x7029], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,702A)', tag_name: "Test Result Comment", tag_key: 'TestResultComment', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0028,702A)', tag_sym: :test_result_comment, tag_ndm: '0028702A', tag_ary: [0x0028,0x702A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,702B)', tag_name: "Test Image Validation", tag_key: 'TestImageValidation', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0028,702B)', tag_sym: :test_image_validation, tag_ndm: '0028702B', tag_ary: [0x0028,0x702B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,702C)', tag_name: "Test Pattern Code Sequence", tag_key: 'TestPatternCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0028,702C)', tag_sym: :test_pattern_code_sequence, tag_ndm: '0028702C', tag_ary: [0x0028,0x702C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,702D)', tag_name: "Measurement Pattern Code Sequence", tag_key: 'MeasurementPatternCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0028,702D)', tag_sym: :measurement_pattern_code_sequence, tag_ndm: '0028702D', tag_ary: [0x0028,0x702D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,702E)', tag_name: "Visual Evaluation Method Code Sequence", tag_key: 'VisualEvaluationMethodCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0028,702E)', tag_sym: :visual_evaluation_method_code_sequence, tag_ndm: '0028702E', tag_ary: [0x0028,0x702E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,7FE0)', tag_name: "Pixel Data Provider URL", tag_key: 'PixelDataProviderURL', tag_vr: [:UR], tag_vm: ["1"], tag_str: '(0028,7FE0)', tag_sym: :pixel_data_provider_url, tag_ndm: '00287FE0', tag_ary: [0x0028,0x7FE0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,9001)', tag_name: "Data Point Rows", tag_key: 'DataPointRows', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0028,9001)', tag_sym: :data_point_rows, tag_ndm: '00289001', tag_ary: [0x0028,0x9001], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,9002)', tag_name: "Data Point Columns", tag_key: 'DataPointColumns', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0028,9002)', tag_sym: :data_point_columns, tag_ndm: '00289002', tag_ary: [0x0028,0x9002], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,9003)', tag_name: "Signal Domain Columns", tag_key: 'SignalDomainColumns', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0028,9003)', tag_sym: :signal_domain_columns, tag_ndm: '00289003', tag_ary: [0x0028,0x9003], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,9099)', tag_name: "Largest Monochrome Pixel Value", tag_key: 'LargestMonochromePixelValue', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0028,9099)', tag_sym: :largest_monochrome_pixel_value, tag_ndm: '00289099', tag_ary: [0x0028,0x9099], tag_multiple: false, tag_note: 'RET (2003)'},
      { tag_ps: '(0028,9108)', tag_name: "Data Representation", tag_key: 'DataRepresentation', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0028,9108)', tag_sym: :data_representation, tag_ndm: '00289108', tag_ary: [0x0028,0x9108], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,9110)', tag_name: "Pixel Measures Sequence", tag_key: 'PixelMeasuresSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0028,9110)', tag_sym: :pixel_measures_sequence, tag_ndm: '00289110', tag_ary: [0x0028,0x9110], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,9132)', tag_name: "Frame VOI LUT Sequence", tag_key: 'FrameVOILUTSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0028,9132)', tag_sym: :frame_voi_lut_sequence, tag_ndm: '00289132', tag_ary: [0x0028,0x9132], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,9145)', tag_name: "Pixel Value Transformation Sequence", tag_key: 'PixelValueTransformationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0028,9145)', tag_sym: :pixel_value_transformation_sequence, tag_ndm: '00289145', tag_ary: [0x0028,0x9145], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,9235)', tag_name: "Signal Domain Rows", tag_key: 'SignalDomainRows', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0028,9235)', tag_sym: :signal_domain_rows, tag_ndm: '00289235', tag_ary: [0x0028,0x9235], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,9411)', tag_name: "Display Filter Percentage", tag_key: 'DisplayFilterPercentage', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0028,9411)', tag_sym: :display_filter_percentage, tag_ndm: '00289411', tag_ary: [0x0028,0x9411], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,9415)', tag_name: "Frame Pixel Shift Sequence", tag_key: 'FramePixelShiftSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0028,9415)', tag_sym: :frame_pixel_shift_sequence, tag_ndm: '00289415', tag_ary: [0x0028,0x9415], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,9416)', tag_name: "Subtraction Item ID", tag_key: 'SubtractionItemID', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0028,9416)', tag_sym: :subtraction_item_id, tag_ndm: '00289416', tag_ary: [0x0028,0x9416], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,9422)', tag_name: "Pixel Intensity Relationship LUT Sequence", tag_key: 'PixelIntensityRelationshipLUTSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0028,9422)', tag_sym: :pixel_intensity_relationship_lut_sequence, tag_ndm: '00289422', tag_ary: [0x0028,0x9422], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,9443)', tag_name: "Frame Pixel Data Properties Sequence", tag_key: 'FramePixelDataPropertiesSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0028,9443)', tag_sym: :frame_pixel_data_properties_sequence, tag_ndm: '00289443', tag_ary: [0x0028,0x9443], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,9444)', tag_name: "Geometrical Properties", tag_key: 'GeometricalProperties', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0028,9444)', tag_sym: :geometrical_properties, tag_ndm: '00289444', tag_ary: [0x0028,0x9444], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,9445)', tag_name: "Geometric Maximum Distortion", tag_key: 'GeometricMaximumDistortion', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0028,9445)', tag_sym: :geometric_maximum_distortion, tag_ndm: '00289445', tag_ary: [0x0028,0x9445], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,9446)', tag_name: "Image Processing Applied", tag_key: 'ImageProcessingApplied', tag_vr: [:CS], tag_vm: ["1-n"], tag_str: '(0028,9446)', tag_sym: :image_processing_applied, tag_ndm: '00289446', tag_ary: [0x0028,0x9446], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,9454)', tag_name: "Mask Selection Mode", tag_key: 'MaskSelectionMode', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0028,9454)', tag_sym: :mask_selection_mode, tag_ndm: '00289454', tag_ary: [0x0028,0x9454], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,9474)', tag_name: "LUT Function", tag_key: 'LUTFunction', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0028,9474)', tag_sym: :lut_function, tag_ndm: '00289474', tag_ary: [0x0028,0x9474], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,9478)', tag_name: "Mask Visibility Percentage", tag_key: 'MaskVisibilityPercentage', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0028,9478)', tag_sym: :mask_visibility_percentage, tag_ndm: '00289478', tag_ary: [0x0028,0x9478], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,9501)', tag_name: "Pixel Shift Sequence", tag_key: 'PixelShiftSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0028,9501)', tag_sym: :pixel_shift_sequence, tag_ndm: '00289501', tag_ary: [0x0028,0x9501], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,9502)', tag_name: "Region Pixel Shift Sequence", tag_key: 'RegionPixelShiftSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0028,9502)', tag_sym: :region_pixel_shift_sequence, tag_ndm: '00289502', tag_ary: [0x0028,0x9502], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,9503)', tag_name: "Vertices of the Region", tag_key: 'VerticesOfTheRegion', tag_vr: [:SS], tag_vm: ["2-2n"], tag_str: '(0028,9503)', tag_sym: :vertices_of_the_region, tag_ndm: '00289503', tag_ary: [0x0028,0x9503], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,9505)', tag_name: "Multi-frame Presentation Sequence", tag_key: 'MultiFramePresentationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0028,9505)', tag_sym: :multi_frame_presentation_sequence, tag_ndm: '00289505', tag_ary: [0x0028,0x9505], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,9506)', tag_name: "Pixel Shift Frame Range", tag_key: 'PixelShiftFrameRange', tag_vr: [:US], tag_vm: ["2-2n"], tag_str: '(0028,9506)', tag_sym: :pixel_shift_frame_range, tag_ndm: '00289506', tag_ary: [0x0028,0x9506], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,9507)', tag_name: "LUT Frame Range", tag_key: 'LUTFrameRange', tag_vr: [:US], tag_vm: ["2-2n"], tag_str: '(0028,9507)', tag_sym: :lut_frame_range, tag_ndm: '00289507', tag_ary: [0x0028,0x9507], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,9520)', tag_name: "Image to Equipment Mapping Matrix", tag_key: 'ImageToEquipmentMappingMatrix', tag_vr: [:DS], tag_vm: ["16"], tag_str: '(0028,9520)', tag_sym: :image_to_equipment_mapping_matrix, tag_ndm: '00289520', tag_ary: [0x0028,0x9520], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0028,9537)', tag_name: "Equipment Coordinate System Identification", tag_key: 'EquipmentCoordinateSystemIdentification', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0028,9537)', tag_sym: :equipment_coordinate_system_identification, tag_ndm: '00289537', tag_ary: [0x0028,0x9537], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0032,000A)', tag_name: "Study Status ID", tag_key: 'StudyStatusID', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0032,000A)', tag_sym: :study_status_id, tag_ndm: '0032000A', tag_ary: [0x0032,0x000A], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(0032,000C)', tag_name: "Study Priority ID", tag_key: 'StudyPriorityID', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0032,000C)', tag_sym: :study_priority_id, tag_ndm: '0032000C', tag_ary: [0x0032,0x000C], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(0032,0012)', tag_name: "Study ID Issuer", tag_key: 'StudyIDIssuer', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0032,0012)', tag_sym: :study_id_issuer, tag_ndm: '00320012', tag_ary: [0x0032,0x0012], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(0032,0032)', tag_name: "Study Verified Date", tag_key: 'StudyVerifiedDate', tag_vr: [:DA], tag_vm: ["1"], tag_str: '(0032,0032)', tag_sym: :study_verified_date, tag_ndm: '00320032', tag_ary: [0x0032,0x0032], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(0032,0033)', tag_name: "Study Verified Time", tag_key: 'StudyVerifiedTime', tag_vr: [:TM], tag_vm: ["1"], tag_str: '(0032,0033)', tag_sym: :study_verified_time, tag_ndm: '00320033', tag_ary: [0x0032,0x0033], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(0032,0034)', tag_name: "Study Read Date", tag_key: 'StudyReadDate', tag_vr: [:DA], tag_vm: ["1"], tag_str: '(0032,0034)', tag_sym: :study_read_date, tag_ndm: '00320034', tag_ary: [0x0032,0x0034], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(0032,0035)', tag_name: "Study Read Time", tag_key: 'StudyReadTime', tag_vr: [:TM], tag_vm: ["1"], tag_str: '(0032,0035)', tag_sym: :study_read_time, tag_ndm: '00320035', tag_ary: [0x0032,0x0035], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(0032,1000)', tag_name: "Scheduled Study Start Date", tag_key: 'ScheduledStudyStartDate', tag_vr: [:DA], tag_vm: ["1"], tag_str: '(0032,1000)', tag_sym: :scheduled_study_start_date, tag_ndm: '00321000', tag_ary: [0x0032,0x1000], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(0032,1001)', tag_name: "Scheduled Study Start Time", tag_key: 'ScheduledStudyStartTime', tag_vr: [:TM], tag_vm: ["1"], tag_str: '(0032,1001)', tag_sym: :scheduled_study_start_time, tag_ndm: '00321001', tag_ary: [0x0032,0x1001], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(0032,1010)', tag_name: "Scheduled Study Stop Date", tag_key: 'ScheduledStudyStopDate', tag_vr: [:DA], tag_vm: ["1"], tag_str: '(0032,1010)', tag_sym: :scheduled_study_stop_date, tag_ndm: '00321010', tag_ary: [0x0032,0x1010], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(0032,1011)', tag_name: "Scheduled Study Stop Time", tag_key: 'ScheduledStudyStopTime', tag_vr: [:TM], tag_vm: ["1"], tag_str: '(0032,1011)', tag_sym: :scheduled_study_stop_time, tag_ndm: '00321011', tag_ary: [0x0032,0x1011], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(0032,1020)', tag_name: "Scheduled Study Location", tag_key: 'ScheduledStudyLocation', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0032,1020)', tag_sym: :scheduled_study_location, tag_ndm: '00321020', tag_ary: [0x0032,0x1020], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(0032,1021)', tag_name: "Scheduled Study Location AE Title", tag_key: 'ScheduledStudyLocationAETitle', tag_vr: [:AE], tag_vm: ["1-n"], tag_str: '(0032,1021)', tag_sym: :scheduled_study_location_ae_title, tag_ndm: '00321021', tag_ary: [0x0032,0x1021], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(0032,1030)', tag_name: "Reason for Study", tag_key: 'ReasonForStudy', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0032,1030)', tag_sym: :reason_for_study, tag_ndm: '00321030', tag_ary: [0x0032,0x1030], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(0032,1031)', tag_name: "Requesting Physician Identification Sequence", tag_key: 'RequestingPhysicianIdentificationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0032,1031)', tag_sym: :requesting_physician_identification_sequence, tag_ndm: '00321031', tag_ary: [0x0032,0x1031], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0032,1032)', tag_name: "Requesting Physician", tag_key: 'RequestingPhysician', tag_vr: [:PN], tag_vm: ["1"], tag_str: '(0032,1032)', tag_sym: :requesting_physician, tag_ndm: '00321032', tag_ary: [0x0032,0x1032], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0032,1033)', tag_name: "Requesting Service", tag_key: 'RequestingService', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0032,1033)', tag_sym: :requesting_service, tag_ndm: '00321033', tag_ary: [0x0032,0x1033], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0032,1034)', tag_name: "Requesting Service Code Sequence", tag_key: 'RequestingServiceCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0032,1034)', tag_sym: :requesting_service_code_sequence, tag_ndm: '00321034', tag_ary: [0x0032,0x1034], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0032,1040)', tag_name: "Study Arrival Date", tag_key: 'StudyArrivalDate', tag_vr: [:DA], tag_vm: ["1"], tag_str: '(0032,1040)', tag_sym: :study_arrival_date, tag_ndm: '00321040', tag_ary: [0x0032,0x1040], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(0032,1041)', tag_name: "Study Arrival Time", tag_key: 'StudyArrivalTime', tag_vr: [:TM], tag_vm: ["1"], tag_str: '(0032,1041)', tag_sym: :study_arrival_time, tag_ndm: '00321041', tag_ary: [0x0032,0x1041], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(0032,1050)', tag_name: "Study Completion Date", tag_key: 'StudyCompletionDate', tag_vr: [:DA], tag_vm: ["1"], tag_str: '(0032,1050)', tag_sym: :study_completion_date, tag_ndm: '00321050', tag_ary: [0x0032,0x1050], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(0032,1051)', tag_name: "Study Completion Time", tag_key: 'StudyCompletionTime', tag_vr: [:TM], tag_vm: ["1"], tag_str: '(0032,1051)', tag_sym: :study_completion_time, tag_ndm: '00321051', tag_ary: [0x0032,0x1051], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(0032,1055)', tag_name: "Study Component Status ID", tag_key: 'StudyComponentStatusID', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0032,1055)', tag_sym: :study_component_status_id, tag_ndm: '00321055', tag_ary: [0x0032,0x1055], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(0032,1060)', tag_name: "Requested Procedure Description", tag_key: 'RequestedProcedureDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0032,1060)', tag_sym: :requested_procedure_description, tag_ndm: '00321060', tag_ary: [0x0032,0x1060], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0032,1064)', tag_name: "Requested Procedure Code Sequence", tag_key: 'RequestedProcedureCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0032,1064)', tag_sym: :requested_procedure_code_sequence, tag_ndm: '00321064', tag_ary: [0x0032,0x1064], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0032,1065)', tag_name: "Requested Laterality Code Sequence", tag_key: 'RequestedLateralityCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0032,1065)', tag_sym: :requested_laterality_code_sequence, tag_ndm: '00321065', tag_ary: [0x0032,0x1065], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0032,1066)', tag_name: "Reason for Visit", tag_key: 'ReasonForVisit', tag_vr: [:UT], tag_vm: ["1"], tag_str: '(0032,1066)', tag_sym: :reason_for_visit, tag_ndm: '00321066', tag_ary: [0x0032,0x1066], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0032,1067)', tag_name: "Reason for Visit Code Sequence", tag_key: 'ReasonForVisitCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0032,1067)', tag_sym: :reason_for_visit_code_sequence, tag_ndm: '00321067', tag_ary: [0x0032,0x1067], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0032,1070)', tag_name: "Requested Contrast Agent", tag_key: 'RequestedContrastAgent', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0032,1070)', tag_sym: :requested_contrast_agent, tag_ndm: '00321070', tag_ary: [0x0032,0x1070], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0032,4000)', tag_name: "Study Comments", tag_key: 'StudyComments', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(0032,4000)', tag_sym: :study_comments, tag_ndm: '00324000', tag_ary: [0x0032,0x4000], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0034,0001)', tag_name: "Flow Identifier Sequence", tag_key: 'FlowIdentifierSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0034,0001)', tag_sym: :flow_identifier_sequence, tag_ndm: '00340001', tag_ary: [0x0034,0x0001], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0034,0002)', tag_name: "Flow Identifier", tag_key: 'FlowIdentifier', tag_vr: [:OB], tag_vm: ["1"], tag_str: '(0034,0002)', tag_sym: :flow_identifier, tag_ndm: '00340002', tag_ary: [0x0034,0x0002], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0034,0003)', tag_name: "Flow Transfer Syntax UID", tag_key: 'FlowTransferSyntaxUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0034,0003)', tag_sym: :flow_transfer_syntax_uid, tag_ndm: '00340003', tag_ary: [0x0034,0x0003], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0034,0004)', tag_name: "Flow RTP Sampling Rate", tag_key: 'FlowRTPSamplingRate', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0034,0004)', tag_sym: :flow_rtp_sampling_rate, tag_ndm: '00340004', tag_ary: [0x0034,0x0004], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0034,0005)', tag_name: "Source Identifier", tag_key: 'SourceIdentifier', tag_vr: [:OB], tag_vm: ["1"], tag_str: '(0034,0005)', tag_sym: :source_identifier, tag_ndm: '00340005', tag_ary: [0x0034,0x0005], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0034,0007)', tag_name: "Frame Origin Timestamp", tag_key: 'FrameOriginTimestamp', tag_vr: [:OB], tag_vm: ["1"], tag_str: '(0034,0007)', tag_sym: :frame_origin_timestamp, tag_ndm: '00340007', tag_ary: [0x0034,0x0007], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0034,0008)', tag_name: "Includes Imaging Subject", tag_key: 'IncludesImagingSubject', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0034,0008)', tag_sym: :includes_imaging_subject, tag_ndm: '00340008', tag_ary: [0x0034,0x0008], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0034,0009)', tag_name: "Frame Usefulness Group Sequence", tag_key: 'FrameUsefulnessGroupSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0034,0009)', tag_sym: :frame_usefulness_group_sequence, tag_ndm: '00340009', tag_ary: [0x0034,0x0009], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0034,000A)', tag_name: "Real-Time Bulk Data Flow Sequence", tag_key: 'RealTimeBulkDataFlowSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0034,000A)', tag_sym: :real_time_bulk_data_flow_sequence, tag_ndm: '0034000A', tag_ary: [0x0034,0x000A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0034,000B)', tag_name: "Camera Position Group Sequence", tag_key: 'CameraPositionGroupSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0034,000B)', tag_sym: :camera_position_group_sequence, tag_ndm: '0034000B', tag_ary: [0x0034,0x000B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0034,000C)', tag_name: "Includes Information", tag_key: 'IncludesInformation', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0034,000C)', tag_sym: :includes_information, tag_ndm: '0034000C', tag_ary: [0x0034,0x000C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0034,000D)', tag_name: "Time of Frame Group Sequence", tag_key: 'TimeOfFrameGroupSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0034,000D)', tag_sym: :time_of_frame_group_sequence, tag_ndm: '0034000D', tag_ary: [0x0034,0x000D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0038,0004)', tag_name: "Referenced Patient Alias Sequence", tag_key: 'ReferencedPatientAliasSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0038,0004)', tag_sym: :referenced_patient_alias_sequence, tag_ndm: '00380004', tag_ary: [0x0038,0x0004], tag_multiple: false, tag_note: 'RET (2023d)'},
      { tag_ps: '(0038,0008)', tag_name: "Visit Status ID", tag_key: 'VisitStatusID', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0038,0008)', tag_sym: :visit_status_id, tag_ndm: '00380008', tag_ary: [0x0038,0x0008], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0038,0010)', tag_name: "Admission ID", tag_key: 'AdmissionID', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0038,0010)', tag_sym: :admission_id, tag_ndm: '00380010', tag_ary: [0x0038,0x0010], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0038,0011)', tag_name: "Issuer of Admission ID", tag_key: 'IssuerOfAdmissionID', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0038,0011)', tag_sym: :issuer_of_admission_id, tag_ndm: '00380011', tag_ary: [0x0038,0x0011], tag_multiple: false, tag_note: 'RET (2008)'},
      { tag_ps: '(0038,0014)', tag_name: "Issuer of Admission ID Sequence", tag_key: 'IssuerOfAdmissionIDSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0038,0014)', tag_sym: :issuer_of_admission_id_sequence, tag_ndm: '00380014', tag_ary: [0x0038,0x0014], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0038,0016)', tag_name: "Route of Admissions", tag_key: 'RouteOfAdmissions', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0038,0016)', tag_sym: :route_of_admissions, tag_ndm: '00380016', tag_ary: [0x0038,0x0016], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0038,001A)', tag_name: "Scheduled Admission Date", tag_key: 'ScheduledAdmissionDate', tag_vr: [:DA], tag_vm: ["1"], tag_str: '(0038,001A)', tag_sym: :scheduled_admission_date, tag_ndm: '0038001A', tag_ary: [0x0038,0x001A], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(0038,001B)', tag_name: "Scheduled Admission Time", tag_key: 'ScheduledAdmissionTime', tag_vr: [:TM], tag_vm: ["1"], tag_str: '(0038,001B)', tag_sym: :scheduled_admission_time, tag_ndm: '0038001B', tag_ary: [0x0038,0x001B], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(0038,001C)', tag_name: "Scheduled Discharge Date", tag_key: 'ScheduledDischargeDate', tag_vr: [:DA], tag_vm: ["1"], tag_str: '(0038,001C)', tag_sym: :scheduled_discharge_date, tag_ndm: '0038001C', tag_ary: [0x0038,0x001C], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(0038,001D)', tag_name: "Scheduled Discharge Time", tag_key: 'ScheduledDischargeTime', tag_vr: [:TM], tag_vm: ["1"], tag_str: '(0038,001D)', tag_sym: :scheduled_discharge_time, tag_ndm: '0038001D', tag_ary: [0x0038,0x001D], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(0038,001E)', tag_name: "Scheduled Patient Institution Residence", tag_key: 'ScheduledPatientInstitutionResidence', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0038,001E)', tag_sym: :scheduled_patient_institution_residence, tag_ndm: '0038001E', tag_ary: [0x0038,0x001E], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(0038,0020)', tag_name: "Admitting Date", tag_key: 'AdmittingDate', tag_vr: [:DA], tag_vm: ["1"], tag_str: '(0038,0020)', tag_sym: :admitting_date, tag_ndm: '00380020', tag_ary: [0x0038,0x0020], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0038,0021)', tag_name: "Admitting Time", tag_key: 'AdmittingTime', tag_vr: [:TM], tag_vm: ["1"], tag_str: '(0038,0021)', tag_sym: :admitting_time, tag_ndm: '00380021', tag_ary: [0x0038,0x0021], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0038,0030)', tag_name: "Discharge Date", tag_key: 'DischargeDate', tag_vr: [:DA], tag_vm: ["1"], tag_str: '(0038,0030)', tag_sym: :discharge_date, tag_ndm: '00380030', tag_ary: [0x0038,0x0030], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(0038,0032)', tag_name: "Discharge Time", tag_key: 'DischargeTime', tag_vr: [:TM], tag_vm: ["1"], tag_str: '(0038,0032)', tag_sym: :discharge_time, tag_ndm: '00380032', tag_ary: [0x0038,0x0032], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(0038,0040)', tag_name: "Discharge Diagnosis Description", tag_key: 'DischargeDiagnosisDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0038,0040)', tag_sym: :discharge_diagnosis_description, tag_ndm: '00380040', tag_ary: [0x0038,0x0040], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(0038,0044)', tag_name: "Discharge Diagnosis Code Sequence", tag_key: 'DischargeDiagnosisCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0038,0044)', tag_sym: :discharge_diagnosis_code_sequence, tag_ndm: '00380044', tag_ary: [0x0038,0x0044], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(0038,0050)', tag_name: "Special Needs", tag_key: 'SpecialNeeds', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0038,0050)', tag_sym: :special_needs, tag_ndm: '00380050', tag_ary: [0x0038,0x0050], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0038,0060)', tag_name: "Service Episode ID", tag_key: 'ServiceEpisodeID', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0038,0060)', tag_sym: :service_episode_id, tag_ndm: '00380060', tag_ary: [0x0038,0x0060], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0038,0061)', tag_name: "Issuer of Service Episode ID", tag_key: 'IssuerOfServiceEpisodeID', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0038,0061)', tag_sym: :issuer_of_service_episode_id, tag_ndm: '00380061', tag_ary: [0x0038,0x0061], tag_multiple: false, tag_note: 'RET (2008)'},
      { tag_ps: '(0038,0062)', tag_name: "Service Episode Description", tag_key: 'ServiceEpisodeDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0038,0062)', tag_sym: :service_episode_description, tag_ndm: '00380062', tag_ary: [0x0038,0x0062], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0038,0064)', tag_name: "Issuer of Service Episode ID Sequence", tag_key: 'IssuerOfServiceEpisodeIDSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0038,0064)', tag_sym: :issuer_of_service_episode_id_sequence, tag_ndm: '00380064', tag_ary: [0x0038,0x0064], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0038,0100)', tag_name: "Pertinent Documents Sequence", tag_key: 'PertinentDocumentsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0038,0100)', tag_sym: :pertinent_documents_sequence, tag_ndm: '00380100', tag_ary: [0x0038,0x0100], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0038,0101)', tag_name: "Pertinent Resources Sequence", tag_key: 'PertinentResourcesSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0038,0101)', tag_sym: :pertinent_resources_sequence, tag_ndm: '00380101', tag_ary: [0x0038,0x0101], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0038,0102)', tag_name: "Resource Description", tag_key: 'ResourceDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0038,0102)', tag_sym: :resource_description, tag_ndm: '00380102', tag_ary: [0x0038,0x0102], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0038,0300)', tag_name: "Current Patient Location", tag_key: 'CurrentPatientLocation', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0038,0300)', tag_sym: :current_patient_location, tag_ndm: '00380300', tag_ary: [0x0038,0x0300], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0038,0400)', tag_name: "Patient's Institution Residence", tag_key: 'PatientInstitutionResidence', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0038,0400)', tag_sym: :patient_institution_residence, tag_ndm: '00380400', tag_ary: [0x0038,0x0400], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0038,0500)', tag_name: "Patient State", tag_key: 'PatientState', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0038,0500)', tag_sym: :patient_state, tag_ndm: '00380500', tag_ary: [0x0038,0x0500], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0038,0502)', tag_name: "Patient Clinical Trial Participation Sequence", tag_key: 'PatientClinicalTrialParticipationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0038,0502)', tag_sym: :patient_clinical_trial_participation_sequence, tag_ndm: '00380502', tag_ary: [0x0038,0x0502], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0038,4000)', tag_name: "Visit Comments", tag_key: 'VisitComments', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(0038,4000)', tag_sym: :visit_comments, tag_ndm: '00384000', tag_ary: [0x0038,0x4000], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,0004)', tag_name: "Waveform Originality", tag_key: 'WaveformOriginality', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(003A,0004)', tag_sym: :waveform_originality, tag_ndm: '003A0004', tag_ary: [0x003A,0x0004], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,0005)', tag_name: "Number of Waveform Channels", tag_key: 'NumberOfWaveformChannels', tag_vr: [:US], tag_vm: ["1"], tag_str: '(003A,0005)', tag_sym: :number_of_waveform_channels, tag_ndm: '003A0005', tag_ary: [0x003A,0x0005], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,0010)', tag_name: "Number of Waveform Samples", tag_key: 'NumberOfWaveformSamples', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(003A,0010)', tag_sym: :number_of_waveform_samples, tag_ndm: '003A0010', tag_ary: [0x003A,0x0010], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,001A)', tag_name: "Sampling Frequency", tag_key: 'SamplingFrequency', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(003A,001A)', tag_sym: :sampling_frequency, tag_ndm: '003A001A', tag_ary: [0x003A,0x001A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,0020)', tag_name: "Multiplex Group Label", tag_key: 'MultiplexGroupLabel', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(003A,0020)', tag_sym: :multiplex_group_label, tag_ndm: '003A0020', tag_ary: [0x003A,0x0020], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,0200)', tag_name: "Channel Definition Sequence", tag_key: 'ChannelDefinitionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(003A,0200)', tag_sym: :channel_definition_sequence, tag_ndm: '003A0200', tag_ary: [0x003A,0x0200], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,0202)', tag_name: "Waveform Channel Number", tag_key: 'WaveformChannelNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(003A,0202)', tag_sym: :waveform_channel_number, tag_ndm: '003A0202', tag_ary: [0x003A,0x0202], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,0203)', tag_name: "Channel Label", tag_key: 'ChannelLabel', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(003A,0203)', tag_sym: :channel_label, tag_ndm: '003A0203', tag_ary: [0x003A,0x0203], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,0205)', tag_name: "Channel Status", tag_key: 'ChannelStatus', tag_vr: [:CS], tag_vm: ["1-n"], tag_str: '(003A,0205)', tag_sym: :channel_status, tag_ndm: '003A0205', tag_ary: [0x003A,0x0205], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,0208)', tag_name: "Channel Source Sequence", tag_key: 'ChannelSourceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(003A,0208)', tag_sym: :channel_source_sequence, tag_ndm: '003A0208', tag_ary: [0x003A,0x0208], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,0209)', tag_name: "Channel Source Modifiers Sequence", tag_key: 'ChannelSourceModifiersSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(003A,0209)', tag_sym: :channel_source_modifiers_sequence, tag_ndm: '003A0209', tag_ary: [0x003A,0x0209], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,020A)', tag_name: "Source Waveform Sequence", tag_key: 'SourceWaveformSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(003A,020A)', tag_sym: :source_waveform_sequence, tag_ndm: '003A020A', tag_ary: [0x003A,0x020A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,020C)', tag_name: "Channel Derivation Description", tag_key: 'ChannelDerivationDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(003A,020C)', tag_sym: :channel_derivation_description, tag_ndm: '003A020C', tag_ary: [0x003A,0x020C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,0210)', tag_name: "Channel Sensitivity", tag_key: 'ChannelSensitivity', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(003A,0210)', tag_sym: :channel_sensitivity, tag_ndm: '003A0210', tag_ary: [0x003A,0x0210], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,0211)', tag_name: "Channel Sensitivity Units Sequence", tag_key: 'ChannelSensitivityUnitsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(003A,0211)', tag_sym: :channel_sensitivity_units_sequence, tag_ndm: '003A0211', tag_ary: [0x003A,0x0211], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,0212)', tag_name: "Channel Sensitivity Correction Factor", tag_key: 'ChannelSensitivityCorrectionFactor', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(003A,0212)', tag_sym: :channel_sensitivity_correction_factor, tag_ndm: '003A0212', tag_ary: [0x003A,0x0212], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,0213)', tag_name: "Channel Baseline", tag_key: 'ChannelBaseline', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(003A,0213)', tag_sym: :channel_baseline, tag_ndm: '003A0213', tag_ary: [0x003A,0x0213], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,0214)', tag_name: "Channel Time Skew", tag_key: 'ChannelTimeSkew', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(003A,0214)', tag_sym: :channel_time_skew, tag_ndm: '003A0214', tag_ary: [0x003A,0x0214], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,0215)', tag_name: "Channel Sample Skew", tag_key: 'ChannelSampleSkew', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(003A,0215)', tag_sym: :channel_sample_skew, tag_ndm: '003A0215', tag_ary: [0x003A,0x0215], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,0218)', tag_name: "Channel Offset", tag_key: 'ChannelOffset', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(003A,0218)', tag_sym: :channel_offset, tag_ndm: '003A0218', tag_ary: [0x003A,0x0218], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,021A)', tag_name: "Waveform Bits Stored", tag_key: 'WaveformBitsStored', tag_vr: [:US], tag_vm: ["1"], tag_str: '(003A,021A)', tag_sym: :waveform_bits_stored, tag_ndm: '003A021A', tag_ary: [0x003A,0x021A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,0220)', tag_name: "Filter Low Frequency", tag_key: 'FilterLowFrequency', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(003A,0220)', tag_sym: :filter_low_frequency, tag_ndm: '003A0220', tag_ary: [0x003A,0x0220], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,0221)', tag_name: "Filter High Frequency", tag_key: 'FilterHighFrequency', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(003A,0221)', tag_sym: :filter_high_frequency, tag_ndm: '003A0221', tag_ary: [0x003A,0x0221], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,0222)', tag_name: "Notch Filter Frequency", tag_key: 'NotchFilterFrequency', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(003A,0222)', tag_sym: :notch_filter_frequency, tag_ndm: '003A0222', tag_ary: [0x003A,0x0222], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,0223)', tag_name: "Notch Filter Bandwidth", tag_key: 'NotchFilterBandwidth', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(003A,0223)', tag_sym: :notch_filter_bandwidth, tag_ndm: '003A0223', tag_ary: [0x003A,0x0223], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,0230)', tag_name: "Waveform Data Display Scale", tag_key: 'WaveformDataDisplayScale', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(003A,0230)', tag_sym: :waveform_data_display_scale, tag_ndm: '003A0230', tag_ary: [0x003A,0x0230], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,0231)', tag_name: "Waveform Display Background CIELab Value", tag_key: 'WaveformDisplayBackgroundCIELabValue', tag_vr: [:US], tag_vm: ["3"], tag_str: '(003A,0231)', tag_sym: :waveform_display_background_cie_lab_value, tag_ndm: '003A0231', tag_ary: [0x003A,0x0231], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,0240)', tag_name: "Waveform Presentation Group Sequence", tag_key: 'WaveformPresentationGroupSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(003A,0240)', tag_sym: :waveform_presentation_group_sequence, tag_ndm: '003A0240', tag_ary: [0x003A,0x0240], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,0241)', tag_name: "Presentation Group Number", tag_key: 'PresentationGroupNumber', tag_vr: [:US], tag_vm: ["1"], tag_str: '(003A,0241)', tag_sym: :presentation_group_number, tag_ndm: '003A0241', tag_ary: [0x003A,0x0241], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,0242)', tag_name: "Channel Display Sequence", tag_key: 'ChannelDisplaySequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(003A,0242)', tag_sym: :channel_display_sequence, tag_ndm: '003A0242', tag_ary: [0x003A,0x0242], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,0244)', tag_name: "Channel Recommended Display CIELab Value", tag_key: 'ChannelRecommendedDisplayCIELabValue', tag_vr: [:US], tag_vm: ["3"], tag_str: '(003A,0244)', tag_sym: :channel_recommended_display_cie_lab_value, tag_ndm: '003A0244', tag_ary: [0x003A,0x0244], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,0245)', tag_name: "Channel Position", tag_key: 'ChannelPosition', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(003A,0245)', tag_sym: :channel_position, tag_ndm: '003A0245', tag_ary: [0x003A,0x0245], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,0246)', tag_name: "Display Shading Flag", tag_key: 'DisplayShadingFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(003A,0246)', tag_sym: :display_shading_flag, tag_ndm: '003A0246', tag_ary: [0x003A,0x0246], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,0247)', tag_name: "Fractional Channel Display Scale", tag_key: 'FractionalChannelDisplayScale', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(003A,0247)', tag_sym: :fractional_channel_display_scale, tag_ndm: '003A0247', tag_ary: [0x003A,0x0247], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,0248)', tag_name: "Absolute Channel Display Scale", tag_key: 'AbsoluteChannelDisplayScale', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(003A,0248)', tag_sym: :absolute_channel_display_scale, tag_ndm: '003A0248', tag_ary: [0x003A,0x0248], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,0300)', tag_name: "Multiplexed Audio Channels Description Code Sequence", tag_key: 'MultiplexedAudioChannelsDescriptionCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(003A,0300)', tag_sym: :multiplexed_audio_channels_description_code_sequence, tag_ndm: '003A0300', tag_ary: [0x003A,0x0300], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,0301)', tag_name: "Channel Identification Code", tag_key: 'ChannelIdentificationCode', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(003A,0301)', tag_sym: :channel_identification_code, tag_ndm: '003A0301', tag_ary: [0x003A,0x0301], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,0302)', tag_name: "Channel Mode", tag_key: 'ChannelMode', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(003A,0302)', tag_sym: :channel_mode, tag_ndm: '003A0302', tag_ary: [0x003A,0x0302], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,0310)', tag_name: "Multiplex Group UID", tag_key: 'MultiplexGroupUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(003A,0310)', tag_sym: :multiplex_group_uid, tag_ndm: '003A0310', tag_ary: [0x003A,0x0310], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,0311)', tag_name: "Powerline Frequency", tag_key: 'PowerlineFrequency', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(003A,0311)', tag_sym: :powerline_frequency, tag_ndm: '003A0311', tag_ary: [0x003A,0x0311], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,0312)', tag_name: "Channel Impedance Sequence", tag_key: 'ChannelImpedanceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(003A,0312)', tag_sym: :channel_impedance_sequence, tag_ndm: '003A0312', tag_ary: [0x003A,0x0312], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,0313)', tag_name: "Impedance Value", tag_key: 'ImpedanceValue', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(003A,0313)', tag_sym: :impedance_value, tag_ndm: '003A0313', tag_ary: [0x003A,0x0313], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,0314)', tag_name: "Impedance Measurement DateTime", tag_key: 'ImpedanceMeasurementDateTime', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(003A,0314)', tag_sym: :impedance_measurement_date_time, tag_ndm: '003A0314', tag_ary: [0x003A,0x0314], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,0315)', tag_name: "Impedance Measurement Frequency", tag_key: 'ImpedanceMeasurementFrequency', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(003A,0315)', tag_sym: :impedance_measurement_frequency, tag_ndm: '003A0315', tag_ary: [0x003A,0x0315], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,0316)', tag_name: "Impedance Measurement Current Type", tag_key: 'ImpedanceMeasurementCurrentType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(003A,0316)', tag_sym: :impedance_measurement_current_type, tag_ndm: '003A0316', tag_ary: [0x003A,0x0316], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,0317)', tag_name: "Waveform Amplifier Type", tag_key: 'WaveformAmplifierType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(003A,0317)', tag_sym: :waveform_amplifier_type, tag_ndm: '003A0317', tag_ary: [0x003A,0x0317], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,0318)', tag_name: "Filter Low Frequency Characteristics Sequence", tag_key: 'FilterLowFrequencyCharacteristicsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(003A,0318)', tag_sym: :filter_low_frequency_characteristics_sequence, tag_ndm: '003A0318', tag_ary: [0x003A,0x0318], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,0319)', tag_name: "Filter High Frequency Characteristics Sequence", tag_key: 'FilterHighFrequencyCharacteristicsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(003A,0319)', tag_sym: :filter_high_frequency_characteristics_sequence, tag_ndm: '003A0319', tag_ary: [0x003A,0x0319], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,0320)', tag_name: "Summarized Filter Lookup Table Sequence", tag_key: 'SummarizedFilterLookupTableSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(003A,0320)', tag_sym: :summarized_filter_lookup_table_sequence, tag_ndm: '003A0320', tag_ary: [0x003A,0x0320], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,0321)', tag_name: "Notch Filter Characteristics Sequence", tag_key: 'NotchFilterCharacteristicsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(003A,0321)', tag_sym: :notch_filter_characteristics_sequence, tag_ndm: '003A0321', tag_ary: [0x003A,0x0321], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,0322)', tag_name: "Waveform Filter Type", tag_key: 'WaveformFilterType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(003A,0322)', tag_sym: :waveform_filter_type, tag_ndm: '003A0322', tag_ary: [0x003A,0x0322], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,0323)', tag_name: "Analog Filter Characteristics Sequence", tag_key: 'AnalogFilterCharacteristicsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(003A,0323)', tag_sym: :analog_filter_characteristics_sequence, tag_ndm: '003A0323', tag_ary: [0x003A,0x0323], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,0324)', tag_name: "Analog Filter Roll Off", tag_key: 'AnalogFilterRollOff', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(003A,0324)', tag_sym: :analog_filter_roll_off, tag_ndm: '003A0324', tag_ary: [0x003A,0x0324], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,0325)', tag_name: "Analog Filter Type Code Sequence", tag_key: 'AnalogFilterTypeCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(003A,0325)', tag_sym: :analog_filter_type_code_sequence, tag_ndm: '003A0325', tag_ary: [0x003A,0x0325], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,0326)', tag_name: "Digital Filter Characteristics Sequence", tag_key: 'DigitalFilterCharacteristicsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(003A,0326)', tag_sym: :digital_filter_characteristics_sequence, tag_ndm: '003A0326', tag_ary: [0x003A,0x0326], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,0327)', tag_name: "Digital Filter Order", tag_key: 'DigitalFilterOrder', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(003A,0327)', tag_sym: :digital_filter_order, tag_ndm: '003A0327', tag_ary: [0x003A,0x0327], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,0328)', tag_name: "Digital Filter Type Code Sequence", tag_key: 'DigitalFilterTypeCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(003A,0328)', tag_sym: :digital_filter_type_code_sequence, tag_ndm: '003A0328', tag_ary: [0x003A,0x0328], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,0329)', tag_name: "Waveform Filter Description", tag_key: 'WaveformFilterDescription', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(003A,0329)', tag_sym: :waveform_filter_description, tag_ndm: '003A0329', tag_ary: [0x003A,0x0329], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,032A)', tag_name: "Filter Lookup Table Sequence", tag_key: 'FilterLookupTableSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(003A,032A)', tag_sym: :filter_lookup_table_sequence, tag_ndm: '003A032A', tag_ary: [0x003A,0x032A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,032B)', tag_name: "Filter Lookup Table Description", tag_key: 'FilterLookupTableDescription', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(003A,032B)', tag_sym: :filter_lookup_table_description, tag_ndm: '003A032B', tag_ary: [0x003A,0x032B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,032C)', tag_name: "Frequency Encoding Code Sequence", tag_key: 'FrequencyEncodingCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(003A,032C)', tag_sym: :frequency_encoding_code_sequence, tag_ndm: '003A032C', tag_ary: [0x003A,0x032C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,032D)', tag_name: "Magnitude Encoding Code Sequence", tag_key: 'MagnitudeEncodingCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(003A,032D)', tag_sym: :magnitude_encoding_code_sequence, tag_ndm: '003A032D', tag_ary: [0x003A,0x032D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(003A,032E)', tag_name: "Filter Lookup Table Data", tag_key: 'FilterLookupTableData', tag_vr: [:OD], tag_vm: ["1"], tag_str: '(003A,032E)', tag_sym: :filter_lookup_table_data, tag_ndm: '003A032E', tag_ary: [0x003A,0x032E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0001)', tag_name: "Scheduled Station AE Title", tag_key: 'ScheduledStationAETitle', tag_vr: [:AE], tag_vm: ["1-n"], tag_str: '(0040,0001)', tag_sym: :scheduled_station_ae_title, tag_ndm: '00400001', tag_ary: [0x0040,0x0001], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0002)', tag_name: "Scheduled Procedure Step Start Date", tag_key: 'ScheduledProcedureStepStartDate', tag_vr: [:DA], tag_vm: ["1"], tag_str: '(0040,0002)', tag_sym: :scheduled_procedure_step_start_date, tag_ndm: '00400002', tag_ary: [0x0040,0x0002], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0003)', tag_name: "Scheduled Procedure Step Start Time", tag_key: 'ScheduledProcedureStepStartTime', tag_vr: [:TM], tag_vm: ["1"], tag_str: '(0040,0003)', tag_sym: :scheduled_procedure_step_start_time, tag_ndm: '00400003', tag_ary: [0x0040,0x0003], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0004)', tag_name: "Scheduled Procedure Step End Date", tag_key: 'ScheduledProcedureStepEndDate', tag_vr: [:DA], tag_vm: ["1"], tag_str: '(0040,0004)', tag_sym: :scheduled_procedure_step_end_date, tag_ndm: '00400004', tag_ary: [0x0040,0x0004], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0005)', tag_name: "Scheduled Procedure Step End Time", tag_key: 'ScheduledProcedureStepEndTime', tag_vr: [:TM], tag_vm: ["1"], tag_str: '(0040,0005)', tag_sym: :scheduled_procedure_step_end_time, tag_ndm: '00400005', tag_ary: [0x0040,0x0005], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0006)', tag_name: "Scheduled Performing Physician's Name", tag_key: 'ScheduledPerformingPhysicianName', tag_vr: [:PN], tag_vm: ["1"], tag_str: '(0040,0006)', tag_sym: :scheduled_performing_physician_name, tag_ndm: '00400006', tag_ary: [0x0040,0x0006], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0007)', tag_name: "Scheduled Procedure Step Description", tag_key: 'ScheduledProcedureStepDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0040,0007)', tag_sym: :scheduled_procedure_step_description, tag_ndm: '00400007', tag_ary: [0x0040,0x0007], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0008)', tag_name: "Scheduled Protocol Code Sequence", tag_key: 'ScheduledProtocolCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,0008)', tag_sym: :scheduled_protocol_code_sequence, tag_ndm: '00400008', tag_ary: [0x0040,0x0008], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0009)', tag_name: "Scheduled Procedure Step ID", tag_key: 'ScheduledProcedureStepID', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0040,0009)', tag_sym: :scheduled_procedure_step_id, tag_ndm: '00400009', tag_ary: [0x0040,0x0009], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,000A)', tag_name: "Stage Code Sequence", tag_key: 'StageCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,000A)', tag_sym: :stage_code_sequence, tag_ndm: '0040000A', tag_ary: [0x0040,0x000A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,000B)', tag_name: "Scheduled Performing Physician Identification Sequence", tag_key: 'ScheduledPerformingPhysicianIdentificationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,000B)', tag_sym: :scheduled_performing_physician_identification_sequence, tag_ndm: '0040000B', tag_ary: [0x0040,0x000B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0010)', tag_name: "Scheduled Station Name", tag_key: 'ScheduledStationName', tag_vr: [:SH], tag_vm: ["1-n"], tag_str: '(0040,0010)', tag_sym: :scheduled_station_name, tag_ndm: '00400010', tag_ary: [0x0040,0x0010], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0011)', tag_name: "Scheduled Procedure Step Location", tag_key: 'ScheduledProcedureStepLocation', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0040,0011)', tag_sym: :scheduled_procedure_step_location, tag_ndm: '00400011', tag_ary: [0x0040,0x0011], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0012)', tag_name: "Pre-Medication", tag_key: 'PreMedication', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0040,0012)', tag_sym: :pre_medication, tag_ndm: '00400012', tag_ary: [0x0040,0x0012], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0020)', tag_name: "Scheduled Procedure Step Status", tag_key: 'ScheduledProcedureStepStatus', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0040,0020)', tag_sym: :scheduled_procedure_step_status, tag_ndm: '00400020', tag_ary: [0x0040,0x0020], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0026)', tag_name: "Order Placer Identifier Sequence", tag_key: 'OrderPlacerIdentifierSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,0026)', tag_sym: :order_placer_identifier_sequence, tag_ndm: '00400026', tag_ary: [0x0040,0x0026], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0027)', tag_name: "Order Filler Identifier Sequence", tag_key: 'OrderFillerIdentifierSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,0027)', tag_sym: :order_filler_identifier_sequence, tag_ndm: '00400027', tag_ary: [0x0040,0x0027], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0031)', tag_name: "Local Namespace Entity ID", tag_key: 'LocalNamespaceEntityID', tag_vr: [:UT], tag_vm: ["1"], tag_str: '(0040,0031)', tag_sym: :local_namespace_entity_id, tag_ndm: '00400031', tag_ary: [0x0040,0x0031], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0032)', tag_name: "Universal Entity ID", tag_key: 'UniversalEntityID', tag_vr: [:UT], tag_vm: ["1"], tag_str: '(0040,0032)', tag_sym: :universal_entity_id, tag_ndm: '00400032', tag_ary: [0x0040,0x0032], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0033)', tag_name: "Universal Entity ID Type", tag_key: 'UniversalEntityIDType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0040,0033)', tag_sym: :universal_entity_id_type, tag_ndm: '00400033', tag_ary: [0x0040,0x0033], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0035)', tag_name: "Identifier Type Code", tag_key: 'IdentifierTypeCode', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0040,0035)', tag_sym: :identifier_type_code, tag_ndm: '00400035', tag_ary: [0x0040,0x0035], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0036)', tag_name: "Assigning Facility Sequence", tag_key: 'AssigningFacilitySequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,0036)', tag_sym: :assigning_facility_sequence, tag_ndm: '00400036', tag_ary: [0x0040,0x0036], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0039)', tag_name: "Assigning Jurisdiction Code Sequence", tag_key: 'AssigningJurisdictionCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,0039)', tag_sym: :assigning_jurisdiction_code_sequence, tag_ndm: '00400039', tag_ary: [0x0040,0x0039], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,003A)', tag_name: "Assigning Agency or Department Code Sequence", tag_key: 'AssigningAgencyOrDepartmentCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,003A)', tag_sym: :assigning_agency_or_department_code_sequence, tag_ndm: '0040003A', tag_ary: [0x0040,0x003A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0100)', tag_name: "Scheduled Procedure Step Sequence", tag_key: 'ScheduledProcedureStepSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,0100)', tag_sym: :scheduled_procedure_step_sequence, tag_ndm: '00400100', tag_ary: [0x0040,0x0100], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0220)', tag_name: "Referenced Non-Image Composite SOP Instance Sequence", tag_key: 'ReferencedNonImageCompositeSOPInstanceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,0220)', tag_sym: :referenced_non_image_composite_sop_instance_sequence, tag_ndm: '00400220', tag_ary: [0x0040,0x0220], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0241)', tag_name: "Performed Station AE Title", tag_key: 'PerformedStationAETitle', tag_vr: [:AE], tag_vm: ["1"], tag_str: '(0040,0241)', tag_sym: :performed_station_ae_title, tag_ndm: '00400241', tag_ary: [0x0040,0x0241], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0242)', tag_name: "Performed Station Name", tag_key: 'PerformedStationName', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0040,0242)', tag_sym: :performed_station_name, tag_ndm: '00400242', tag_ary: [0x0040,0x0242], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0243)', tag_name: "Performed Location", tag_key: 'PerformedLocation', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0040,0243)', tag_sym: :performed_location, tag_ndm: '00400243', tag_ary: [0x0040,0x0243], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0244)', tag_name: "Performed Procedure Step Start Date", tag_key: 'PerformedProcedureStepStartDate', tag_vr: [:DA], tag_vm: ["1"], tag_str: '(0040,0244)', tag_sym: :performed_procedure_step_start_date, tag_ndm: '00400244', tag_ary: [0x0040,0x0244], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0245)', tag_name: "Performed Procedure Step Start Time", tag_key: 'PerformedProcedureStepStartTime', tag_vr: [:TM], tag_vm: ["1"], tag_str: '(0040,0245)', tag_sym: :performed_procedure_step_start_time, tag_ndm: '00400245', tag_ary: [0x0040,0x0245], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0250)', tag_name: "Performed Procedure Step End Date", tag_key: 'PerformedProcedureStepEndDate', tag_vr: [:DA], tag_vm: ["1"], tag_str: '(0040,0250)', tag_sym: :performed_procedure_step_end_date, tag_ndm: '00400250', tag_ary: [0x0040,0x0250], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0251)', tag_name: "Performed Procedure Step End Time", tag_key: 'PerformedProcedureStepEndTime', tag_vr: [:TM], tag_vm: ["1"], tag_str: '(0040,0251)', tag_sym: :performed_procedure_step_end_time, tag_ndm: '00400251', tag_ary: [0x0040,0x0251], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0252)', tag_name: "Performed Procedure Step Status", tag_key: 'PerformedProcedureStepStatus', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0040,0252)', tag_sym: :performed_procedure_step_status, tag_ndm: '00400252', tag_ary: [0x0040,0x0252], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0253)', tag_name: "Performed Procedure Step ID", tag_key: 'PerformedProcedureStepID', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0040,0253)', tag_sym: :performed_procedure_step_id, tag_ndm: '00400253', tag_ary: [0x0040,0x0253], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0254)', tag_name: "Performed Procedure Step Description", tag_key: 'PerformedProcedureStepDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0040,0254)', tag_sym: :performed_procedure_step_description, tag_ndm: '00400254', tag_ary: [0x0040,0x0254], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0255)', tag_name: "Performed Procedure Type Description", tag_key: 'PerformedProcedureTypeDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0040,0255)', tag_sym: :performed_procedure_type_description, tag_ndm: '00400255', tag_ary: [0x0040,0x0255], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0260)', tag_name: "Performed Protocol Code Sequence", tag_key: 'PerformedProtocolCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,0260)', tag_sym: :performed_protocol_code_sequence, tag_ndm: '00400260', tag_ary: [0x0040,0x0260], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0261)', tag_name: "Performed Protocol Type", tag_key: 'PerformedProtocolType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0040,0261)', tag_sym: :performed_protocol_type, tag_ndm: '00400261', tag_ary: [0x0040,0x0261], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0270)', tag_name: "Scheduled Step Attributes Sequence", tag_key: 'ScheduledStepAttributesSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,0270)', tag_sym: :scheduled_step_attributes_sequence, tag_ndm: '00400270', tag_ary: [0x0040,0x0270], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0275)', tag_name: "Request Attributes Sequence", tag_key: 'RequestAttributesSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,0275)', tag_sym: :request_attributes_sequence, tag_ndm: '00400275', tag_ary: [0x0040,0x0275], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0280)', tag_name: "Comments on the Performed Procedure Step", tag_key: 'CommentsOnThePerformedProcedureStep', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0040,0280)', tag_sym: :comments_on_the_performed_procedure_step, tag_ndm: '00400280', tag_ary: [0x0040,0x0280], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0281)', tag_name: "Performed Procedure Step Discontinuation Reason Code Sequence", tag_key: 'PerformedProcedureStepDiscontinuationReasonCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,0281)', tag_sym: :performed_procedure_step_discontinuation_reason_code_sequence, tag_ndm: '00400281', tag_ary: [0x0040,0x0281], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0293)', tag_name: "Quantity Sequence", tag_key: 'QuantitySequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,0293)', tag_sym: :quantity_sequence, tag_ndm: '00400293', tag_ary: [0x0040,0x0293], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0294)', tag_name: "Quantity", tag_key: 'Quantity', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0040,0294)', tag_sym: :quantity, tag_ndm: '00400294', tag_ary: [0x0040,0x0294], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0295)', tag_name: "Measuring Units Sequence", tag_key: 'MeasuringUnitsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,0295)', tag_sym: :measuring_units_sequence, tag_ndm: '00400295', tag_ary: [0x0040,0x0295], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0296)', tag_name: "Billing Item Sequence", tag_key: 'BillingItemSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,0296)', tag_sym: :billing_item_sequence, tag_ndm: '00400296', tag_ary: [0x0040,0x0296], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0300)', tag_name: "Total Time of Fluoroscopy", tag_key: 'TotalTimeOfFluoroscopy', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0040,0300)', tag_sym: :total_time_of_fluoroscopy, tag_ndm: '00400300', tag_ary: [0x0040,0x0300], tag_multiple: false, tag_note: 'RET (2017c)'},
      { tag_ps: '(0040,0301)', tag_name: "Total Number of Exposures", tag_key: 'TotalNumberOfExposures', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0040,0301)', tag_sym: :total_number_of_exposures, tag_ndm: '00400301', tag_ary: [0x0040,0x0301], tag_multiple: false, tag_note: 'RET (2017c)'},
      { tag_ps: '(0040,0302)', tag_name: "Entrance Dose", tag_key: 'EntranceDose', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0040,0302)', tag_sym: :entrance_dose, tag_ndm: '00400302', tag_ary: [0x0040,0x0302], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0303)', tag_name: "Exposed Area", tag_key: 'ExposedArea', tag_vr: [:US], tag_vm: ["1-2"], tag_str: '(0040,0303)', tag_sym: :exposed_area, tag_ndm: '00400303', tag_ary: [0x0040,0x0303], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0306)', tag_name: "Distance Source to Entrance", tag_key: 'DistanceSourceToEntrance', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0040,0306)', tag_sym: :distance_source_to_entrance, tag_ndm: '00400306', tag_ary: [0x0040,0x0306], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0307)', tag_name: "Distance Source to Support", tag_key: 'DistanceSourceToSupport', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0040,0307)', tag_sym: :distance_source_to_support, tag_ndm: '00400307', tag_ary: [0x0040,0x0307], tag_multiple: false, tag_note: 'RET (2001)'},
      { tag_ps: '(0040,030E)', tag_name: "Exposure Dose Sequence", tag_key: 'ExposureDoseSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,030E)', tag_sym: :exposure_dose_sequence, tag_ndm: '0040030E', tag_ary: [0x0040,0x030E], tag_multiple: false, tag_note: 'RET (2017c)'},
      { tag_ps: '(0040,0310)', tag_name: "Comments on Radiation Dose", tag_key: 'CommentsOnRadiationDose', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0040,0310)', tag_sym: :comments_on_radiation_dose, tag_ndm: '00400310', tag_ary: [0x0040,0x0310], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0312)', tag_name: "X-Ray Output", tag_key: 'XRayOutput', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0040,0312)', tag_sym: :x_ray_output, tag_ndm: '00400312', tag_ary: [0x0040,0x0312], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0314)', tag_name: "Half Value Layer", tag_key: 'HalfValueLayer', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0040,0314)', tag_sym: :half_value_layer, tag_ndm: '00400314', tag_ary: [0x0040,0x0314], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0316)', tag_name: "Organ Dose", tag_key: 'OrganDose', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0040,0316)', tag_sym: :organ_dose, tag_ndm: '00400316', tag_ary: [0x0040,0x0316], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0318)', tag_name: "Organ Exposed", tag_key: 'OrganExposed', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0040,0318)', tag_sym: :organ_exposed, tag_ndm: '00400318', tag_ary: [0x0040,0x0318], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0320)', tag_name: "Billing Procedure Step Sequence", tag_key: 'BillingProcedureStepSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,0320)', tag_sym: :billing_procedure_step_sequence, tag_ndm: '00400320', tag_ary: [0x0040,0x0320], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0321)', tag_name: "Film Consumption Sequence", tag_key: 'FilmConsumptionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,0321)', tag_sym: :film_consumption_sequence, tag_ndm: '00400321', tag_ary: [0x0040,0x0321], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0324)', tag_name: "Billing Supplies and Devices Sequence", tag_key: 'BillingSuppliesAndDevicesSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,0324)', tag_sym: :billing_supplies_and_devices_sequence, tag_ndm: '00400324', tag_ary: [0x0040,0x0324], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0330)', tag_name: "Referenced Procedure Step Sequence", tag_key: 'ReferencedProcedureStepSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,0330)', tag_sym: :referenced_procedure_step_sequence, tag_ndm: '00400330', tag_ary: [0x0040,0x0330], tag_multiple: false, tag_note: 'RET (2001)'},
      { tag_ps: '(0040,0340)', tag_name: "Performed Series Sequence", tag_key: 'PerformedSeriesSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,0340)', tag_sym: :performed_series_sequence, tag_ndm: '00400340', tag_ary: [0x0040,0x0340], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0400)', tag_name: "Comments on the Scheduled Procedure Step", tag_key: 'CommentsOnTheScheduledProcedureStep', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(0040,0400)', tag_sym: :comments_on_the_scheduled_procedure_step, tag_ndm: '00400400', tag_ary: [0x0040,0x0400], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0440)', tag_name: "Protocol Context Sequence", tag_key: 'ProtocolContextSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,0440)', tag_sym: :protocol_context_sequence, tag_ndm: '00400440', tag_ary: [0x0040,0x0440], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0441)', tag_name: "Content Item Modifier Sequence", tag_key: 'ContentItemModifierSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,0441)', tag_sym: :content_item_modifier_sequence, tag_ndm: '00400441', tag_ary: [0x0040,0x0441], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0500)', tag_name: "Scheduled Specimen Sequence", tag_key: 'ScheduledSpecimenSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,0500)', tag_sym: :scheduled_specimen_sequence, tag_ndm: '00400500', tag_ary: [0x0040,0x0500], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,050A)', tag_name: "Specimen Accession Number", tag_key: 'SpecimenAccessionNumber', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0040,050A)', tag_sym: :specimen_accession_number, tag_ndm: '0040050A', tag_ary: [0x0040,0x050A], tag_multiple: false, tag_note: 'RET (2008)'},
      { tag_ps: '(0040,0512)', tag_name: "Container Identifier", tag_key: 'ContainerIdentifier', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0040,0512)', tag_sym: :container_identifier, tag_ndm: '00400512', tag_ary: [0x0040,0x0512], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0513)', tag_name: "Issuer of the Container Identifier Sequence", tag_key: 'IssuerOfTheContainerIdentifierSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,0513)', tag_sym: :issuer_of_the_container_identifier_sequence, tag_ndm: '00400513', tag_ary: [0x0040,0x0513], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0515)', tag_name: "Alternate Container Identifier Sequence", tag_key: 'AlternateContainerIdentifierSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,0515)', tag_sym: :alternate_container_identifier_sequence, tag_ndm: '00400515', tag_ary: [0x0040,0x0515], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0518)', tag_name: "Container Type Code Sequence", tag_key: 'ContainerTypeCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,0518)', tag_sym: :container_type_code_sequence, tag_ndm: '00400518', tag_ary: [0x0040,0x0518], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,051A)', tag_name: "Container Description", tag_key: 'ContainerDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0040,051A)', tag_sym: :container_description, tag_ndm: '0040051A', tag_ary: [0x0040,0x051A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0520)', tag_name: "Container Component Sequence", tag_key: 'ContainerComponentSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,0520)', tag_sym: :container_component_sequence, tag_ndm: '00400520', tag_ary: [0x0040,0x0520], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0550)', tag_name: "Specimen Sequence", tag_key: 'SpecimenSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,0550)', tag_sym: :specimen_sequence, tag_ndm: '00400550', tag_ary: [0x0040,0x0550], tag_multiple: false, tag_note: 'RET (2008)'},
      { tag_ps: '(0040,0551)', tag_name: "Specimen Identifier", tag_key: 'SpecimenIdentifier', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0040,0551)', tag_sym: :specimen_identifier, tag_ndm: '00400551', tag_ary: [0x0040,0x0551], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0552)', tag_name: "Specimen Description Sequence (Trial)", tag_key: 'SpecimenDescriptionSequenceTrial', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,0552)', tag_sym: :specimen_description_sequence_trial, tag_ndm: '00400552', tag_ary: [0x0040,0x0552], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0040,0553)', tag_name: "Specimen Description (Trial)", tag_key: 'SpecimenDescriptionTrial', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0040,0553)', tag_sym: :specimen_description_trial, tag_ndm: '00400553', tag_ary: [0x0040,0x0553], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0040,0554)', tag_name: "Specimen UID", tag_key: 'SpecimenUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0040,0554)', tag_sym: :specimen_uid, tag_ndm: '00400554', tag_ary: [0x0040,0x0554], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0555)', tag_name: "Acquisition Context Sequence", tag_key: 'AcquisitionContextSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,0555)', tag_sym: :acquisition_context_sequence, tag_ndm: '00400555', tag_ary: [0x0040,0x0555], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0556)', tag_name: "Acquisition Context Description", tag_key: 'AcquisitionContextDescription', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0040,0556)', tag_sym: :acquisition_context_description, tag_ndm: '00400556', tag_ary: [0x0040,0x0556], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,059A)', tag_name: "Specimen Type Code Sequence", tag_key: 'SpecimenTypeCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,059A)', tag_sym: :specimen_type_code_sequence, tag_ndm: '0040059A', tag_ary: [0x0040,0x059A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0560)', tag_name: "Specimen Description Sequence", tag_key: 'SpecimenDescriptionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,0560)', tag_sym: :specimen_description_sequence, tag_ndm: '00400560', tag_ary: [0x0040,0x0560], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0562)', tag_name: "Issuer of the Specimen Identifier Sequence", tag_key: 'IssuerOfTheSpecimenIdentifierSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,0562)', tag_sym: :issuer_of_the_specimen_identifier_sequence, tag_ndm: '00400562', tag_ary: [0x0040,0x0562], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0600)', tag_name: "Specimen Short Description", tag_key: 'SpecimenShortDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0040,0600)', tag_sym: :specimen_short_description, tag_ndm: '00400600', tag_ary: [0x0040,0x0600], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0602)', tag_name: "Specimen Detailed Description", tag_key: 'SpecimenDetailedDescription', tag_vr: [:UT], tag_vm: ["1"], tag_str: '(0040,0602)', tag_sym: :specimen_detailed_description, tag_ndm: '00400602', tag_ary: [0x0040,0x0602], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0610)', tag_name: "Specimen Preparation Sequence", tag_key: 'SpecimenPreparationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,0610)', tag_sym: :specimen_preparation_sequence, tag_ndm: '00400610', tag_ary: [0x0040,0x0610], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0612)', tag_name: "Specimen Preparation Step Content Item Sequence", tag_key: 'SpecimenPreparationStepContentItemSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,0612)', tag_sym: :specimen_preparation_step_content_item_sequence, tag_ndm: '00400612', tag_ary: [0x0040,0x0612], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,0620)', tag_name: "Specimen Localization Content Item Sequence", tag_key: 'SpecimenLocalizationContentItemSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,0620)', tag_sym: :specimen_localization_content_item_sequence, tag_ndm: '00400620', tag_ary: [0x0040,0x0620], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,06FA)', tag_name: "Slide Identifier", tag_key: 'SlideIdentifier', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0040,06FA)', tag_sym: :slide_identifier, tag_ndm: '004006FA', tag_ary: [0x0040,0x06FA], tag_multiple: false, tag_note: 'RET (2008)'},
      { tag_ps: '(0040,0710)', tag_name: "Whole Slide Microscopy Image Frame Type Sequence", tag_key: 'WholeSlideMicroscopyImageFrameTypeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,0710)', tag_sym: :whole_slide_microscopy_image_frame_type_sequence, tag_ndm: '00400710', tag_ary: [0x0040,0x0710], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,071A)', tag_name: "Image Center Point Coordinates Sequence", tag_key: 'ImageCenterPointCoordinatesSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,071A)', tag_sym: :image_center_point_coordinates_sequence, tag_ndm: '0040071A', tag_ary: [0x0040,0x071A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,072A)', tag_name: "X Offset in Slide Coordinate System", tag_key: 'XOffsetInSlideCoordinateSystem', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0040,072A)', tag_sym: :x_offset_in_slide_coordinate_system, tag_ndm: '0040072A', tag_ary: [0x0040,0x072A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,073A)', tag_name: "Y Offset in Slide Coordinate System", tag_key: 'YOffsetInSlideCoordinateSystem', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0040,073A)', tag_sym: :y_offset_in_slide_coordinate_system, tag_ndm: '0040073A', tag_ary: [0x0040,0x073A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,074A)', tag_name: "Z Offset in Slide Coordinate System", tag_key: 'ZOffsetInSlideCoordinateSystem', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0040,074A)', tag_sym: :z_offset_in_slide_coordinate_system, tag_ndm: '0040074A', tag_ary: [0x0040,0x074A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,08D8)', tag_name: "Pixel Spacing Sequence", tag_key: 'PixelSpacingSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,08D8)', tag_sym: :pixel_spacing_sequence, tag_ndm: '004008D8', tag_ary: [0x0040,0x08D8], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0040,08DA)', tag_name: "Coordinate System Axis Code Sequence", tag_key: 'CoordinateSystemAxisCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,08DA)', tag_sym: :coordinate_system_axis_code_sequence, tag_ndm: '004008DA', tag_ary: [0x0040,0x08DA], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0040,08EA)', tag_name: "Measurement Units Code Sequence", tag_key: 'MeasurementUnitsCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,08EA)', tag_sym: :measurement_units_code_sequence, tag_ndm: '004008EA', tag_ary: [0x0040,0x08EA], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,09F8)', tag_name: "Vital Stain Code Sequence (Trial)", tag_key: 'VitalStainCodeSequenceTrial', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,09F8)', tag_sym: :vital_stain_code_sequence_trial, tag_ndm: '004009F8', tag_ary: [0x0040,0x09F8], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0040,1001)', tag_name: "Requested Procedure ID", tag_key: 'RequestedProcedureID', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0040,1001)', tag_sym: :requested_procedure_id, tag_ndm: '00401001', tag_ary: [0x0040,0x1001], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,1002)', tag_name: "Reason for the Requested Procedure", tag_key: 'ReasonForTheRequestedProcedure', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0040,1002)', tag_sym: :reason_for_the_requested_procedure, tag_ndm: '00401002', tag_ary: [0x0040,0x1002], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,1003)', tag_name: "Requested Procedure Priority", tag_key: 'RequestedProcedurePriority', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0040,1003)', tag_sym: :requested_procedure_priority, tag_ndm: '00401003', tag_ary: [0x0040,0x1003], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,1004)', tag_name: "Patient Transport Arrangements", tag_key: 'PatientTransportArrangements', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0040,1004)', tag_sym: :patient_transport_arrangements, tag_ndm: '00401004', tag_ary: [0x0040,0x1004], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,1005)', tag_name: "Requested Procedure Location", tag_key: 'RequestedProcedureLocation', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0040,1005)', tag_sym: :requested_procedure_location, tag_ndm: '00401005', tag_ary: [0x0040,0x1005], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,1006)', tag_name: "Placer Order Number / Procedure", tag_key: 'PlacerOrderNumberProcedure', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0040,1006)', tag_sym: :placer_order_number_procedure, tag_ndm: '00401006', tag_ary: [0x0040,0x1006], tag_multiple: false, tag_note: 'RET (1998)'},
      { tag_ps: '(0040,1007)', tag_name: "Filler Order Number / Procedure", tag_key: 'FillerOrderNumberProcedure', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0040,1007)', tag_sym: :filler_order_number_procedure, tag_ndm: '00401007', tag_ary: [0x0040,0x1007], tag_multiple: false, tag_note: 'RET (1998)'},
      { tag_ps: '(0040,1008)', tag_name: "Confidentiality Code", tag_key: 'ConfidentialityCode', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0040,1008)', tag_sym: :confidentiality_code, tag_ndm: '00401008', tag_ary: [0x0040,0x1008], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,1009)', tag_name: "Reporting Priority", tag_key: 'ReportingPriority', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0040,1009)', tag_sym: :reporting_priority, tag_ndm: '00401009', tag_ary: [0x0040,0x1009], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,100A)', tag_name: "Reason for Requested Procedure Code Sequence", tag_key: 'ReasonForRequestedProcedureCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,100A)', tag_sym: :reason_for_requested_procedure_code_sequence, tag_ndm: '0040100A', tag_ary: [0x0040,0x100A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,1010)', tag_name: "Names of Intended Recipients of Results", tag_key: 'NamesOfIntendedRecipientsOfResults', tag_vr: [:PN], tag_vm: ["1-n"], tag_str: '(0040,1010)', tag_sym: :names_of_intended_recipients_of_results, tag_ndm: '00401010', tag_ary: [0x0040,0x1010], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,1011)', tag_name: "Intended Recipients of Results Identification Sequence", tag_key: 'IntendedRecipientsOfResultsIdentificationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,1011)', tag_sym: :intended_recipients_of_results_identification_sequence, tag_ndm: '00401011', tag_ary: [0x0040,0x1011], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,1012)', tag_name: "Reason For Performed Procedure Code Sequence", tag_key: 'ReasonForPerformedProcedureCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,1012)', tag_sym: :reason_for_performed_procedure_code_sequence, tag_ndm: '00401012', tag_ary: [0x0040,0x1012], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,1060)', tag_name: "Requested Procedure Description (Trial)", tag_key: 'RequestedProcedureDescriptionTrial', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0040,1060)', tag_sym: :requested_procedure_description_trial, tag_ndm: '00401060', tag_ary: [0x0040,0x1060], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0040,1101)', tag_name: "Person Identification Code Sequence", tag_key: 'PersonIdentificationCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,1101)', tag_sym: :person_identification_code_sequence, tag_ndm: '00401101', tag_ary: [0x0040,0x1101], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,1102)', tag_name: "Person's Address", tag_key: 'PersonAddress', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0040,1102)', tag_sym: :person_address, tag_ndm: '00401102', tag_ary: [0x0040,0x1102], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,1103)', tag_name: "Person's Telephone Numbers", tag_key: 'PersonTelephoneNumbers', tag_vr: [:LO], tag_vm: ["1-n"], tag_str: '(0040,1103)', tag_sym: :person_telephone_numbers, tag_ndm: '00401103', tag_ary: [0x0040,0x1103], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,1104)', tag_name: "Person's Telecom Information", tag_key: 'PersonTelecomInformation', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(0040,1104)', tag_sym: :person_telecom_information, tag_ndm: '00401104', tag_ary: [0x0040,0x1104], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,1400)', tag_name: "Requested Procedure Comments", tag_key: 'RequestedProcedureComments', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(0040,1400)', tag_sym: :requested_procedure_comments, tag_ndm: '00401400', tag_ary: [0x0040,0x1400], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,2001)', tag_name: "Reason for the Imaging Service Request", tag_key: 'ReasonForTheImagingServiceRequest', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0040,2001)', tag_sym: :reason_for_the_imaging_service_request, tag_ndm: '00402001', tag_ary: [0x0040,0x2001], tag_multiple: false, tag_note: 'RET (2003)'},
      { tag_ps: '(0040,2004)', tag_name: "Issue Date of Imaging Service Request", tag_key: 'IssueDateOfImagingServiceRequest', tag_vr: [:DA], tag_vm: ["1"], tag_str: '(0040,2004)', tag_sym: :issue_date_of_imaging_service_request, tag_ndm: '00402004', tag_ary: [0x0040,0x2004], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,2005)', tag_name: "Issue Time of Imaging Service Request", tag_key: 'IssueTimeOfImagingServiceRequest', tag_vr: [:TM], tag_vm: ["1"], tag_str: '(0040,2005)', tag_sym: :issue_time_of_imaging_service_request, tag_ndm: '00402005', tag_ary: [0x0040,0x2005], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,2006)', tag_name: "Placer Order Number / Imaging Service Request (Retired)", tag_key: 'PlacerOrderNumberImagingServiceRequestRetired', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0040,2006)', tag_sym: :placer_order_number_imaging_service_request_retired, tag_ndm: '00402006', tag_ary: [0x0040,0x2006], tag_multiple: false, tag_note: 'RET (1998)'},
      { tag_ps: '(0040,2007)', tag_name: "Filler Order Number / Imaging Service Request (Retired)", tag_key: 'FillerOrderNumberImagingServiceRequestRetired', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0040,2007)', tag_sym: :filler_order_number_imaging_service_request_retired, tag_ndm: '00402007', tag_ary: [0x0040,0x2007], tag_multiple: false, tag_note: 'RET (1998)'},
      { tag_ps: '(0040,2008)', tag_name: "Order Entered By", tag_key: 'OrderEnteredBy', tag_vr: [:PN], tag_vm: ["1"], tag_str: '(0040,2008)', tag_sym: :order_entered_by, tag_ndm: '00402008', tag_ary: [0x0040,0x2008], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,2009)', tag_name: "Order Enterer's Location", tag_key: 'OrderEntererLocation', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0040,2009)', tag_sym: :order_enterer_location, tag_ndm: '00402009', tag_ary: [0x0040,0x2009], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,2010)', tag_name: "Order Callback Phone Number", tag_key: 'OrderCallbackPhoneNumber', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0040,2010)', tag_sym: :order_callback_phone_number, tag_ndm: '00402010', tag_ary: [0x0040,0x2010], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,2011)', tag_name: "Order Callback Telecom Information", tag_key: 'OrderCallbackTelecomInformation', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(0040,2011)', tag_sym: :order_callback_telecom_information, tag_ndm: '00402011', tag_ary: [0x0040,0x2011], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,2016)', tag_name: "Placer Order Number / Imaging Service Request", tag_key: 'PlacerOrderNumberImagingServiceRequest', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0040,2016)', tag_sym: :placer_order_number_imaging_service_request, tag_ndm: '00402016', tag_ary: [0x0040,0x2016], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,2017)', tag_name: "Filler Order Number / Imaging Service Request", tag_key: 'FillerOrderNumberImagingServiceRequest', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0040,2017)', tag_sym: :filler_order_number_imaging_service_request, tag_ndm: '00402017', tag_ary: [0x0040,0x2017], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,2400)', tag_name: "Imaging Service Request Comments", tag_key: 'ImagingServiceRequestComments', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(0040,2400)', tag_sym: :imaging_service_request_comments, tag_ndm: '00402400', tag_ary: [0x0040,0x2400], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,3001)', tag_name: "Confidentiality Constraint on Patient Data Description", tag_key: 'ConfidentialityConstraintOnPatientDataDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0040,3001)', tag_sym: :confidentiality_constraint_on_patient_data_description, tag_ndm: '00403001', tag_ary: [0x0040,0x3001], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,4001)', tag_name: "General Purpose Scheduled Procedure Step Status", tag_key: 'GeneralPurposeScheduledProcedureStepStatus', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0040,4001)', tag_sym: :general_purpose_scheduled_procedure_step_status, tag_ndm: '00404001', tag_ary: [0x0040,0x4001], tag_multiple: false, tag_note: 'RET (2011)'},
      { tag_ps: '(0040,4002)', tag_name: "General Purpose Performed Procedure Step Status", tag_key: 'GeneralPurposePerformedProcedureStepStatus', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0040,4002)', tag_sym: :general_purpose_performed_procedure_step_status, tag_ndm: '00404002', tag_ary: [0x0040,0x4002], tag_multiple: false, tag_note: 'RET (2011)'},
      { tag_ps: '(0040,4003)', tag_name: "General Purpose Scheduled Procedure Step Priority", tag_key: 'GeneralPurposeScheduledProcedureStepPriority', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0040,4003)', tag_sym: :general_purpose_scheduled_procedure_step_priority, tag_ndm: '00404003', tag_ary: [0x0040,0x4003], tag_multiple: false, tag_note: 'RET (2011)'},
      { tag_ps: '(0040,4004)', tag_name: "Scheduled Processing Applications Code Sequence", tag_key: 'ScheduledProcessingApplicationsCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,4004)', tag_sym: :scheduled_processing_applications_code_sequence, tag_ndm: '00404004', tag_ary: [0x0040,0x4004], tag_multiple: false, tag_note: 'RET (2011)'},
      { tag_ps: '(0040,4005)', tag_name: "Scheduled Procedure Step Start DateTime", tag_key: 'ScheduledProcedureStepStartDateTime', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(0040,4005)', tag_sym: :scheduled_procedure_step_start_date_time, tag_ndm: '00404005', tag_ary: [0x0040,0x4005], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,4006)', tag_name: "Multiple Copies Flag", tag_key: 'MultipleCopiesFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0040,4006)', tag_sym: :multiple_copies_flag, tag_ndm: '00404006', tag_ary: [0x0040,0x4006], tag_multiple: false, tag_note: 'RET (2011)'},
      { tag_ps: '(0040,4007)', tag_name: "Performed Processing Applications Code Sequence", tag_key: 'PerformedProcessingApplicationsCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,4007)', tag_sym: :performed_processing_applications_code_sequence, tag_ndm: '00404007', tag_ary: [0x0040,0x4007], tag_multiple: false, tag_note: 'RET (2017e)'},
      { tag_ps: '(0040,4008)', tag_name: "Scheduled Procedure Step Expiration DateTime", tag_key: 'ScheduledProcedureStepExpirationDateTime', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(0040,4008)', tag_sym: :scheduled_procedure_step_expiration_date_time, tag_ndm: '00404008', tag_ary: [0x0040,0x4008], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,4009)', tag_name: "Human Performer Code Sequence", tag_key: 'HumanPerformerCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,4009)', tag_sym: :human_performer_code_sequence, tag_ndm: '00404009', tag_ary: [0x0040,0x4009], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,4010)', tag_name: "Scheduled Procedure Step Modification DateTime", tag_key: 'ScheduledProcedureStepModificationDateTime', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(0040,4010)', tag_sym: :scheduled_procedure_step_modification_date_time, tag_ndm: '00404010', tag_ary: [0x0040,0x4010], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,4011)', tag_name: "Expected Completion DateTime", tag_key: 'ExpectedCompletionDateTime', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(0040,4011)', tag_sym: :expected_completion_date_time, tag_ndm: '00404011', tag_ary: [0x0040,0x4011], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,4015)', tag_name: "Resulting General Purpose Performed Procedure Steps Sequence", tag_key: 'ResultingGeneralPurposePerformedProcedureStepsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,4015)', tag_sym: :resulting_general_purpose_performed_procedure_steps_sequence, tag_ndm: '00404015', tag_ary: [0x0040,0x4015], tag_multiple: false, tag_note: 'RET (2011)'},
      { tag_ps: '(0040,4016)', tag_name: "Referenced General Purpose Scheduled Procedure Step Sequence", tag_key: 'ReferencedGeneralPurposeScheduledProcedureStepSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,4016)', tag_sym: :referenced_general_purpose_scheduled_procedure_step_sequence, tag_ndm: '00404016', tag_ary: [0x0040,0x4016], tag_multiple: false, tag_note: 'RET (2011)'},
      { tag_ps: '(0040,4018)', tag_name: "Scheduled Workitem Code Sequence", tag_key: 'ScheduledWorkitemCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,4018)', tag_sym: :scheduled_workitem_code_sequence, tag_ndm: '00404018', tag_ary: [0x0040,0x4018], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,4019)', tag_name: "Performed Workitem Code Sequence", tag_key: 'PerformedWorkitemCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,4019)', tag_sym: :performed_workitem_code_sequence, tag_ndm: '00404019', tag_ary: [0x0040,0x4019], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,4020)', tag_name: "Input Availability Flag", tag_key: 'InputAvailabilityFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0040,4020)', tag_sym: :input_availability_flag, tag_ndm: '00404020', tag_ary: [0x0040,0x4020], tag_multiple: false, tag_note: 'RET (2017b)'},
      { tag_ps: '(0040,4021)', tag_name: "Input Information Sequence", tag_key: 'InputInformationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,4021)', tag_sym: :input_information_sequence, tag_ndm: '00404021', tag_ary: [0x0040,0x4021], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,4022)', tag_name: "Relevant Information Sequence", tag_key: 'RelevantInformationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,4022)', tag_sym: :relevant_information_sequence, tag_ndm: '00404022', tag_ary: [0x0040,0x4022], tag_multiple: false, tag_note: 'RET (2011)'},
      { tag_ps: '(0040,4023)', tag_name: "Referenced General Purpose Scheduled Procedure Step Transaction UID", tag_key: 'ReferencedGeneralPurposeScheduledProcedureStepTransactionUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0040,4023)', tag_sym: :referenced_general_purpose_scheduled_procedure_step_transaction_uid, tag_ndm: '00404023', tag_ary: [0x0040,0x4023], tag_multiple: false, tag_note: 'RET (2011)'},
      { tag_ps: '(0040,4025)', tag_name: "Scheduled Station Name Code Sequence", tag_key: 'ScheduledStationNameCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,4025)', tag_sym: :scheduled_station_name_code_sequence, tag_ndm: '00404025', tag_ary: [0x0040,0x4025], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,4026)', tag_name: "Scheduled Station Class Code Sequence", tag_key: 'ScheduledStationClassCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,4026)', tag_sym: :scheduled_station_class_code_sequence, tag_ndm: '00404026', tag_ary: [0x0040,0x4026], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,4027)', tag_name: "Scheduled Station Geographic Location Code Sequence", tag_key: 'ScheduledStationGeographicLocationCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,4027)', tag_sym: :scheduled_station_geographic_location_code_sequence, tag_ndm: '00404027', tag_ary: [0x0040,0x4027], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,4028)', tag_name: "Performed Station Name Code Sequence", tag_key: 'PerformedStationNameCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,4028)', tag_sym: :performed_station_name_code_sequence, tag_ndm: '00404028', tag_ary: [0x0040,0x4028], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,4029)', tag_name: "Performed Station Class Code Sequence", tag_key: 'PerformedStationClassCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,4029)', tag_sym: :performed_station_class_code_sequence, tag_ndm: '00404029', tag_ary: [0x0040,0x4029], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,4030)', tag_name: "Performed Station Geographic Location Code Sequence", tag_key: 'PerformedStationGeographicLocationCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,4030)', tag_sym: :performed_station_geographic_location_code_sequence, tag_ndm: '00404030', tag_ary: [0x0040,0x4030], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,4031)', tag_name: "Requested Subsequent Workitem Code Sequence", tag_key: 'RequestedSubsequentWorkitemCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,4031)', tag_sym: :requested_subsequent_workitem_code_sequence, tag_ndm: '00404031', tag_ary: [0x0040,0x4031], tag_multiple: false, tag_note: 'RET (2011)'},
      { tag_ps: '(0040,4032)', tag_name: "Non-DICOM Output Code Sequence", tag_key: 'NonDICOMOutputCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,4032)', tag_sym: :non_dicom_output_code_sequence, tag_ndm: '00404032', tag_ary: [0x0040,0x4032], tag_multiple: false, tag_note: 'RET (2011)'},
      { tag_ps: '(0040,4033)', tag_name: "Output Information Sequence", tag_key: 'OutputInformationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,4033)', tag_sym: :output_information_sequence, tag_ndm: '00404033', tag_ary: [0x0040,0x4033], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,4034)', tag_name: "Scheduled Human Performers Sequence", tag_key: 'ScheduledHumanPerformersSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,4034)', tag_sym: :scheduled_human_performers_sequence, tag_ndm: '00404034', tag_ary: [0x0040,0x4034], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,4035)', tag_name: "Actual Human Performers Sequence", tag_key: 'ActualHumanPerformersSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,4035)', tag_sym: :actual_human_performers_sequence, tag_ndm: '00404035', tag_ary: [0x0040,0x4035], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,4036)', tag_name: "Human Performer's Organization", tag_key: 'HumanPerformerOrganization', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0040,4036)', tag_sym: :human_performer_organization, tag_ndm: '00404036', tag_ary: [0x0040,0x4036], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,4037)', tag_name: "Human Performer's Name", tag_key: 'HumanPerformerName', tag_vr: [:PN], tag_vm: ["1"], tag_str: '(0040,4037)', tag_sym: :human_performer_name, tag_ndm: '00404037', tag_ary: [0x0040,0x4037], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,4040)', tag_name: "Raw Data Handling", tag_key: 'RawDataHandling', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0040,4040)', tag_sym: :raw_data_handling, tag_ndm: '00404040', tag_ary: [0x0040,0x4040], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,4041)', tag_name: "Input Readiness State", tag_key: 'InputReadinessState', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0040,4041)', tag_sym: :input_readiness_state, tag_ndm: '00404041', tag_ary: [0x0040,0x4041], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,4050)', tag_name: "Performed Procedure Step Start DateTime", tag_key: 'PerformedProcedureStepStartDateTime', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(0040,4050)', tag_sym: :performed_procedure_step_start_date_time, tag_ndm: '00404050', tag_ary: [0x0040,0x4050], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,4051)', tag_name: "Performed Procedure Step End DateTime", tag_key: 'PerformedProcedureStepEndDateTime', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(0040,4051)', tag_sym: :performed_procedure_step_end_date_time, tag_ndm: '00404051', tag_ary: [0x0040,0x4051], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,4052)', tag_name: "Procedure Step Cancellation DateTime", tag_key: 'ProcedureStepCancellationDateTime', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(0040,4052)', tag_sym: :procedure_step_cancellation_date_time, tag_ndm: '00404052', tag_ary: [0x0040,0x4052], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,4070)', tag_name: "Output Destination Sequence", tag_key: 'OutputDestinationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,4070)', tag_sym: :output_destination_sequence, tag_ndm: '00404070', tag_ary: [0x0040,0x4070], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,4071)', tag_name: "DICOM Storage Sequence", tag_key: 'DICOMStorageSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,4071)', tag_sym: :dicom_storage_sequence, tag_ndm: '00404071', tag_ary: [0x0040,0x4071], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,4072)', tag_name: "STOW-RS Storage Sequence", tag_key: 'STOWRSStorageSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,4072)', tag_sym: :stow_rs_storage_sequence, tag_ndm: '00404072', tag_ary: [0x0040,0x4072], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,4073)', tag_name: "Storage URL", tag_key: 'StorageURL', tag_vr: [:UR], tag_vm: ["1"], tag_str: '(0040,4073)', tag_sym: :storage_url, tag_ndm: '00404073', tag_ary: [0x0040,0x4073], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,4074)', tag_name: "XDS Storage Sequence", tag_key: 'XDSStorageSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,4074)', tag_sym: :xds_storage_sequence, tag_ndm: '00404074', tag_ary: [0x0040,0x4074], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,8302)', tag_name: "Entrance Dose in mGy", tag_key: 'EntranceDoseInmGy', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0040,8302)', tag_sym: :entrance_dose_inm_gy, tag_ndm: '00408302', tag_ary: [0x0040,0x8302], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,8303)', tag_name: "Entrance Dose Derivation", tag_key: 'EntranceDoseDerivation', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0040,8303)', tag_sym: :entrance_dose_derivation, tag_ndm: '00408303', tag_ary: [0x0040,0x8303], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,9092)', tag_name: "Parametric Map Frame Type Sequence", tag_key: 'ParametricMapFrameTypeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,9092)', tag_sym: :parametric_map_frame_type_sequence, tag_ndm: '00409092', tag_ary: [0x0040,0x9092], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,9094)', tag_name: "Referenced Image Real World Value Mapping Sequence", tag_key: 'ReferencedImageRealWorldValueMappingSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,9094)', tag_sym: :referenced_image_real_world_value_mapping_sequence, tag_ndm: '00409094', tag_ary: [0x0040,0x9094], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,9096)', tag_name: "Real World Value Mapping Sequence", tag_key: 'RealWorldValueMappingSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,9096)', tag_sym: :real_world_value_mapping_sequence, tag_ndm: '00409096', tag_ary: [0x0040,0x9096], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,9098)', tag_name: "Pixel Value Mapping Code Sequence", tag_key: 'PixelValueMappingCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,9098)', tag_sym: :pixel_value_mapping_code_sequence, tag_ndm: '00409098', tag_ary: [0x0040,0x9098], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,9210)', tag_name: "LUT Label", tag_key: 'LUTLabel', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0040,9210)', tag_sym: :lut_label, tag_ndm: '00409210', tag_ary: [0x0040,0x9210], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,9211)', tag_name: "Real World Value Last Value Mapped", tag_key: 'RealWorldValueLastValueMapped', tag_vr: [:US, :SS], tag_vm: ["1"], tag_str: '(0040,9211)', tag_sym: :real_world_value_last_value_mapped, tag_ndm: '00409211', tag_ary: [0x0040,0x9211], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,9212)', tag_name: "Real World Value LUT Data", tag_key: 'RealWorldValueLUTData', tag_vr: [:FD], tag_vm: ["1-n"], tag_str: '(0040,9212)', tag_sym: :real_world_value_lut_data, tag_ndm: '00409212', tag_ary: [0x0040,0x9212], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,9213)', tag_name: "Double Float Real World Value Last Value Mapped", tag_key: 'DoubleFloatRealWorldValueLastValueMapped', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0040,9213)', tag_sym: :double_float_real_world_value_last_value_mapped, tag_ndm: '00409213', tag_ary: [0x0040,0x9213], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,9214)', tag_name: "Double Float Real World Value First Value Mapped", tag_key: 'DoubleFloatRealWorldValueFirstValueMapped', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0040,9214)', tag_sym: :double_float_real_world_value_first_value_mapped, tag_ndm: '00409214', tag_ary: [0x0040,0x9214], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,9216)', tag_name: "Real World Value First Value Mapped", tag_key: 'RealWorldValueFirstValueMapped', tag_vr: [:US, :SS], tag_vm: ["1"], tag_str: '(0040,9216)', tag_sym: :real_world_value_first_value_mapped, tag_ndm: '00409216', tag_ary: [0x0040,0x9216], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,9220)', tag_name: "Quantity Definition Sequence", tag_key: 'QuantityDefinitionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,9220)', tag_sym: :quantity_definition_sequence, tag_ndm: '00409220', tag_ary: [0x0040,0x9220], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,9224)', tag_name: "Real World Value Intercept", tag_key: 'RealWorldValueIntercept', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0040,9224)', tag_sym: :real_world_value_intercept, tag_ndm: '00409224', tag_ary: [0x0040,0x9224], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,9225)', tag_name: "Real World Value Slope", tag_key: 'RealWorldValueSlope', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0040,9225)', tag_sym: :real_world_value_slope, tag_ndm: '00409225', tag_ary: [0x0040,0x9225], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A007)', tag_name: "Findings Flag (Trial)", tag_key: 'FindingsFlagTrial', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0040,A007)', tag_sym: :findings_flag_trial, tag_ndm: '0040A007', tag_ary: [0x0040,0xA007], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0040,A010)', tag_name: "Relationship Type", tag_key: 'RelationshipType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0040,A010)', tag_sym: :relationship_type, tag_ndm: '0040A010', tag_ary: [0x0040,0xA010], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A020)', tag_name: "Findings Sequence (Trial)", tag_key: 'FindingsSequenceTrial', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,A020)', tag_sym: :findings_sequence_trial, tag_ndm: '0040A020', tag_ary: [0x0040,0xA020], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0040,A021)', tag_name: "Findings Group UID (Trial)", tag_key: 'FindingsGroupUIDTrial', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0040,A021)', tag_sym: :findings_group_uid_trial, tag_ndm: '0040A021', tag_ary: [0x0040,0xA021], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0040,A022)', tag_name: "Referenced Findings Group UID (Trial)", tag_key: 'ReferencedFindingsGroupUIDTrial', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0040,A022)', tag_sym: :referenced_findings_group_uid_trial, tag_ndm: '0040A022', tag_ary: [0x0040,0xA022], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0040,A023)', tag_name: "Findings Group Recording Date (Trial)", tag_key: 'FindingsGroupRecordingDateTrial', tag_vr: [:DA], tag_vm: ["1"], tag_str: '(0040,A023)', tag_sym: :findings_group_recording_date_trial, tag_ndm: '0040A023', tag_ary: [0x0040,0xA023], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0040,A024)', tag_name: "Findings Group Recording Time (Trial)", tag_key: 'FindingsGroupRecordingTimeTrial', tag_vr: [:TM], tag_vm: ["1"], tag_str: '(0040,A024)', tag_sym: :findings_group_recording_time_trial, tag_ndm: '0040A024', tag_ary: [0x0040,0xA024], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0040,A026)', tag_name: "Findings Source Category Code Sequence (Trial)", tag_key: 'FindingsSourceCategoryCodeSequenceTrial', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,A026)', tag_sym: :findings_source_category_code_sequence_trial, tag_ndm: '0040A026', tag_ary: [0x0040,0xA026], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0040,A027)', tag_name: "Verifying Organization", tag_key: 'VerifyingOrganization', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0040,A027)', tag_sym: :verifying_organization, tag_ndm: '0040A027', tag_ary: [0x0040,0xA027], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A028)', tag_name: "Documenting Organization Identifier Code Sequence (Trial)", tag_key: 'DocumentingOrganizationIdentifierCodeSequenceTrial', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,A028)', tag_sym: :documenting_organization_identifier_code_sequence_trial, tag_ndm: '0040A028', tag_ary: [0x0040,0xA028], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0040,A030)', tag_name: "Verification DateTime", tag_key: 'VerificationDateTime', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(0040,A030)', tag_sym: :verification_date_time, tag_ndm: '0040A030', tag_ary: [0x0040,0xA030], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A032)', tag_name: "Observation DateTime", tag_key: 'ObservationDateTime', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(0040,A032)', tag_sym: :observation_date_time, tag_ndm: '0040A032', tag_ary: [0x0040,0xA032], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A033)', tag_name: "Observation Start DateTime", tag_key: 'ObservationStartDateTime', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(0040,A033)', tag_sym: :observation_start_date_time, tag_ndm: '0040A033', tag_ary: [0x0040,0xA033], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A034)', tag_name: "Effective Start DateTime", tag_key: 'EffectiveStartDateTime', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(0040,A034)', tag_sym: :effective_start_date_time, tag_ndm: '0040A034', tag_ary: [0x0040,0xA034], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A035)', tag_name: "Effective Stop DateTime", tag_key: 'EffectiveStopDateTime', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(0040,A035)', tag_sym: :effective_stop_date_time, tag_ndm: '0040A035', tag_ary: [0x0040,0xA035], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A040)', tag_name: "Value Type", tag_key: 'ValueType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0040,A040)', tag_sym: :value_type, tag_ndm: '0040A040', tag_ary: [0x0040,0xA040], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A043)', tag_name: "Concept Name Code Sequence", tag_key: 'ConceptNameCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,A043)', tag_sym: :concept_name_code_sequence, tag_ndm: '0040A043', tag_ary: [0x0040,0xA043], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A047)', tag_name: "Measurement Precision Description (Trial)", tag_key: 'MeasurementPrecisionDescriptionTrial', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0040,A047)', tag_sym: :measurement_precision_description_trial, tag_ndm: '0040A047', tag_ary: [0x0040,0xA047], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0040,A050)', tag_name: "Continuity Of Content", tag_key: 'ContinuityOfContent', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0040,A050)', tag_sym: :continuity_of_content, tag_ndm: '0040A050', tag_ary: [0x0040,0xA050], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A057)', tag_name: "Urgency or Priority Alerts (Trial)", tag_key: 'UrgencyOrPriorityAlertsTrial', tag_vr: [:CS], tag_vm: ["1-n"], tag_str: '(0040,A057)', tag_sym: :urgency_or_priority_alerts_trial, tag_ndm: '0040A057', tag_ary: [0x0040,0xA057], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0040,A060)', tag_name: "Sequencing Indicator (Trial)", tag_key: 'SequencingIndicatorTrial', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0040,A060)', tag_sym: :sequencing_indicator_trial, tag_ndm: '0040A060', tag_ary: [0x0040,0xA060], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0040,A066)', tag_name: "Document Identifier Code Sequence (Trial)", tag_key: 'DocumentIdentifierCodeSequenceTrial', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,A066)', tag_sym: :document_identifier_code_sequence_trial, tag_ndm: '0040A066', tag_ary: [0x0040,0xA066], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0040,A067)', tag_name: "Document Author (Trial)", tag_key: 'DocumentAuthorTrial', tag_vr: [:PN], tag_vm: ["1"], tag_str: '(0040,A067)', tag_sym: :document_author_trial, tag_ndm: '0040A067', tag_ary: [0x0040,0xA067], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0040,A068)', tag_name: "Document Author Identifier Code Sequence (Trial)", tag_key: 'DocumentAuthorIdentifierCodeSequenceTrial', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,A068)', tag_sym: :document_author_identifier_code_sequence_trial, tag_ndm: '0040A068', tag_ary: [0x0040,0xA068], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0040,A070)', tag_name: "Identifier Code Sequence (Trial)", tag_key: 'IdentifierCodeSequenceTrial', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,A070)', tag_sym: :identifier_code_sequence_trial, tag_ndm: '0040A070', tag_ary: [0x0040,0xA070], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0040,A073)', tag_name: "Verifying Observer Sequence", tag_key: 'VerifyingObserverSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,A073)', tag_sym: :verifying_observer_sequence, tag_ndm: '0040A073', tag_ary: [0x0040,0xA073], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A074)', tag_name: "Object Binary Identifier (Trial)", tag_key: 'ObjectBinaryIdentifierTrial', tag_vr: [:OB], tag_vm: ["1"], tag_str: '(0040,A074)', tag_sym: :object_binary_identifier_trial, tag_ndm: '0040A074', tag_ary: [0x0040,0xA074], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0040,A075)', tag_name: "Verifying Observer Name", tag_key: 'VerifyingObserverName', tag_vr: [:PN], tag_vm: ["1"], tag_str: '(0040,A075)', tag_sym: :verifying_observer_name, tag_ndm: '0040A075', tag_ary: [0x0040,0xA075], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A076)', tag_name: "Documenting Observer Identifier Code Sequence (Trial)", tag_key: 'DocumentingObserverIdentifierCodeSequenceTrial', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,A076)', tag_sym: :documenting_observer_identifier_code_sequence_trial, tag_ndm: '0040A076', tag_ary: [0x0040,0xA076], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0040,A078)', tag_name: "Author Observer Sequence", tag_key: 'AuthorObserverSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,A078)', tag_sym: :author_observer_sequence, tag_ndm: '0040A078', tag_ary: [0x0040,0xA078], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A07A)', tag_name: "Participant Sequence", tag_key: 'ParticipantSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,A07A)', tag_sym: :participant_sequence, tag_ndm: '0040A07A', tag_ary: [0x0040,0xA07A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A07C)', tag_name: "Custodial Organization Sequence", tag_key: 'CustodialOrganizationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,A07C)', tag_sym: :custodial_organization_sequence, tag_ndm: '0040A07C', tag_ary: [0x0040,0xA07C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A080)', tag_name: "Participation Type", tag_key: 'ParticipationType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0040,A080)', tag_sym: :participation_type, tag_ndm: '0040A080', tag_ary: [0x0040,0xA080], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A082)', tag_name: "Participation DateTime", tag_key: 'ParticipationDateTime', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(0040,A082)', tag_sym: :participation_date_time, tag_ndm: '0040A082', tag_ary: [0x0040,0xA082], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A084)', tag_name: "Observer Type", tag_key: 'ObserverType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0040,A084)', tag_sym: :observer_type, tag_ndm: '0040A084', tag_ary: [0x0040,0xA084], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A085)', tag_name: "Procedure Identifier Code Sequence (Trial)", tag_key: 'ProcedureIdentifierCodeSequenceTrial', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,A085)', tag_sym: :procedure_identifier_code_sequence_trial, tag_ndm: '0040A085', tag_ary: [0x0040,0xA085], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0040,A088)', tag_name: "Verifying Observer Identification Code Sequence", tag_key: 'VerifyingObserverIdentificationCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,A088)', tag_sym: :verifying_observer_identification_code_sequence, tag_ndm: '0040A088', tag_ary: [0x0040,0xA088], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A089)', tag_name: "Object Directory Binary Identifier (Trial)", tag_key: 'ObjectDirectoryBinaryIdentifierTrial', tag_vr: [:OB], tag_vm: ["1"], tag_str: '(0040,A089)', tag_sym: :object_directory_binary_identifier_trial, tag_ndm: '0040A089', tag_ary: [0x0040,0xA089], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0040,A090)', tag_name: "Equivalent CDA Document Sequence", tag_key: 'EquivalentCDADocumentSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,A090)', tag_sym: :equivalent_cda_document_sequence, tag_ndm: '0040A090', tag_ary: [0x0040,0xA090], tag_multiple: false, tag_note: 'RET (2006)'},
      { tag_ps: '(0040,A0B0)', tag_name: "Referenced Waveform Channels", tag_key: 'ReferencedWaveformChannels', tag_vr: [:US], tag_vm: ["2-2n"], tag_str: '(0040,A0B0)', tag_sym: :referenced_waveform_channels, tag_ndm: '0040A0B0', tag_ary: [0x0040,0xA0B0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A110)', tag_name: "Date of Document or Verbal Transaction (Trial)", tag_key: 'DateOfDocumentOrVerbalTransactionTrial', tag_vr: [:DA], tag_vm: ["1"], tag_str: '(0040,A110)', tag_sym: :date_of_document_or_verbal_transaction_trial, tag_ndm: '0040A110', tag_ary: [0x0040,0xA110], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0040,A112)', tag_name: "Time of Document Creation or Verbal Transaction (Trial)", tag_key: 'TimeOfDocumentCreationOrVerbalTransactionTrial', tag_vr: [:TM], tag_vm: ["1"], tag_str: '(0040,A112)', tag_sym: :time_of_document_creation_or_verbal_transaction_trial, tag_ndm: '0040A112', tag_ary: [0x0040,0xA112], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0040,A120)', tag_name: "DateTime", tag_key: 'DateTime', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(0040,A120)', tag_sym: :date_time, tag_ndm: '0040A120', tag_ary: [0x0040,0xA120], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A121)', tag_name: "Date", tag_key: 'Date', tag_vr: [:DA], tag_vm: ["1"], tag_str: '(0040,A121)', tag_sym: :date, tag_ndm: '0040A121', tag_ary: [0x0040,0xA121], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A122)', tag_name: "Time", tag_key: 'Time', tag_vr: [:TM], tag_vm: ["1"], tag_str: '(0040,A122)', tag_sym: :time, tag_ndm: '0040A122', tag_ary: [0x0040,0xA122], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A123)', tag_name: "Person Name", tag_key: 'PersonName', tag_vr: [:PN], tag_vm: ["1"], tag_str: '(0040,A123)', tag_sym: :person_name, tag_ndm: '0040A123', tag_ary: [0x0040,0xA123], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A124)', tag_name: "UID", tag_key: 'UID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0040,A124)', tag_sym: :uid, tag_ndm: '0040A124', tag_ary: [0x0040,0xA124], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A125)', tag_name: "Report Status ID (Trial)", tag_key: 'ReportStatusIDTrial', tag_vr: [:CS], tag_vm: ["2"], tag_str: '(0040,A125)', tag_sym: :report_status_id_trial, tag_ndm: '0040A125', tag_ary: [0x0040,0xA125], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0040,A130)', tag_name: "Temporal Range Type", tag_key: 'TemporalRangeType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0040,A130)', tag_sym: :temporal_range_type, tag_ndm: '0040A130', tag_ary: [0x0040,0xA130], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A132)', tag_name: "Referenced Sample Positions", tag_key: 'ReferencedSamplePositions', tag_vr: [:UL], tag_vm: ["1-n"], tag_str: '(0040,A132)', tag_sym: :referenced_sample_positions, tag_ndm: '0040A132', tag_ary: [0x0040,0xA132], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A136)', tag_name: "Referenced Frame Numbers", tag_key: 'ReferencedFrameNumbers', tag_vr: [:US], tag_vm: ["1-n"], tag_str: '(0040,A136)', tag_sym: :referenced_frame_numbers, tag_ndm: '0040A136', tag_ary: [0x0040,0xA136], tag_multiple: false, tag_note: 'RET (2019)'},
      { tag_ps: '(0040,A138)', tag_name: "Referenced Time Offsets", tag_key: 'ReferencedTimeOffsets', tag_vr: [:DS], tag_vm: ["1-n"], tag_str: '(0040,A138)', tag_sym: :referenced_time_offsets, tag_ndm: '0040A138', tag_ary: [0x0040,0xA138], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A13A)', tag_name: "Referenced DateTime", tag_key: 'ReferencedDateTime', tag_vr: [:DT], tag_vm: ["1-n"], tag_str: '(0040,A13A)', tag_sym: :referenced_date_time, tag_ndm: '0040A13A', tag_ary: [0x0040,0xA13A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A160)', tag_name: "Text Value", tag_key: 'TextValue', tag_vr: [:UT], tag_vm: ["1"], tag_str: '(0040,A160)', tag_sym: :text_value, tag_ndm: '0040A160', tag_ary: [0x0040,0xA160], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A161)', tag_name: "Floating Point Value", tag_key: 'FloatingPointValue', tag_vr: [:FD], tag_vm: ["1-n"], tag_str: '(0040,A161)', tag_sym: :floating_point_value, tag_ndm: '0040A161', tag_ary: [0x0040,0xA161], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A162)', tag_name: "Rational Numerator Value", tag_key: 'RationalNumeratorValue', tag_vr: [:SL], tag_vm: ["1-n"], tag_str: '(0040,A162)', tag_sym: :rational_numerator_value, tag_ndm: '0040A162', tag_ary: [0x0040,0xA162], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A163)', tag_name: "Rational Denominator Value", tag_key: 'RationalDenominatorValue', tag_vr: [:UL], tag_vm: ["1-n"], tag_str: '(0040,A163)', tag_sym: :rational_denominator_value, tag_ndm: '0040A163', tag_ary: [0x0040,0xA163], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A167)', tag_name: "Observation Category Code Sequence (Trial)", tag_key: 'ObservationCategoryCodeSequenceTrial', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,A167)', tag_sym: :observation_category_code_sequence_trial, tag_ndm: '0040A167', tag_ary: [0x0040,0xA167], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0040,A168)', tag_name: "Concept Code Sequence", tag_key: 'ConceptCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,A168)', tag_sym: :concept_code_sequence, tag_ndm: '0040A168', tag_ary: [0x0040,0xA168], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A16A)', tag_name: "Bibliographic Citation (Trial)", tag_key: 'BibliographicCitationTrial', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0040,A16A)', tag_sym: :bibliographic_citation_trial, tag_ndm: '0040A16A', tag_ary: [0x0040,0xA16A], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0040,A170)', tag_name: "Purpose of Reference Code Sequence", tag_key: 'PurposeOfReferenceCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,A170)', tag_sym: :purpose_of_reference_code_sequence, tag_ndm: '0040A170', tag_ary: [0x0040,0xA170], tag_multiple: false, tag_note: 'See Note'},
      { tag_ps: '(0040,A171)', tag_name: "Observation UID", tag_key: 'ObservationUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0040,A171)', tag_sym: :observation_uid, tag_ndm: '0040A171', tag_ary: [0x0040,0xA171], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A172)', tag_name: "Referenced Observation UID (Trial)", tag_key: 'ReferencedObservationUIDTrial', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0040,A172)', tag_sym: :referenced_observation_uid_trial, tag_ndm: '0040A172', tag_ary: [0x0040,0xA172], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0040,A173)', tag_name: "Referenced Observation Class (Trial)", tag_key: 'ReferencedObservationClassTrial', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0040,A173)', tag_sym: :referenced_observation_class_trial, tag_ndm: '0040A173', tag_ary: [0x0040,0xA173], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0040,A174)', tag_name: "Referenced Object Observation Class (Trial)", tag_key: 'ReferencedObjectObservationClassTrial', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0040,A174)', tag_sym: :referenced_object_observation_class_trial, tag_ndm: '0040A174', tag_ary: [0x0040,0xA174], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0040,A180)', tag_name: "Annotation Group Number", tag_key: 'AnnotationGroupNumber', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0040,A180)', tag_sym: :annotation_group_number, tag_ndm: '0040A180', tag_ary: [0x0040,0xA180], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A192)', tag_name: "Observation Date (Trial)", tag_key: 'ObservationDateTrial', tag_vr: [:DA], tag_vm: ["1"], tag_str: '(0040,A192)', tag_sym: :observation_date_trial, tag_ndm: '0040A192', tag_ary: [0x0040,0xA192], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0040,A193)', tag_name: "Observation Time (Trial)", tag_key: 'ObservationTimeTrial', tag_vr: [:TM], tag_vm: ["1"], tag_str: '(0040,A193)', tag_sym: :observation_time_trial, tag_ndm: '0040A193', tag_ary: [0x0040,0xA193], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0040,A194)', tag_name: "Measurement Automation (Trial)", tag_key: 'MeasurementAutomationTrial', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0040,A194)', tag_sym: :measurement_automation_trial, tag_ndm: '0040A194', tag_ary: [0x0040,0xA194], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0040,A195)', tag_name: "Modifier Code Sequence", tag_key: 'ModifierCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,A195)', tag_sym: :modifier_code_sequence, tag_ndm: '0040A195', tag_ary: [0x0040,0xA195], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A224)', tag_name: "Identification Description (Trial)", tag_key: 'IdentificationDescriptionTrial', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0040,A224)', tag_sym: :identification_description_trial, tag_ndm: '0040A224', tag_ary: [0x0040,0xA224], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0040,A290)', tag_name: "Coordinates Set Geometric Type (Trial)", tag_key: 'CoordinatesSetGeometricTypeTrial', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0040,A290)', tag_sym: :coordinates_set_geometric_type_trial, tag_ndm: '0040A290', tag_ary: [0x0040,0xA290], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0040,A296)', tag_name: "Algorithm Code Sequence (Trial)", tag_key: 'AlgorithmCodeSequenceTrial', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,A296)', tag_sym: :algorithm_code_sequence_trial, tag_ndm: '0040A296', tag_ary: [0x0040,0xA296], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0040,A297)', tag_name: "Algorithm Description (Trial)", tag_key: 'AlgorithmDescriptionTrial', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0040,A297)', tag_sym: :algorithm_description_trial, tag_ndm: '0040A297', tag_ary: [0x0040,0xA297], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0040,A29A)', tag_name: "Pixel Coordinates Set (Trial)", tag_key: 'PixelCoordinatesSetTrial', tag_vr: [:SL], tag_vm: ["2-2n"], tag_str: '(0040,A29A)', tag_sym: :pixel_coordinates_set_trial, tag_ndm: '0040A29A', tag_ary: [0x0040,0xA29A], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0040,A300)', tag_name: "Measured Value Sequence", tag_key: 'MeasuredValueSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,A300)', tag_sym: :measured_value_sequence, tag_ndm: '0040A300', tag_ary: [0x0040,0xA300], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A301)', tag_name: "Numeric Value Qualifier Code Sequence", tag_key: 'NumericValueQualifierCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,A301)', tag_sym: :numeric_value_qualifier_code_sequence, tag_ndm: '0040A301', tag_ary: [0x0040,0xA301], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A307)', tag_name: "Current Observer (Trial)", tag_key: 'CurrentObserverTrial', tag_vr: [:PN], tag_vm: ["1"], tag_str: '(0040,A307)', tag_sym: :current_observer_trial, tag_ndm: '0040A307', tag_ary: [0x0040,0xA307], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0040,A30A)', tag_name: "Numeric Value", tag_key: 'NumericValue', tag_vr: [:DS], tag_vm: ["1-n"], tag_str: '(0040,A30A)', tag_sym: :numeric_value, tag_ndm: '0040A30A', tag_ary: [0x0040,0xA30A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A313)', tag_name: "Referenced Accession Sequence (Trial)", tag_key: 'ReferencedAccessionSequenceTrial', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,A313)', tag_sym: :referenced_accession_sequence_trial, tag_ndm: '0040A313', tag_ary: [0x0040,0xA313], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0040,A33A)', tag_name: "Report Status Comment (Trial)", tag_key: 'ReportStatusCommentTrial', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0040,A33A)', tag_sym: :report_status_comment_trial, tag_ndm: '0040A33A', tag_ary: [0x0040,0xA33A], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0040,A340)', tag_name: "Procedure Context Sequence (Trial)", tag_key: 'ProcedureContextSequenceTrial', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,A340)', tag_sym: :procedure_context_sequence_trial, tag_ndm: '0040A340', tag_ary: [0x0040,0xA340], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0040,A352)', tag_name: "Verbal Source (Trial)", tag_key: 'VerbalSourceTrial', tag_vr: [:PN], tag_vm: ["1"], tag_str: '(0040,A352)', tag_sym: :verbal_source_trial, tag_ndm: '0040A352', tag_ary: [0x0040,0xA352], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0040,A353)', tag_name: "Address (Trial)", tag_key: 'AddressTrial', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0040,A353)', tag_sym: :address_trial, tag_ndm: '0040A353', tag_ary: [0x0040,0xA353], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0040,A354)', tag_name: "Telephone Number (Trial)", tag_key: 'TelephoneNumberTrial', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0040,A354)', tag_sym: :telephone_number_trial, tag_ndm: '0040A354', tag_ary: [0x0040,0xA354], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0040,A358)', tag_name: "Verbal Source Identifier Code Sequence (Trial)", tag_key: 'VerbalSourceIdentifierCodeSequenceTrial', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,A358)', tag_sym: :verbal_source_identifier_code_sequence_trial, tag_ndm: '0040A358', tag_ary: [0x0040,0xA358], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0040,A360)', tag_name: "Predecessor Documents Sequence", tag_key: 'PredecessorDocumentsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,A360)', tag_sym: :predecessor_documents_sequence, tag_ndm: '0040A360', tag_ary: [0x0040,0xA360], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A370)', tag_name: "Referenced Request Sequence", tag_key: 'ReferencedRequestSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,A370)', tag_sym: :referenced_request_sequence, tag_ndm: '0040A370', tag_ary: [0x0040,0xA370], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A372)', tag_name: "Performed Procedure Code Sequence", tag_key: 'PerformedProcedureCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,A372)', tag_sym: :performed_procedure_code_sequence, tag_ndm: '0040A372', tag_ary: [0x0040,0xA372], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A375)', tag_name: "Current Requested Procedure Evidence Sequence", tag_key: 'CurrentRequestedProcedureEvidenceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,A375)', tag_sym: :current_requested_procedure_evidence_sequence, tag_ndm: '0040A375', tag_ary: [0x0040,0xA375], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A380)', tag_name: "Report Detail Sequence (Trial)", tag_key: 'ReportDetailSequenceTrial', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,A380)', tag_sym: :report_detail_sequence_trial, tag_ndm: '0040A380', tag_ary: [0x0040,0xA380], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0040,A385)', tag_name: "Pertinent Other Evidence Sequence", tag_key: 'PertinentOtherEvidenceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,A385)', tag_sym: :pertinent_other_evidence_sequence, tag_ndm: '0040A385', tag_ary: [0x0040,0xA385], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A390)', tag_name: "HL7 Structured Document Reference Sequence", tag_key: 'HL7StructuredDocumentReferenceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,A390)', tag_sym: :hl7_structured_document_reference_sequence, tag_ndm: '0040A390', tag_ary: [0x0040,0xA390], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A402)', tag_name: "Observation Subject UID (Trial)", tag_key: 'ObservationSubjectUIDTrial', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0040,A402)', tag_sym: :observation_subject_uid_trial, tag_ndm: '0040A402', tag_ary: [0x0040,0xA402], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0040,A403)', tag_name: "Observation Subject Class (Trial)", tag_key: 'ObservationSubjectClassTrial', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0040,A403)', tag_sym: :observation_subject_class_trial, tag_ndm: '0040A403', tag_ary: [0x0040,0xA403], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0040,A404)', tag_name: "Observation Subject Type Code Sequence (Trial)", tag_key: 'ObservationSubjectTypeCodeSequenceTrial', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,A404)', tag_sym: :observation_subject_type_code_sequence_trial, tag_ndm: '0040A404', tag_ary: [0x0040,0xA404], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0040,A491)', tag_name: "Completion Flag", tag_key: 'CompletionFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0040,A491)', tag_sym: :completion_flag, tag_ndm: '0040A491', tag_ary: [0x0040,0xA491], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A492)', tag_name: "Completion Flag Description", tag_key: 'CompletionFlagDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0040,A492)', tag_sym: :completion_flag_description, tag_ndm: '0040A492', tag_ary: [0x0040,0xA492], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A493)', tag_name: "Verification Flag", tag_key: 'VerificationFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0040,A493)', tag_sym: :verification_flag, tag_ndm: '0040A493', tag_ary: [0x0040,0xA493], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A494)', tag_name: "Archive Requested", tag_key: 'ArchiveRequested', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0040,A494)', tag_sym: :archive_requested, tag_ndm: '0040A494', tag_ary: [0x0040,0xA494], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A496)', tag_name: "Preliminary Flag", tag_key: 'PreliminaryFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0040,A496)', tag_sym: :preliminary_flag, tag_ndm: '0040A496', tag_ary: [0x0040,0xA496], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A504)', tag_name: "Content Template Sequence", tag_key: 'ContentTemplateSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,A504)', tag_sym: :content_template_sequence, tag_ndm: '0040A504', tag_ary: [0x0040,0xA504], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A525)', tag_name: "Identical Documents Sequence", tag_key: 'IdenticalDocumentsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,A525)', tag_sym: :identical_documents_sequence, tag_ndm: '0040A525', tag_ary: [0x0040,0xA525], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A600)', tag_name: "Observation Subject Context Flag (Trial)", tag_key: 'ObservationSubjectContextFlagTrial', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0040,A600)', tag_sym: :observation_subject_context_flag_trial, tag_ndm: '0040A600', tag_ary: [0x0040,0xA600], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0040,A601)', tag_name: "Observer Context Flag (Trial)", tag_key: 'ObserverContextFlagTrial', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0040,A601)', tag_sym: :observer_context_flag_trial, tag_ndm: '0040A601', tag_ary: [0x0040,0xA601], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0040,A603)', tag_name: "Procedure Context Flag (Trial)", tag_key: 'ProcedureContextFlagTrial', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0040,A603)', tag_sym: :procedure_context_flag_trial, tag_ndm: '0040A603', tag_ary: [0x0040,0xA603], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0040,A730)', tag_name: "Content Sequence", tag_key: 'ContentSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,A730)', tag_sym: :content_sequence, tag_ndm: '0040A730', tag_ary: [0x0040,0xA730], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A731)', tag_name: "Relationship Sequence (Trial)", tag_key: 'RelationshipSequenceTrial', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,A731)', tag_sym: :relationship_sequence_trial, tag_ndm: '0040A731', tag_ary: [0x0040,0xA731], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0040,A732)', tag_name: "Relationship Type Code Sequence (Trial)", tag_key: 'RelationshipTypeCodeSequenceTrial', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,A732)', tag_sym: :relationship_type_code_sequence_trial, tag_ndm: '0040A732', tag_ary: [0x0040,0xA732], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0040,A744)', tag_name: "Language Code Sequence (Trial)", tag_key: 'LanguageCodeSequenceTrial', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,A744)', tag_sym: :language_code_sequence_trial, tag_ndm: '0040A744', tag_ary: [0x0040,0xA744], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0040,A801)', tag_name: "Tabulated Values Sequence", tag_key: 'TabulatedValuesSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,A801)', tag_sym: :tabulated_values_sequence, tag_ndm: '0040A801', tag_ary: [0x0040,0xA801], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A802)', tag_name: "Number of Table Rows", tag_key: 'NumberOfTableRows', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0040,A802)', tag_sym: :number_of_table_rows, tag_ndm: '0040A802', tag_ary: [0x0040,0xA802], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A803)', tag_name: "Number of Table Columns", tag_key: 'NumberOfTableColumns', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0040,A803)', tag_sym: :number_of_table_columns, tag_ndm: '0040A803', tag_ary: [0x0040,0xA803], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A804)', tag_name: "Table Row Number", tag_key: 'TableRowNumber', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0040,A804)', tag_sym: :table_row_number, tag_ndm: '0040A804', tag_ary: [0x0040,0xA804], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A805)', tag_name: "Table Column Number", tag_key: 'TableColumnNumber', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0040,A805)', tag_sym: :table_column_number, tag_ndm: '0040A805', tag_ary: [0x0040,0xA805], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A806)', tag_name: "Table Row Definition Sequence", tag_key: 'TableRowDefinitionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,A806)', tag_sym: :table_row_definition_sequence, tag_ndm: '0040A806', tag_ary: [0x0040,0xA806], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A807)', tag_name: "Table Column Definition Sequence", tag_key: 'TableColumnDefinitionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,A807)', tag_sym: :table_column_definition_sequence, tag_ndm: '0040A807', tag_ary: [0x0040,0xA807], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A808)', tag_name: "Cell Values Sequence", tag_key: 'CellValuesSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,A808)', tag_sym: :cell_values_sequence, tag_ndm: '0040A808', tag_ary: [0x0040,0xA808], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,A992)', tag_name: "Uniform Resource Locator (Trial)", tag_key: 'UniformResourceLocatorTrial', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0040,A992)', tag_sym: :uniform_resource_locator_trial, tag_ndm: '0040A992', tag_ary: [0x0040,0xA992], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0040,B020)', tag_name: "Waveform Annotation Sequence", tag_key: 'WaveformAnnotationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,B020)', tag_sym: :waveform_annotation_sequence, tag_ndm: '0040B020', tag_ary: [0x0040,0xB020], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,B030)', tag_name: "Structured Waveform Annotation Sequence", tag_key: 'StructuredWaveformAnnotationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,B030)', tag_sym: :structured_waveform_annotation_sequence, tag_ndm: '0040B030', tag_ary: [0x0040,0xB030], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,B031)', tag_name: "Waveform Annotation Display Selection Sequence", tag_key: 'WaveformAnnotationDisplaySelectionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,B031)', tag_sym: :waveform_annotation_display_selection_sequence, tag_ndm: '0040B031', tag_ary: [0x0040,0xB031], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,B032)', tag_name: "Referenced Montage Index", tag_key: 'ReferencedMontageIndex', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0040,B032)', tag_sym: :referenced_montage_index, tag_ndm: '0040B032', tag_ary: [0x0040,0xB032], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,B033)', tag_name: "Waveform Textual Annotation Sequence", tag_key: 'WaveformTextualAnnotationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,B033)', tag_sym: :waveform_textual_annotation_sequence, tag_ndm: '0040B033', tag_ary: [0x0040,0xB033], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,B034)', tag_name: "Annotation DateTime", tag_key: 'AnnotationDateTime', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(0040,B034)', tag_sym: :annotation_date_time, tag_ndm: '0040B034', tag_ary: [0x0040,0xB034], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,B035)', tag_name: "Displayed Waveform Segment Sequence", tag_key: 'DisplayedWaveformSegmentSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,B035)', tag_sym: :displayed_waveform_segment_sequence, tag_ndm: '0040B035', tag_ary: [0x0040,0xB035], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,B036)', tag_name: "Segment Definition DateTime", tag_key: 'SegmentDefinitionDateTime', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(0040,B036)', tag_sym: :segment_definition_date_time, tag_ndm: '0040B036', tag_ary: [0x0040,0xB036], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,B037)', tag_name: "Montage Activation Sequence", tag_key: 'MontageActivationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,B037)', tag_sym: :montage_activation_sequence, tag_ndm: '0040B037', tag_ary: [0x0040,0xB037], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,B038)', tag_name: "Montage Activation Time Offset", tag_key: 'MontageActivationTimeOffset', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0040,B038)', tag_sym: :montage_activation_time_offset, tag_ndm: '0040B038', tag_ary: [0x0040,0xB038], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,B039)', tag_name: "Waveform Montage Sequence", tag_key: 'WaveformMontageSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,B039)', tag_sym: :waveform_montage_sequence, tag_ndm: '0040B039', tag_ary: [0x0040,0xB039], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,B03A)', tag_name: "Referenced Montage Channel Number", tag_key: 'ReferencedMontageChannelNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0040,B03A)', tag_sym: :referenced_montage_channel_number, tag_ndm: '0040B03A', tag_ary: [0x0040,0xB03A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,B03B)', tag_name: "Montage Name", tag_key: 'MontageName', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(0040,B03B)', tag_sym: :montage_name, tag_ndm: '0040B03B', tag_ary: [0x0040,0xB03B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,B03C)', tag_name: "Montage Channel Sequence", tag_key: 'MontageChannelSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,B03C)', tag_sym: :montage_channel_sequence, tag_ndm: '0040B03C', tag_ary: [0x0040,0xB03C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,B03D)', tag_name: "Montage Index", tag_key: 'MontageIndex', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0040,B03D)', tag_sym: :montage_index, tag_ndm: '0040B03D', tag_ary: [0x0040,0xB03D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,B03E)', tag_name: "Montage Channel Number", tag_key: 'MontageChannelNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0040,B03E)', tag_sym: :montage_channel_number, tag_ndm: '0040B03E', tag_ary: [0x0040,0xB03E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,B03F)', tag_name: "Montage Channel Label", tag_key: 'MontageChannelLabel', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0040,B03F)', tag_sym: :montage_channel_label, tag_ndm: '0040B03F', tag_ary: [0x0040,0xB03F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,B040)', tag_name: "Montage Channel Source Code Sequence", tag_key: 'MontageChannelSourceCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,B040)', tag_sym: :montage_channel_source_code_sequence, tag_ndm: '0040B040', tag_ary: [0x0040,0xB040], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,B041)', tag_name: "Contributing Channel Sources Sequence", tag_key: 'ContributingChannelSourcesSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,B041)', tag_sym: :contributing_channel_sources_sequence, tag_ndm: '0040B041', tag_ary: [0x0040,0xB041], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,B042)', tag_name: "Channel Weight", tag_key: 'ChannelWeight', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0040,B042)', tag_sym: :channel_weight, tag_ndm: '0040B042', tag_ary: [0x0040,0xB042], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,DB00)', tag_name: "Template Identifier", tag_key: 'TemplateIdentifier', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0040,DB00)', tag_sym: :template_identifier, tag_ndm: '0040DB00', tag_ary: [0x0040,0xDB00], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,DB06)', tag_name: "Template Version", tag_key: 'TemplateVersion', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(0040,DB06)', tag_sym: :template_version, tag_ndm: '0040DB06', tag_ary: [0x0040,0xDB06], tag_multiple: false, tag_note: 'RET (2001)'},
      { tag_ps: '(0040,DB07)', tag_name: "Template Local Version", tag_key: 'TemplateLocalVersion', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(0040,DB07)', tag_sym: :template_local_version, tag_ndm: '0040DB07', tag_ary: [0x0040,0xDB07], tag_multiple: false, tag_note: 'RET (2001)'},
      { tag_ps: '(0040,DB0B)', tag_name: "Template Extension Flag", tag_key: 'TemplateExtensionFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0040,DB0B)', tag_sym: :template_extension_flag, tag_ndm: '0040DB0B', tag_ary: [0x0040,0xDB0B], tag_multiple: false, tag_note: 'RET (2001)'},
      { tag_ps: '(0040,DB0C)', tag_name: "Template Extension Organization UID", tag_key: 'TemplateExtensionOrganizationUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0040,DB0C)', tag_sym: :template_extension_organization_uid, tag_ndm: '0040DB0C', tag_ary: [0x0040,0xDB0C], tag_multiple: false, tag_note: 'RET (2001)'},
      { tag_ps: '(0040,DB0D)', tag_name: "Template Extension Creator UID", tag_key: 'TemplateExtensionCreatorUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0040,DB0D)', tag_sym: :template_extension_creator_uid, tag_ndm: '0040DB0D', tag_ary: [0x0040,0xDB0D], tag_multiple: false, tag_note: 'RET (2001)'},
      { tag_ps: '(0040,DB73)', tag_name: "Referenced Content Item Identifier", tag_key: 'ReferencedContentItemIdentifier', tag_vr: [:UL], tag_vm: ["1-n"], tag_str: '(0040,DB73)', tag_sym: :referenced_content_item_identifier, tag_ndm: '0040DB73', tag_ary: [0x0040,0xDB73], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,E001)', tag_name: "HL7 Instance Identifier", tag_key: 'HL7InstanceIdentifier', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0040,E001)', tag_sym: :hl7_instance_identifier, tag_ndm: '0040E001', tag_ary: [0x0040,0xE001], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,E004)', tag_name: "HL7 Document Effective Time", tag_key: 'HL7DocumentEffectiveTime', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(0040,E004)', tag_sym: :hl7_document_effective_time, tag_ndm: '0040E004', tag_ary: [0x0040,0xE004], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,E006)', tag_name: "HL7 Document Type Code Sequence", tag_key: 'HL7DocumentTypeCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,E006)', tag_sym: :hl7_document_type_code_sequence, tag_ndm: '0040E006', tag_ary: [0x0040,0xE006], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,E008)', tag_name: "Document Class Code Sequence", tag_key: 'DocumentClassCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,E008)', tag_sym: :document_class_code_sequence, tag_ndm: '0040E008', tag_ary: [0x0040,0xE008], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,E010)', tag_name: "Retrieve URI", tag_key: 'RetrieveURI', tag_vr: [:UR], tag_vm: ["1"], tag_str: '(0040,E010)', tag_sym: :retrieve_uri, tag_ndm: '0040E010', tag_ary: [0x0040,0xE010], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,E011)', tag_name: "Retrieve Location UID", tag_key: 'RetrieveLocationUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0040,E011)', tag_sym: :retrieve_location_uid, tag_ndm: '0040E011', tag_ary: [0x0040,0xE011], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,E020)', tag_name: "Type of Instances", tag_key: 'TypeOfInstances', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0040,E020)', tag_sym: :type_of_instances, tag_ndm: '0040E020', tag_ary: [0x0040,0xE020], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,E021)', tag_name: "DICOM Retrieval Sequence", tag_key: 'DICOMRetrievalSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,E021)', tag_sym: :dicom_retrieval_sequence, tag_ndm: '0040E021', tag_ary: [0x0040,0xE021], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,E022)', tag_name: "DICOM Media Retrieval Sequence", tag_key: 'DICOMMediaRetrievalSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,E022)', tag_sym: :dicom_media_retrieval_sequence, tag_ndm: '0040E022', tag_ary: [0x0040,0xE022], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,E023)', tag_name: "WADO Retrieval Sequence", tag_key: 'WADORetrievalSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,E023)', tag_sym: :wado_retrieval_sequence, tag_ndm: '0040E023', tag_ary: [0x0040,0xE023], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,E024)', tag_name: "XDS Retrieval Sequence", tag_key: 'XDSRetrievalSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,E024)', tag_sym: :xds_retrieval_sequence, tag_ndm: '0040E024', tag_ary: [0x0040,0xE024], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,E025)', tag_name: "WADO-RS Retrieval Sequence", tag_key: 'WADORSRetrievalSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0040,E025)', tag_sym: :wado_rs_retrieval_sequence, tag_ndm: '0040E025', tag_ary: [0x0040,0xE025], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,E030)', tag_name: "Repository Unique ID", tag_key: 'RepositoryUniqueID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0040,E030)', tag_sym: :repository_unique_id, tag_ndm: '0040E030', tag_ary: [0x0040,0xE030], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0040,E031)', tag_name: "Home Community ID", tag_key: 'HomeCommunityID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0040,E031)', tag_sym: :home_community_id, tag_ndm: '0040E031', tag_ary: [0x0040,0xE031], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0042,0010)', tag_name: "Document Title", tag_key: 'DocumentTitle', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0042,0010)', tag_sym: :document_title, tag_ndm: '00420010', tag_ary: [0x0042,0x0010], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0042,0011)', tag_name: "Encapsulated Document", tag_key: 'EncapsulatedDocument', tag_vr: [:OB], tag_vm: ["1"], tag_str: '(0042,0011)', tag_sym: :encapsulated_document, tag_ndm: '00420011', tag_ary: [0x0042,0x0011], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0042,0012)', tag_name: "MIME Type of Encapsulated Document", tag_key: 'MIMETypeOfEncapsulatedDocument', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0042,0012)', tag_sym: :mime_type_of_encapsulated_document, tag_ndm: '00420012', tag_ary: [0x0042,0x0012], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0042,0013)', tag_name: "Source Instance Sequence", tag_key: 'SourceInstanceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0042,0013)', tag_sym: :source_instance_sequence, tag_ndm: '00420013', tag_ary: [0x0042,0x0013], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0042,0014)', tag_name: "List of MIME Types", tag_key: 'ListOfMIMETypes', tag_vr: [:LO], tag_vm: ["1-n"], tag_str: '(0042,0014)', tag_sym: :list_of_mime_types, tag_ndm: '00420014', tag_ary: [0x0042,0x0014], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0042,0015)', tag_name: "Encapsulated Document Length", tag_key: 'EncapsulatedDocumentLength', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0042,0015)', tag_sym: :encapsulated_document_length, tag_ndm: '00420015', tag_ary: [0x0042,0x0015], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0044,0001)', tag_name: "Product Package Identifier", tag_key: 'ProductPackageIdentifier', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0044,0001)', tag_sym: :product_package_identifier, tag_ndm: '00440001', tag_ary: [0x0044,0x0001], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0044,0002)', tag_name: "Substance Administration Approval", tag_key: 'SubstanceAdministrationApproval', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0044,0002)', tag_sym: :substance_administration_approval, tag_ndm: '00440002', tag_ary: [0x0044,0x0002], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0044,0003)', tag_name: "Approval Status Further Description", tag_key: 'ApprovalStatusFurtherDescription', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(0044,0003)', tag_sym: :approval_status_further_description, tag_ndm: '00440003', tag_ary: [0x0044,0x0003], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0044,0004)', tag_name: "Approval Status DateTime", tag_key: 'ApprovalStatusDateTime', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(0044,0004)', tag_sym: :approval_status_date_time, tag_ndm: '00440004', tag_ary: [0x0044,0x0004], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0044,0007)', tag_name: "Product Type Code Sequence", tag_key: 'ProductTypeCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0044,0007)', tag_sym: :product_type_code_sequence, tag_ndm: '00440007', tag_ary: [0x0044,0x0007], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0044,0008)', tag_name: "Product Name", tag_key: 'ProductName', tag_vr: [:LO], tag_vm: ["1-n"], tag_str: '(0044,0008)', tag_sym: :product_name, tag_ndm: '00440008', tag_ary: [0x0044,0x0008], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0044,0009)', tag_name: "Product Description", tag_key: 'ProductDescription', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(0044,0009)', tag_sym: :product_description, tag_ndm: '00440009', tag_ary: [0x0044,0x0009], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0044,000A)', tag_name: "Product Lot Identifier", tag_key: 'ProductLotIdentifier', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0044,000A)', tag_sym: :product_lot_identifier, tag_ndm: '0044000A', tag_ary: [0x0044,0x000A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0044,000B)', tag_name: "Product Expiration DateTime", tag_key: 'ProductExpirationDateTime', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(0044,000B)', tag_sym: :product_expiration_date_time, tag_ndm: '0044000B', tag_ary: [0x0044,0x000B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0044,0010)', tag_name: "Substance Administration DateTime", tag_key: 'SubstanceAdministrationDateTime', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(0044,0010)', tag_sym: :substance_administration_date_time, tag_ndm: '00440010', tag_ary: [0x0044,0x0010], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0044,0011)', tag_name: "Substance Administration Notes", tag_key: 'SubstanceAdministrationNotes', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0044,0011)', tag_sym: :substance_administration_notes, tag_ndm: '00440011', tag_ary: [0x0044,0x0011], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0044,0012)', tag_name: "Substance Administration Device ID", tag_key: 'SubstanceAdministrationDeviceID', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0044,0012)', tag_sym: :substance_administration_device_id, tag_ndm: '00440012', tag_ary: [0x0044,0x0012], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0044,0013)', tag_name: "Product Parameter Sequence", tag_key: 'ProductParameterSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0044,0013)', tag_sym: :product_parameter_sequence, tag_ndm: '00440013', tag_ary: [0x0044,0x0013], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0044,0019)', tag_name: "Substance Administration Parameter Sequence", tag_key: 'SubstanceAdministrationParameterSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0044,0019)', tag_sym: :substance_administration_parameter_sequence, tag_ndm: '00440019', tag_ary: [0x0044,0x0019], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0044,0100)', tag_name: "Approval Sequence", tag_key: 'ApprovalSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0044,0100)', tag_sym: :approval_sequence, tag_ndm: '00440100', tag_ary: [0x0044,0x0100], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0044,0101)', tag_name: "Assertion Code Sequence", tag_key: 'AssertionCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0044,0101)', tag_sym: :assertion_code_sequence, tag_ndm: '00440101', tag_ary: [0x0044,0x0101], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0044,0102)', tag_name: "Assertion UID", tag_key: 'AssertionUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0044,0102)', tag_sym: :assertion_uid, tag_ndm: '00440102', tag_ary: [0x0044,0x0102], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0044,0103)', tag_name: "Asserter Identification Sequence", tag_key: 'AsserterIdentificationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0044,0103)', tag_sym: :asserter_identification_sequence, tag_ndm: '00440103', tag_ary: [0x0044,0x0103], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0044,0104)', tag_name: "Assertion DateTime", tag_key: 'AssertionDateTime', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(0044,0104)', tag_sym: :assertion_date_time, tag_ndm: '00440104', tag_ary: [0x0044,0x0104], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0044,0105)', tag_name: "Assertion Expiration DateTime", tag_key: 'AssertionExpirationDateTime', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(0044,0105)', tag_sym: :assertion_expiration_date_time, tag_ndm: '00440105', tag_ary: [0x0044,0x0105], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0044,0106)', tag_name: "Assertion Comments", tag_key: 'AssertionComments', tag_vr: [:UT], tag_vm: ["1"], tag_str: '(0044,0106)', tag_sym: :assertion_comments, tag_ndm: '00440106', tag_ary: [0x0044,0x0106], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0044,0107)', tag_name: "Related Assertion Sequence", tag_key: 'RelatedAssertionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0044,0107)', tag_sym: :related_assertion_sequence, tag_ndm: '00440107', tag_ary: [0x0044,0x0107], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0044,0108)', tag_name: "Referenced Assertion UID", tag_key: 'ReferencedAssertionUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0044,0108)', tag_sym: :referenced_assertion_uid, tag_ndm: '00440108', tag_ary: [0x0044,0x0108], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0044,0109)', tag_name: "Approval Subject Sequence", tag_key: 'ApprovalSubjectSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0044,0109)', tag_sym: :approval_subject_sequence, tag_ndm: '00440109', tag_ary: [0x0044,0x0109], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0044,010A)', tag_name: "Organizational Role Code Sequence", tag_key: 'OrganizationalRoleCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0044,010A)', tag_sym: :organizational_role_code_sequence, tag_ndm: '0044010A', tag_ary: [0x0044,0x010A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0012)', tag_name: "Lens Description", tag_key: 'LensDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0046,0012)', tag_sym: :lens_description, tag_ndm: '00460012', tag_ary: [0x0046,0x0012], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0014)', tag_name: "Right Lens Sequence", tag_key: 'RightLensSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0046,0014)', tag_sym: :right_lens_sequence, tag_ndm: '00460014', tag_ary: [0x0046,0x0014], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0015)', tag_name: "Left Lens Sequence", tag_key: 'LeftLensSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0046,0015)', tag_sym: :left_lens_sequence, tag_ndm: '00460015', tag_ary: [0x0046,0x0015], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0016)', tag_name: "Unspecified Laterality Lens Sequence", tag_key: 'UnspecifiedLateralityLensSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0046,0016)', tag_sym: :unspecified_laterality_lens_sequence, tag_ndm: '00460016', tag_ary: [0x0046,0x0016], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0018)', tag_name: "Cylinder Sequence", tag_key: 'CylinderSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0046,0018)', tag_sym: :cylinder_sequence, tag_ndm: '00460018', tag_ary: [0x0046,0x0018], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0028)', tag_name: "Prism Sequence", tag_key: 'PrismSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0046,0028)', tag_sym: :prism_sequence, tag_ndm: '00460028', tag_ary: [0x0046,0x0028], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0030)', tag_name: "Horizontal Prism Power", tag_key: 'HorizontalPrismPower', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0046,0030)', tag_sym: :horizontal_prism_power, tag_ndm: '00460030', tag_ary: [0x0046,0x0030], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0032)', tag_name: "Horizontal Prism Base", tag_key: 'HorizontalPrismBase', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0046,0032)', tag_sym: :horizontal_prism_base, tag_ndm: '00460032', tag_ary: [0x0046,0x0032], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0034)', tag_name: "Vertical Prism Power", tag_key: 'VerticalPrismPower', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0046,0034)', tag_sym: :vertical_prism_power, tag_ndm: '00460034', tag_ary: [0x0046,0x0034], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0036)', tag_name: "Vertical Prism Base", tag_key: 'VerticalPrismBase', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0046,0036)', tag_sym: :vertical_prism_base, tag_ndm: '00460036', tag_ary: [0x0046,0x0036], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0038)', tag_name: "Lens Segment Type", tag_key: 'LensSegmentType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0046,0038)', tag_sym: :lens_segment_type, tag_ndm: '00460038', tag_ary: [0x0046,0x0038], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0040)', tag_name: "Optical Transmittance", tag_key: 'OpticalTransmittance', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0046,0040)', tag_sym: :optical_transmittance, tag_ndm: '00460040', tag_ary: [0x0046,0x0040], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0042)', tag_name: "Channel Width", tag_key: 'ChannelWidth', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0046,0042)', tag_sym: :channel_width, tag_ndm: '00460042', tag_ary: [0x0046,0x0042], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0044)', tag_name: "Pupil Size", tag_key: 'PupilSize', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0046,0044)', tag_sym: :pupil_size, tag_ndm: '00460044', tag_ary: [0x0046,0x0044], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0046)', tag_name: "Corneal Size", tag_key: 'CornealSize', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0046,0046)', tag_sym: :corneal_size, tag_ndm: '00460046', tag_ary: [0x0046,0x0046], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0047)', tag_name: "Corneal Size Sequence", tag_key: 'CornealSizeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0046,0047)', tag_sym: :corneal_size_sequence, tag_ndm: '00460047', tag_ary: [0x0046,0x0047], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0050)', tag_name: "Autorefraction Right Eye Sequence", tag_key: 'AutorefractionRightEyeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0046,0050)', tag_sym: :autorefraction_right_eye_sequence, tag_ndm: '00460050', tag_ary: [0x0046,0x0050], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0052)', tag_name: "Autorefraction Left Eye Sequence", tag_key: 'AutorefractionLeftEyeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0046,0052)', tag_sym: :autorefraction_left_eye_sequence, tag_ndm: '00460052', tag_ary: [0x0046,0x0052], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0060)', tag_name: "Distance Pupillary Distance", tag_key: 'DistancePupillaryDistance', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0046,0060)', tag_sym: :distance_pupillary_distance, tag_ndm: '00460060', tag_ary: [0x0046,0x0060], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0062)', tag_name: "Near Pupillary Distance", tag_key: 'NearPupillaryDistance', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0046,0062)', tag_sym: :near_pupillary_distance, tag_ndm: '00460062', tag_ary: [0x0046,0x0062], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0063)', tag_name: "Intermediate Pupillary Distance", tag_key: 'IntermediatePupillaryDistance', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0046,0063)', tag_sym: :intermediate_pupillary_distance, tag_ndm: '00460063', tag_ary: [0x0046,0x0063], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0064)', tag_name: "Other Pupillary Distance", tag_key: 'OtherPupillaryDistance', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0046,0064)', tag_sym: :other_pupillary_distance, tag_ndm: '00460064', tag_ary: [0x0046,0x0064], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0070)', tag_name: "Keratometry Right Eye Sequence", tag_key: 'KeratometryRightEyeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0046,0070)', tag_sym: :keratometry_right_eye_sequence, tag_ndm: '00460070', tag_ary: [0x0046,0x0070], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0071)', tag_name: "Keratometry Left Eye Sequence", tag_key: 'KeratometryLeftEyeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0046,0071)', tag_sym: :keratometry_left_eye_sequence, tag_ndm: '00460071', tag_ary: [0x0046,0x0071], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0074)', tag_name: "Steep Keratometric Axis Sequence", tag_key: 'SteepKeratometricAxisSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0046,0074)', tag_sym: :steep_keratometric_axis_sequence, tag_ndm: '00460074', tag_ary: [0x0046,0x0074], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0075)', tag_name: "Radius of Curvature", tag_key: 'RadiusOfCurvature', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0046,0075)', tag_sym: :radius_of_curvature, tag_ndm: '00460075', tag_ary: [0x0046,0x0075], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0076)', tag_name: "Keratometric Power", tag_key: 'KeratometricPower', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0046,0076)', tag_sym: :keratometric_power, tag_ndm: '00460076', tag_ary: [0x0046,0x0076], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0077)', tag_name: "Keratometric Axis", tag_key: 'KeratometricAxis', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0046,0077)', tag_sym: :keratometric_axis, tag_ndm: '00460077', tag_ary: [0x0046,0x0077], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0080)', tag_name: "Flat Keratometric Axis Sequence", tag_key: 'FlatKeratometricAxisSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0046,0080)', tag_sym: :flat_keratometric_axis_sequence, tag_ndm: '00460080', tag_ary: [0x0046,0x0080], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0092)', tag_name: "Background Color", tag_key: 'BackgroundColor', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0046,0092)', tag_sym: :background_color, tag_ndm: '00460092', tag_ary: [0x0046,0x0092], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0094)', tag_name: "Optotype", tag_key: 'Optotype', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0046,0094)', tag_sym: :optotype, tag_ndm: '00460094', tag_ary: [0x0046,0x0094], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0095)', tag_name: "Optotype Presentation", tag_key: 'OptotypePresentation', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0046,0095)', tag_sym: :optotype_presentation, tag_ndm: '00460095', tag_ary: [0x0046,0x0095], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0097)', tag_name: "Subjective Refraction Right Eye Sequence", tag_key: 'SubjectiveRefractionRightEyeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0046,0097)', tag_sym: :subjective_refraction_right_eye_sequence, tag_ndm: '00460097', tag_ary: [0x0046,0x0097], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0098)', tag_name: "Subjective Refraction Left Eye Sequence", tag_key: 'SubjectiveRefractionLeftEyeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0046,0098)', tag_sym: :subjective_refraction_left_eye_sequence, tag_ndm: '00460098', tag_ary: [0x0046,0x0098], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0100)', tag_name: "Add Near Sequence", tag_key: 'AddNearSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0046,0100)', tag_sym: :add_near_sequence, tag_ndm: '00460100', tag_ary: [0x0046,0x0100], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0101)', tag_name: "Add Intermediate Sequence", tag_key: 'AddIntermediateSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0046,0101)', tag_sym: :add_intermediate_sequence, tag_ndm: '00460101', tag_ary: [0x0046,0x0101], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0102)', tag_name: "Add Other Sequence", tag_key: 'AddOtherSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0046,0102)', tag_sym: :add_other_sequence, tag_ndm: '00460102', tag_ary: [0x0046,0x0102], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0104)', tag_name: "Add Power", tag_key: 'AddPower', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0046,0104)', tag_sym: :add_power, tag_ndm: '00460104', tag_ary: [0x0046,0x0104], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0106)', tag_name: "Viewing Distance", tag_key: 'ViewingDistance', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0046,0106)', tag_sym: :viewing_distance, tag_ndm: '00460106', tag_ary: [0x0046,0x0106], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0110)', tag_name: "Cornea Measurements Sequence", tag_key: 'CorneaMeasurementsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0046,0110)', tag_sym: :cornea_measurements_sequence, tag_ndm: '00460110', tag_ary: [0x0046,0x0110], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0111)', tag_name: "Source of Cornea Measurement Data Code Sequence", tag_key: 'SourceOfCorneaMeasurementDataCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0046,0111)', tag_sym: :source_of_cornea_measurement_data_code_sequence, tag_ndm: '00460111', tag_ary: [0x0046,0x0111], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0112)', tag_name: "Steep Corneal Axis Sequence", tag_key: 'SteepCornealAxisSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0046,0112)', tag_sym: :steep_corneal_axis_sequence, tag_ndm: '00460112', tag_ary: [0x0046,0x0112], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0113)', tag_name: "Flat Corneal Axis Sequence", tag_key: 'FlatCornealAxisSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0046,0113)', tag_sym: :flat_corneal_axis_sequence, tag_ndm: '00460113', tag_ary: [0x0046,0x0113], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0114)', tag_name: "Corneal Power", tag_key: 'CornealPower', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0046,0114)', tag_sym: :corneal_power, tag_ndm: '00460114', tag_ary: [0x0046,0x0114], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0115)', tag_name: "Corneal Axis", tag_key: 'CornealAxis', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0046,0115)', tag_sym: :corneal_axis, tag_ndm: '00460115', tag_ary: [0x0046,0x0115], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0116)', tag_name: "Cornea Measurement Method Code Sequence", tag_key: 'CorneaMeasurementMethodCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0046,0116)', tag_sym: :cornea_measurement_method_code_sequence, tag_ndm: '00460116', tag_ary: [0x0046,0x0116], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0117)', tag_name: "Refractive Index of Cornea", tag_key: 'RefractiveIndexOfCornea', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0046,0117)', tag_sym: :refractive_index_of_cornea, tag_ndm: '00460117', tag_ary: [0x0046,0x0117], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0118)', tag_name: "Refractive Index of Aqueous Humor", tag_key: 'RefractiveIndexOfAqueousHumor', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0046,0118)', tag_sym: :refractive_index_of_aqueous_humor, tag_ndm: '00460118', tag_ary: [0x0046,0x0118], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0121)', tag_name: "Visual Acuity Type Code Sequence", tag_key: 'VisualAcuityTypeCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0046,0121)', tag_sym: :visual_acuity_type_code_sequence, tag_ndm: '00460121', tag_ary: [0x0046,0x0121], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0122)', tag_name: "Visual Acuity Right Eye Sequence", tag_key: 'VisualAcuityRightEyeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0046,0122)', tag_sym: :visual_acuity_right_eye_sequence, tag_ndm: '00460122', tag_ary: [0x0046,0x0122], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0123)', tag_name: "Visual Acuity Left Eye Sequence", tag_key: 'VisualAcuityLeftEyeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0046,0123)', tag_sym: :visual_acuity_left_eye_sequence, tag_ndm: '00460123', tag_ary: [0x0046,0x0123], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0124)', tag_name: "Visual Acuity Both Eyes Open Sequence", tag_key: 'VisualAcuityBothEyesOpenSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0046,0124)', tag_sym: :visual_acuity_both_eyes_open_sequence, tag_ndm: '00460124', tag_ary: [0x0046,0x0124], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0125)', tag_name: "Viewing Distance Type", tag_key: 'ViewingDistanceType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0046,0125)', tag_sym: :viewing_distance_type, tag_ndm: '00460125', tag_ary: [0x0046,0x0125], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0135)', tag_name: "Visual Acuity Modifiers", tag_key: 'VisualAcuityModifiers', tag_vr: [:SS], tag_vm: ["2"], tag_str: '(0046,0135)', tag_sym: :visual_acuity_modifiers, tag_ndm: '00460135', tag_ary: [0x0046,0x0135], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0137)', tag_name: "Decimal Visual Acuity", tag_key: 'DecimalVisualAcuity', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0046,0137)', tag_sym: :decimal_visual_acuity, tag_ndm: '00460137', tag_ary: [0x0046,0x0137], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0139)', tag_name: "Optotype Detailed Definition", tag_key: 'OptotypeDetailedDefinition', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0046,0139)', tag_sym: :optotype_detailed_definition, tag_ndm: '00460139', tag_ary: [0x0046,0x0139], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0145)', tag_name: "Referenced Refractive Measurements Sequence", tag_key: 'ReferencedRefractiveMeasurementsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0046,0145)', tag_sym: :referenced_refractive_measurements_sequence, tag_ndm: '00460145', tag_ary: [0x0046,0x0145], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0146)', tag_name: "Sphere Power", tag_key: 'SpherePower', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0046,0146)', tag_sym: :sphere_power, tag_ndm: '00460146', tag_ary: [0x0046,0x0146], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0147)', tag_name: "Cylinder Power", tag_key: 'CylinderPower', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0046,0147)', tag_sym: :cylinder_power, tag_ndm: '00460147', tag_ary: [0x0046,0x0147], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0201)', tag_name: "Corneal Topography Surface", tag_key: 'CornealTopographySurface', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0046,0201)', tag_sym: :corneal_topography_surface, tag_ndm: '00460201', tag_ary: [0x0046,0x0201], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0202)', tag_name: "Corneal Vertex Location", tag_key: 'CornealVertexLocation', tag_vr: [:FL], tag_vm: ["2"], tag_str: '(0046,0202)', tag_sym: :corneal_vertex_location, tag_ndm: '00460202', tag_ary: [0x0046,0x0202], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0203)', tag_name: "Pupil Centroid X-Coordinate", tag_key: 'PupilCentroidXCoordinate', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0046,0203)', tag_sym: :pupil_centroid_x_coordinate, tag_ndm: '00460203', tag_ary: [0x0046,0x0203], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0204)', tag_name: "Pupil Centroid Y-Coordinate", tag_key: 'PupilCentroidYCoordinate', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0046,0204)', tag_sym: :pupil_centroid_y_coordinate, tag_ndm: '00460204', tag_ary: [0x0046,0x0204], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0205)', tag_name: "Equivalent Pupil Radius", tag_key: 'EquivalentPupilRadius', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0046,0205)', tag_sym: :equivalent_pupil_radius, tag_ndm: '00460205', tag_ary: [0x0046,0x0205], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0207)', tag_name: "Corneal Topography Map Type Code Sequence", tag_key: 'CornealTopographyMapTypeCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0046,0207)', tag_sym: :corneal_topography_map_type_code_sequence, tag_ndm: '00460207', tag_ary: [0x0046,0x0207], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0208)', tag_name: "Vertices of the Outline of Pupil", tag_key: 'VerticesOfTheOutlineOfPupil', tag_vr: [:IS], tag_vm: ["2-2n"], tag_str: '(0046,0208)', tag_sym: :vertices_of_the_outline_of_pupil, tag_ndm: '00460208', tag_ary: [0x0046,0x0208], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0210)', tag_name: "Corneal Topography Mapping Normals Sequence", tag_key: 'CornealTopographyMappingNormalsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0046,0210)', tag_sym: :corneal_topography_mapping_normals_sequence, tag_ndm: '00460210', tag_ary: [0x0046,0x0210], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0211)', tag_name: "Maximum Corneal Curvature Sequence", tag_key: 'MaximumCornealCurvatureSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0046,0211)', tag_sym: :maximum_corneal_curvature_sequence, tag_ndm: '00460211', tag_ary: [0x0046,0x0211], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0212)', tag_name: "Maximum Corneal Curvature", tag_key: 'MaximumCornealCurvature', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0046,0212)', tag_sym: :maximum_corneal_curvature, tag_ndm: '00460212', tag_ary: [0x0046,0x0212], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0213)', tag_name: "Maximum Corneal Curvature Location", tag_key: 'MaximumCornealCurvatureLocation', tag_vr: [:FL], tag_vm: ["2"], tag_str: '(0046,0213)', tag_sym: :maximum_corneal_curvature_location, tag_ndm: '00460213', tag_ary: [0x0046,0x0213], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0215)', tag_name: "Minimum Keratometric Sequence", tag_key: 'MinimumKeratometricSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0046,0215)', tag_sym: :minimum_keratometric_sequence, tag_ndm: '00460215', tag_ary: [0x0046,0x0215], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0218)', tag_name: "Simulated Keratometric Cylinder Sequence", tag_key: 'SimulatedKeratometricCylinderSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0046,0218)', tag_sym: :simulated_keratometric_cylinder_sequence, tag_ndm: '00460218', tag_ary: [0x0046,0x0218], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0220)', tag_name: "Average Corneal Power", tag_key: 'AverageCornealPower', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0046,0220)', tag_sym: :average_corneal_power, tag_ndm: '00460220', tag_ary: [0x0046,0x0220], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0224)', tag_name: "Corneal I-S Value", tag_key: 'CornealISValue', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0046,0224)', tag_sym: :corneal_is_value, tag_ndm: '00460224', tag_ary: [0x0046,0x0224], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0227)', tag_name: "Analyzed Area", tag_key: 'AnalyzedArea', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0046,0227)', tag_sym: :analyzed_area, tag_ndm: '00460227', tag_ary: [0x0046,0x0227], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0230)', tag_name: "Surface Regularity Index", tag_key: 'SurfaceRegularityIndex', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0046,0230)', tag_sym: :surface_regularity_index, tag_ndm: '00460230', tag_ary: [0x0046,0x0230], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0232)', tag_name: "Surface Asymmetry Index", tag_key: 'SurfaceAsymmetryIndex', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0046,0232)', tag_sym: :surface_asymmetry_index, tag_ndm: '00460232', tag_ary: [0x0046,0x0232], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0234)', tag_name: "Corneal Eccentricity Index", tag_key: 'CornealEccentricityIndex', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0046,0234)', tag_sym: :corneal_eccentricity_index, tag_ndm: '00460234', tag_ary: [0x0046,0x0234], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0236)', tag_name: "Keratoconus Prediction Index", tag_key: 'KeratoconusPredictionIndex', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0046,0236)', tag_sym: :keratoconus_prediction_index, tag_ndm: '00460236', tag_ary: [0x0046,0x0236], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0238)', tag_name: "Decimal Potential Visual Acuity", tag_key: 'DecimalPotentialVisualAcuity', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0046,0238)', tag_sym: :decimal_potential_visual_acuity, tag_ndm: '00460238', tag_ary: [0x0046,0x0238], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0242)', tag_name: "Corneal Topography Map Quality Evaluation", tag_key: 'CornealTopographyMapQualityEvaluation', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0046,0242)', tag_sym: :corneal_topography_map_quality_evaluation, tag_ndm: '00460242', tag_ary: [0x0046,0x0242], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0244)', tag_name: "Source Image Corneal Processed Data Sequence", tag_key: 'SourceImageCornealProcessedDataSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0046,0244)', tag_sym: :source_image_corneal_processed_data_sequence, tag_ndm: '00460244', tag_ary: [0x0046,0x0244], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0247)', tag_name: "Corneal Point Location", tag_key: 'CornealPointLocation', tag_vr: [:FL], tag_vm: ["3"], tag_str: '(0046,0247)', tag_sym: :corneal_point_location, tag_ndm: '00460247', tag_ary: [0x0046,0x0247], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0248)', tag_name: "Corneal Point Estimated", tag_key: 'CornealPointEstimated', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0046,0248)', tag_sym: :corneal_point_estimated, tag_ndm: '00460248', tag_ary: [0x0046,0x0248], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0249)', tag_name: "Axial Power", tag_key: 'AxialPower', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0046,0249)', tag_sym: :axial_power, tag_ndm: '00460249', tag_ary: [0x0046,0x0249], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0250)', tag_name: "Tangential Power", tag_key: 'TangentialPower', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0046,0250)', tag_sym: :tangential_power, tag_ndm: '00460250', tag_ary: [0x0046,0x0250], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0251)', tag_name: "Refractive Power", tag_key: 'RefractivePower', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0046,0251)', tag_sym: :refractive_power, tag_ndm: '00460251', tag_ary: [0x0046,0x0251], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0252)', tag_name: "Relative Elevation", tag_key: 'RelativeElevation', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0046,0252)', tag_sym: :relative_elevation, tag_ndm: '00460252', tag_ary: [0x0046,0x0252], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0046,0253)', tag_name: "Corneal Wavefront", tag_key: 'CornealWavefront', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0046,0253)', tag_sym: :corneal_wavefront, tag_ndm: '00460253', tag_ary: [0x0046,0x0253], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0048,0001)', tag_name: "Imaged Volume Width", tag_key: 'ImagedVolumeWidth', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0048,0001)', tag_sym: :imaged_volume_width, tag_ndm: '00480001', tag_ary: [0x0048,0x0001], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0048,0002)', tag_name: "Imaged Volume Height", tag_key: 'ImagedVolumeHeight', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0048,0002)', tag_sym: :imaged_volume_height, tag_ndm: '00480002', tag_ary: [0x0048,0x0002], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0048,0003)', tag_name: "Imaged Volume Depth", tag_key: 'ImagedVolumeDepth', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0048,0003)', tag_sym: :imaged_volume_depth, tag_ndm: '00480003', tag_ary: [0x0048,0x0003], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0048,0006)', tag_name: "Total Pixel Matrix Columns", tag_key: 'TotalPixelMatrixColumns', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0048,0006)', tag_sym: :total_pixel_matrix_columns, tag_ndm: '00480006', tag_ary: [0x0048,0x0006], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0048,0007)', tag_name: "Total Pixel Matrix Rows", tag_key: 'TotalPixelMatrixRows', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0048,0007)', tag_sym: :total_pixel_matrix_rows, tag_ndm: '00480007', tag_ary: [0x0048,0x0007], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0048,0008)', tag_name: "Total Pixel Matrix Origin Sequence", tag_key: 'TotalPixelMatrixOriginSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0048,0008)', tag_sym: :total_pixel_matrix_origin_sequence, tag_ndm: '00480008', tag_ary: [0x0048,0x0008], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0048,0010)', tag_name: "Specimen Label in Image", tag_key: 'SpecimenLabelInImage', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0048,0010)', tag_sym: :specimen_label_in_image, tag_ndm: '00480010', tag_ary: [0x0048,0x0010], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0048,0011)', tag_name: "Focus Method", tag_key: 'FocusMethod', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0048,0011)', tag_sym: :focus_method, tag_ndm: '00480011', tag_ary: [0x0048,0x0011], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0048,0012)', tag_name: "Extended Depth of Field", tag_key: 'ExtendedDepthOfField', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0048,0012)', tag_sym: :extended_depth_of_field, tag_ndm: '00480012', tag_ary: [0x0048,0x0012], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0048,0013)', tag_name: "Number of Focal Planes", tag_key: 'NumberOfFocalPlanes', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0048,0013)', tag_sym: :number_of_focal_planes, tag_ndm: '00480013', tag_ary: [0x0048,0x0013], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0048,0014)', tag_name: "Distance Between Focal Planes", tag_key: 'DistanceBetweenFocalPlanes', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0048,0014)', tag_sym: :distance_between_focal_planes, tag_ndm: '00480014', tag_ary: [0x0048,0x0014], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0048,0015)', tag_name: "Recommended Absent Pixel CIELab Value", tag_key: 'RecommendedAbsentPixelCIELabValue', tag_vr: [:US], tag_vm: ["3"], tag_str: '(0048,0015)', tag_sym: :recommended_absent_pixel_cie_lab_value, tag_ndm: '00480015', tag_ary: [0x0048,0x0015], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0048,0100)', tag_name: "Illuminator Type Code Sequence", tag_key: 'IlluminatorTypeCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0048,0100)', tag_sym: :illuminator_type_code_sequence, tag_ndm: '00480100', tag_ary: [0x0048,0x0100], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0048,0102)', tag_name: "Image Orientation (Slide)", tag_key: 'ImageOrientationSlide', tag_vr: [:DS], tag_vm: ["6"], tag_str: '(0048,0102)', tag_sym: :image_orientation_slide, tag_ndm: '00480102', tag_ary: [0x0048,0x0102], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0048,0105)', tag_name: "Optical Path Sequence", tag_key: 'OpticalPathSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0048,0105)', tag_sym: :optical_path_sequence, tag_ndm: '00480105', tag_ary: [0x0048,0x0105], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0048,0106)', tag_name: "Optical Path Identifier", tag_key: 'OpticalPathIdentifier', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0048,0106)', tag_sym: :optical_path_identifier, tag_ndm: '00480106', tag_ary: [0x0048,0x0106], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0048,0107)', tag_name: "Optical Path Description", tag_key: 'OpticalPathDescription', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0048,0107)', tag_sym: :optical_path_description, tag_ndm: '00480107', tag_ary: [0x0048,0x0107], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0048,0108)', tag_name: "Illumination Color Code Sequence", tag_key: 'IlluminationColorCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0048,0108)', tag_sym: :illumination_color_code_sequence, tag_ndm: '00480108', tag_ary: [0x0048,0x0108], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0048,0110)', tag_name: "Specimen Reference Sequence", tag_key: 'SpecimenReferenceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0048,0110)', tag_sym: :specimen_reference_sequence, tag_ndm: '00480110', tag_ary: [0x0048,0x0110], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0048,0111)', tag_name: "Condenser Lens Power", tag_key: 'CondenserLensPower', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0048,0111)', tag_sym: :condenser_lens_power, tag_ndm: '00480111', tag_ary: [0x0048,0x0111], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0048,0112)', tag_name: "Objective Lens Power", tag_key: 'ObjectiveLensPower', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0048,0112)', tag_sym: :objective_lens_power, tag_ndm: '00480112', tag_ary: [0x0048,0x0112], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0048,0113)', tag_name: "Objective Lens Numerical Aperture", tag_key: 'ObjectiveLensNumericalAperture', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0048,0113)', tag_sym: :objective_lens_numerical_aperture, tag_ndm: '00480113', tag_ary: [0x0048,0x0113], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0048,0114)', tag_name: "Confocal Mode", tag_key: 'ConfocalMode', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0048,0114)', tag_sym: :confocal_mode, tag_ndm: '00480114', tag_ary: [0x0048,0x0114], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0048,0115)', tag_name: "Tissue Location", tag_key: 'TissueLocation', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0048,0115)', tag_sym: :tissue_location, tag_ndm: '00480115', tag_ary: [0x0048,0x0115], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0048,0116)', tag_name: "Confocal Microscopy Image Frame Type Sequence", tag_key: 'ConfocalMicroscopyImageFrameTypeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0048,0116)', tag_sym: :confocal_microscopy_image_frame_type_sequence, tag_ndm: '00480116', tag_ary: [0x0048,0x0116], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0048,0117)', tag_name: "Image Acquisition Depth", tag_key: 'ImageAcquisitionDepth', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0048,0117)', tag_sym: :image_acquisition_depth, tag_ndm: '00480117', tag_ary: [0x0048,0x0117], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0048,0120)', tag_name: "Palette Color Lookup Table Sequence", tag_key: 'PaletteColorLookupTableSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0048,0120)', tag_sym: :palette_color_lookup_table_sequence, tag_ndm: '00480120', tag_ary: [0x0048,0x0120], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0048,0200)', tag_name: "Referenced Image Navigation Sequence", tag_key: 'ReferencedImageNavigationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0048,0200)', tag_sym: :referenced_image_navigation_sequence, tag_ndm: '00480200', tag_ary: [0x0048,0x0200], tag_multiple: false, tag_note: 'RET (2021c)'},
      { tag_ps: '(0048,0201)', tag_name: "Top Left Hand Corner of Localizer Area", tag_key: 'TopLeftHandCornerOfLocalizerArea', tag_vr: [:US], tag_vm: ["2"], tag_str: '(0048,0201)', tag_sym: :top_left_hand_corner_of_localizer_area, tag_ndm: '00480201', tag_ary: [0x0048,0x0201], tag_multiple: false, tag_note: 'RET (2021c)'},
      { tag_ps: '(0048,0202)', tag_name: "Bottom Right Hand Corner of Localizer Area", tag_key: 'BottomRightHandCornerOfLocalizerArea', tag_vr: [:US], tag_vm: ["2"], tag_str: '(0048,0202)', tag_sym: :bottom_right_hand_corner_of_localizer_area, tag_ndm: '00480202', tag_ary: [0x0048,0x0202], tag_multiple: false, tag_note: 'RET (2021c)'},
      { tag_ps: '(0048,0207)', tag_name: "Optical Path Identification Sequence", tag_key: 'OpticalPathIdentificationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0048,0207)', tag_sym: :optical_path_identification_sequence, tag_ndm: '00480207', tag_ary: [0x0048,0x0207], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0048,021A)', tag_name: "Plane Position (Slide) Sequence", tag_key: 'PlanePositionSlideSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0048,021A)', tag_sym: :plane_position_slide_sequence, tag_ndm: '0048021A', tag_ary: [0x0048,0x021A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0048,021E)', tag_name: "Column Position In Total Image Pixel Matrix", tag_key: 'ColumnPositionInTotalImagePixelMatrix', tag_vr: [:SL], tag_vm: ["1"], tag_str: '(0048,021E)', tag_sym: :column_position_in_total_image_pixel_matrix, tag_ndm: '0048021E', tag_ary: [0x0048,0x021E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0048,021F)', tag_name: "Row Position In Total Image Pixel Matrix", tag_key: 'RowPositionInTotalImagePixelMatrix', tag_vr: [:SL], tag_vm: ["1"], tag_str: '(0048,021F)', tag_sym: :row_position_in_total_image_pixel_matrix, tag_ndm: '0048021F', tag_ary: [0x0048,0x021F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0048,0301)', tag_name: "Pixel Origin Interpretation", tag_key: 'PixelOriginInterpretation', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0048,0301)', tag_sym: :pixel_origin_interpretation, tag_ndm: '00480301', tag_ary: [0x0048,0x0301], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0048,0302)', tag_name: "Number of Optical Paths", tag_key: 'NumberOfOpticalPaths', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0048,0302)', tag_sym: :number_of_optical_paths, tag_ndm: '00480302', tag_ary: [0x0048,0x0302], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0048,0303)', tag_name: "Total Pixel Matrix Focal Planes", tag_key: 'TotalPixelMatrixFocalPlanes', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0048,0303)', tag_sym: :total_pixel_matrix_focal_planes, tag_ndm: '00480303', tag_ary: [0x0048,0x0303], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0048,0304)', tag_name: "Tiles Overlap", tag_key: 'TilesOverlap', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0048,0304)', tag_sym: :tiles_overlap, tag_ndm: '00480304', tag_ary: [0x0048,0x0304], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0050,0004)', tag_name: "Calibration Image", tag_key: 'CalibrationImage', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0050,0004)', tag_sym: :calibration_image, tag_ndm: '00500004', tag_ary: [0x0050,0x0004], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0050,0010)', tag_name: "Device Sequence", tag_key: 'DeviceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0050,0010)', tag_sym: :device_sequence, tag_ndm: '00500010', tag_ary: [0x0050,0x0010], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0050,0012)', tag_name: "Container Component Type Code Sequence", tag_key: 'ContainerComponentTypeCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0050,0012)', tag_sym: :container_component_type_code_sequence, tag_ndm: '00500012', tag_ary: [0x0050,0x0012], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0050,0013)', tag_name: "Container Component Thickness", tag_key: 'ContainerComponentThickness', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0050,0013)', tag_sym: :container_component_thickness, tag_ndm: '00500013', tag_ary: [0x0050,0x0013], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0050,0014)', tag_name: "Device Length", tag_key: 'DeviceLength', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0050,0014)', tag_sym: :device_length, tag_ndm: '00500014', tag_ary: [0x0050,0x0014], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0050,0015)', tag_name: "Container Component Width", tag_key: 'ContainerComponentWidth', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0050,0015)', tag_sym: :container_component_width, tag_ndm: '00500015', tag_ary: [0x0050,0x0015], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0050,0016)', tag_name: "Device Diameter", tag_key: 'DeviceDiameter', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0050,0016)', tag_sym: :device_diameter, tag_ndm: '00500016', tag_ary: [0x0050,0x0016], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0050,0017)', tag_name: "Device Diameter Units", tag_key: 'DeviceDiameterUnits', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0050,0017)', tag_sym: :device_diameter_units, tag_ndm: '00500017', tag_ary: [0x0050,0x0017], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0050,0018)', tag_name: "Device Volume", tag_key: 'DeviceVolume', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0050,0018)', tag_sym: :device_volume, tag_ndm: '00500018', tag_ary: [0x0050,0x0018], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0050,0019)', tag_name: "Inter-Marker Distance", tag_key: 'InterMarkerDistance', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0050,0019)', tag_sym: :inter_marker_distance, tag_ndm: '00500019', tag_ary: [0x0050,0x0019], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0050,001A)', tag_name: "Container Component Material", tag_key: 'ContainerComponentMaterial', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0050,001A)', tag_sym: :container_component_material, tag_ndm: '0050001A', tag_ary: [0x0050,0x001A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0050,001B)', tag_name: "Container Component ID", tag_key: 'ContainerComponentID', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0050,001B)', tag_sym: :container_component_id, tag_ndm: '0050001B', tag_ary: [0x0050,0x001B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0050,001C)', tag_name: "Container Component Length", tag_key: 'ContainerComponentLength', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0050,001C)', tag_sym: :container_component_length, tag_ndm: '0050001C', tag_ary: [0x0050,0x001C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0050,001D)', tag_name: "Container Component Diameter", tag_key: 'ContainerComponentDiameter', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0050,001D)', tag_sym: :container_component_diameter, tag_ndm: '0050001D', tag_ary: [0x0050,0x001D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0050,001E)', tag_name: "Container Component Description", tag_key: 'ContainerComponentDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0050,001E)', tag_sym: :container_component_description, tag_ndm: '0050001E', tag_ary: [0x0050,0x001E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0050,0020)', tag_name: "Device Description", tag_key: 'DeviceDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0050,0020)', tag_sym: :device_description, tag_ndm: '00500020', tag_ary: [0x0050,0x0020], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0050,0021)', tag_name: "Long Device Description", tag_key: 'LongDeviceDescription', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0050,0021)', tag_sym: :long_device_description, tag_ndm: '00500021', tag_ary: [0x0050,0x0021], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0052,0001)', tag_name: "Contrast/Bolus Ingredient Percent by Volume", tag_key: 'ContrastBolusIngredientPercentByVolume', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0052,0001)', tag_sym: :contrast_bolus_ingredient_percent_by_volume, tag_ndm: '00520001', tag_ary: [0x0052,0x0001], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0052,0002)', tag_name: "OCT Focal Distance", tag_key: 'OCTFocalDistance', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0052,0002)', tag_sym: :oct_focal_distance, tag_ndm: '00520002', tag_ary: [0x0052,0x0002], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0052,0003)', tag_name: "Beam Spot Size", tag_key: 'BeamSpotSize', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0052,0003)', tag_sym: :beam_spot_size, tag_ndm: '00520003', tag_ary: [0x0052,0x0003], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0052,0004)', tag_name: "Effective Refractive Index", tag_key: 'EffectiveRefractiveIndex', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0052,0004)', tag_sym: :effective_refractive_index, tag_ndm: '00520004', tag_ary: [0x0052,0x0004], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0052,0006)', tag_name: "OCT Acquisition Domain", tag_key: 'OCTAcquisitionDomain', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0052,0006)', tag_sym: :oct_acquisition_domain, tag_ndm: '00520006', tag_ary: [0x0052,0x0006], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0052,0007)', tag_name: "OCT Optical Center Wavelength", tag_key: 'OCTOpticalCenterWavelength', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0052,0007)', tag_sym: :oct_optical_center_wavelength, tag_ndm: '00520007', tag_ary: [0x0052,0x0007], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0052,0008)', tag_name: "Axial Resolution", tag_key: 'AxialResolution', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0052,0008)', tag_sym: :axial_resolution, tag_ndm: '00520008', tag_ary: [0x0052,0x0008], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0052,0009)', tag_name: "Ranging Depth", tag_key: 'RangingDepth', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0052,0009)', tag_sym: :ranging_depth, tag_ndm: '00520009', tag_ary: [0x0052,0x0009], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0052,0011)', tag_name: "A-line Rate", tag_key: 'ALineRate', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0052,0011)', tag_sym: :a_line_rate, tag_ndm: '00520011', tag_ary: [0x0052,0x0011], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0052,0012)', tag_name: "A-lines Per Frame", tag_key: 'ALinesPerFrame', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0052,0012)', tag_sym: :a_lines_per_frame, tag_ndm: '00520012', tag_ary: [0x0052,0x0012], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0052,0013)', tag_name: "Catheter Rotational Rate", tag_key: 'CatheterRotationalRate', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0052,0013)', tag_sym: :catheter_rotational_rate, tag_ndm: '00520013', tag_ary: [0x0052,0x0013], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0052,0014)', tag_name: "A-line Pixel Spacing", tag_key: 'ALinePixelSpacing', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0052,0014)', tag_sym: :a_line_pixel_spacing, tag_ndm: '00520014', tag_ary: [0x0052,0x0014], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0052,0016)', tag_name: "Mode of Percutaneous Access Sequence", tag_key: 'ModeOfPercutaneousAccessSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0052,0016)', tag_sym: :mode_of_percutaneous_access_sequence, tag_ndm: '00520016', tag_ary: [0x0052,0x0016], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0052,0025)', tag_name: "Intravascular OCT Frame Type Sequence", tag_key: 'IntravascularOCTFrameTypeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0052,0025)', tag_sym: :intravascular_oct_frame_type_sequence, tag_ndm: '00520025', tag_ary: [0x0052,0x0025], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0052,0026)', tag_name: "OCT Z Offset Applied", tag_key: 'OCTZOffsetApplied', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0052,0026)', tag_sym: :oct_z_offset_applied, tag_ndm: '00520026', tag_ary: [0x0052,0x0026], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0052,0027)', tag_name: "Intravascular Frame Content Sequence", tag_key: 'IntravascularFrameContentSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0052,0027)', tag_sym: :intravascular_frame_content_sequence, tag_ndm: '00520027', tag_ary: [0x0052,0x0027], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0052,0028)', tag_name: "Intravascular Longitudinal Distance", tag_key: 'IntravascularLongitudinalDistance', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0052,0028)', tag_sym: :intravascular_longitudinal_distance, tag_ndm: '00520028', tag_ary: [0x0052,0x0028], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0052,0029)', tag_name: "Intravascular OCT Frame Content Sequence", tag_key: 'IntravascularOCTFrameContentSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0052,0029)', tag_sym: :intravascular_oct_frame_content_sequence, tag_ndm: '00520029', tag_ary: [0x0052,0x0029], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0052,0030)', tag_name: "OCT Z Offset Correction", tag_key: 'OCTZOffsetCorrection', tag_vr: [:SS], tag_vm: ["1"], tag_str: '(0052,0030)', tag_sym: :oct_z_offset_correction, tag_ndm: '00520030', tag_ary: [0x0052,0x0030], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0052,0031)', tag_name: "Catheter Direction of Rotation", tag_key: 'CatheterDirectionOfRotation', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0052,0031)', tag_sym: :catheter_direction_of_rotation, tag_ndm: '00520031', tag_ary: [0x0052,0x0031], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0052,0033)', tag_name: "Seam Line Location", tag_key: 'SeamLineLocation', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0052,0033)', tag_sym: :seam_line_location, tag_ndm: '00520033', tag_ary: [0x0052,0x0033], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0052,0034)', tag_name: "First A-line Location", tag_key: 'FirstALineLocation', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0052,0034)', tag_sym: :first_a_line_location, tag_ndm: '00520034', tag_ary: [0x0052,0x0034], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0052,0036)', tag_name: "Seam Line Index", tag_key: 'SeamLineIndex', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0052,0036)', tag_sym: :seam_line_index, tag_ndm: '00520036', tag_ary: [0x0052,0x0036], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0052,0038)', tag_name: "Number of Padded A-lines", tag_key: 'NumberOfPaddedALines', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0052,0038)', tag_sym: :number_of_padded_a_lines, tag_ndm: '00520038', tag_ary: [0x0052,0x0038], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0052,0039)', tag_name: "Interpolation Type", tag_key: 'InterpolationType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0052,0039)', tag_sym: :interpolation_type, tag_ndm: '00520039', tag_ary: [0x0052,0x0039], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0052,003A)', tag_name: "Refractive Index Applied", tag_key: 'RefractiveIndexApplied', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0052,003A)', tag_sym: :refractive_index_applied, tag_ndm: '0052003A', tag_ary: [0x0052,0x003A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,0010)', tag_name: "Energy Window Vector", tag_key: 'EnergyWindowVector', tag_vr: [:US], tag_vm: ["1-n"], tag_str: '(0054,0010)', tag_sym: :energy_window_vector, tag_ndm: '00540010', tag_ary: [0x0054,0x0010], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,0011)', tag_name: "Number of Energy Windows", tag_key: 'NumberOfEnergyWindows', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0054,0011)', tag_sym: :number_of_energy_windows, tag_ndm: '00540011', tag_ary: [0x0054,0x0011], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,0012)', tag_name: "Energy Window Information Sequence", tag_key: 'EnergyWindowInformationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0054,0012)', tag_sym: :energy_window_information_sequence, tag_ndm: '00540012', tag_ary: [0x0054,0x0012], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,0013)', tag_name: "Energy Window Range Sequence", tag_key: 'EnergyWindowRangeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0054,0013)', tag_sym: :energy_window_range_sequence, tag_ndm: '00540013', tag_ary: [0x0054,0x0013], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,0014)', tag_name: "Energy Window Lower Limit", tag_key: 'EnergyWindowLowerLimit', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0054,0014)', tag_sym: :energy_window_lower_limit, tag_ndm: '00540014', tag_ary: [0x0054,0x0014], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,0015)', tag_name: "Energy Window Upper Limit", tag_key: 'EnergyWindowUpperLimit', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0054,0015)', tag_sym: :energy_window_upper_limit, tag_ndm: '00540015', tag_ary: [0x0054,0x0015], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,0016)', tag_name: "Radiopharmaceutical Information Sequence", tag_key: 'RadiopharmaceuticalInformationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0054,0016)', tag_sym: :radiopharmaceutical_information_sequence, tag_ndm: '00540016', tag_ary: [0x0054,0x0016], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,0017)', tag_name: "Residual Syringe Counts", tag_key: 'ResidualSyringeCounts', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0054,0017)', tag_sym: :residual_syringe_counts, tag_ndm: '00540017', tag_ary: [0x0054,0x0017], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,0018)', tag_name: "Energy Window Name", tag_key: 'EnergyWindowName', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0054,0018)', tag_sym: :energy_window_name, tag_ndm: '00540018', tag_ary: [0x0054,0x0018], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,0020)', tag_name: "Detector Vector", tag_key: 'DetectorVector', tag_vr: [:US], tag_vm: ["1-n"], tag_str: '(0054,0020)', tag_sym: :detector_vector, tag_ndm: '00540020', tag_ary: [0x0054,0x0020], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,0021)', tag_name: "Number of Detectors", tag_key: 'NumberOfDetectors', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0054,0021)', tag_sym: :number_of_detectors, tag_ndm: '00540021', tag_ary: [0x0054,0x0021], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,0022)', tag_name: "Detector Information Sequence", tag_key: 'DetectorInformationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0054,0022)', tag_sym: :detector_information_sequence, tag_ndm: '00540022', tag_ary: [0x0054,0x0022], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,0030)', tag_name: "Phase Vector", tag_key: 'PhaseVector', tag_vr: [:US], tag_vm: ["1-n"], tag_str: '(0054,0030)', tag_sym: :phase_vector, tag_ndm: '00540030', tag_ary: [0x0054,0x0030], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,0031)', tag_name: "Number of Phases", tag_key: 'NumberOfPhases', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0054,0031)', tag_sym: :number_of_phases, tag_ndm: '00540031', tag_ary: [0x0054,0x0031], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,0032)', tag_name: "Phase Information Sequence", tag_key: 'PhaseInformationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0054,0032)', tag_sym: :phase_information_sequence, tag_ndm: '00540032', tag_ary: [0x0054,0x0032], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,0033)', tag_name: "Number of Frames in Phase", tag_key: 'NumberOfFramesInPhase', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0054,0033)', tag_sym: :number_of_frames_in_phase, tag_ndm: '00540033', tag_ary: [0x0054,0x0033], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,0036)', tag_name: "Phase Delay", tag_key: 'PhaseDelay', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0054,0036)', tag_sym: :phase_delay, tag_ndm: '00540036', tag_ary: [0x0054,0x0036], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,0038)', tag_name: "Pause Between Frames", tag_key: 'PauseBetweenFrames', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0054,0038)', tag_sym: :pause_between_frames, tag_ndm: '00540038', tag_ary: [0x0054,0x0038], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,0039)', tag_name: "Phase Description", tag_key: 'PhaseDescription', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0054,0039)', tag_sym: :phase_description, tag_ndm: '00540039', tag_ary: [0x0054,0x0039], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,0050)', tag_name: "Rotation Vector", tag_key: 'RotationVector', tag_vr: [:US], tag_vm: ["1-n"], tag_str: '(0054,0050)', tag_sym: :rotation_vector, tag_ndm: '00540050', tag_ary: [0x0054,0x0050], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,0051)', tag_name: "Number of Rotations", tag_key: 'NumberOfRotations', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0054,0051)', tag_sym: :number_of_rotations, tag_ndm: '00540051', tag_ary: [0x0054,0x0051], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,0052)', tag_name: "Rotation Information Sequence", tag_key: 'RotationInformationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0054,0052)', tag_sym: :rotation_information_sequence, tag_ndm: '00540052', tag_ary: [0x0054,0x0052], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,0053)', tag_name: "Number of Frames in Rotation", tag_key: 'NumberOfFramesInRotation', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0054,0053)', tag_sym: :number_of_frames_in_rotation, tag_ndm: '00540053', tag_ary: [0x0054,0x0053], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,0060)', tag_name: "R-R Interval Vector", tag_key: 'RRIntervalVector', tag_vr: [:US], tag_vm: ["1-n"], tag_str: '(0054,0060)', tag_sym: :rr_interval_vector, tag_ndm: '00540060', tag_ary: [0x0054,0x0060], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,0061)', tag_name: "Number of R-R Intervals", tag_key: 'NumberOfRRIntervals', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0054,0061)', tag_sym: :number_of_rr_intervals, tag_ndm: '00540061', tag_ary: [0x0054,0x0061], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,0062)', tag_name: "Gated Information Sequence", tag_key: 'GatedInformationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0054,0062)', tag_sym: :gated_information_sequence, tag_ndm: '00540062', tag_ary: [0x0054,0x0062], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,0063)', tag_name: "Data Information Sequence", tag_key: 'DataInformationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0054,0063)', tag_sym: :data_information_sequence, tag_ndm: '00540063', tag_ary: [0x0054,0x0063], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,0070)', tag_name: "Time Slot Vector", tag_key: 'TimeSlotVector', tag_vr: [:US], tag_vm: ["1-n"], tag_str: '(0054,0070)', tag_sym: :time_slot_vector, tag_ndm: '00540070', tag_ary: [0x0054,0x0070], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,0071)', tag_name: "Number of Time Slots", tag_key: 'NumberOfTimeSlots', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0054,0071)', tag_sym: :number_of_time_slots, tag_ndm: '00540071', tag_ary: [0x0054,0x0071], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,0072)', tag_name: "Time Slot Information Sequence", tag_key: 'TimeSlotInformationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0054,0072)', tag_sym: :time_slot_information_sequence, tag_ndm: '00540072', tag_ary: [0x0054,0x0072], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,0073)', tag_name: "Time Slot Time", tag_key: 'TimeSlotTime', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0054,0073)', tag_sym: :time_slot_time, tag_ndm: '00540073', tag_ary: [0x0054,0x0073], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,0080)', tag_name: "Slice Vector", tag_key: 'SliceVector', tag_vr: [:US], tag_vm: ["1-n"], tag_str: '(0054,0080)', tag_sym: :slice_vector, tag_ndm: '00540080', tag_ary: [0x0054,0x0080], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,0081)', tag_name: "Number of Slices", tag_key: 'NumberOfSlices', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0054,0081)', tag_sym: :number_of_slices, tag_ndm: '00540081', tag_ary: [0x0054,0x0081], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,0090)', tag_name: "Angular View Vector", tag_key: 'AngularViewVector', tag_vr: [:US], tag_vm: ["1-n"], tag_str: '(0054,0090)', tag_sym: :angular_view_vector, tag_ndm: '00540090', tag_ary: [0x0054,0x0090], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,0100)', tag_name: "Time Slice Vector", tag_key: 'TimeSliceVector', tag_vr: [:US], tag_vm: ["1-n"], tag_str: '(0054,0100)', tag_sym: :time_slice_vector, tag_ndm: '00540100', tag_ary: [0x0054,0x0100], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,0101)', tag_name: "Number of Time Slices", tag_key: 'NumberOfTimeSlices', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0054,0101)', tag_sym: :number_of_time_slices, tag_ndm: '00540101', tag_ary: [0x0054,0x0101], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,0200)', tag_name: "Start Angle", tag_key: 'StartAngle', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0054,0200)', tag_sym: :start_angle, tag_ndm: '00540200', tag_ary: [0x0054,0x0200], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,0202)', tag_name: "Type of Detector Motion", tag_key: 'TypeOfDetectorMotion', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0054,0202)', tag_sym: :type_of_detector_motion, tag_ndm: '00540202', tag_ary: [0x0054,0x0202], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,0210)', tag_name: "Trigger Vector", tag_key: 'TriggerVector', tag_vr: [:IS], tag_vm: ["1-n"], tag_str: '(0054,0210)', tag_sym: :trigger_vector, tag_ndm: '00540210', tag_ary: [0x0054,0x0210], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,0211)', tag_name: "Number of Triggers in Phase", tag_key: 'NumberOfTriggersInPhase', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0054,0211)', tag_sym: :number_of_triggers_in_phase, tag_ndm: '00540211', tag_ary: [0x0054,0x0211], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,0220)', tag_name: "View Code Sequence", tag_key: 'ViewCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0054,0220)', tag_sym: :view_code_sequence, tag_ndm: '00540220', tag_ary: [0x0054,0x0220], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,0222)', tag_name: "View Modifier Code Sequence", tag_key: 'ViewModifierCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0054,0222)', tag_sym: :view_modifier_code_sequence, tag_ndm: '00540222', tag_ary: [0x0054,0x0222], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,0300)', tag_name: "Radionuclide Code Sequence", tag_key: 'RadionuclideCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0054,0300)', tag_sym: :radionuclide_code_sequence, tag_ndm: '00540300', tag_ary: [0x0054,0x0300], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,0302)', tag_name: "Administration Route Code Sequence", tag_key: 'AdministrationRouteCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0054,0302)', tag_sym: :administration_route_code_sequence, tag_ndm: '00540302', tag_ary: [0x0054,0x0302], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,0304)', tag_name: "Radiopharmaceutical Code Sequence", tag_key: 'RadiopharmaceuticalCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0054,0304)', tag_sym: :radiopharmaceutical_code_sequence, tag_ndm: '00540304', tag_ary: [0x0054,0x0304], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,0306)', tag_name: "Calibration Data Sequence", tag_key: 'CalibrationDataSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0054,0306)', tag_sym: :calibration_data_sequence, tag_ndm: '00540306', tag_ary: [0x0054,0x0306], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,0308)', tag_name: "Energy Window Number", tag_key: 'EnergyWindowNumber', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0054,0308)', tag_sym: :energy_window_number, tag_ndm: '00540308', tag_ary: [0x0054,0x0308], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,0400)', tag_name: "Image ID", tag_key: 'ImageID', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0054,0400)', tag_sym: :image_id, tag_ndm: '00540400', tag_ary: [0x0054,0x0400], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,0410)', tag_name: "Patient Orientation Code Sequence", tag_key: 'PatientOrientationCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0054,0410)', tag_sym: :patient_orientation_code_sequence, tag_ndm: '00540410', tag_ary: [0x0054,0x0410], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,0412)', tag_name: "Patient Orientation Modifier Code Sequence", tag_key: 'PatientOrientationModifierCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0054,0412)', tag_sym: :patient_orientation_modifier_code_sequence, tag_ndm: '00540412', tag_ary: [0x0054,0x0412], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,0414)', tag_name: "Patient Gantry Relationship Code Sequence", tag_key: 'PatientGantryRelationshipCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0054,0414)', tag_sym: :patient_gantry_relationship_code_sequence, tag_ndm: '00540414', tag_ary: [0x0054,0x0414], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,0500)', tag_name: "Slice Progression Direction", tag_key: 'SliceProgressionDirection', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0054,0500)', tag_sym: :slice_progression_direction, tag_ndm: '00540500', tag_ary: [0x0054,0x0500], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,0501)', tag_name: "Scan Progression Direction", tag_key: 'ScanProgressionDirection', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0054,0501)', tag_sym: :scan_progression_direction, tag_ndm: '00540501', tag_ary: [0x0054,0x0501], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,1000)', tag_name: "Series Type", tag_key: 'SeriesType', tag_vr: [:CS], tag_vm: ["2"], tag_str: '(0054,1000)', tag_sym: :series_type, tag_ndm: '00541000', tag_ary: [0x0054,0x1000], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,1001)', tag_name: "Units", tag_key: 'Units', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0054,1001)', tag_sym: :units, tag_ndm: '00541001', tag_ary: [0x0054,0x1001], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,1002)', tag_name: "Counts Source", tag_key: 'CountsSource', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0054,1002)', tag_sym: :counts_source, tag_ndm: '00541002', tag_ary: [0x0054,0x1002], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,1004)', tag_name: "Reprojection Method", tag_key: 'ReprojectionMethod', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0054,1004)', tag_sym: :reprojection_method, tag_ndm: '00541004', tag_ary: [0x0054,0x1004], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,1006)', tag_name: "SUV Type", tag_key: 'SUVType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0054,1006)', tag_sym: :suv_type, tag_ndm: '00541006', tag_ary: [0x0054,0x1006], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,1100)', tag_name: "Randoms Correction Method", tag_key: 'RandomsCorrectionMethod', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0054,1100)', tag_sym: :randoms_correction_method, tag_ndm: '00541100', tag_ary: [0x0054,0x1100], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,1101)', tag_name: "Attenuation Correction Method", tag_key: 'AttenuationCorrectionMethod', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0054,1101)', tag_sym: :attenuation_correction_method, tag_ndm: '00541101', tag_ary: [0x0054,0x1101], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,1102)', tag_name: "Decay Correction", tag_key: 'DecayCorrection', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0054,1102)', tag_sym: :decay_correction, tag_ndm: '00541102', tag_ary: [0x0054,0x1102], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,1103)', tag_name: "Reconstruction Method", tag_key: 'ReconstructionMethod', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0054,1103)', tag_sym: :reconstruction_method, tag_ndm: '00541103', tag_ary: [0x0054,0x1103], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,1104)', tag_name: "Detector Lines of Response Used", tag_key: 'DetectorLinesOfResponseUsed', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0054,1104)', tag_sym: :detector_lines_of_response_used, tag_ndm: '00541104', tag_ary: [0x0054,0x1104], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,1105)', tag_name: "Scatter Correction Method", tag_key: 'ScatterCorrectionMethod', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0054,1105)', tag_sym: :scatter_correction_method, tag_ndm: '00541105', tag_ary: [0x0054,0x1105], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,1200)', tag_name: "Axial Acceptance", tag_key: 'AxialAcceptance', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0054,1200)', tag_sym: :axial_acceptance, tag_ndm: '00541200', tag_ary: [0x0054,0x1200], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,1201)', tag_name: "Axial Mash", tag_key: 'AxialMash', tag_vr: [:IS], tag_vm: ["2"], tag_str: '(0054,1201)', tag_sym: :axial_mash, tag_ndm: '00541201', tag_ary: [0x0054,0x1201], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,1202)', tag_name: "Transverse Mash", tag_key: 'TransverseMash', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0054,1202)', tag_sym: :transverse_mash, tag_ndm: '00541202', tag_ary: [0x0054,0x1202], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,1203)', tag_name: "Detector Element Size", tag_key: 'DetectorElementSize', tag_vr: [:DS], tag_vm: ["2"], tag_str: '(0054,1203)', tag_sym: :detector_element_size, tag_ndm: '00541203', tag_ary: [0x0054,0x1203], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,1210)', tag_name: "Coincidence Window Width", tag_key: 'CoincidenceWindowWidth', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0054,1210)', tag_sym: :coincidence_window_width, tag_ndm: '00541210', tag_ary: [0x0054,0x1210], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,1220)', tag_name: "Secondary Counts Type", tag_key: 'SecondaryCountsType', tag_vr: [:CS], tag_vm: ["1-n"], tag_str: '(0054,1220)', tag_sym: :secondary_counts_type, tag_ndm: '00541220', tag_ary: [0x0054,0x1220], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,1300)', tag_name: "Frame Reference Time", tag_key: 'FrameReferenceTime', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0054,1300)', tag_sym: :frame_reference_time, tag_ndm: '00541300', tag_ary: [0x0054,0x1300], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,1310)', tag_name: "Primary (Prompts) Counts Accumulated", tag_key: 'PrimaryPromptsCountsAccumulated', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0054,1310)', tag_sym: :primary_prompts_counts_accumulated, tag_ndm: '00541310', tag_ary: [0x0054,0x1310], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,1311)', tag_name: "Secondary Counts Accumulated", tag_key: 'SecondaryCountsAccumulated', tag_vr: [:IS], tag_vm: ["1-n"], tag_str: '(0054,1311)', tag_sym: :secondary_counts_accumulated, tag_ndm: '00541311', tag_ary: [0x0054,0x1311], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,1320)', tag_name: "Slice Sensitivity Factor", tag_key: 'SliceSensitivityFactor', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0054,1320)', tag_sym: :slice_sensitivity_factor, tag_ndm: '00541320', tag_ary: [0x0054,0x1320], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,1321)', tag_name: "Decay Factor", tag_key: 'DecayFactor', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0054,1321)', tag_sym: :decay_factor, tag_ndm: '00541321', tag_ary: [0x0054,0x1321], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,1322)', tag_name: "Dose Calibration Factor", tag_key: 'DoseCalibrationFactor', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0054,1322)', tag_sym: :dose_calibration_factor, tag_ndm: '00541322', tag_ary: [0x0054,0x1322], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,1323)', tag_name: "Scatter Fraction Factor", tag_key: 'ScatterFractionFactor', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0054,1323)', tag_sym: :scatter_fraction_factor, tag_ndm: '00541323', tag_ary: [0x0054,0x1323], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,1324)', tag_name: "Dead Time Factor", tag_key: 'DeadTimeFactor', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0054,1324)', tag_sym: :dead_time_factor, tag_ndm: '00541324', tag_ary: [0x0054,0x1324], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,1330)', tag_name: "Image Index", tag_key: 'ImageIndex', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0054,1330)', tag_sym: :image_index, tag_ndm: '00541330', tag_ary: [0x0054,0x1330], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0054,1400)', tag_name: "Counts Included", tag_key: 'CountsIncluded', tag_vr: [:CS], tag_vm: ["1-n"], tag_str: '(0054,1400)', tag_sym: :counts_included, tag_ndm: '00541400', tag_ary: [0x0054,0x1400], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0054,1401)', tag_name: "Dead Time Correction Flag", tag_key: 'DeadTimeCorrectionFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0054,1401)', tag_sym: :dead_time_correction_flag, tag_ndm: '00541401', tag_ary: [0x0054,0x1401], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0060,3000)', tag_name: "Histogram Sequence", tag_key: 'HistogramSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0060,3000)', tag_sym: :histogram_sequence, tag_ndm: '00603000', tag_ary: [0x0060,0x3000], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0060,3002)', tag_name: "Histogram Number of Bins", tag_key: 'HistogramNumberOfBins', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0060,3002)', tag_sym: :histogram_number_of_bins, tag_ndm: '00603002', tag_ary: [0x0060,0x3002], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0060,3004)', tag_name: "Histogram First Bin Value", tag_key: 'HistogramFirstBinValue', tag_vr: [:US, :SS], tag_vm: ["1"], tag_str: '(0060,3004)', tag_sym: :histogram_first_bin_value, tag_ndm: '00603004', tag_ary: [0x0060,0x3004], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0060,3006)', tag_name: "Histogram Last Bin Value", tag_key: 'HistogramLastBinValue', tag_vr: [:US, :SS], tag_vm: ["1"], tag_str: '(0060,3006)', tag_sym: :histogram_last_bin_value, tag_ndm: '00603006', tag_ary: [0x0060,0x3006], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0060,3008)', tag_name: "Histogram Bin Width", tag_key: 'HistogramBinWidth', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0060,3008)', tag_sym: :histogram_bin_width, tag_ndm: '00603008', tag_ary: [0x0060,0x3008], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0060,3010)', tag_name: "Histogram Explanation", tag_key: 'HistogramExplanation', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0060,3010)', tag_sym: :histogram_explanation, tag_ndm: '00603010', tag_ary: [0x0060,0x3010], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0060,3020)', tag_name: "Histogram Data", tag_key: 'HistogramData', tag_vr: [:UL], tag_vm: ["1-n"], tag_str: '(0060,3020)', tag_sym: :histogram_data, tag_ndm: '00603020', tag_ary: [0x0060,0x3020], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0062,0001)', tag_name: "Segmentation Type", tag_key: 'SegmentationType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0062,0001)', tag_sym: :segmentation_type, tag_ndm: '00620001', tag_ary: [0x0062,0x0001], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0062,0002)', tag_name: "Segment Sequence", tag_key: 'SegmentSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0062,0002)', tag_sym: :segment_sequence, tag_ndm: '00620002', tag_ary: [0x0062,0x0002], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0062,0003)', tag_name: "Segmented Property Category Code Sequence", tag_key: 'SegmentedPropertyCategoryCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0062,0003)', tag_sym: :segmented_property_category_code_sequence, tag_ndm: '00620003', tag_ary: [0x0062,0x0003], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0062,0004)', tag_name: "Segment Number", tag_key: 'SegmentNumber', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0062,0004)', tag_sym: :segment_number, tag_ndm: '00620004', tag_ary: [0x0062,0x0004], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0062,0005)', tag_name: "Segment Label", tag_key: 'SegmentLabel', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0062,0005)', tag_sym: :segment_label, tag_ndm: '00620005', tag_ary: [0x0062,0x0005], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0062,0006)', tag_name: "Segment Description", tag_key: 'SegmentDescription', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0062,0006)', tag_sym: :segment_description, tag_ndm: '00620006', tag_ary: [0x0062,0x0006], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0062,0007)', tag_name: "Segmentation Algorithm Identification Sequence", tag_key: 'SegmentationAlgorithmIdentificationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0062,0007)', tag_sym: :segmentation_algorithm_identification_sequence, tag_ndm: '00620007', tag_ary: [0x0062,0x0007], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0062,0008)', tag_name: "Segment Algorithm Type", tag_key: 'SegmentAlgorithmType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0062,0008)', tag_sym: :segment_algorithm_type, tag_ndm: '00620008', tag_ary: [0x0062,0x0008], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0062,0009)', tag_name: "Segment Algorithm Name", tag_key: 'SegmentAlgorithmName', tag_vr: [:LO], tag_vm: ["1-n"], tag_str: '(0062,0009)', tag_sym: :segment_algorithm_name, tag_ndm: '00620009', tag_ary: [0x0062,0x0009], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0062,000A)', tag_name: "Segment Identification Sequence", tag_key: 'SegmentIdentificationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0062,000A)', tag_sym: :segment_identification_sequence, tag_ndm: '0062000A', tag_ary: [0x0062,0x000A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0062,000B)', tag_name: "Referenced Segment Number", tag_key: 'ReferencedSegmentNumber', tag_vr: [:US], tag_vm: ["1-n"], tag_str: '(0062,000B)', tag_sym: :referenced_segment_number, tag_ndm: '0062000B', tag_ary: [0x0062,0x000B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0062,000C)', tag_name: "Recommended Display Grayscale Value", tag_key: 'RecommendedDisplayGrayscaleValue', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0062,000C)', tag_sym: :recommended_display_grayscale_value, tag_ndm: '0062000C', tag_ary: [0x0062,0x000C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0062,000D)', tag_name: "Recommended Display CIELab Value", tag_key: 'RecommendedDisplayCIELabValue', tag_vr: [:US], tag_vm: ["3"], tag_str: '(0062,000D)', tag_sym: :recommended_display_cie_lab_value, tag_ndm: '0062000D', tag_ary: [0x0062,0x000D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0062,000E)', tag_name: "Maximum Fractional Value", tag_key: 'MaximumFractionalValue', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0062,000E)', tag_sym: :maximum_fractional_value, tag_ndm: '0062000E', tag_ary: [0x0062,0x000E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0062,000F)', tag_name: "Segmented Property Type Code Sequence", tag_key: 'SegmentedPropertyTypeCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0062,000F)', tag_sym: :segmented_property_type_code_sequence, tag_ndm: '0062000F', tag_ary: [0x0062,0x000F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0062,0010)', tag_name: "Segmentation Fractional Type", tag_key: 'SegmentationFractionalType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0062,0010)', tag_sym: :segmentation_fractional_type, tag_ndm: '00620010', tag_ary: [0x0062,0x0010], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0062,0011)', tag_name: "Segmented Property Type Modifier Code Sequence", tag_key: 'SegmentedPropertyTypeModifierCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0062,0011)', tag_sym: :segmented_property_type_modifier_code_sequence, tag_ndm: '00620011', tag_ary: [0x0062,0x0011], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0062,0012)', tag_name: "Used Segments Sequence", tag_key: 'UsedSegmentsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0062,0012)', tag_sym: :used_segments_sequence, tag_ndm: '00620012', tag_ary: [0x0062,0x0012], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0062,0013)', tag_name: "Segments Overlap", tag_key: 'SegmentsOverlap', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0062,0013)', tag_sym: :segments_overlap, tag_ndm: '00620013', tag_ary: [0x0062,0x0013], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0062,0020)', tag_name: "Tracking ID", tag_key: 'TrackingID', tag_vr: [:UT], tag_vm: ["1"], tag_str: '(0062,0020)', tag_sym: :tracking_id, tag_ndm: '00620020', tag_ary: [0x0062,0x0020], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0062,0021)', tag_name: "Tracking UID", tag_key: 'TrackingUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0062,0021)', tag_sym: :tracking_uid, tag_ndm: '00620021', tag_ary: [0x0062,0x0021], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0064,0002)', tag_name: "Deformable Registration Sequence", tag_key: 'DeformableRegistrationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0064,0002)', tag_sym: :deformable_registration_sequence, tag_ndm: '00640002', tag_ary: [0x0064,0x0002], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0064,0003)', tag_name: "Source Frame of Reference UID", tag_key: 'SourceFrameOfReferenceUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0064,0003)', tag_sym: :source_frame_of_reference_uid, tag_ndm: '00640003', tag_ary: [0x0064,0x0003], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0064,0005)', tag_name: "Deformable Registration Grid Sequence", tag_key: 'DeformableRegistrationGridSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0064,0005)', tag_sym: :deformable_registration_grid_sequence, tag_ndm: '00640005', tag_ary: [0x0064,0x0005], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0064,0007)', tag_name: "Grid Dimensions", tag_key: 'GridDimensions', tag_vr: [:UL], tag_vm: ["3"], tag_str: '(0064,0007)', tag_sym: :grid_dimensions, tag_ndm: '00640007', tag_ary: [0x0064,0x0007], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0064,0008)', tag_name: "Grid Resolution", tag_key: 'GridResolution', tag_vr: [:FD], tag_vm: ["3"], tag_str: '(0064,0008)', tag_sym: :grid_resolution, tag_ndm: '00640008', tag_ary: [0x0064,0x0008], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0064,0009)', tag_name: "Vector Grid Data", tag_key: 'VectorGridData', tag_vr: [:OF], tag_vm: ["1"], tag_str: '(0064,0009)', tag_sym: :vector_grid_data, tag_ndm: '00640009', tag_ary: [0x0064,0x0009], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0064,000F)', tag_name: "Pre Deformation Matrix Registration Sequence", tag_key: 'PreDeformationMatrixRegistrationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0064,000F)', tag_sym: :pre_deformation_matrix_registration_sequence, tag_ndm: '0064000F', tag_ary: [0x0064,0x000F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0064,0010)', tag_name: "Post Deformation Matrix Registration Sequence", tag_key: 'PostDeformationMatrixRegistrationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0064,0010)', tag_sym: :post_deformation_matrix_registration_sequence, tag_ndm: '00640010', tag_ary: [0x0064,0x0010], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,0001)', tag_name: "Number of Surfaces", tag_key: 'NumberOfSurfaces', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0066,0001)', tag_sym: :number_of_surfaces, tag_ndm: '00660001', tag_ary: [0x0066,0x0001], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,0002)', tag_name: "Surface Sequence", tag_key: 'SurfaceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0066,0002)', tag_sym: :surface_sequence, tag_ndm: '00660002', tag_ary: [0x0066,0x0002], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,0003)', tag_name: "Surface Number", tag_key: 'SurfaceNumber', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0066,0003)', tag_sym: :surface_number, tag_ndm: '00660003', tag_ary: [0x0066,0x0003], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,0004)', tag_name: "Surface Comments", tag_key: 'SurfaceComments', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(0066,0004)', tag_sym: :surface_comments, tag_ndm: '00660004', tag_ary: [0x0066,0x0004], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,0005)', tag_name: "Surface Offset", tag_key: 'SurfaceOffset', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0066,0005)', tag_sym: :surface_offset, tag_ndm: '00660005', tag_ary: [0x0066,0x0005], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,0009)', tag_name: "Surface Processing", tag_key: 'SurfaceProcessing', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0066,0009)', tag_sym: :surface_processing, tag_ndm: '00660009', tag_ary: [0x0066,0x0009], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,000A)', tag_name: "Surface Processing Ratio", tag_key: 'SurfaceProcessingRatio', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0066,000A)', tag_sym: :surface_processing_ratio, tag_ndm: '0066000A', tag_ary: [0x0066,0x000A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,000B)', tag_name: "Surface Processing Description", tag_key: 'SurfaceProcessingDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0066,000B)', tag_sym: :surface_processing_description, tag_ndm: '0066000B', tag_ary: [0x0066,0x000B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,000C)', tag_name: "Recommended Presentation Opacity", tag_key: 'RecommendedPresentationOpacity', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0066,000C)', tag_sym: :recommended_presentation_opacity, tag_ndm: '0066000C', tag_ary: [0x0066,0x000C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,000D)', tag_name: "Recommended Presentation Type", tag_key: 'RecommendedPresentationType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0066,000D)', tag_sym: :recommended_presentation_type, tag_ndm: '0066000D', tag_ary: [0x0066,0x000D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,000E)', tag_name: "Finite Volume", tag_key: 'FiniteVolume', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0066,000E)', tag_sym: :finite_volume, tag_ndm: '0066000E', tag_ary: [0x0066,0x000E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,0010)', tag_name: "Manifold", tag_key: 'Manifold', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0066,0010)', tag_sym: :manifold, tag_ndm: '00660010', tag_ary: [0x0066,0x0010], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,0011)', tag_name: "Surface Points Sequence", tag_key: 'SurfacePointsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0066,0011)', tag_sym: :surface_points_sequence, tag_ndm: '00660011', tag_ary: [0x0066,0x0011], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,0012)', tag_name: "Surface Points Normals Sequence", tag_key: 'SurfacePointsNormalsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0066,0012)', tag_sym: :surface_points_normals_sequence, tag_ndm: '00660012', tag_ary: [0x0066,0x0012], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,0013)', tag_name: "Surface Mesh Primitives Sequence", tag_key: 'SurfaceMeshPrimitivesSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0066,0013)', tag_sym: :surface_mesh_primitives_sequence, tag_ndm: '00660013', tag_ary: [0x0066,0x0013], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,0015)', tag_name: "Number of Surface Points", tag_key: 'NumberOfSurfacePoints', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0066,0015)', tag_sym: :number_of_surface_points, tag_ndm: '00660015', tag_ary: [0x0066,0x0015], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,0016)', tag_name: "Point Coordinates Data", tag_key: 'PointCoordinatesData', tag_vr: [:OF], tag_vm: ["1"], tag_str: '(0066,0016)', tag_sym: :point_coordinates_data, tag_ndm: '00660016', tag_ary: [0x0066,0x0016], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,0017)', tag_name: "Point Position Accuracy", tag_key: 'PointPositionAccuracy', tag_vr: [:FL], tag_vm: ["3"], tag_str: '(0066,0017)', tag_sym: :point_position_accuracy, tag_ndm: '00660017', tag_ary: [0x0066,0x0017], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,0018)', tag_name: "Mean Point Distance", tag_key: 'MeanPointDistance', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0066,0018)', tag_sym: :mean_point_distance, tag_ndm: '00660018', tag_ary: [0x0066,0x0018], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,0019)', tag_name: "Maximum Point Distance", tag_key: 'MaximumPointDistance', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0066,0019)', tag_sym: :maximum_point_distance, tag_ndm: '00660019', tag_ary: [0x0066,0x0019], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,001A)', tag_name: "Points Bounding Box Coordinates", tag_key: 'PointsBoundingBoxCoordinates', tag_vr: [:FL], tag_vm: ["6"], tag_str: '(0066,001A)', tag_sym: :points_bounding_box_coordinates, tag_ndm: '0066001A', tag_ary: [0x0066,0x001A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,001B)', tag_name: "Axis of Rotation", tag_key: 'AxisOfRotation', tag_vr: [:FL], tag_vm: ["3"], tag_str: '(0066,001B)', tag_sym: :axis_of_rotation, tag_ndm: '0066001B', tag_ary: [0x0066,0x001B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,001C)', tag_name: "Center of Rotation", tag_key: 'CenterOfRotation', tag_vr: [:FL], tag_vm: ["3"], tag_str: '(0066,001C)', tag_sym: :center_of_rotation, tag_ndm: '0066001C', tag_ary: [0x0066,0x001C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,001E)', tag_name: "Number of Vectors", tag_key: 'NumberOfVectors', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0066,001E)', tag_sym: :number_of_vectors, tag_ndm: '0066001E', tag_ary: [0x0066,0x001E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,001F)', tag_name: "Vector Dimensionality", tag_key: 'VectorDimensionality', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0066,001F)', tag_sym: :vector_dimensionality, tag_ndm: '0066001F', tag_ary: [0x0066,0x001F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,0020)', tag_name: "Vector Accuracy", tag_key: 'VectorAccuracy', tag_vr: [:FL], tag_vm: ["1-n"], tag_str: '(0066,0020)', tag_sym: :vector_accuracy, tag_ndm: '00660020', tag_ary: [0x0066,0x0020], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,0021)', tag_name: "Vector Coordinate Data", tag_key: 'VectorCoordinateData', tag_vr: [:OF], tag_vm: ["1"], tag_str: '(0066,0021)', tag_sym: :vector_coordinate_data, tag_ndm: '00660021', tag_ary: [0x0066,0x0021], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,0022)', tag_name: "Double Point Coordinates Data", tag_key: 'DoublePointCoordinatesData', tag_vr: [:OD], tag_vm: ["1"], tag_str: '(0066,0022)', tag_sym: :double_point_coordinates_data, tag_ndm: '00660022', tag_ary: [0x0066,0x0022], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,0023)', tag_name: "Triangle Point Index List", tag_key: 'TrianglePointIndexList', tag_vr: [:OW], tag_vm: ["1"], tag_str: '(0066,0023)', tag_sym: :triangle_point_index_list, tag_ndm: '00660023', tag_ary: [0x0066,0x0023], tag_multiple: false, tag_note: 'RET (2015c)'},
      { tag_ps: '(0066,0024)', tag_name: "Edge Point Index List", tag_key: 'EdgePointIndexList', tag_vr: [:OW], tag_vm: ["1"], tag_str: '(0066,0024)', tag_sym: :edge_point_index_list, tag_ndm: '00660024', tag_ary: [0x0066,0x0024], tag_multiple: false, tag_note: 'RET (2015c)'},
      { tag_ps: '(0066,0025)', tag_name: "Vertex Point Index List", tag_key: 'VertexPointIndexList', tag_vr: [:OW], tag_vm: ["1"], tag_str: '(0066,0025)', tag_sym: :vertex_point_index_list, tag_ndm: '00660025', tag_ary: [0x0066,0x0025], tag_multiple: false, tag_note: 'RET (2015c)'},
      { tag_ps: '(0066,0026)', tag_name: "Triangle Strip Sequence", tag_key: 'TriangleStripSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0066,0026)', tag_sym: :triangle_strip_sequence, tag_ndm: '00660026', tag_ary: [0x0066,0x0026], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,0027)', tag_name: "Triangle Fan Sequence", tag_key: 'TriangleFanSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0066,0027)', tag_sym: :triangle_fan_sequence, tag_ndm: '00660027', tag_ary: [0x0066,0x0027], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,0028)', tag_name: "Line Sequence", tag_key: 'LineSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0066,0028)', tag_sym: :line_sequence, tag_ndm: '00660028', tag_ary: [0x0066,0x0028], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,0029)', tag_name: "Primitive Point Index List", tag_key: 'PrimitivePointIndexList', tag_vr: [:OW], tag_vm: ["1"], tag_str: '(0066,0029)', tag_sym: :primitive_point_index_list, tag_ndm: '00660029', tag_ary: [0x0066,0x0029], tag_multiple: false, tag_note: 'RET (2015c)'},
      { tag_ps: '(0066,002A)', tag_name: "Surface Count", tag_key: 'SurfaceCount', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0066,002A)', tag_sym: :surface_count, tag_ndm: '0066002A', tag_ary: [0x0066,0x002A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,002B)', tag_name: "Referenced Surface Sequence", tag_key: 'ReferencedSurfaceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0066,002B)', tag_sym: :referenced_surface_sequence, tag_ndm: '0066002B', tag_ary: [0x0066,0x002B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,002C)', tag_name: "Referenced Surface Number", tag_key: 'ReferencedSurfaceNumber', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0066,002C)', tag_sym: :referenced_surface_number, tag_ndm: '0066002C', tag_ary: [0x0066,0x002C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,002D)', tag_name: "Segment Surface Generation Algorithm Identification Sequence", tag_key: 'SegmentSurfaceGenerationAlgorithmIdentificationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0066,002D)', tag_sym: :segment_surface_generation_algorithm_identification_sequence, tag_ndm: '0066002D', tag_ary: [0x0066,0x002D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,002E)', tag_name: "Segment Surface Source Instance Sequence", tag_key: 'SegmentSurfaceSourceInstanceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0066,002E)', tag_sym: :segment_surface_source_instance_sequence, tag_ndm: '0066002E', tag_ary: [0x0066,0x002E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,002F)', tag_name: "Algorithm Family Code Sequence", tag_key: 'AlgorithmFamilyCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0066,002F)', tag_sym: :algorithm_family_code_sequence, tag_ndm: '0066002F', tag_ary: [0x0066,0x002F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,0030)', tag_name: "Algorithm Name Code Sequence", tag_key: 'AlgorithmNameCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0066,0030)', tag_sym: :algorithm_name_code_sequence, tag_ndm: '00660030', tag_ary: [0x0066,0x0030], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,0031)', tag_name: "Algorithm Version", tag_key: 'AlgorithmVersion', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0066,0031)', tag_sym: :algorithm_version, tag_ndm: '00660031', tag_ary: [0x0066,0x0031], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,0032)', tag_name: "Algorithm Parameters", tag_key: 'AlgorithmParameters', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(0066,0032)', tag_sym: :algorithm_parameters, tag_ndm: '00660032', tag_ary: [0x0066,0x0032], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,0034)', tag_name: "Facet Sequence", tag_key: 'FacetSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0066,0034)', tag_sym: :facet_sequence, tag_ndm: '00660034', tag_ary: [0x0066,0x0034], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,0035)', tag_name: "Surface Processing Algorithm Identification Sequence", tag_key: 'SurfaceProcessingAlgorithmIdentificationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0066,0035)', tag_sym: :surface_processing_algorithm_identification_sequence, tag_ndm: '00660035', tag_ary: [0x0066,0x0035], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,0036)', tag_name: "Algorithm Name", tag_key: 'AlgorithmName', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0066,0036)', tag_sym: :algorithm_name, tag_ndm: '00660036', tag_ary: [0x0066,0x0036], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,0037)', tag_name: "Recommended Point Radius", tag_key: 'RecommendedPointRadius', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0066,0037)', tag_sym: :recommended_point_radius, tag_ndm: '00660037', tag_ary: [0x0066,0x0037], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,0038)', tag_name: "Recommended Line Thickness", tag_key: 'RecommendedLineThickness', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0066,0038)', tag_sym: :recommended_line_thickness, tag_ndm: '00660038', tag_ary: [0x0066,0x0038], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,0040)', tag_name: "Long Primitive Point Index List", tag_key: 'LongPrimitivePointIndexList', tag_vr: [:OL], tag_vm: ["1"], tag_str: '(0066,0040)', tag_sym: :long_primitive_point_index_list, tag_ndm: '00660040', tag_ary: [0x0066,0x0040], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,0041)', tag_name: "Long Triangle Point Index List", tag_key: 'LongTrianglePointIndexList', tag_vr: [:OL], tag_vm: ["1"], tag_str: '(0066,0041)', tag_sym: :long_triangle_point_index_list, tag_ndm: '00660041', tag_ary: [0x0066,0x0041], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,0042)', tag_name: "Long Edge Point Index List", tag_key: 'LongEdgePointIndexList', tag_vr: [:OL], tag_vm: ["1"], tag_str: '(0066,0042)', tag_sym: :long_edge_point_index_list, tag_ndm: '00660042', tag_ary: [0x0066,0x0042], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,0043)', tag_name: "Long Vertex Point Index List", tag_key: 'LongVertexPointIndexList', tag_vr: [:OL], tag_vm: ["1"], tag_str: '(0066,0043)', tag_sym: :long_vertex_point_index_list, tag_ndm: '00660043', tag_ary: [0x0066,0x0043], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,0101)', tag_name: "Track Set Sequence", tag_key: 'TrackSetSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0066,0101)', tag_sym: :track_set_sequence, tag_ndm: '00660101', tag_ary: [0x0066,0x0101], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,0102)', tag_name: "Track Sequence", tag_key: 'TrackSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0066,0102)', tag_sym: :track_sequence, tag_ndm: '00660102', tag_ary: [0x0066,0x0102], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,0103)', tag_name: "Recommended Display CIELab Value List", tag_key: 'RecommendedDisplayCIELabValueList', tag_vr: [:OW], tag_vm: ["1"], tag_str: '(0066,0103)', tag_sym: :recommended_display_cie_lab_value_list, tag_ndm: '00660103', tag_ary: [0x0066,0x0103], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,0104)', tag_name: "Tracking Algorithm Identification Sequence", tag_key: 'TrackingAlgorithmIdentificationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0066,0104)', tag_sym: :tracking_algorithm_identification_sequence, tag_ndm: '00660104', tag_ary: [0x0066,0x0104], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,0105)', tag_name: "Track Set Number", tag_key: 'TrackSetNumber', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0066,0105)', tag_sym: :track_set_number, tag_ndm: '00660105', tag_ary: [0x0066,0x0105], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,0106)', tag_name: "Track Set Label", tag_key: 'TrackSetLabel', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0066,0106)', tag_sym: :track_set_label, tag_ndm: '00660106', tag_ary: [0x0066,0x0106], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,0107)', tag_name: "Track Set Description", tag_key: 'TrackSetDescription', tag_vr: [:UT], tag_vm: ["1"], tag_str: '(0066,0107)', tag_sym: :track_set_description, tag_ndm: '00660107', tag_ary: [0x0066,0x0107], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,0108)', tag_name: "Track Set Anatomical Type Code Sequence", tag_key: 'TrackSetAnatomicalTypeCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0066,0108)', tag_sym: :track_set_anatomical_type_code_sequence, tag_ndm: '00660108', tag_ary: [0x0066,0x0108], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,0121)', tag_name: "Measurements Sequence", tag_key: 'MeasurementsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0066,0121)', tag_sym: :measurements_sequence, tag_ndm: '00660121', tag_ary: [0x0066,0x0121], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,0124)', tag_name: "Track Set Statistics Sequence", tag_key: 'TrackSetStatisticsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0066,0124)', tag_sym: :track_set_statistics_sequence, tag_ndm: '00660124', tag_ary: [0x0066,0x0124], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,0125)', tag_name: "Floating Point Values", tag_key: 'FloatingPointValues', tag_vr: [:OF], tag_vm: ["1"], tag_str: '(0066,0125)', tag_sym: :floating_point_values, tag_ndm: '00660125', tag_ary: [0x0066,0x0125], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,0129)', tag_name: "Track Point Index List", tag_key: 'TrackPointIndexList', tag_vr: [:OL], tag_vm: ["1"], tag_str: '(0066,0129)', tag_sym: :track_point_index_list, tag_ndm: '00660129', tag_ary: [0x0066,0x0129], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,0130)', tag_name: "Track Statistics Sequence", tag_key: 'TrackStatisticsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0066,0130)', tag_sym: :track_statistics_sequence, tag_ndm: '00660130', tag_ary: [0x0066,0x0130], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,0132)', tag_name: "Measurement Values Sequence", tag_key: 'MeasurementValuesSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0066,0132)', tag_sym: :measurement_values_sequence, tag_ndm: '00660132', tag_ary: [0x0066,0x0132], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,0133)', tag_name: "Diffusion Acquisition Code Sequence", tag_key: 'DiffusionAcquisitionCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0066,0133)', tag_sym: :diffusion_acquisition_code_sequence, tag_ndm: '00660133', tag_ary: [0x0066,0x0133], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0066,0134)', tag_name: "Diffusion Model Code Sequence", tag_key: 'DiffusionModelCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0066,0134)', tag_sym: :diffusion_model_code_sequence, tag_ndm: '00660134', tag_ary: [0x0066,0x0134], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,6210)', tag_name: "Implant Size", tag_key: 'ImplantSize', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0068,6210)', tag_sym: :implant_size, tag_ndm: '00686210', tag_ary: [0x0068,0x6210], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,6221)', tag_name: "Implant Template Version", tag_key: 'ImplantTemplateVersion', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0068,6221)', tag_sym: :implant_template_version, tag_ndm: '00686221', tag_ary: [0x0068,0x6221], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,6222)', tag_name: "Replaced Implant Template Sequence", tag_key: 'ReplacedImplantTemplateSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0068,6222)', tag_sym: :replaced_implant_template_sequence, tag_ndm: '00686222', tag_ary: [0x0068,0x6222], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,6223)', tag_name: "Implant Type", tag_key: 'ImplantType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0068,6223)', tag_sym: :implant_type, tag_ndm: '00686223', tag_ary: [0x0068,0x6223], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,6224)', tag_name: "Derivation Implant Template Sequence", tag_key: 'DerivationImplantTemplateSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0068,6224)', tag_sym: :derivation_implant_template_sequence, tag_ndm: '00686224', tag_ary: [0x0068,0x6224], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,6225)', tag_name: "Original Implant Template Sequence", tag_key: 'OriginalImplantTemplateSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0068,6225)', tag_sym: :original_implant_template_sequence, tag_ndm: '00686225', tag_ary: [0x0068,0x6225], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,6226)', tag_name: "Effective DateTime", tag_key: 'EffectiveDateTime', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(0068,6226)', tag_sym: :effective_date_time, tag_ndm: '00686226', tag_ary: [0x0068,0x6226], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,6230)', tag_name: "Implant Target Anatomy Sequence", tag_key: 'ImplantTargetAnatomySequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0068,6230)', tag_sym: :implant_target_anatomy_sequence, tag_ndm: '00686230', tag_ary: [0x0068,0x6230], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,6260)', tag_name: "Information From Manufacturer Sequence", tag_key: 'InformationFromManufacturerSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0068,6260)', tag_sym: :information_from_manufacturer_sequence, tag_ndm: '00686260', tag_ary: [0x0068,0x6260], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,6265)', tag_name: "Notification From Manufacturer Sequence", tag_key: 'NotificationFromManufacturerSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0068,6265)', tag_sym: :notification_from_manufacturer_sequence, tag_ndm: '00686265', tag_ary: [0x0068,0x6265], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,6270)', tag_name: "Information Issue DateTime", tag_key: 'InformationIssueDateTime', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(0068,6270)', tag_sym: :information_issue_date_time, tag_ndm: '00686270', tag_ary: [0x0068,0x6270], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,6280)', tag_name: "Information Summary", tag_key: 'InformationSummary', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0068,6280)', tag_sym: :information_summary, tag_ndm: '00686280', tag_ary: [0x0068,0x6280], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,62A0)', tag_name: "Implant Regulatory Disapproval Code Sequence", tag_key: 'ImplantRegulatoryDisapprovalCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0068,62A0)', tag_sym: :implant_regulatory_disapproval_code_sequence, tag_ndm: '006862A0', tag_ary: [0x0068,0x62A0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,62A5)', tag_name: "Overall Template Spatial Tolerance", tag_key: 'OverallTemplateSpatialTolerance', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0068,62A5)', tag_sym: :overall_template_spatial_tolerance, tag_ndm: '006862A5', tag_ary: [0x0068,0x62A5], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,62C0)', tag_name: "HPGL Document Sequence", tag_key: 'HPGLDocumentSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0068,62C0)', tag_sym: :hpgl_document_sequence, tag_ndm: '006862C0', tag_ary: [0x0068,0x62C0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,62D0)', tag_name: "HPGL Document ID", tag_key: 'HPGLDocumentID', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0068,62D0)', tag_sym: :hpgl_document_id, tag_ndm: '006862D0', tag_ary: [0x0068,0x62D0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,62D5)', tag_name: "HPGL Document Label", tag_key: 'HPGLDocumentLabel', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0068,62D5)', tag_sym: :hpgl_document_label, tag_ndm: '006862D5', tag_ary: [0x0068,0x62D5], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,62E0)', tag_name: "View Orientation Code Sequence", tag_key: 'ViewOrientationCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0068,62E0)', tag_sym: :view_orientation_code_sequence, tag_ndm: '006862E0', tag_ary: [0x0068,0x62E0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,62F0)', tag_name: "View Orientation Modifier Code Sequence", tag_key: 'ViewOrientationModifierCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0068,62F0)', tag_sym: :view_orientation_modifier_code_sequence, tag_ndm: '006862F0', tag_ary: [0x0068,0x62F0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,62F2)', tag_name: "HPGL Document Scaling", tag_key: 'HPGLDocumentScaling', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0068,62F2)', tag_sym: :hpgl_document_scaling, tag_ndm: '006862F2', tag_ary: [0x0068,0x62F2], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,6300)', tag_name: "HPGL Document", tag_key: 'HPGLDocument', tag_vr: [:OB], tag_vm: ["1"], tag_str: '(0068,6300)', tag_sym: :hpgl_document, tag_ndm: '00686300', tag_ary: [0x0068,0x6300], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,6310)', tag_name: "HPGL Contour Pen Number", tag_key: 'HPGLContourPenNumber', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0068,6310)', tag_sym: :hpgl_contour_pen_number, tag_ndm: '00686310', tag_ary: [0x0068,0x6310], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,6320)', tag_name: "HPGL Pen Sequence", tag_key: 'HPGLPenSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0068,6320)', tag_sym: :hpgl_pen_sequence, tag_ndm: '00686320', tag_ary: [0x0068,0x6320], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,6330)', tag_name: "HPGL Pen Number", tag_key: 'HPGLPenNumber', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0068,6330)', tag_sym: :hpgl_pen_number, tag_ndm: '00686330', tag_ary: [0x0068,0x6330], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,6340)', tag_name: "HPGL Pen Label", tag_key: 'HPGLPenLabel', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0068,6340)', tag_sym: :hpgl_pen_label, tag_ndm: '00686340', tag_ary: [0x0068,0x6340], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,6345)', tag_name: "HPGL Pen Description", tag_key: 'HPGLPenDescription', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0068,6345)', tag_sym: :hpgl_pen_description, tag_ndm: '00686345', tag_ary: [0x0068,0x6345], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,6346)', tag_name: "Recommended Rotation Point", tag_key: 'RecommendedRotationPoint', tag_vr: [:FD], tag_vm: ["2"], tag_str: '(0068,6346)', tag_sym: :recommended_rotation_point, tag_ndm: '00686346', tag_ary: [0x0068,0x6346], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,6347)', tag_name: "Bounding Rectangle", tag_key: 'BoundingRectangle', tag_vr: [:FD], tag_vm: ["4"], tag_str: '(0068,6347)', tag_sym: :bounding_rectangle, tag_ndm: '00686347', tag_ary: [0x0068,0x6347], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,6350)', tag_name: "Implant Template 3D Model Surface Number", tag_key: 'ImplantTemplate3DModelSurfaceNumber', tag_vr: [:US], tag_vm: ["1-n"], tag_str: '(0068,6350)', tag_sym: :implant_template_3d_model_surface_number, tag_ndm: '00686350', tag_ary: [0x0068,0x6350], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,6360)', tag_name: "Surface Model Description Sequence", tag_key: 'SurfaceModelDescriptionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0068,6360)', tag_sym: :surface_model_description_sequence, tag_ndm: '00686360', tag_ary: [0x0068,0x6360], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,6380)', tag_name: "Surface Model Label", tag_key: 'SurfaceModelLabel', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0068,6380)', tag_sym: :surface_model_label, tag_ndm: '00686380', tag_ary: [0x0068,0x6380], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,6390)', tag_name: "Surface Model Scaling Factor", tag_key: 'SurfaceModelScalingFactor', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0068,6390)', tag_sym: :surface_model_scaling_factor, tag_ndm: '00686390', tag_ary: [0x0068,0x6390], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,63A0)', tag_name: "Materials Code Sequence", tag_key: 'MaterialsCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0068,63A0)', tag_sym: :materials_code_sequence, tag_ndm: '006863A0', tag_ary: [0x0068,0x63A0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,63A4)', tag_name: "Coating Materials Code Sequence", tag_key: 'CoatingMaterialsCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0068,63A4)', tag_sym: :coating_materials_code_sequence, tag_ndm: '006863A4', tag_ary: [0x0068,0x63A4], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,63A8)', tag_name: "Implant Type Code Sequence", tag_key: 'ImplantTypeCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0068,63A8)', tag_sym: :implant_type_code_sequence, tag_ndm: '006863A8', tag_ary: [0x0068,0x63A8], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,63AC)', tag_name: "Fixation Method Code Sequence", tag_key: 'FixationMethodCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0068,63AC)', tag_sym: :fixation_method_code_sequence, tag_ndm: '006863AC', tag_ary: [0x0068,0x63AC], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,63B0)', tag_name: "Mating Feature Sets Sequence", tag_key: 'MatingFeatureSetsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0068,63B0)', tag_sym: :mating_feature_sets_sequence, tag_ndm: '006863B0', tag_ary: [0x0068,0x63B0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,63C0)', tag_name: "Mating Feature Set ID", tag_key: 'MatingFeatureSetID', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0068,63C0)', tag_sym: :mating_feature_set_id, tag_ndm: '006863C0', tag_ary: [0x0068,0x63C0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,63D0)', tag_name: "Mating Feature Set Label", tag_key: 'MatingFeatureSetLabel', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0068,63D0)', tag_sym: :mating_feature_set_label, tag_ndm: '006863D0', tag_ary: [0x0068,0x63D0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,63E0)', tag_name: "Mating Feature Sequence", tag_key: 'MatingFeatureSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0068,63E0)', tag_sym: :mating_feature_sequence, tag_ndm: '006863E0', tag_ary: [0x0068,0x63E0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,63F0)', tag_name: "Mating Feature ID", tag_key: 'MatingFeatureID', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0068,63F0)', tag_sym: :mating_feature_id, tag_ndm: '006863F0', tag_ary: [0x0068,0x63F0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,6400)', tag_name: "Mating Feature Degree of Freedom Sequence", tag_key: 'MatingFeatureDegreeOfFreedomSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0068,6400)', tag_sym: :mating_feature_degree_of_freedom_sequence, tag_ndm: '00686400', tag_ary: [0x0068,0x6400], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,6410)', tag_name: "Degree of Freedom ID", tag_key: 'DegreeOfFreedomID', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0068,6410)', tag_sym: :degree_of_freedom_id, tag_ndm: '00686410', tag_ary: [0x0068,0x6410], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,6420)', tag_name: "Degree of Freedom Type", tag_key: 'DegreeOfFreedomType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0068,6420)', tag_sym: :degree_of_freedom_type, tag_ndm: '00686420', tag_ary: [0x0068,0x6420], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,6430)', tag_name: "2D Mating Feature Coordinates Sequence", tag_key: 'TwoDMatingFeatureCoordinatesSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0068,6430)', tag_sym: :two_d_mating_feature_coordinates_sequence, tag_ndm: '00686430', tag_ary: [0x0068,0x6430], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,6440)', tag_name: "Referenced HPGL Document ID", tag_key: 'ReferencedHPGLDocumentID', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0068,6440)', tag_sym: :referenced_hpgl_document_id, tag_ndm: '00686440', tag_ary: [0x0068,0x6440], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,6450)', tag_name: "2D Mating Point", tag_key: 'TwoDMatingPoint', tag_vr: [:FD], tag_vm: ["2"], tag_str: '(0068,6450)', tag_sym: :two_d_mating_point, tag_ndm: '00686450', tag_ary: [0x0068,0x6450], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,6460)', tag_name: "2D Mating Axes", tag_key: 'TwoDMatingAxes', tag_vr: [:FD], tag_vm: ["4"], tag_str: '(0068,6460)', tag_sym: :two_d_mating_axes, tag_ndm: '00686460', tag_ary: [0x0068,0x6460], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,6470)', tag_name: "2D Degree of Freedom Sequence", tag_key: 'TwoDDegreeOfFreedomSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0068,6470)', tag_sym: :two_d_degree_of_freedom_sequence, tag_ndm: '00686470', tag_ary: [0x0068,0x6470], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,6490)', tag_name: "3D Degree of Freedom Axis", tag_key: 'ThreeDDegreeOfFreedomAxis', tag_vr: [:FD], tag_vm: ["3"], tag_str: '(0068,6490)', tag_sym: :three_d_degree_of_freedom_axis, tag_ndm: '00686490', tag_ary: [0x0068,0x6490], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,64A0)', tag_name: "Range of Freedom", tag_key: 'RangeOfFreedom', tag_vr: [:FD], tag_vm: ["2"], tag_str: '(0068,64A0)', tag_sym: :range_of_freedom, tag_ndm: '006864A0', tag_ary: [0x0068,0x64A0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,64C0)', tag_name: "3D Mating Point", tag_key: 'ThreeDMatingPoint', tag_vr: [:FD], tag_vm: ["3"], tag_str: '(0068,64C0)', tag_sym: :three_d_mating_point, tag_ndm: '006864C0', tag_ary: [0x0068,0x64C0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,64D0)', tag_name: "3D Mating Axes", tag_key: 'ThreeDMatingAxes', tag_vr: [:FD], tag_vm: ["9"], tag_str: '(0068,64D0)', tag_sym: :three_d_mating_axes, tag_ndm: '006864D0', tag_ary: [0x0068,0x64D0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,64F0)', tag_name: "2D Degree of Freedom Axis", tag_key: 'TwoDDegreeOfFreedomAxis', tag_vr: [:FD], tag_vm: ["3"], tag_str: '(0068,64F0)', tag_sym: :two_d_degree_of_freedom_axis, tag_ndm: '006864F0', tag_ary: [0x0068,0x64F0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,6500)', tag_name: "Planning Landmark Point Sequence", tag_key: 'PlanningLandmarkPointSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0068,6500)', tag_sym: :planning_landmark_point_sequence, tag_ndm: '00686500', tag_ary: [0x0068,0x6500], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,6510)', tag_name: "Planning Landmark Line Sequence", tag_key: 'PlanningLandmarkLineSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0068,6510)', tag_sym: :planning_landmark_line_sequence, tag_ndm: '00686510', tag_ary: [0x0068,0x6510], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,6520)', tag_name: "Planning Landmark Plane Sequence", tag_key: 'PlanningLandmarkPlaneSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0068,6520)', tag_sym: :planning_landmark_plane_sequence, tag_ndm: '00686520', tag_ary: [0x0068,0x6520], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,6530)', tag_name: "Planning Landmark ID", tag_key: 'PlanningLandmarkID', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0068,6530)', tag_sym: :planning_landmark_id, tag_ndm: '00686530', tag_ary: [0x0068,0x6530], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,6540)', tag_name: "Planning Landmark Description", tag_key: 'PlanningLandmarkDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0068,6540)', tag_sym: :planning_landmark_description, tag_ndm: '00686540', tag_ary: [0x0068,0x6540], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,6545)', tag_name: "Planning Landmark Identification Code Sequence", tag_key: 'PlanningLandmarkIdentificationCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0068,6545)', tag_sym: :planning_landmark_identification_code_sequence, tag_ndm: '00686545', tag_ary: [0x0068,0x6545], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,6550)', tag_name: "2D Point Coordinates Sequence", tag_key: 'TwoDPointCoordinatesSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0068,6550)', tag_sym: :two_d_point_coordinates_sequence, tag_ndm: '00686550', tag_ary: [0x0068,0x6550], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,6560)', tag_name: "2D Point Coordinates", tag_key: 'TwoDPointCoordinates', tag_vr: [:FD], tag_vm: ["2"], tag_str: '(0068,6560)', tag_sym: :two_d_point_coordinates, tag_ndm: '00686560', tag_ary: [0x0068,0x6560], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,6590)', tag_name: "3D Point Coordinates", tag_key: 'ThreeDPointCoordinates', tag_vr: [:FD], tag_vm: ["3"], tag_str: '(0068,6590)', tag_sym: :three_d_point_coordinates, tag_ndm: '00686590', tag_ary: [0x0068,0x6590], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,65A0)', tag_name: "2D Line Coordinates Sequence", tag_key: 'TwoDLineCoordinatesSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0068,65A0)', tag_sym: :two_d_line_coordinates_sequence, tag_ndm: '006865A0', tag_ary: [0x0068,0x65A0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,65B0)', tag_name: "2D Line Coordinates", tag_key: 'TwoDLineCoordinates', tag_vr: [:FD], tag_vm: ["4"], tag_str: '(0068,65B0)', tag_sym: :two_d_line_coordinates, tag_ndm: '006865B0', tag_ary: [0x0068,0x65B0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,65D0)', tag_name: "3D Line Coordinates", tag_key: 'ThreeDLineCoordinates', tag_vr: [:FD], tag_vm: ["6"], tag_str: '(0068,65D0)', tag_sym: :three_d_line_coordinates, tag_ndm: '006865D0', tag_ary: [0x0068,0x65D0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,65E0)', tag_name: "2D Plane Coordinates Sequence", tag_key: 'TwoDPlaneCoordinatesSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0068,65E0)', tag_sym: :two_d_plane_coordinates_sequence, tag_ndm: '006865E0', tag_ary: [0x0068,0x65E0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,65F0)', tag_name: "2D Plane Intersection", tag_key: 'TwoDPlaneIntersection', tag_vr: [:FD], tag_vm: ["4"], tag_str: '(0068,65F0)', tag_sym: :two_d_plane_intersection, tag_ndm: '006865F0', tag_ary: [0x0068,0x65F0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,6610)', tag_name: "3D Plane Origin", tag_key: 'ThreeDPlaneOrigin', tag_vr: [:FD], tag_vm: ["3"], tag_str: '(0068,6610)', tag_sym: :three_d_plane_origin, tag_ndm: '00686610', tag_ary: [0x0068,0x6610], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,6620)', tag_name: "3D Plane Normal", tag_key: 'ThreeDPlaneNormal', tag_vr: [:FD], tag_vm: ["3"], tag_str: '(0068,6620)', tag_sym: :three_d_plane_normal, tag_ndm: '00686620', tag_ary: [0x0068,0x6620], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,7001)', tag_name: "Model Modification", tag_key: 'ModelModification', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0068,7001)', tag_sym: :model_modification, tag_ndm: '00687001', tag_ary: [0x0068,0x7001], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,7002)', tag_name: "Model Mirroring", tag_key: 'ModelMirroring', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0068,7002)', tag_sym: :model_mirroring, tag_ndm: '00687002', tag_ary: [0x0068,0x7002], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,7003)', tag_name: "Model Usage Code Sequence", tag_key: 'ModelUsageCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0068,7003)', tag_sym: :model_usage_code_sequence, tag_ndm: '00687003', tag_ary: [0x0068,0x7003], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,7004)', tag_name: "Model Group UID", tag_key: 'ModelGroupUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0068,7004)', tag_sym: :model_group_uid, tag_ndm: '00687004', tag_ary: [0x0068,0x7004], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0068,7005)', tag_name: "Relative URI Reference Within Encapsulated Document", tag_key: 'RelativeURIReferenceWithinEncapsulatedDocument', tag_vr: [:UR], tag_vm: ["1"], tag_str: '(0068,7005)', tag_sym: :relative_uri_reference_within_encapsulated_document, tag_ndm: '00687005', tag_ary: [0x0068,0x7005], tag_multiple: false, tag_note: ''},
      { tag_ps: '(006A,0001)', tag_name: "Annotation Coordinate Type", tag_key: 'AnnotationCoordinateType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(006A,0001)', tag_sym: :annotation_coordinate_type, tag_ndm: '006A0001', tag_ary: [0x006A,0x0001], tag_multiple: false, tag_note: ''},
      { tag_ps: '(006A,0002)', tag_name: "Annotation Group Sequence", tag_key: 'AnnotationGroupSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(006A,0002)', tag_sym: :annotation_group_sequence, tag_ndm: '006A0002', tag_ary: [0x006A,0x0002], tag_multiple: false, tag_note: ''},
      { tag_ps: '(006A,0003)', tag_name: "Annotation Group UID", tag_key: 'AnnotationGroupUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(006A,0003)', tag_sym: :annotation_group_uid, tag_ndm: '006A0003', tag_ary: [0x006A,0x0003], tag_multiple: false, tag_note: ''},
      { tag_ps: '(006A,0005)', tag_name: "Annotation Group Label", tag_key: 'AnnotationGroupLabel', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(006A,0005)', tag_sym: :annotation_group_label, tag_ndm: '006A0005', tag_ary: [0x006A,0x0005], tag_multiple: false, tag_note: ''},
      { tag_ps: '(006A,0006)', tag_name: "Annotation Group Description", tag_key: 'AnnotationGroupDescription', tag_vr: [:UT], tag_vm: ["1"], tag_str: '(006A,0006)', tag_sym: :annotation_group_description, tag_ndm: '006A0006', tag_ary: [0x006A,0x0006], tag_multiple: false, tag_note: ''},
      { tag_ps: '(006A,0007)', tag_name: "Annotation Group Generation Type", tag_key: 'AnnotationGroupGenerationType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(006A,0007)', tag_sym: :annotation_group_generation_type, tag_ndm: '006A0007', tag_ary: [0x006A,0x0007], tag_multiple: false, tag_note: ''},
      { tag_ps: '(006A,0008)', tag_name: "Annotation Group Algorithm Identification Sequence", tag_key: 'AnnotationGroupAlgorithmIdentificationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(006A,0008)', tag_sym: :annotation_group_algorithm_identification_sequence, tag_ndm: '006A0008', tag_ary: [0x006A,0x0008], tag_multiple: false, tag_note: ''},
      { tag_ps: '(006A,0009)', tag_name: "Annotation Property Category Code Sequence", tag_key: 'AnnotationPropertyCategoryCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(006A,0009)', tag_sym: :annotation_property_category_code_sequence, tag_ndm: '006A0009', tag_ary: [0x006A,0x0009], tag_multiple: false, tag_note: ''},
      { tag_ps: '(006A,000A)', tag_name: "Annotation Property Type Code Sequence", tag_key: 'AnnotationPropertyTypeCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(006A,000A)', tag_sym: :annotation_property_type_code_sequence, tag_ndm: '006A000A', tag_ary: [0x006A,0x000A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(006A,000B)', tag_name: "Annotation Property Type Modifier Code Sequence", tag_key: 'AnnotationPropertyTypeModifierCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(006A,000B)', tag_sym: :annotation_property_type_modifier_code_sequence, tag_ndm: '006A000B', tag_ary: [0x006A,0x000B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(006A,000C)', tag_name: "Number of Annotations", tag_key: 'NumberOfAnnotations', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(006A,000C)', tag_sym: :number_of_annotations, tag_ndm: '006A000C', tag_ary: [0x006A,0x000C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(006A,000D)', tag_name: "Annotation Applies to All Optical Paths", tag_key: 'AnnotationAppliesToAllOpticalPaths', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(006A,000D)', tag_sym: :annotation_applies_to_all_optical_paths, tag_ndm: '006A000D', tag_ary: [0x006A,0x000D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(006A,000E)', tag_name: "Referenced Optical Path Identifier", tag_key: 'ReferencedOpticalPathIdentifier', tag_vr: [:SH], tag_vm: ["1-n"], tag_str: '(006A,000E)', tag_sym: :referenced_optical_path_identifier, tag_ndm: '006A000E', tag_ary: [0x006A,0x000E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(006A,000F)', tag_name: "Annotation Applies to All Z Planes", tag_key: 'AnnotationAppliesToAllZPlanes', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(006A,000F)', tag_sym: :annotation_applies_to_all_z_planes, tag_ndm: '006A000F', tag_ary: [0x006A,0x000F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(006A,0010)', tag_name: "Common Z Coordinate Value", tag_key: 'CommonZCoordinateValue', tag_vr: [:FD], tag_vm: ["1-n"], tag_str: '(006A,0010)', tag_sym: :common_z_coordinate_value, tag_ndm: '006A0010', tag_ary: [0x006A,0x0010], tag_multiple: false, tag_note: ''},
      { tag_ps: '(006A,0011)', tag_name: "Annotation Index List", tag_key: 'AnnotationIndexList', tag_vr: [:OL], tag_vm: ["1"], tag_str: '(006A,0011)', tag_sym: :annotation_index_list, tag_ndm: '006A0011', tag_ary: [0x006A,0x0011], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0001)', tag_name: "Graphic Annotation Sequence", tag_key: 'GraphicAnnotationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0070,0001)', tag_sym: :graphic_annotation_sequence, tag_ndm: '00700001', tag_ary: [0x0070,0x0001], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0002)', tag_name: "Graphic Layer", tag_key: 'GraphicLayer', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0070,0002)', tag_sym: :graphic_layer, tag_ndm: '00700002', tag_ary: [0x0070,0x0002], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0003)', tag_name: "Bounding Box Annotation Units", tag_key: 'BoundingBoxAnnotationUnits', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0070,0003)', tag_sym: :bounding_box_annotation_units, tag_ndm: '00700003', tag_ary: [0x0070,0x0003], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0004)', tag_name: "Anchor Point Annotation Units", tag_key: 'AnchorPointAnnotationUnits', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0070,0004)', tag_sym: :anchor_point_annotation_units, tag_ndm: '00700004', tag_ary: [0x0070,0x0004], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0005)', tag_name: "Graphic Annotation Units", tag_key: 'GraphicAnnotationUnits', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0070,0005)', tag_sym: :graphic_annotation_units, tag_ndm: '00700005', tag_ary: [0x0070,0x0005], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0006)', tag_name: "Unformatted Text Value", tag_key: 'UnformattedTextValue', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0070,0006)', tag_sym: :unformatted_text_value, tag_ndm: '00700006', tag_ary: [0x0070,0x0006], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0008)', tag_name: "Text Object Sequence", tag_key: 'TextObjectSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0070,0008)', tag_sym: :text_object_sequence, tag_ndm: '00700008', tag_ary: [0x0070,0x0008], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0009)', tag_name: "Graphic Object Sequence", tag_key: 'GraphicObjectSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0070,0009)', tag_sym: :graphic_object_sequence, tag_ndm: '00700009', tag_ary: [0x0070,0x0009], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0010)', tag_name: "Bounding Box Top Left Hand Corner", tag_key: 'BoundingBoxTopLeftHandCorner', tag_vr: [:FL], tag_vm: ["2"], tag_str: '(0070,0010)', tag_sym: :bounding_box_top_left_hand_corner, tag_ndm: '00700010', tag_ary: [0x0070,0x0010], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0011)', tag_name: "Bounding Box Bottom Right Hand Corner", tag_key: 'BoundingBoxBottomRightHandCorner', tag_vr: [:FL], tag_vm: ["2"], tag_str: '(0070,0011)', tag_sym: :bounding_box_bottom_right_hand_corner, tag_ndm: '00700011', tag_ary: [0x0070,0x0011], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0012)', tag_name: "Bounding Box Text Horizontal Justification", tag_key: 'BoundingBoxTextHorizontalJustification', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0070,0012)', tag_sym: :bounding_box_text_horizontal_justification, tag_ndm: '00700012', tag_ary: [0x0070,0x0012], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0014)', tag_name: "Anchor Point", tag_key: 'AnchorPoint', tag_vr: [:FL], tag_vm: ["2"], tag_str: '(0070,0014)', tag_sym: :anchor_point, tag_ndm: '00700014', tag_ary: [0x0070,0x0014], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0015)', tag_name: "Anchor Point Visibility", tag_key: 'AnchorPointVisibility', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0070,0015)', tag_sym: :anchor_point_visibility, tag_ndm: '00700015', tag_ary: [0x0070,0x0015], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0020)', tag_name: "Graphic Dimensions", tag_key: 'GraphicDimensions', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0070,0020)', tag_sym: :graphic_dimensions, tag_ndm: '00700020', tag_ary: [0x0070,0x0020], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0021)', tag_name: "Number of Graphic Points", tag_key: 'NumberOfGraphicPoints', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0070,0021)', tag_sym: :number_of_graphic_points, tag_ndm: '00700021', tag_ary: [0x0070,0x0021], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0022)', tag_name: "Graphic Data", tag_key: 'GraphicData', tag_vr: [:FL], tag_vm: ["2-n"], tag_str: '(0070,0022)', tag_sym: :graphic_data, tag_ndm: '00700022', tag_ary: [0x0070,0x0022], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0023)', tag_name: "Graphic Type", tag_key: 'GraphicType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0070,0023)', tag_sym: :graphic_type, tag_ndm: '00700023', tag_ary: [0x0070,0x0023], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0024)', tag_name: "Graphic Filled", tag_key: 'GraphicFilled', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0070,0024)', tag_sym: :graphic_filled, tag_ndm: '00700024', tag_ary: [0x0070,0x0024], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0040)', tag_name: "Image Rotation (Retired)", tag_key: 'ImageRotationRetired', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0070,0040)', tag_sym: :image_rotation_retired, tag_ndm: '00700040', tag_ary: [0x0070,0x0040], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0070,0041)', tag_name: "Image Horizontal Flip", tag_key: 'ImageHorizontalFlip', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0070,0041)', tag_sym: :image_horizontal_flip, tag_ndm: '00700041', tag_ary: [0x0070,0x0041], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0042)', tag_name: "Image Rotation", tag_key: 'ImageRotation', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0070,0042)', tag_sym: :image_rotation, tag_ndm: '00700042', tag_ary: [0x0070,0x0042], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0050)', tag_name: "Displayed Area Top Left Hand Corner (Trial)", tag_key: 'DisplayedAreaTopLeftHandCornerTrial', tag_vr: [:US], tag_vm: ["2"], tag_str: '(0070,0050)', tag_sym: :displayed_area_top_left_hand_corner_trial, tag_ndm: '00700050', tag_ary: [0x0070,0x0050], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0070,0051)', tag_name: "Displayed Area Bottom Right Hand Corner (Trial)", tag_key: 'DisplayedAreaBottomRightHandCornerTrial', tag_vr: [:US], tag_vm: ["2"], tag_str: '(0070,0051)', tag_sym: :displayed_area_bottom_right_hand_corner_trial, tag_ndm: '00700051', tag_ary: [0x0070,0x0051], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0070,0052)', tag_name: "Displayed Area Top Left Hand Corner", tag_key: 'DisplayedAreaTopLeftHandCorner', tag_vr: [:SL], tag_vm: ["2"], tag_str: '(0070,0052)', tag_sym: :displayed_area_top_left_hand_corner, tag_ndm: '00700052', tag_ary: [0x0070,0x0052], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0053)', tag_name: "Displayed Area Bottom Right Hand Corner", tag_key: 'DisplayedAreaBottomRightHandCorner', tag_vr: [:SL], tag_vm: ["2"], tag_str: '(0070,0053)', tag_sym: :displayed_area_bottom_right_hand_corner, tag_ndm: '00700053', tag_ary: [0x0070,0x0053], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,005A)', tag_name: "Displayed Area Selection Sequence", tag_key: 'DisplayedAreaSelectionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0070,005A)', tag_sym: :displayed_area_selection_sequence, tag_ndm: '0070005A', tag_ary: [0x0070,0x005A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0060)', tag_name: "Graphic Layer Sequence", tag_key: 'GraphicLayerSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0070,0060)', tag_sym: :graphic_layer_sequence, tag_ndm: '00700060', tag_ary: [0x0070,0x0060], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0062)', tag_name: "Graphic Layer Order", tag_key: 'GraphicLayerOrder', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0070,0062)', tag_sym: :graphic_layer_order, tag_ndm: '00700062', tag_ary: [0x0070,0x0062], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0066)', tag_name: "Graphic Layer Recommended Display Grayscale Value", tag_key: 'GraphicLayerRecommendedDisplayGrayscaleValue', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0070,0066)', tag_sym: :graphic_layer_recommended_display_grayscale_value, tag_ndm: '00700066', tag_ary: [0x0070,0x0066], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0067)', tag_name: "Graphic Layer Recommended Display RGB Value", tag_key: 'GraphicLayerRecommendedDisplayRGBValue', tag_vr: [:US], tag_vm: ["3"], tag_str: '(0070,0067)', tag_sym: :graphic_layer_recommended_display_rgb_value, tag_ndm: '00700067', tag_ary: [0x0070,0x0067], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(0070,0068)', tag_name: "Graphic Layer Description", tag_key: 'GraphicLayerDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0070,0068)', tag_sym: :graphic_layer_description, tag_ndm: '00700068', tag_ary: [0x0070,0x0068], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0080)', tag_name: "Content Label", tag_key: 'ContentLabel', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0070,0080)', tag_sym: :content_label, tag_ndm: '00700080', tag_ary: [0x0070,0x0080], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0081)', tag_name: "Content Description", tag_key: 'ContentDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0070,0081)', tag_sym: :content_description, tag_ndm: '00700081', tag_ary: [0x0070,0x0081], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0082)', tag_name: "Presentation Creation Date", tag_key: 'PresentationCreationDate', tag_vr: [:DA], tag_vm: ["1"], tag_str: '(0070,0082)', tag_sym: :presentation_creation_date, tag_ndm: '00700082', tag_ary: [0x0070,0x0082], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0083)', tag_name: "Presentation Creation Time", tag_key: 'PresentationCreationTime', tag_vr: [:TM], tag_vm: ["1"], tag_str: '(0070,0083)', tag_sym: :presentation_creation_time, tag_ndm: '00700083', tag_ary: [0x0070,0x0083], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0084)', tag_name: "Content Creator's Name", tag_key: 'ContentCreatorName', tag_vr: [:PN], tag_vm: ["1"], tag_str: '(0070,0084)', tag_sym: :content_creator_name, tag_ndm: '00700084', tag_ary: [0x0070,0x0084], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0086)', tag_name: "Content Creator's Identification Code Sequence", tag_key: 'ContentCreatorIdentificationCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0070,0086)', tag_sym: :content_creator_identification_code_sequence, tag_ndm: '00700086', tag_ary: [0x0070,0x0086], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0087)', tag_name: "Alternate Content Description Sequence", tag_key: 'AlternateContentDescriptionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0070,0087)', tag_sym: :alternate_content_description_sequence, tag_ndm: '00700087', tag_ary: [0x0070,0x0087], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0100)', tag_name: "Presentation Size Mode", tag_key: 'PresentationSizeMode', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0070,0100)', tag_sym: :presentation_size_mode, tag_ndm: '00700100', tag_ary: [0x0070,0x0100], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0101)', tag_name: "Presentation Pixel Spacing", tag_key: 'PresentationPixelSpacing', tag_vr: [:DS], tag_vm: ["2"], tag_str: '(0070,0101)', tag_sym: :presentation_pixel_spacing, tag_ndm: '00700101', tag_ary: [0x0070,0x0101], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0102)', tag_name: "Presentation Pixel Aspect Ratio", tag_key: 'PresentationPixelAspectRatio', tag_vr: [:IS], tag_vm: ["2"], tag_str: '(0070,0102)', tag_sym: :presentation_pixel_aspect_ratio, tag_ndm: '00700102', tag_ary: [0x0070,0x0102], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0103)', tag_name: "Presentation Pixel Magnification Ratio", tag_key: 'PresentationPixelMagnificationRatio', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0070,0103)', tag_sym: :presentation_pixel_magnification_ratio, tag_ndm: '00700103', tag_ary: [0x0070,0x0103], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0207)', tag_name: "Graphic Group Label", tag_key: 'GraphicGroupLabel', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0070,0207)', tag_sym: :graphic_group_label, tag_ndm: '00700207', tag_ary: [0x0070,0x0207], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0208)', tag_name: "Graphic Group Description", tag_key: 'GraphicGroupDescription', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0070,0208)', tag_sym: :graphic_group_description, tag_ndm: '00700208', tag_ary: [0x0070,0x0208], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0209)', tag_name: "Compound Graphic Sequence", tag_key: 'CompoundGraphicSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0070,0209)', tag_sym: :compound_graphic_sequence, tag_ndm: '00700209', tag_ary: [0x0070,0x0209], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0226)', tag_name: "Compound Graphic Instance ID", tag_key: 'CompoundGraphicInstanceID', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0070,0226)', tag_sym: :compound_graphic_instance_id, tag_ndm: '00700226', tag_ary: [0x0070,0x0226], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0227)', tag_name: "Font Name", tag_key: 'FontName', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0070,0227)', tag_sym: :font_name, tag_ndm: '00700227', tag_ary: [0x0070,0x0227], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0228)', tag_name: "Font Name Type", tag_key: 'FontNameType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0070,0228)', tag_sym: :font_name_type, tag_ndm: '00700228', tag_ary: [0x0070,0x0228], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0229)', tag_name: "CSS Font Name", tag_key: 'CSSFontName', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0070,0229)', tag_sym: :css_font_name, tag_ndm: '00700229', tag_ary: [0x0070,0x0229], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0230)', tag_name: "Rotation Angle", tag_key: 'RotationAngle', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0070,0230)', tag_sym: :rotation_angle, tag_ndm: '00700230', tag_ary: [0x0070,0x0230], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0231)', tag_name: "Text Style Sequence", tag_key: 'TextStyleSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0070,0231)', tag_sym: :text_style_sequence, tag_ndm: '00700231', tag_ary: [0x0070,0x0231], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0232)', tag_name: "Line Style Sequence", tag_key: 'LineStyleSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0070,0232)', tag_sym: :line_style_sequence, tag_ndm: '00700232', tag_ary: [0x0070,0x0232], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0233)', tag_name: "Fill Style Sequence", tag_key: 'FillStyleSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0070,0233)', tag_sym: :fill_style_sequence, tag_ndm: '00700233', tag_ary: [0x0070,0x0233], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0234)', tag_name: "Graphic Group Sequence", tag_key: 'GraphicGroupSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0070,0234)', tag_sym: :graphic_group_sequence, tag_ndm: '00700234', tag_ary: [0x0070,0x0234], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0241)', tag_name: "Text Color CIELab Value", tag_key: 'TextColorCIELabValue', tag_vr: [:US], tag_vm: ["3"], tag_str: '(0070,0241)', tag_sym: :text_color_cie_lab_value, tag_ndm: '00700241', tag_ary: [0x0070,0x0241], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0242)', tag_name: "Horizontal Alignment", tag_key: 'HorizontalAlignment', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0070,0242)', tag_sym: :horizontal_alignment, tag_ndm: '00700242', tag_ary: [0x0070,0x0242], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0243)', tag_name: "Vertical Alignment", tag_key: 'VerticalAlignment', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0070,0243)', tag_sym: :vertical_alignment, tag_ndm: '00700243', tag_ary: [0x0070,0x0243], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0244)', tag_name: "Shadow Style", tag_key: 'ShadowStyle', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0070,0244)', tag_sym: :shadow_style, tag_ndm: '00700244', tag_ary: [0x0070,0x0244], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0245)', tag_name: "Shadow Offset X", tag_key: 'ShadowOffsetX', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0070,0245)', tag_sym: :shadow_offset_x, tag_ndm: '00700245', tag_ary: [0x0070,0x0245], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0246)', tag_name: "Shadow Offset Y", tag_key: 'ShadowOffsetY', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0070,0246)', tag_sym: :shadow_offset_y, tag_ndm: '00700246', tag_ary: [0x0070,0x0246], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0247)', tag_name: "Shadow Color CIELab Value", tag_key: 'ShadowColorCIELabValue', tag_vr: [:US], tag_vm: ["3"], tag_str: '(0070,0247)', tag_sym: :shadow_color_cie_lab_value, tag_ndm: '00700247', tag_ary: [0x0070,0x0247], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0248)', tag_name: "Underlined", tag_key: 'Underlined', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0070,0248)', tag_sym: :underlined, tag_ndm: '00700248', tag_ary: [0x0070,0x0248], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0249)', tag_name: "Bold", tag_key: 'Bold', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0070,0249)', tag_sym: :bold, tag_ndm: '00700249', tag_ary: [0x0070,0x0249], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0250)', tag_name: "Italic", tag_key: 'Italic', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0070,0250)', tag_sym: :italic, tag_ndm: '00700250', tag_ary: [0x0070,0x0250], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0251)', tag_name: "Pattern On Color CIELab Value", tag_key: 'PatternOnColorCIELabValue', tag_vr: [:US], tag_vm: ["3"], tag_str: '(0070,0251)', tag_sym: :pattern_on_color_cie_lab_value, tag_ndm: '00700251', tag_ary: [0x0070,0x0251], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0252)', tag_name: "Pattern Off Color CIELab Value", tag_key: 'PatternOffColorCIELabValue', tag_vr: [:US], tag_vm: ["3"], tag_str: '(0070,0252)', tag_sym: :pattern_off_color_cie_lab_value, tag_ndm: '00700252', tag_ary: [0x0070,0x0252], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0253)', tag_name: "Line Thickness", tag_key: 'LineThickness', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0070,0253)', tag_sym: :line_thickness, tag_ndm: '00700253', tag_ary: [0x0070,0x0253], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0254)', tag_name: "Line Dashing Style", tag_key: 'LineDashingStyle', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0070,0254)', tag_sym: :line_dashing_style, tag_ndm: '00700254', tag_ary: [0x0070,0x0254], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0255)', tag_name: "Line Pattern", tag_key: 'LinePattern', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0070,0255)', tag_sym: :line_pattern, tag_ndm: '00700255', tag_ary: [0x0070,0x0255], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0256)', tag_name: "Fill Pattern", tag_key: 'FillPattern', tag_vr: [:OB], tag_vm: ["1"], tag_str: '(0070,0256)', tag_sym: :fill_pattern, tag_ndm: '00700256', tag_ary: [0x0070,0x0256], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0257)', tag_name: "Fill Mode", tag_key: 'FillMode', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0070,0257)', tag_sym: :fill_mode, tag_ndm: '00700257', tag_ary: [0x0070,0x0257], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0258)', tag_name: "Shadow Opacity", tag_key: 'ShadowOpacity', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0070,0258)', tag_sym: :shadow_opacity, tag_ndm: '00700258', tag_ary: [0x0070,0x0258], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0261)', tag_name: "Gap Length", tag_key: 'GapLength', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0070,0261)', tag_sym: :gap_length, tag_ndm: '00700261', tag_ary: [0x0070,0x0261], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0262)', tag_name: "Diameter of Visibility", tag_key: 'DiameterOfVisibility', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0070,0262)', tag_sym: :diameter_of_visibility, tag_ndm: '00700262', tag_ary: [0x0070,0x0262], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0273)', tag_name: "Rotation Point", tag_key: 'RotationPoint', tag_vr: [:FL], tag_vm: ["2"], tag_str: '(0070,0273)', tag_sym: :rotation_point, tag_ndm: '00700273', tag_ary: [0x0070,0x0273], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0274)', tag_name: "Tick Alignment", tag_key: 'TickAlignment', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0070,0274)', tag_sym: :tick_alignment, tag_ndm: '00700274', tag_ary: [0x0070,0x0274], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0278)', tag_name: "Show Tick Label", tag_key: 'ShowTickLabel', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0070,0278)', tag_sym: :show_tick_label, tag_ndm: '00700278', tag_ary: [0x0070,0x0278], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0279)', tag_name: "Tick Label Alignment", tag_key: 'TickLabelAlignment', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0070,0279)', tag_sym: :tick_label_alignment, tag_ndm: '00700279', tag_ary: [0x0070,0x0279], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0282)', tag_name: "Compound Graphic Units", tag_key: 'CompoundGraphicUnits', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0070,0282)', tag_sym: :compound_graphic_units, tag_ndm: '00700282', tag_ary: [0x0070,0x0282], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0284)', tag_name: "Pattern On Opacity", tag_key: 'PatternOnOpacity', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0070,0284)', tag_sym: :pattern_on_opacity, tag_ndm: '00700284', tag_ary: [0x0070,0x0284], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0285)', tag_name: "Pattern Off Opacity", tag_key: 'PatternOffOpacity', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0070,0285)', tag_sym: :pattern_off_opacity, tag_ndm: '00700285', tag_ary: [0x0070,0x0285], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0287)', tag_name: "Major Ticks Sequence", tag_key: 'MajorTicksSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0070,0287)', tag_sym: :major_ticks_sequence, tag_ndm: '00700287', tag_ary: [0x0070,0x0287], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0288)', tag_name: "Tick Position", tag_key: 'TickPosition', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0070,0288)', tag_sym: :tick_position, tag_ndm: '00700288', tag_ary: [0x0070,0x0288], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0289)', tag_name: "Tick Label", tag_key: 'TickLabel', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0070,0289)', tag_sym: :tick_label, tag_ndm: '00700289', tag_ary: [0x0070,0x0289], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0294)', tag_name: "Compound Graphic Type", tag_key: 'CompoundGraphicType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0070,0294)', tag_sym: :compound_graphic_type, tag_ndm: '00700294', tag_ary: [0x0070,0x0294], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0295)', tag_name: "Graphic Group ID", tag_key: 'GraphicGroupID', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0070,0295)', tag_sym: :graphic_group_id, tag_ndm: '00700295', tag_ary: [0x0070,0x0295], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0306)', tag_name: "Shape Type", tag_key: 'ShapeType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0070,0306)', tag_sym: :shape_type, tag_ndm: '00700306', tag_ary: [0x0070,0x0306], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0308)', tag_name: "Registration Sequence", tag_key: 'RegistrationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0070,0308)', tag_sym: :registration_sequence, tag_ndm: '00700308', tag_ary: [0x0070,0x0308], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0309)', tag_name: "Matrix Registration Sequence", tag_key: 'MatrixRegistrationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0070,0309)', tag_sym: :matrix_registration_sequence, tag_ndm: '00700309', tag_ary: [0x0070,0x0309], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,030A)', tag_name: "Matrix Sequence", tag_key: 'MatrixSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0070,030A)', tag_sym: :matrix_sequence, tag_ndm: '0070030A', tag_ary: [0x0070,0x030A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,030B)', tag_name: "Frame of Reference to Displayed Coordinate System Transformation Matrix", tag_key: 'FrameOfReferenceToDisplayedCoordinateSystemTransformationMatrix', tag_vr: [:FD], tag_vm: ["16"], tag_str: '(0070,030B)', tag_sym: :frame_of_reference_to_displayed_coordinate_system_transformation_matrix, tag_ndm: '0070030B', tag_ary: [0x0070,0x030B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,030C)', tag_name: "Frame of Reference Transformation Matrix Type", tag_key: 'FrameOfReferenceTransformationMatrixType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0070,030C)', tag_sym: :frame_of_reference_transformation_matrix_type, tag_ndm: '0070030C', tag_ary: [0x0070,0x030C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,030D)', tag_name: "Registration Type Code Sequence", tag_key: 'RegistrationTypeCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0070,030D)', tag_sym: :registration_type_code_sequence, tag_ndm: '0070030D', tag_ary: [0x0070,0x030D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,030F)', tag_name: "Fiducial Description", tag_key: 'FiducialDescription', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0070,030F)', tag_sym: :fiducial_description, tag_ndm: '0070030F', tag_ary: [0x0070,0x030F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0310)', tag_name: "Fiducial Identifier", tag_key: 'FiducialIdentifier', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0070,0310)', tag_sym: :fiducial_identifier, tag_ndm: '00700310', tag_ary: [0x0070,0x0310], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0311)', tag_name: "Fiducial Identifier Code Sequence", tag_key: 'FiducialIdentifierCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0070,0311)', tag_sym: :fiducial_identifier_code_sequence, tag_ndm: '00700311', tag_ary: [0x0070,0x0311], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0312)', tag_name: "Contour Uncertainty Radius", tag_key: 'ContourUncertaintyRadius', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0070,0312)', tag_sym: :contour_uncertainty_radius, tag_ndm: '00700312', tag_ary: [0x0070,0x0312], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0314)', tag_name: "Used Fiducials Sequence", tag_key: 'UsedFiducialsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0070,0314)', tag_sym: :used_fiducials_sequence, tag_ndm: '00700314', tag_ary: [0x0070,0x0314], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0315)', tag_name: "Used RT Structure Set ROI Sequence", tag_key: 'UsedRTStructureSetROISequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0070,0315)', tag_sym: :used_rt_structure_set_roi_sequence, tag_ndm: '00700315', tag_ary: [0x0070,0x0315], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0318)', tag_name: "Graphic Coordinates Data Sequence", tag_key: 'GraphicCoordinatesDataSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0070,0318)', tag_sym: :graphic_coordinates_data_sequence, tag_ndm: '00700318', tag_ary: [0x0070,0x0318], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,031A)', tag_name: "Fiducial UID", tag_key: 'FiducialUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0070,031A)', tag_sym: :fiducial_uid, tag_ndm: '0070031A', tag_ary: [0x0070,0x031A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,031B)', tag_name: "Referenced Fiducial UID", tag_key: 'ReferencedFiducialUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0070,031B)', tag_sym: :referenced_fiducial_uid, tag_ndm: '0070031B', tag_ary: [0x0070,0x031B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,031C)', tag_name: "Fiducial Set Sequence", tag_key: 'FiducialSetSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0070,031C)', tag_sym: :fiducial_set_sequence, tag_ndm: '0070031C', tag_ary: [0x0070,0x031C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,031E)', tag_name: "Fiducial Sequence", tag_key: 'FiducialSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0070,031E)', tag_sym: :fiducial_sequence, tag_ndm: '0070031E', tag_ary: [0x0070,0x031E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,031F)', tag_name: "Fiducials Property Category Code Sequence", tag_key: 'FiducialsPropertyCategoryCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0070,031F)', tag_sym: :fiducials_property_category_code_sequence, tag_ndm: '0070031F', tag_ary: [0x0070,0x031F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0401)', tag_name: "Graphic Layer Recommended Display CIELab Value", tag_key: 'GraphicLayerRecommendedDisplayCIELabValue', tag_vr: [:US], tag_vm: ["3"], tag_str: '(0070,0401)', tag_sym: :graphic_layer_recommended_display_cie_lab_value, tag_ndm: '00700401', tag_ary: [0x0070,0x0401], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0402)', tag_name: "Blending Sequence", tag_key: 'BlendingSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0070,0402)', tag_sym: :blending_sequence, tag_ndm: '00700402', tag_ary: [0x0070,0x0402], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0403)', tag_name: "Relative Opacity", tag_key: 'RelativeOpacity', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0070,0403)', tag_sym: :relative_opacity, tag_ndm: '00700403', tag_ary: [0x0070,0x0403], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0404)', tag_name: "Referenced Spatial Registration Sequence", tag_key: 'ReferencedSpatialRegistrationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0070,0404)', tag_sym: :referenced_spatial_registration_sequence, tag_ndm: '00700404', tag_ary: [0x0070,0x0404], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,0405)', tag_name: "Blending Position", tag_key: 'BlendingPosition', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0070,0405)', tag_sym: :blending_position, tag_ndm: '00700405', tag_ary: [0x0070,0x0405], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1101)', tag_name: "Presentation Display Collection UID", tag_key: 'PresentationDisplayCollectionUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0070,1101)', tag_sym: :presentation_display_collection_uid, tag_ndm: '00701101', tag_ary: [0x0070,0x1101], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1102)', tag_name: "Presentation Sequence Collection UID", tag_key: 'PresentationSequenceCollectionUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0070,1102)', tag_sym: :presentation_sequence_collection_uid, tag_ndm: '00701102', tag_ary: [0x0070,0x1102], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1103)', tag_name: "Presentation Sequence Position Index", tag_key: 'PresentationSequencePositionIndex', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0070,1103)', tag_sym: :presentation_sequence_position_index, tag_ndm: '00701103', tag_ary: [0x0070,0x1103], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1104)', tag_name: "Rendered Image Reference Sequence", tag_key: 'RenderedImageReferenceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0070,1104)', tag_sym: :rendered_image_reference_sequence, tag_ndm: '00701104', tag_ary: [0x0070,0x1104], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1201)', tag_name: "Volumetric Presentation State Input Sequence", tag_key: 'VolumetricPresentationStateInputSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0070,1201)', tag_sym: :volumetric_presentation_state_input_sequence, tag_ndm: '00701201', tag_ary: [0x0070,0x1201], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1202)', tag_name: "Presentation Input Type", tag_key: 'PresentationInputType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0070,1202)', tag_sym: :presentation_input_type, tag_ndm: '00701202', tag_ary: [0x0070,0x1202], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1203)', tag_name: "Input Sequence Position Index", tag_key: 'InputSequencePositionIndex', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0070,1203)', tag_sym: :input_sequence_position_index, tag_ndm: '00701203', tag_ary: [0x0070,0x1203], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1204)', tag_name: "Crop", tag_key: 'Crop', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0070,1204)', tag_sym: :crop, tag_ndm: '00701204', tag_ary: [0x0070,0x1204], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1205)', tag_name: "Cropping Specification Index", tag_key: 'CroppingSpecificationIndex', tag_vr: [:US], tag_vm: ["1-n"], tag_str: '(0070,1205)', tag_sym: :cropping_specification_index, tag_ndm: '00701205', tag_ary: [0x0070,0x1205], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1206)', tag_name: "Compositing Method", tag_key: 'CompositingMethod', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0070,1206)', tag_sym: :compositing_method, tag_ndm: '00701206', tag_ary: [0x0070,0x1206], tag_multiple: false, tag_note: 'RET (2017a)'},
      { tag_ps: '(0070,1207)', tag_name: "Volumetric Presentation Input Number", tag_key: 'VolumetricPresentationInputNumber', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0070,1207)', tag_sym: :volumetric_presentation_input_number, tag_ndm: '00701207', tag_ary: [0x0070,0x1207], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1208)', tag_name: "Image Volume Geometry", tag_key: 'ImageVolumeGeometry', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0070,1208)', tag_sym: :image_volume_geometry, tag_ndm: '00701208', tag_ary: [0x0070,0x1208], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1209)', tag_name: "Volumetric Presentation Input Set UID", tag_key: 'VolumetricPresentationInputSetUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0070,1209)', tag_sym: :volumetric_presentation_input_set_uid, tag_ndm: '00701209', tag_ary: [0x0070,0x1209], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,120A)', tag_name: "Volumetric Presentation Input Set Sequence", tag_key: 'VolumetricPresentationInputSetSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0070,120A)', tag_sym: :volumetric_presentation_input_set_sequence, tag_ndm: '0070120A', tag_ary: [0x0070,0x120A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,120B)', tag_name: "Global Crop", tag_key: 'GlobalCrop', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0070,120B)', tag_sym: :global_crop, tag_ndm: '0070120B', tag_ary: [0x0070,0x120B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,120C)', tag_name: "Global Cropping Specification Index", tag_key: 'GlobalCroppingSpecificationIndex', tag_vr: [:US], tag_vm: ["1-n"], tag_str: '(0070,120C)', tag_sym: :global_cropping_specification_index, tag_ndm: '0070120C', tag_ary: [0x0070,0x120C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,120D)', tag_name: "Rendering Method", tag_key: 'RenderingMethod', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0070,120D)', tag_sym: :rendering_method, tag_ndm: '0070120D', tag_ary: [0x0070,0x120D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1301)', tag_name: "Volume Cropping Sequence", tag_key: 'VolumeCroppingSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0070,1301)', tag_sym: :volume_cropping_sequence, tag_ndm: '00701301', tag_ary: [0x0070,0x1301], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1302)', tag_name: "Volume Cropping Method", tag_key: 'VolumeCroppingMethod', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0070,1302)', tag_sym: :volume_cropping_method, tag_ndm: '00701302', tag_ary: [0x0070,0x1302], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1303)', tag_name: "Bounding Box Crop", tag_key: 'BoundingBoxCrop', tag_vr: [:FD], tag_vm: ["6"], tag_str: '(0070,1303)', tag_sym: :bounding_box_crop, tag_ndm: '00701303', tag_ary: [0x0070,0x1303], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1304)', tag_name: "Oblique Cropping Plane Sequence", tag_key: 'ObliqueCroppingPlaneSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0070,1304)', tag_sym: :oblique_cropping_plane_sequence, tag_ndm: '00701304', tag_ary: [0x0070,0x1304], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1305)', tag_name: "Plane", tag_key: 'Plane', tag_vr: [:FD], tag_vm: ["4"], tag_str: '(0070,1305)', tag_sym: :plane, tag_ndm: '00701305', tag_ary: [0x0070,0x1305], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1306)', tag_name: "Plane Normal", tag_key: 'PlaneNormal', tag_vr: [:FD], tag_vm: ["3"], tag_str: '(0070,1306)', tag_sym: :plane_normal, tag_ndm: '00701306', tag_ary: [0x0070,0x1306], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1309)', tag_name: "Cropping Specification Number", tag_key: 'CroppingSpecificationNumber', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0070,1309)', tag_sym: :cropping_specification_number, tag_ndm: '00701309', tag_ary: [0x0070,0x1309], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1501)', tag_name: "Multi-Planar Reconstruction Style", tag_key: 'MultiPlanarReconstructionStyle', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0070,1501)', tag_sym: :multi_planar_reconstruction_style, tag_ndm: '00701501', tag_ary: [0x0070,0x1501], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1502)', tag_name: "MPR Thickness Type", tag_key: 'MPRThicknessType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0070,1502)', tag_sym: :mpr_thickness_type, tag_ndm: '00701502', tag_ary: [0x0070,0x1502], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1503)', tag_name: "MPR Slab Thickness", tag_key: 'MPRSlabThickness', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0070,1503)', tag_sym: :mpr_slab_thickness, tag_ndm: '00701503', tag_ary: [0x0070,0x1503], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1505)', tag_name: "MPR Top Left Hand Corner", tag_key: 'MPRTopLeftHandCorner', tag_vr: [:FD], tag_vm: ["3"], tag_str: '(0070,1505)', tag_sym: :mpr_top_left_hand_corner, tag_ndm: '00701505', tag_ary: [0x0070,0x1505], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1507)', tag_name: "MPR View Width Direction", tag_key: 'MPRViewWidthDirection', tag_vr: [:FD], tag_vm: ["3"], tag_str: '(0070,1507)', tag_sym: :mpr_view_width_direction, tag_ndm: '00701507', tag_ary: [0x0070,0x1507], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1508)', tag_name: "MPR View Width", tag_key: 'MPRViewWidth', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0070,1508)', tag_sym: :mpr_view_width, tag_ndm: '00701508', tag_ary: [0x0070,0x1508], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,150C)', tag_name: "Number of Volumetric Curve Points", tag_key: 'NumberOfVolumetricCurvePoints', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0070,150C)', tag_sym: :number_of_volumetric_curve_points, tag_ndm: '0070150C', tag_ary: [0x0070,0x150C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,150D)', tag_name: "Volumetric Curve Points", tag_key: 'VolumetricCurvePoints', tag_vr: [:OD], tag_vm: ["1"], tag_str: '(0070,150D)', tag_sym: :volumetric_curve_points, tag_ndm: '0070150D', tag_ary: [0x0070,0x150D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1511)', tag_name: "MPR View Height Direction", tag_key: 'MPRViewHeightDirection', tag_vr: [:FD], tag_vm: ["3"], tag_str: '(0070,1511)', tag_sym: :mpr_view_height_direction, tag_ndm: '00701511', tag_ary: [0x0070,0x1511], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1512)', tag_name: "MPR View Height", tag_key: 'MPRViewHeight', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0070,1512)', tag_sym: :mpr_view_height, tag_ndm: '00701512', tag_ary: [0x0070,0x1512], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1602)', tag_name: "Render Projection", tag_key: 'RenderProjection', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0070,1602)', tag_sym: :render_projection, tag_ndm: '00701602', tag_ary: [0x0070,0x1602], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1603)', tag_name: "Viewpoint Position", tag_key: 'ViewpointPosition', tag_vr: [:FD], tag_vm: ["3"], tag_str: '(0070,1603)', tag_sym: :viewpoint_position, tag_ndm: '00701603', tag_ary: [0x0070,0x1603], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1604)', tag_name: "Viewpoint LookAt Point", tag_key: 'ViewpointLookAtPoint', tag_vr: [:FD], tag_vm: ["3"], tag_str: '(0070,1604)', tag_sym: :viewpoint_look_at_point, tag_ndm: '00701604', tag_ary: [0x0070,0x1604], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1605)', tag_name: "Viewpoint Up Direction", tag_key: 'ViewpointUpDirection', tag_vr: [:FD], tag_vm: ["3"], tag_str: '(0070,1605)', tag_sym: :viewpoint_up_direction, tag_ndm: '00701605', tag_ary: [0x0070,0x1605], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1606)', tag_name: "Render Field of View", tag_key: 'RenderFieldOfView', tag_vr: [:FD], tag_vm: ["6"], tag_str: '(0070,1606)', tag_sym: :render_field_of_view, tag_ndm: '00701606', tag_ary: [0x0070,0x1606], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1607)', tag_name: "Sampling Step Size", tag_key: 'SamplingStepSize', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0070,1607)', tag_sym: :sampling_step_size, tag_ndm: '00701607', tag_ary: [0x0070,0x1607], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1701)', tag_name: "Shading Style", tag_key: 'ShadingStyle', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0070,1701)', tag_sym: :shading_style, tag_ndm: '00701701', tag_ary: [0x0070,0x1701], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1702)', tag_name: "Ambient Reflection Intensity", tag_key: 'AmbientReflectionIntensity', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0070,1702)', tag_sym: :ambient_reflection_intensity, tag_ndm: '00701702', tag_ary: [0x0070,0x1702], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1703)', tag_name: "Light Direction", tag_key: 'LightDirection', tag_vr: [:FD], tag_vm: ["3"], tag_str: '(0070,1703)', tag_sym: :light_direction, tag_ndm: '00701703', tag_ary: [0x0070,0x1703], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1704)', tag_name: "Diffuse Reflection Intensity", tag_key: 'DiffuseReflectionIntensity', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0070,1704)', tag_sym: :diffuse_reflection_intensity, tag_ndm: '00701704', tag_ary: [0x0070,0x1704], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1705)', tag_name: "Specular Reflection Intensity", tag_key: 'SpecularReflectionIntensity', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0070,1705)', tag_sym: :specular_reflection_intensity, tag_ndm: '00701705', tag_ary: [0x0070,0x1705], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1706)', tag_name: "Shininess", tag_key: 'Shininess', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0070,1706)', tag_sym: :shininess, tag_ndm: '00701706', tag_ary: [0x0070,0x1706], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1801)', tag_name: "Presentation State Classification Component Sequence", tag_key: 'PresentationStateClassificationComponentSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0070,1801)', tag_sym: :presentation_state_classification_component_sequence, tag_ndm: '00701801', tag_ary: [0x0070,0x1801], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1802)', tag_name: "Component Type", tag_key: 'ComponentType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0070,1802)', tag_sym: :component_type, tag_ndm: '00701802', tag_ary: [0x0070,0x1802], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1803)', tag_name: "Component Input Sequence", tag_key: 'ComponentInputSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0070,1803)', tag_sym: :component_input_sequence, tag_ndm: '00701803', tag_ary: [0x0070,0x1803], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1804)', tag_name: "Volumetric Presentation Input Index", tag_key: 'VolumetricPresentationInputIndex', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0070,1804)', tag_sym: :volumetric_presentation_input_index, tag_ndm: '00701804', tag_ary: [0x0070,0x1804], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1805)', tag_name: "Presentation State Compositor Component Sequence", tag_key: 'PresentationStateCompositorComponentSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0070,1805)', tag_sym: :presentation_state_compositor_component_sequence, tag_ndm: '00701805', tag_ary: [0x0070,0x1805], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1806)', tag_name: "Weighting Transfer Function Sequence", tag_key: 'WeightingTransferFunctionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0070,1806)', tag_sym: :weighting_transfer_function_sequence, tag_ndm: '00701806', tag_ary: [0x0070,0x1806], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1807)', tag_name: "Weighting Lookup Table Descriptor", tag_key: 'WeightingLookupTableDescriptor', tag_vr: [:US], tag_vm: ["3"], tag_str: '(0070,1807)', tag_sym: :weighting_lookup_table_descriptor, tag_ndm: '00701807', tag_ary: [0x0070,0x1807], tag_multiple: false, tag_note: 'RET (2024a)'},
      { tag_ps: '(0070,1808)', tag_name: "Weighting Lookup Table Data", tag_key: 'WeightingLookupTableData', tag_vr: [:OB], tag_vm: ["1"], tag_str: '(0070,1808)', tag_sym: :weighting_lookup_table_data, tag_ndm: '00701808', tag_ary: [0x0070,0x1808], tag_multiple: false, tag_note: 'RET (2024a)'},
      { tag_ps: '(0070,1901)', tag_name: "Volumetric Annotation Sequence", tag_key: 'VolumetricAnnotationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0070,1901)', tag_sym: :volumetric_annotation_sequence, tag_ndm: '00701901', tag_ary: [0x0070,0x1901], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1903)', tag_name: "Referenced Structured Context Sequence", tag_key: 'ReferencedStructuredContextSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0070,1903)', tag_sym: :referenced_structured_context_sequence, tag_ndm: '00701903', tag_ary: [0x0070,0x1903], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1904)', tag_name: "Referenced Content Item", tag_key: 'ReferencedContentItem', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0070,1904)', tag_sym: :referenced_content_item, tag_ndm: '00701904', tag_ary: [0x0070,0x1904], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1905)', tag_name: "Volumetric Presentation Input Annotation Sequence", tag_key: 'VolumetricPresentationInputAnnotationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0070,1905)', tag_sym: :volumetric_presentation_input_annotation_sequence, tag_ndm: '00701905', tag_ary: [0x0070,0x1905], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1907)', tag_name: "Annotation Clipping", tag_key: 'AnnotationClipping', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0070,1907)', tag_sym: :annotation_clipping, tag_ndm: '00701907', tag_ary: [0x0070,0x1907], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1A01)', tag_name: "Presentation Animation Style", tag_key: 'PresentationAnimationStyle', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0070,1A01)', tag_sym: :presentation_animation_style, tag_ndm: '00701A01', tag_ary: [0x0070,0x1A01], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1A03)', tag_name: "Recommended Animation Rate", tag_key: 'RecommendedAnimationRate', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0070,1A03)', tag_sym: :recommended_animation_rate, tag_ndm: '00701A03', tag_ary: [0x0070,0x1A03], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1A04)', tag_name: "Animation Curve Sequence", tag_key: 'AnimationCurveSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0070,1A04)', tag_sym: :animation_curve_sequence, tag_ndm: '00701A04', tag_ary: [0x0070,0x1A04], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1A05)', tag_name: "Animation Step Size", tag_key: 'AnimationStepSize', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0070,1A05)', tag_sym: :animation_step_size, tag_ndm: '00701A05', tag_ary: [0x0070,0x1A05], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1A06)', tag_name: "Swivel Range", tag_key: 'SwivelRange', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0070,1A06)', tag_sym: :swivel_range, tag_ndm: '00701A06', tag_ary: [0x0070,0x1A06], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1A07)', tag_name: "Volumetric Curve Up Directions", tag_key: 'VolumetricCurveUpDirections', tag_vr: [:OD], tag_vm: ["1"], tag_str: '(0070,1A07)', tag_sym: :volumetric_curve_up_directions, tag_ndm: '00701A07', tag_ary: [0x0070,0x1A07], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1A08)', tag_name: "Volume Stream Sequence", tag_key: 'VolumeStreamSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0070,1A08)', tag_sym: :volume_stream_sequence, tag_ndm: '00701A08', tag_ary: [0x0070,0x1A08], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1A09)', tag_name: "RGBA Transfer Function Description", tag_key: 'RGBATransferFunctionDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0070,1A09)', tag_sym: :rgba_transfer_function_description, tag_ndm: '00701A09', tag_ary: [0x0070,0x1A09], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1B01)', tag_name: "Advanced Blending Sequence", tag_key: 'AdvancedBlendingSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0070,1B01)', tag_sym: :advanced_blending_sequence, tag_ndm: '00701B01', tag_ary: [0x0070,0x1B01], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1B02)', tag_name: "Blending Input Number", tag_key: 'BlendingInputNumber', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0070,1B02)', tag_sym: :blending_input_number, tag_ndm: '00701B02', tag_ary: [0x0070,0x1B02], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1B03)', tag_name: "Blending Display Input Sequence", tag_key: 'BlendingDisplayInputSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0070,1B03)', tag_sym: :blending_display_input_sequence, tag_ndm: '00701B03', tag_ary: [0x0070,0x1B03], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1B04)', tag_name: "Blending Display Sequence", tag_key: 'BlendingDisplaySequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0070,1B04)', tag_sym: :blending_display_sequence, tag_ndm: '00701B04', tag_ary: [0x0070,0x1B04], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1B06)', tag_name: "Blending Mode", tag_key: 'BlendingMode', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0070,1B06)', tag_sym: :blending_mode, tag_ndm: '00701B06', tag_ary: [0x0070,0x1B06], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1B07)', tag_name: "Time Series Blending", tag_key: 'TimeSeriesBlending', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0070,1B07)', tag_sym: :time_series_blending, tag_ndm: '00701B07', tag_ary: [0x0070,0x1B07], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1B08)', tag_name: "Geometry for Display", tag_key: 'GeometryForDisplay', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0070,1B08)', tag_sym: :geometry_for_display, tag_ndm: '00701B08', tag_ary: [0x0070,0x1B08], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1B11)', tag_name: "Threshold Sequence", tag_key: 'ThresholdSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0070,1B11)', tag_sym: :threshold_sequence, tag_ndm: '00701B11', tag_ary: [0x0070,0x1B11], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1B12)', tag_name: "Threshold Value Sequence", tag_key: 'ThresholdValueSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0070,1B12)', tag_sym: :threshold_value_sequence, tag_ndm: '00701B12', tag_ary: [0x0070,0x1B12], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1B13)', tag_name: "Threshold Type", tag_key: 'ThresholdType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0070,1B13)', tag_sym: :threshold_type, tag_ndm: '00701B13', tag_ary: [0x0070,0x1B13], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0070,1B14)', tag_name: "Threshold Value", tag_key: 'ThresholdValue', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0070,1B14)', tag_sym: :threshold_value, tag_ndm: '00701B14', tag_ary: [0x0070,0x1B14], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0002)', tag_name: "Hanging Protocol Name", tag_key: 'HangingProtocolName', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0072,0002)', tag_sym: :hanging_protocol_name, tag_ndm: '00720002', tag_ary: [0x0072,0x0002], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0004)', tag_name: "Hanging Protocol Description", tag_key: 'HangingProtocolDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0072,0004)', tag_sym: :hanging_protocol_description, tag_ndm: '00720004', tag_ary: [0x0072,0x0004], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0006)', tag_name: "Hanging Protocol Level", tag_key: 'HangingProtocolLevel', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0072,0006)', tag_sym: :hanging_protocol_level, tag_ndm: '00720006', tag_ary: [0x0072,0x0006], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0008)', tag_name: "Hanging Protocol Creator", tag_key: 'HangingProtocolCreator', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0072,0008)', tag_sym: :hanging_protocol_creator, tag_ndm: '00720008', tag_ary: [0x0072,0x0008], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,000A)', tag_name: "Hanging Protocol Creation DateTime", tag_key: 'HangingProtocolCreationDateTime', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(0072,000A)', tag_sym: :hanging_protocol_creation_date_time, tag_ndm: '0072000A', tag_ary: [0x0072,0x000A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,000C)', tag_name: "Hanging Protocol Definition Sequence", tag_key: 'HangingProtocolDefinitionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0072,000C)', tag_sym: :hanging_protocol_definition_sequence, tag_ndm: '0072000C', tag_ary: [0x0072,0x000C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,000E)', tag_name: "Hanging Protocol User Identification Code Sequence", tag_key: 'HangingProtocolUserIdentificationCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0072,000E)', tag_sym: :hanging_protocol_user_identification_code_sequence, tag_ndm: '0072000E', tag_ary: [0x0072,0x000E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0010)', tag_name: "Hanging Protocol User Group Name", tag_key: 'HangingProtocolUserGroupName', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0072,0010)', tag_sym: :hanging_protocol_user_group_name, tag_ndm: '00720010', tag_ary: [0x0072,0x0010], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0012)', tag_name: "Source Hanging Protocol Sequence", tag_key: 'SourceHangingProtocolSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0072,0012)', tag_sym: :source_hanging_protocol_sequence, tag_ndm: '00720012', tag_ary: [0x0072,0x0012], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0014)', tag_name: "Number of Priors Referenced", tag_key: 'NumberOfPriorsReferenced', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0072,0014)', tag_sym: :number_of_priors_referenced, tag_ndm: '00720014', tag_ary: [0x0072,0x0014], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0020)', tag_name: "Image Sets Sequence", tag_key: 'ImageSetsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0072,0020)', tag_sym: :image_sets_sequence, tag_ndm: '00720020', tag_ary: [0x0072,0x0020], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0022)', tag_name: "Image Set Selector Sequence", tag_key: 'ImageSetSelectorSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0072,0022)', tag_sym: :image_set_selector_sequence, tag_ndm: '00720022', tag_ary: [0x0072,0x0022], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0024)', tag_name: "Image Set Selector Usage Flag", tag_key: 'ImageSetSelectorUsageFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0072,0024)', tag_sym: :image_set_selector_usage_flag, tag_ndm: '00720024', tag_ary: [0x0072,0x0024], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0026)', tag_name: "Selector Attribute", tag_key: 'SelectorAttribute', tag_vr: [:AT], tag_vm: ["1"], tag_str: '(0072,0026)', tag_sym: :selector_attribute, tag_ndm: '00720026', tag_ary: [0x0072,0x0026], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0028)', tag_name: "Selector Value Number", tag_key: 'SelectorValueNumber', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0072,0028)', tag_sym: :selector_value_number, tag_ndm: '00720028', tag_ary: [0x0072,0x0028], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0030)', tag_name: "Time Based Image Sets Sequence", tag_key: 'TimeBasedImageSetsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0072,0030)', tag_sym: :time_based_image_sets_sequence, tag_ndm: '00720030', tag_ary: [0x0072,0x0030], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0032)', tag_name: "Image Set Number", tag_key: 'ImageSetNumber', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0072,0032)', tag_sym: :image_set_number, tag_ndm: '00720032', tag_ary: [0x0072,0x0032], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0034)', tag_name: "Image Set Selector Category", tag_key: 'ImageSetSelectorCategory', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0072,0034)', tag_sym: :image_set_selector_category, tag_ndm: '00720034', tag_ary: [0x0072,0x0034], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0038)', tag_name: "Relative Time", tag_key: 'RelativeTime', tag_vr: [:US], tag_vm: ["2"], tag_str: '(0072,0038)', tag_sym: :relative_time, tag_ndm: '00720038', tag_ary: [0x0072,0x0038], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,003A)', tag_name: "Relative Time Units", tag_key: 'RelativeTimeUnits', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0072,003A)', tag_sym: :relative_time_units, tag_ndm: '0072003A', tag_ary: [0x0072,0x003A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,003C)', tag_name: "Abstract Prior Value", tag_key: 'AbstractPriorValue', tag_vr: [:SS], tag_vm: ["2"], tag_str: '(0072,003C)', tag_sym: :abstract_prior_value, tag_ndm: '0072003C', tag_ary: [0x0072,0x003C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,003E)', tag_name: "Abstract Prior Code Sequence", tag_key: 'AbstractPriorCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0072,003E)', tag_sym: :abstract_prior_code_sequence, tag_ndm: '0072003E', tag_ary: [0x0072,0x003E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0040)', tag_name: "Image Set Label", tag_key: 'ImageSetLabel', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0072,0040)', tag_sym: :image_set_label, tag_ndm: '00720040', tag_ary: [0x0072,0x0040], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0050)', tag_name: "Selector Attribute VR", tag_key: 'SelectorAttributeVR', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0072,0050)', tag_sym: :selector_attribute_vr, tag_ndm: '00720050', tag_ary: [0x0072,0x0050], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0052)', tag_name: "Selector Sequence Pointer", tag_key: 'SelectorSequencePointer', tag_vr: [:AT], tag_vm: ["1-n"], tag_str: '(0072,0052)', tag_sym: :selector_sequence_pointer, tag_ndm: '00720052', tag_ary: [0x0072,0x0052], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0054)', tag_name: "Selector Sequence Pointer Private Creator", tag_key: 'SelectorSequencePointerPrivateCreator', tag_vr: [:LO], tag_vm: ["1-n"], tag_str: '(0072,0054)', tag_sym: :selector_sequence_pointer_private_creator, tag_ndm: '00720054', tag_ary: [0x0072,0x0054], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0056)', tag_name: "Selector Attribute Private Creator", tag_key: 'SelectorAttributePrivateCreator', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0072,0056)', tag_sym: :selector_attribute_private_creator, tag_ndm: '00720056', tag_ary: [0x0072,0x0056], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,005E)', tag_name: "Selector AE Value", tag_key: 'SelectorAEValue', tag_vr: [:AE], tag_vm: ["1-n"], tag_str: '(0072,005E)', tag_sym: :selector_ae_value, tag_ndm: '0072005E', tag_ary: [0x0072,0x005E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,005F)', tag_name: "Selector AS Value", tag_key: 'SelectorASValue', tag_vr: [:AS], tag_vm: ["1-n"], tag_str: '(0072,005F)', tag_sym: :selector_as_value, tag_ndm: '0072005F', tag_ary: [0x0072,0x005F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0060)', tag_name: "Selector AT Value", tag_key: 'SelectorATValue', tag_vr: [:AT], tag_vm: ["1-n"], tag_str: '(0072,0060)', tag_sym: :selector_at_value, tag_ndm: '00720060', tag_ary: [0x0072,0x0060], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0061)', tag_name: "Selector DA Value", tag_key: 'SelectorDAValue', tag_vr: [:DA], tag_vm: ["1-n"], tag_str: '(0072,0061)', tag_sym: :selector_da_value, tag_ndm: '00720061', tag_ary: [0x0072,0x0061], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0062)', tag_name: "Selector CS Value", tag_key: 'SelectorCSValue', tag_vr: [:CS], tag_vm: ["1-n"], tag_str: '(0072,0062)', tag_sym: :selector_cs_value, tag_ndm: '00720062', tag_ary: [0x0072,0x0062], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0063)', tag_name: "Selector DT Value", tag_key: 'SelectorDTValue', tag_vr: [:DT], tag_vm: ["1-n"], tag_str: '(0072,0063)', tag_sym: :selector_dt_value, tag_ndm: '00720063', tag_ary: [0x0072,0x0063], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0064)', tag_name: "Selector IS Value", tag_key: 'SelectorISValue', tag_vr: [:IS], tag_vm: ["1-n"], tag_str: '(0072,0064)', tag_sym: :selector_is_value, tag_ndm: '00720064', tag_ary: [0x0072,0x0064], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0065)', tag_name: "Selector OB Value", tag_key: 'SelectorOBValue', tag_vr: [:OB], tag_vm: ["1"], tag_str: '(0072,0065)', tag_sym: :selector_ob_value, tag_ndm: '00720065', tag_ary: [0x0072,0x0065], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0066)', tag_name: "Selector LO Value", tag_key: 'SelectorLOValue', tag_vr: [:LO], tag_vm: ["1-n"], tag_str: '(0072,0066)', tag_sym: :selector_lo_value, tag_ndm: '00720066', tag_ary: [0x0072,0x0066], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0067)', tag_name: "Selector OF Value", tag_key: 'SelectorOFValue', tag_vr: [:OF], tag_vm: ["1"], tag_str: '(0072,0067)', tag_sym: :selector_of_value, tag_ndm: '00720067', tag_ary: [0x0072,0x0067], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0068)', tag_name: "Selector LT Value", tag_key: 'SelectorLTValue', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(0072,0068)', tag_sym: :selector_lt_value, tag_ndm: '00720068', tag_ary: [0x0072,0x0068], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0069)', tag_name: "Selector OW Value", tag_key: 'SelectorOWValue', tag_vr: [:OW], tag_vm: ["1"], tag_str: '(0072,0069)', tag_sym: :selector_ow_value, tag_ndm: '00720069', tag_ary: [0x0072,0x0069], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,006A)', tag_name: "Selector PN Value", tag_key: 'SelectorPNValue', tag_vr: [:PN], tag_vm: ["1-n"], tag_str: '(0072,006A)', tag_sym: :selector_pn_value, tag_ndm: '0072006A', tag_ary: [0x0072,0x006A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,006B)', tag_name: "Selector TM Value", tag_key: 'SelectorTMValue', tag_vr: [:TM], tag_vm: ["1-n"], tag_str: '(0072,006B)', tag_sym: :selector_tm_value, tag_ndm: '0072006B', tag_ary: [0x0072,0x006B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,006C)', tag_name: "Selector SH Value", tag_key: 'SelectorSHValue', tag_vr: [:SH], tag_vm: ["1-n"], tag_str: '(0072,006C)', tag_sym: :selector_sh_value, tag_ndm: '0072006C', tag_ary: [0x0072,0x006C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,006D)', tag_name: "Selector UN Value", tag_key: 'SelectorUNValue', tag_vr: [:UN], tag_vm: ["1"], tag_str: '(0072,006D)', tag_sym: :selector_un_value, tag_ndm: '0072006D', tag_ary: [0x0072,0x006D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,006E)', tag_name: "Selector ST Value", tag_key: 'SelectorSTValue', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0072,006E)', tag_sym: :selector_st_value, tag_ndm: '0072006E', tag_ary: [0x0072,0x006E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,006F)', tag_name: "Selector UC Value", tag_key: 'SelectorUCValue', tag_vr: [:UC], tag_vm: ["1-n"], tag_str: '(0072,006F)', tag_sym: :selector_uc_value, tag_ndm: '0072006F', tag_ary: [0x0072,0x006F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0070)', tag_name: "Selector UT Value", tag_key: 'SelectorUTValue', tag_vr: [:UT], tag_vm: ["1"], tag_str: '(0072,0070)', tag_sym: :selector_ut_value, tag_ndm: '00720070', tag_ary: [0x0072,0x0070], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0071)', tag_name: "Selector UR Value", tag_key: 'SelectorURValue', tag_vr: [:UR], tag_vm: ["1"], tag_str: '(0072,0071)', tag_sym: :selector_ur_value, tag_ndm: '00720071', tag_ary: [0x0072,0x0071], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0072)', tag_name: "Selector DS Value", tag_key: 'SelectorDSValue', tag_vr: [:DS], tag_vm: ["1-n"], tag_str: '(0072,0072)', tag_sym: :selector_ds_value, tag_ndm: '00720072', tag_ary: [0x0072,0x0072], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0073)', tag_name: "Selector OD Value", tag_key: 'SelectorODValue', tag_vr: [:OD], tag_vm: ["1"], tag_str: '(0072,0073)', tag_sym: :selector_od_value, tag_ndm: '00720073', tag_ary: [0x0072,0x0073], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0074)', tag_name: "Selector FD Value", tag_key: 'SelectorFDValue', tag_vr: [:FD], tag_vm: ["1-n"], tag_str: '(0072,0074)', tag_sym: :selector_fd_value, tag_ndm: '00720074', tag_ary: [0x0072,0x0074], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0075)', tag_name: "Selector OL Value", tag_key: 'SelectorOLValue', tag_vr: [:OL], tag_vm: ["1"], tag_str: '(0072,0075)', tag_sym: :selector_ol_value, tag_ndm: '00720075', tag_ary: [0x0072,0x0075], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0076)', tag_name: "Selector FL Value", tag_key: 'SelectorFLValue', tag_vr: [:FL], tag_vm: ["1-n"], tag_str: '(0072,0076)', tag_sym: :selector_fl_value, tag_ndm: '00720076', tag_ary: [0x0072,0x0076], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0078)', tag_name: "Selector UL Value", tag_key: 'SelectorULValue', tag_vr: [:UL], tag_vm: ["1-n"], tag_str: '(0072,0078)', tag_sym: :selector_ul_value, tag_ndm: '00720078', tag_ary: [0x0072,0x0078], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,007A)', tag_name: "Selector US Value", tag_key: 'SelectorUSValue', tag_vr: [:US], tag_vm: ["1-n"], tag_str: '(0072,007A)', tag_sym: :selector_us_value, tag_ndm: '0072007A', tag_ary: [0x0072,0x007A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,007C)', tag_name: "Selector SL Value", tag_key: 'SelectorSLValue', tag_vr: [:SL], tag_vm: ["1-n"], tag_str: '(0072,007C)', tag_sym: :selector_sl_value, tag_ndm: '0072007C', tag_ary: [0x0072,0x007C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,007E)', tag_name: "Selector SS Value", tag_key: 'SelectorSSValue', tag_vr: [:SS], tag_vm: ["1-n"], tag_str: '(0072,007E)', tag_sym: :selector_ss_value, tag_ndm: '0072007E', tag_ary: [0x0072,0x007E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,007F)', tag_name: "Selector UI Value", tag_key: 'SelectorUIValue', tag_vr: [:UI], tag_vm: ["1-n"], tag_str: '(0072,007F)', tag_sym: :selector_ui_value, tag_ndm: '0072007F', tag_ary: [0x0072,0x007F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0080)', tag_name: "Selector Code Sequence Value", tag_key: 'SelectorCodeSequenceValue', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0072,0080)', tag_sym: :selector_code_sequence_value, tag_ndm: '00720080', tag_ary: [0x0072,0x0080], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0081)', tag_name: "Selector OV Value", tag_key: 'SelectorOVValue', tag_vr: [:OV], tag_vm: ["1"], tag_str: '(0072,0081)', tag_sym: :selector_ov_value, tag_ndm: '00720081', tag_ary: [0x0072,0x0081], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0082)', tag_name: "Selector SV Value", tag_key: 'SelectorSVValue', tag_vr: [:SV], tag_vm: ["1-n"], tag_str: '(0072,0082)', tag_sym: :selector_sv_value, tag_ndm: '00720082', tag_ary: [0x0072,0x0082], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0083)', tag_name: "Selector UV Value", tag_key: 'SelectorUVValue', tag_vr: [:UV], tag_vm: ["1-n"], tag_str: '(0072,0083)', tag_sym: :selector_uv_value, tag_ndm: '00720083', tag_ary: [0x0072,0x0083], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0100)', tag_name: "Number of Screens", tag_key: 'NumberOfScreens', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0072,0100)', tag_sym: :number_of_screens, tag_ndm: '00720100', tag_ary: [0x0072,0x0100], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0102)', tag_name: "Nominal Screen Definition Sequence", tag_key: 'NominalScreenDefinitionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0072,0102)', tag_sym: :nominal_screen_definition_sequence, tag_ndm: '00720102', tag_ary: [0x0072,0x0102], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0104)', tag_name: "Number of Vertical Pixels", tag_key: 'NumberOfVerticalPixels', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0072,0104)', tag_sym: :number_of_vertical_pixels, tag_ndm: '00720104', tag_ary: [0x0072,0x0104], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0106)', tag_name: "Number of Horizontal Pixels", tag_key: 'NumberOfHorizontalPixels', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0072,0106)', tag_sym: :number_of_horizontal_pixels, tag_ndm: '00720106', tag_ary: [0x0072,0x0106], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0108)', tag_name: "Display Environment Spatial Position", tag_key: 'DisplayEnvironmentSpatialPosition', tag_vr: [:FD], tag_vm: ["4"], tag_str: '(0072,0108)', tag_sym: :display_environment_spatial_position, tag_ndm: '00720108', tag_ary: [0x0072,0x0108], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,010A)', tag_name: "Screen Minimum Grayscale Bit Depth", tag_key: 'ScreenMinimumGrayscaleBitDepth', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0072,010A)', tag_sym: :screen_minimum_grayscale_bit_depth, tag_ndm: '0072010A', tag_ary: [0x0072,0x010A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,010C)', tag_name: "Screen Minimum Color Bit Depth", tag_key: 'ScreenMinimumColorBitDepth', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0072,010C)', tag_sym: :screen_minimum_color_bit_depth, tag_ndm: '0072010C', tag_ary: [0x0072,0x010C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,010E)', tag_name: "Application Maximum Repaint Time", tag_key: 'ApplicationMaximumRepaintTime', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0072,010E)', tag_sym: :application_maximum_repaint_time, tag_ndm: '0072010E', tag_ary: [0x0072,0x010E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0200)', tag_name: "Display Sets Sequence", tag_key: 'DisplaySetsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0072,0200)', tag_sym: :display_sets_sequence, tag_ndm: '00720200', tag_ary: [0x0072,0x0200], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0202)', tag_name: "Display Set Number", tag_key: 'DisplaySetNumber', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0072,0202)', tag_sym: :display_set_number, tag_ndm: '00720202', tag_ary: [0x0072,0x0202], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0203)', tag_name: "Display Set Label", tag_key: 'DisplaySetLabel', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0072,0203)', tag_sym: :display_set_label, tag_ndm: '00720203', tag_ary: [0x0072,0x0203], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0204)', tag_name: "Display Set Presentation Group", tag_key: 'DisplaySetPresentationGroup', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0072,0204)', tag_sym: :display_set_presentation_group, tag_ndm: '00720204', tag_ary: [0x0072,0x0204], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0206)', tag_name: "Display Set Presentation Group Description", tag_key: 'DisplaySetPresentationGroupDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0072,0206)', tag_sym: :display_set_presentation_group_description, tag_ndm: '00720206', tag_ary: [0x0072,0x0206], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0208)', tag_name: "Partial Data Display Handling", tag_key: 'PartialDataDisplayHandling', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0072,0208)', tag_sym: :partial_data_display_handling, tag_ndm: '00720208', tag_ary: [0x0072,0x0208], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0210)', tag_name: "Synchronized Scrolling Sequence", tag_key: 'SynchronizedScrollingSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0072,0210)', tag_sym: :synchronized_scrolling_sequence, tag_ndm: '00720210', tag_ary: [0x0072,0x0210], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0212)', tag_name: "Display Set Scrolling Group", tag_key: 'DisplaySetScrollingGroup', tag_vr: [:US], tag_vm: ["2-n"], tag_str: '(0072,0212)', tag_sym: :display_set_scrolling_group, tag_ndm: '00720212', tag_ary: [0x0072,0x0212], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0214)', tag_name: "Navigation Indicator Sequence", tag_key: 'NavigationIndicatorSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0072,0214)', tag_sym: :navigation_indicator_sequence, tag_ndm: '00720214', tag_ary: [0x0072,0x0214], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0216)', tag_name: "Navigation Display Set", tag_key: 'NavigationDisplaySet', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0072,0216)', tag_sym: :navigation_display_set, tag_ndm: '00720216', tag_ary: [0x0072,0x0216], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0218)', tag_name: "Reference Display Sets", tag_key: 'ReferenceDisplaySets', tag_vr: [:US], tag_vm: ["1-n"], tag_str: '(0072,0218)', tag_sym: :reference_display_sets, tag_ndm: '00720218', tag_ary: [0x0072,0x0218], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0300)', tag_name: "Image Boxes Sequence", tag_key: 'ImageBoxesSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0072,0300)', tag_sym: :image_boxes_sequence, tag_ndm: '00720300', tag_ary: [0x0072,0x0300], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0302)', tag_name: "Image Box Number", tag_key: 'ImageBoxNumber', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0072,0302)', tag_sym: :image_box_number, tag_ndm: '00720302', tag_ary: [0x0072,0x0302], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0304)', tag_name: "Image Box Layout Type", tag_key: 'ImageBoxLayoutType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0072,0304)', tag_sym: :image_box_layout_type, tag_ndm: '00720304', tag_ary: [0x0072,0x0304], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0306)', tag_name: "Image Box Tile Horizontal Dimension", tag_key: 'ImageBoxTileHorizontalDimension', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0072,0306)', tag_sym: :image_box_tile_horizontal_dimension, tag_ndm: '00720306', tag_ary: [0x0072,0x0306], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0308)', tag_name: "Image Box Tile Vertical Dimension", tag_key: 'ImageBoxTileVerticalDimension', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0072,0308)', tag_sym: :image_box_tile_vertical_dimension, tag_ndm: '00720308', tag_ary: [0x0072,0x0308], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0310)', tag_name: "Image Box Scroll Direction", tag_key: 'ImageBoxScrollDirection', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0072,0310)', tag_sym: :image_box_scroll_direction, tag_ndm: '00720310', tag_ary: [0x0072,0x0310], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0312)', tag_name: "Image Box Small Scroll Type", tag_key: 'ImageBoxSmallScrollType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0072,0312)', tag_sym: :image_box_small_scroll_type, tag_ndm: '00720312', tag_ary: [0x0072,0x0312], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0314)', tag_name: "Image Box Small Scroll Amount", tag_key: 'ImageBoxSmallScrollAmount', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0072,0314)', tag_sym: :image_box_small_scroll_amount, tag_ndm: '00720314', tag_ary: [0x0072,0x0314], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0316)', tag_name: "Image Box Large Scroll Type", tag_key: 'ImageBoxLargeScrollType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0072,0316)', tag_sym: :image_box_large_scroll_type, tag_ndm: '00720316', tag_ary: [0x0072,0x0316], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0318)', tag_name: "Image Box Large Scroll Amount", tag_key: 'ImageBoxLargeScrollAmount', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0072,0318)', tag_sym: :image_box_large_scroll_amount, tag_ndm: '00720318', tag_ary: [0x0072,0x0318], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0320)', tag_name: "Image Box Overlap Priority", tag_key: 'ImageBoxOverlapPriority', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0072,0320)', tag_sym: :image_box_overlap_priority, tag_ndm: '00720320', tag_ary: [0x0072,0x0320], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0330)', tag_name: "Cine Relative to Real-Time", tag_key: 'CineRelativeToRealTime', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0072,0330)', tag_sym: :cine_relative_to_real_time, tag_ndm: '00720330', tag_ary: [0x0072,0x0330], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0400)', tag_name: "Filter Operations Sequence", tag_key: 'FilterOperationsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0072,0400)', tag_sym: :filter_operations_sequence, tag_ndm: '00720400', tag_ary: [0x0072,0x0400], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0402)', tag_name: "Filter-by Category", tag_key: 'FilterByCategory', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0072,0402)', tag_sym: :filter_by_category, tag_ndm: '00720402', tag_ary: [0x0072,0x0402], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0404)', tag_name: "Filter-by Attribute Presence", tag_key: 'FilterByAttributePresence', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0072,0404)', tag_sym: :filter_by_attribute_presence, tag_ndm: '00720404', tag_ary: [0x0072,0x0404], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0406)', tag_name: "Filter-by Operator", tag_key: 'FilterByOperator', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0072,0406)', tag_sym: :filter_by_operator, tag_ndm: '00720406', tag_ary: [0x0072,0x0406], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0420)', tag_name: "Structured Display Background CIELab Value", tag_key: 'StructuredDisplayBackgroundCIELabValue', tag_vr: [:US], tag_vm: ["3"], tag_str: '(0072,0420)', tag_sym: :structured_display_background_cie_lab_value, tag_ndm: '00720420', tag_ary: [0x0072,0x0420], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0421)', tag_name: "Empty Image Box CIELab Value", tag_key: 'EmptyImageBoxCIELabValue', tag_vr: [:US], tag_vm: ["3"], tag_str: '(0072,0421)', tag_sym: :empty_image_box_cie_lab_value, tag_ndm: '00720421', tag_ary: [0x0072,0x0421], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0422)', tag_name: "Structured Display Image Box Sequence", tag_key: 'StructuredDisplayImageBoxSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0072,0422)', tag_sym: :structured_display_image_box_sequence, tag_ndm: '00720422', tag_ary: [0x0072,0x0422], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0424)', tag_name: "Structured Display Text Box Sequence", tag_key: 'StructuredDisplayTextBoxSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0072,0424)', tag_sym: :structured_display_text_box_sequence, tag_ndm: '00720424', tag_ary: [0x0072,0x0424], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0427)', tag_name: "Referenced First Frame Sequence", tag_key: 'ReferencedFirstFrameSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0072,0427)', tag_sym: :referenced_first_frame_sequence, tag_ndm: '00720427', tag_ary: [0x0072,0x0427], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0430)', tag_name: "Image Box Synchronization Sequence", tag_key: 'ImageBoxSynchronizationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0072,0430)', tag_sym: :image_box_synchronization_sequence, tag_ndm: '00720430', tag_ary: [0x0072,0x0430], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0432)', tag_name: "Synchronized Image Box List", tag_key: 'SynchronizedImageBoxList', tag_vr: [:US], tag_vm: ["2-n"], tag_str: '(0072,0432)', tag_sym: :synchronized_image_box_list, tag_ndm: '00720432', tag_ary: [0x0072,0x0432], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0434)', tag_name: "Type of Synchronization", tag_key: 'TypeOfSynchronization', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0072,0434)', tag_sym: :type_of_synchronization, tag_ndm: '00720434', tag_ary: [0x0072,0x0434], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0500)', tag_name: "Blending Operation Type", tag_key: 'BlendingOperationType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0072,0500)', tag_sym: :blending_operation_type, tag_ndm: '00720500', tag_ary: [0x0072,0x0500], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0510)', tag_name: "Reformatting Operation Type", tag_key: 'ReformattingOperationType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0072,0510)', tag_sym: :reformatting_operation_type, tag_ndm: '00720510', tag_ary: [0x0072,0x0510], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0512)', tag_name: "Reformatting Thickness", tag_key: 'ReformattingThickness', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0072,0512)', tag_sym: :reformatting_thickness, tag_ndm: '00720512', tag_ary: [0x0072,0x0512], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0514)', tag_name: "Reformatting Interval", tag_key: 'ReformattingInterval', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0072,0514)', tag_sym: :reformatting_interval, tag_ndm: '00720514', tag_ary: [0x0072,0x0514], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0516)', tag_name: "Reformatting Operation Initial View Direction", tag_key: 'ReformattingOperationInitialViewDirection', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0072,0516)', tag_sym: :reformatting_operation_initial_view_direction, tag_ndm: '00720516', tag_ary: [0x0072,0x0516], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0520)', tag_name: "3D Rendering Type", tag_key: 'ThreeDRenderingType', tag_vr: [:CS], tag_vm: ["1-n"], tag_str: '(0072,0520)', tag_sym: :three_d_rendering_type, tag_ndm: '00720520', tag_ary: [0x0072,0x0520], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0600)', tag_name: "Sorting Operations Sequence", tag_key: 'SortingOperationsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0072,0600)', tag_sym: :sorting_operations_sequence, tag_ndm: '00720600', tag_ary: [0x0072,0x0600], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0602)', tag_name: "Sort-by Category", tag_key: 'SortByCategory', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0072,0602)', tag_sym: :sort_by_category, tag_ndm: '00720602', tag_ary: [0x0072,0x0602], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0604)', tag_name: "Sorting Direction", tag_key: 'SortingDirection', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0072,0604)', tag_sym: :sorting_direction, tag_ndm: '00720604', tag_ary: [0x0072,0x0604], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0700)', tag_name: "Display Set Patient Orientation", tag_key: 'DisplaySetPatientOrientation', tag_vr: [:CS], tag_vm: ["2"], tag_str: '(0072,0700)', tag_sym: :display_set_patient_orientation, tag_ndm: '00720700', tag_ary: [0x0072,0x0700], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0702)', tag_name: "VOI Type", tag_key: 'VOIType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0072,0702)', tag_sym: :voi_type, tag_ndm: '00720702', tag_ary: [0x0072,0x0702], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0704)', tag_name: "Pseudo-Color Type", tag_key: 'PseudoColorType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0072,0704)', tag_sym: :pseudo_color_type, tag_ndm: '00720704', tag_ary: [0x0072,0x0704], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0705)', tag_name: "Pseudo-Color Palette Instance Reference Sequence", tag_key: 'PseudoColorPaletteInstanceReferenceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0072,0705)', tag_sym: :pseudo_color_palette_instance_reference_sequence, tag_ndm: '00720705', tag_ary: [0x0072,0x0705], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0706)', tag_name: "Show Grayscale Inverted", tag_key: 'ShowGrayscaleInverted', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0072,0706)', tag_sym: :show_grayscale_inverted, tag_ndm: '00720706', tag_ary: [0x0072,0x0706], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0710)', tag_name: "Show Image True Size Flag", tag_key: 'ShowImageTrueSizeFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0072,0710)', tag_sym: :show_image_true_size_flag, tag_ndm: '00720710', tag_ary: [0x0072,0x0710], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0712)', tag_name: "Show Graphic Annotation Flag", tag_key: 'ShowGraphicAnnotationFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0072,0712)', tag_sym: :show_graphic_annotation_flag, tag_ndm: '00720712', tag_ary: [0x0072,0x0712], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0714)', tag_name: "Show Patient Demographics Flag", tag_key: 'ShowPatientDemographicsFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0072,0714)', tag_sym: :show_patient_demographics_flag, tag_ndm: '00720714', tag_ary: [0x0072,0x0714], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0716)', tag_name: "Show Acquisition Techniques Flag", tag_key: 'ShowAcquisitionTechniquesFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0072,0716)', tag_sym: :show_acquisition_techniques_flag, tag_ndm: '00720716', tag_ary: [0x0072,0x0716], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0717)', tag_name: "Display Set Horizontal Justification", tag_key: 'DisplaySetHorizontalJustification', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0072,0717)', tag_sym: :display_set_horizontal_justification, tag_ndm: '00720717', tag_ary: [0x0072,0x0717], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0072,0718)', tag_name: "Display Set Vertical Justification", tag_key: 'DisplaySetVerticalJustification', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0072,0718)', tag_sym: :display_set_vertical_justification, tag_ndm: '00720718', tag_ary: [0x0072,0x0718], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,0120)', tag_name: "Continuation Start Meterset", tag_key: 'ContinuationStartMeterset', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0074,0120)', tag_sym: :continuation_start_meterset, tag_ndm: '00740120', tag_ary: [0x0074,0x0120], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,0121)', tag_name: "Continuation End Meterset", tag_key: 'ContinuationEndMeterset', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0074,0121)', tag_sym: :continuation_end_meterset, tag_ndm: '00740121', tag_ary: [0x0074,0x0121], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,1000)', tag_name: "Procedure Step State", tag_key: 'ProcedureStepState', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0074,1000)', tag_sym: :procedure_step_state, tag_ndm: '00741000', tag_ary: [0x0074,0x1000], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,1002)', tag_name: "Procedure Step Progress Information Sequence", tag_key: 'ProcedureStepProgressInformationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0074,1002)', tag_sym: :procedure_step_progress_information_sequence, tag_ndm: '00741002', tag_ary: [0x0074,0x1002], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,1004)', tag_name: "Procedure Step Progress", tag_key: 'ProcedureStepProgress', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0074,1004)', tag_sym: :procedure_step_progress, tag_ndm: '00741004', tag_ary: [0x0074,0x1004], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,1006)', tag_name: "Procedure Step Progress Description", tag_key: 'ProcedureStepProgressDescription', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0074,1006)', tag_sym: :procedure_step_progress_description, tag_ndm: '00741006', tag_ary: [0x0074,0x1006], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,1007)', tag_name: "Procedure Step Progress Parameters Sequence", tag_key: 'ProcedureStepProgressParametersSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0074,1007)', tag_sym: :procedure_step_progress_parameters_sequence, tag_ndm: '00741007', tag_ary: [0x0074,0x1007], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,1008)', tag_name: "Procedure Step Communications URI Sequence", tag_key: 'ProcedureStepCommunicationsURISequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0074,1008)', tag_sym: :procedure_step_communications_uri_sequence, tag_ndm: '00741008', tag_ary: [0x0074,0x1008], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,100A)', tag_name: "Contact URI", tag_key: 'ContactURI', tag_vr: [:UR], tag_vm: ["1"], tag_str: '(0074,100A)', tag_sym: :contact_uri, tag_ndm: '0074100A', tag_ary: [0x0074,0x100A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,100C)', tag_name: "Contact Display Name", tag_key: 'ContactDisplayName', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0074,100C)', tag_sym: :contact_display_name, tag_ndm: '0074100C', tag_ary: [0x0074,0x100C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,100E)', tag_name: "Procedure Step Discontinuation Reason Code Sequence", tag_key: 'ProcedureStepDiscontinuationReasonCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0074,100E)', tag_sym: :procedure_step_discontinuation_reason_code_sequence, tag_ndm: '0074100E', tag_ary: [0x0074,0x100E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,1020)', tag_name: "Beam Task Sequence", tag_key: 'BeamTaskSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0074,1020)', tag_sym: :beam_task_sequence, tag_ndm: '00741020', tag_ary: [0x0074,0x1020], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,1022)', tag_name: "Beam Task Type", tag_key: 'BeamTaskType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0074,1022)', tag_sym: :beam_task_type, tag_ndm: '00741022', tag_ary: [0x0074,0x1022], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,1024)', tag_name: "Beam Order Index (Trial)", tag_key: 'BeamOrderIndexTrial', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0074,1024)', tag_sym: :beam_order_index_trial, tag_ndm: '00741024', tag_ary: [0x0074,0x1024], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0074,1025)', tag_name: "Autosequence Flag", tag_key: 'AutosequenceFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0074,1025)', tag_sym: :autosequence_flag, tag_ndm: '00741025', tag_ary: [0x0074,0x1025], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,1026)', tag_name: "Table Top Vertical Adjusted Position", tag_key: 'TableTopVerticalAdjustedPosition', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0074,1026)', tag_sym: :table_top_vertical_adjusted_position, tag_ndm: '00741026', tag_ary: [0x0074,0x1026], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,1027)', tag_name: "Table Top Longitudinal Adjusted Position", tag_key: 'TableTopLongitudinalAdjustedPosition', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0074,1027)', tag_sym: :table_top_longitudinal_adjusted_position, tag_ndm: '00741027', tag_ary: [0x0074,0x1027], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,1028)', tag_name: "Table Top Lateral Adjusted Position", tag_key: 'TableTopLateralAdjustedPosition', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0074,1028)', tag_sym: :table_top_lateral_adjusted_position, tag_ndm: '00741028', tag_ary: [0x0074,0x1028], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,102A)', tag_name: "Patient Support Adjusted Angle", tag_key: 'PatientSupportAdjustedAngle', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0074,102A)', tag_sym: :patient_support_adjusted_angle, tag_ndm: '0074102A', tag_ary: [0x0074,0x102A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,102B)', tag_name: "Table Top Eccentric Adjusted Angle", tag_key: 'TableTopEccentricAdjustedAngle', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0074,102B)', tag_sym: :table_top_eccentric_adjusted_angle, tag_ndm: '0074102B', tag_ary: [0x0074,0x102B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,102C)', tag_name: "Table Top Pitch Adjusted Angle", tag_key: 'TableTopPitchAdjustedAngle', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0074,102C)', tag_sym: :table_top_pitch_adjusted_angle, tag_ndm: '0074102C', tag_ary: [0x0074,0x102C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,102D)', tag_name: "Table Top Roll Adjusted Angle", tag_key: 'TableTopRollAdjustedAngle', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0074,102D)', tag_sym: :table_top_roll_adjusted_angle, tag_ndm: '0074102D', tag_ary: [0x0074,0x102D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,1030)', tag_name: "Delivery Verification Image Sequence", tag_key: 'DeliveryVerificationImageSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0074,1030)', tag_sym: :delivery_verification_image_sequence, tag_ndm: '00741030', tag_ary: [0x0074,0x1030], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,1032)', tag_name: "Verification Image Timing", tag_key: 'VerificationImageTiming', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0074,1032)', tag_sym: :verification_image_timing, tag_ndm: '00741032', tag_ary: [0x0074,0x1032], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,1034)', tag_name: "Double Exposure Flag", tag_key: 'DoubleExposureFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0074,1034)', tag_sym: :double_exposure_flag, tag_ndm: '00741034', tag_ary: [0x0074,0x1034], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,1036)', tag_name: "Double Exposure Ordering", tag_key: 'DoubleExposureOrdering', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0074,1036)', tag_sym: :double_exposure_ordering, tag_ndm: '00741036', tag_ary: [0x0074,0x1036], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,1038)', tag_name: "Double Exposure Meterset (Trial)", tag_key: 'DoubleExposureMetersetTrial', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0074,1038)', tag_sym: :double_exposure_meterset_trial, tag_ndm: '00741038', tag_ary: [0x0074,0x1038], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0074,103A)', tag_name: "Double Exposure Field Delta (Trial)", tag_key: 'DoubleExposureFieldDeltaTrial', tag_vr: [:DS], tag_vm: ["4"], tag_str: '(0074,103A)', tag_sym: :double_exposure_field_delta_trial, tag_ndm: '0074103A', tag_ary: [0x0074,0x103A], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0074,1040)', tag_name: "Related Reference RT Image Sequence", tag_key: 'RelatedReferenceRTImageSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0074,1040)', tag_sym: :related_reference_rt_image_sequence, tag_ndm: '00741040', tag_ary: [0x0074,0x1040], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,1042)', tag_name: "General Machine Verification Sequence", tag_key: 'GeneralMachineVerificationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0074,1042)', tag_sym: :general_machine_verification_sequence, tag_ndm: '00741042', tag_ary: [0x0074,0x1042], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,1044)', tag_name: "Conventional Machine Verification Sequence", tag_key: 'ConventionalMachineVerificationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0074,1044)', tag_sym: :conventional_machine_verification_sequence, tag_ndm: '00741044', tag_ary: [0x0074,0x1044], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,1046)', tag_name: "Ion Machine Verification Sequence", tag_key: 'IonMachineVerificationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0074,1046)', tag_sym: :ion_machine_verification_sequence, tag_ndm: '00741046', tag_ary: [0x0074,0x1046], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,1048)', tag_name: "Failed Attributes Sequence", tag_key: 'FailedAttributesSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0074,1048)', tag_sym: :failed_attributes_sequence, tag_ndm: '00741048', tag_ary: [0x0074,0x1048], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,104A)', tag_name: "Overridden Attributes Sequence", tag_key: 'OverriddenAttributesSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0074,104A)', tag_sym: :overridden_attributes_sequence, tag_ndm: '0074104A', tag_ary: [0x0074,0x104A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,104C)', tag_name: "Conventional Control Point Verification Sequence", tag_key: 'ConventionalControlPointVerificationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0074,104C)', tag_sym: :conventional_control_point_verification_sequence, tag_ndm: '0074104C', tag_ary: [0x0074,0x104C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,104E)', tag_name: "Ion Control Point Verification Sequence", tag_key: 'IonControlPointVerificationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0074,104E)', tag_sym: :ion_control_point_verification_sequence, tag_ndm: '0074104E', tag_ary: [0x0074,0x104E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,1050)', tag_name: "Attribute Occurrence Sequence", tag_key: 'AttributeOccurrenceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0074,1050)', tag_sym: :attribute_occurrence_sequence, tag_ndm: '00741050', tag_ary: [0x0074,0x1050], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,1052)', tag_name: "Attribute Occurrence Pointer", tag_key: 'AttributeOccurrencePointer', tag_vr: [:AT], tag_vm: ["1"], tag_str: '(0074,1052)', tag_sym: :attribute_occurrence_pointer, tag_ndm: '00741052', tag_ary: [0x0074,0x1052], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,1054)', tag_name: "Attribute Item Selector", tag_key: 'AttributeItemSelector', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0074,1054)', tag_sym: :attribute_item_selector, tag_ndm: '00741054', tag_ary: [0x0074,0x1054], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,1056)', tag_name: "Attribute Occurrence Private Creator", tag_key: 'AttributeOccurrencePrivateCreator', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0074,1056)', tag_sym: :attribute_occurrence_private_creator, tag_ndm: '00741056', tag_ary: [0x0074,0x1056], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,1057)', tag_name: "Selector Sequence Pointer Items", tag_key: 'SelectorSequencePointerItems', tag_vr: [:IS], tag_vm: ["1-n"], tag_str: '(0074,1057)', tag_sym: :selector_sequence_pointer_items, tag_ndm: '00741057', tag_ary: [0x0074,0x1057], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,1200)', tag_name: "Scheduled Procedure Step Priority", tag_key: 'ScheduledProcedureStepPriority', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0074,1200)', tag_sym: :scheduled_procedure_step_priority, tag_ndm: '00741200', tag_ary: [0x0074,0x1200], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,1202)', tag_name: "Worklist Label", tag_key: 'WorklistLabel', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0074,1202)', tag_sym: :worklist_label, tag_ndm: '00741202', tag_ary: [0x0074,0x1202], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,1204)', tag_name: "Procedure Step Label", tag_key: 'ProcedureStepLabel', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0074,1204)', tag_sym: :procedure_step_label, tag_ndm: '00741204', tag_ary: [0x0074,0x1204], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,1210)', tag_name: "Scheduled Processing Parameters Sequence", tag_key: 'ScheduledProcessingParametersSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0074,1210)', tag_sym: :scheduled_processing_parameters_sequence, tag_ndm: '00741210', tag_ary: [0x0074,0x1210], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,1212)', tag_name: "Performed Processing Parameters Sequence", tag_key: 'PerformedProcessingParametersSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0074,1212)', tag_sym: :performed_processing_parameters_sequence, tag_ndm: '00741212', tag_ary: [0x0074,0x1212], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,1216)', tag_name: "Unified Procedure Step Performed Procedure Sequence", tag_key: 'UnifiedProcedureStepPerformedProcedureSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0074,1216)', tag_sym: :unified_procedure_step_performed_procedure_sequence, tag_ndm: '00741216', tag_ary: [0x0074,0x1216], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,1220)', tag_name: "Related Procedure Step Sequence", tag_key: 'RelatedProcedureStepSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0074,1220)', tag_sym: :related_procedure_step_sequence, tag_ndm: '00741220', tag_ary: [0x0074,0x1220], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0074,1222)', tag_name: "Procedure Step Relationship Type", tag_key: 'ProcedureStepRelationshipType', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0074,1222)', tag_sym: :procedure_step_relationship_type, tag_ndm: '00741222', tag_ary: [0x0074,0x1222], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(0074,1224)', tag_name: "Replaced Procedure Step Sequence", tag_key: 'ReplacedProcedureStepSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0074,1224)', tag_sym: :replaced_procedure_step_sequence, tag_ndm: '00741224', tag_ary: [0x0074,0x1224], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,1230)', tag_name: "Deletion Lock", tag_key: 'DeletionLock', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0074,1230)', tag_sym: :deletion_lock, tag_ndm: '00741230', tag_ary: [0x0074,0x1230], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,1234)', tag_name: "Receiving AE", tag_key: 'ReceivingAE', tag_vr: [:AE], tag_vm: ["1"], tag_str: '(0074,1234)', tag_sym: :receiving_ae, tag_ndm: '00741234', tag_ary: [0x0074,0x1234], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,1236)', tag_name: "Requesting AE", tag_key: 'RequestingAE', tag_vr: [:AE], tag_vm: ["1"], tag_str: '(0074,1236)', tag_sym: :requesting_ae, tag_ndm: '00741236', tag_ary: [0x0074,0x1236], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,1238)', tag_name: "Reason for Cancellation", tag_key: 'ReasonForCancellation', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(0074,1238)', tag_sym: :reason_for_cancellation, tag_ndm: '00741238', tag_ary: [0x0074,0x1238], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,1242)', tag_name: "SCP Status", tag_key: 'SCPStatus', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0074,1242)', tag_sym: :scp_status, tag_ndm: '00741242', tag_ary: [0x0074,0x1242], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,1244)', tag_name: "Subscription List Status", tag_key: 'SubscriptionListStatus', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0074,1244)', tag_sym: :subscription_list_status, tag_ndm: '00741244', tag_ary: [0x0074,0x1244], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,1246)', tag_name: "Unified Procedure Step List Status", tag_key: 'UnifiedProcedureStepListStatus', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0074,1246)', tag_sym: :unified_procedure_step_list_status, tag_ndm: '00741246', tag_ary: [0x0074,0x1246], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,1324)', tag_name: "Beam Order Index", tag_key: 'BeamOrderIndex', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0074,1324)', tag_sym: :beam_order_index, tag_ndm: '00741324', tag_ary: [0x0074,0x1324], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,1338)', tag_name: "Double Exposure Meterset", tag_key: 'DoubleExposureMeterset', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0074,1338)', tag_sym: :double_exposure_meterset, tag_ndm: '00741338', tag_ary: [0x0074,0x1338], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,133A)', tag_name: "Double Exposure Field Delta", tag_key: 'DoubleExposureFieldDelta', tag_vr: [:FD], tag_vm: ["4"], tag_str: '(0074,133A)', tag_sym: :double_exposure_field_delta, tag_ndm: '0074133A', tag_ary: [0x0074,0x133A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,1401)', tag_name: "Brachy Task Sequence", tag_key: 'BrachyTaskSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0074,1401)', tag_sym: :brachy_task_sequence, tag_ndm: '00741401', tag_ary: [0x0074,0x1401], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,1402)', tag_name: "Continuation Start Total Reference Air Kerma", tag_key: 'ContinuationStartTotalReferenceAirKerma', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0074,1402)', tag_sym: :continuation_start_total_reference_air_kerma, tag_ndm: '00741402', tag_ary: [0x0074,0x1402], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,1403)', tag_name: "Continuation End Total Reference Air Kerma", tag_key: 'ContinuationEndTotalReferenceAirKerma', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0074,1403)', tag_sym: :continuation_end_total_reference_air_kerma, tag_ndm: '00741403', tag_ary: [0x0074,0x1403], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,1404)', tag_name: "Continuation Pulse Number", tag_key: 'ContinuationPulseNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0074,1404)', tag_sym: :continuation_pulse_number, tag_ndm: '00741404', tag_ary: [0x0074,0x1404], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,1405)', tag_name: "Channel Delivery Order Sequence", tag_key: 'ChannelDeliveryOrderSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0074,1405)', tag_sym: :channel_delivery_order_sequence, tag_ndm: '00741405', tag_ary: [0x0074,0x1405], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,1406)', tag_name: "Referenced Channel Number", tag_key: 'ReferencedChannelNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0074,1406)', tag_sym: :referenced_channel_number, tag_ndm: '00741406', tag_ary: [0x0074,0x1406], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,1407)', tag_name: "Start Cumulative Time Weight", tag_key: 'StartCumulativeTimeWeight', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0074,1407)', tag_sym: :start_cumulative_time_weight, tag_ndm: '00741407', tag_ary: [0x0074,0x1407], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,1408)', tag_name: "End Cumulative Time Weight", tag_key: 'EndCumulativeTimeWeight', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(0074,1408)', tag_sym: :end_cumulative_time_weight, tag_ndm: '00741408', tag_ary: [0x0074,0x1408], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,1409)', tag_name: "Omitted Channel Sequence", tag_key: 'OmittedChannelSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0074,1409)', tag_sym: :omitted_channel_sequence, tag_ndm: '00741409', tag_ary: [0x0074,0x1409], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,140A)', tag_name: "Reason for Channel Omission", tag_key: 'ReasonForChannelOmission', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0074,140A)', tag_sym: :reason_for_channel_omission, tag_ndm: '0074140A', tag_ary: [0x0074,0x140A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,140B)', tag_name: "Reason for Channel Omission Description", tag_key: 'ReasonForChannelOmissionDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0074,140B)', tag_sym: :reason_for_channel_omission_description, tag_ndm: '0074140B', tag_ary: [0x0074,0x140B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,140C)', tag_name: "Channel Delivery Order Index", tag_key: 'ChannelDeliveryOrderIndex', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(0074,140C)', tag_sym: :channel_delivery_order_index, tag_ndm: '0074140C', tag_ary: [0x0074,0x140C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,140D)', tag_name: "Channel Delivery Continuation Sequence", tag_key: 'ChannelDeliveryContinuationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0074,140D)', tag_sym: :channel_delivery_continuation_sequence, tag_ndm: '0074140D', tag_ary: [0x0074,0x140D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0074,140E)', tag_name: "Omitted Application Setup Sequence", tag_key: 'OmittedApplicationSetupSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0074,140E)', tag_sym: :omitted_application_setup_sequence, tag_ndm: '0074140E', tag_ary: [0x0074,0x140E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0076,0001)', tag_name: "Implant Assembly Template Name", tag_key: 'ImplantAssemblyTemplateName', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0076,0001)', tag_sym: :implant_assembly_template_name, tag_ndm: '00760001', tag_ary: [0x0076,0x0001], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0076,0003)', tag_name: "Implant Assembly Template Issuer", tag_key: 'ImplantAssemblyTemplateIssuer', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0076,0003)', tag_sym: :implant_assembly_template_issuer, tag_ndm: '00760003', tag_ary: [0x0076,0x0003], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0076,0006)', tag_name: "Implant Assembly Template Version", tag_key: 'ImplantAssemblyTemplateVersion', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0076,0006)', tag_sym: :implant_assembly_template_version, tag_ndm: '00760006', tag_ary: [0x0076,0x0006], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0076,0008)', tag_name: "Replaced Implant Assembly Template Sequence", tag_key: 'ReplacedImplantAssemblyTemplateSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0076,0008)', tag_sym: :replaced_implant_assembly_template_sequence, tag_ndm: '00760008', tag_ary: [0x0076,0x0008], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0076,000A)', tag_name: "Implant Assembly Template Type", tag_key: 'ImplantAssemblyTemplateType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0076,000A)', tag_sym: :implant_assembly_template_type, tag_ndm: '0076000A', tag_ary: [0x0076,0x000A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0076,000C)', tag_name: "Original Implant Assembly Template Sequence", tag_key: 'OriginalImplantAssemblyTemplateSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0076,000C)', tag_sym: :original_implant_assembly_template_sequence, tag_ndm: '0076000C', tag_ary: [0x0076,0x000C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0076,000E)', tag_name: "Derivation Implant Assembly Template Sequence", tag_key: 'DerivationImplantAssemblyTemplateSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0076,000E)', tag_sym: :derivation_implant_assembly_template_sequence, tag_ndm: '0076000E', tag_ary: [0x0076,0x000E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0076,0010)', tag_name: "Implant Assembly Template Target Anatomy Sequence", tag_key: 'ImplantAssemblyTemplateTargetAnatomySequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0076,0010)', tag_sym: :implant_assembly_template_target_anatomy_sequence, tag_ndm: '00760010', tag_ary: [0x0076,0x0010], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0076,0020)', tag_name: "Procedure Type Code Sequence", tag_key: 'ProcedureTypeCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0076,0020)', tag_sym: :procedure_type_code_sequence, tag_ndm: '00760020', tag_ary: [0x0076,0x0020], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0076,0030)', tag_name: "Surgical Technique", tag_key: 'SurgicalTechnique', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0076,0030)', tag_sym: :surgical_technique, tag_ndm: '00760030', tag_ary: [0x0076,0x0030], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0076,0032)', tag_name: "Component Types Sequence", tag_key: 'ComponentTypesSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0076,0032)', tag_sym: :component_types_sequence, tag_ndm: '00760032', tag_ary: [0x0076,0x0032], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0076,0034)', tag_name: "Component Type Code Sequence", tag_key: 'ComponentTypeCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0076,0034)', tag_sym: :component_type_code_sequence, tag_ndm: '00760034', tag_ary: [0x0076,0x0034], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0076,0036)', tag_name: "Exclusive Component Type", tag_key: 'ExclusiveComponentType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0076,0036)', tag_sym: :exclusive_component_type, tag_ndm: '00760036', tag_ary: [0x0076,0x0036], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0076,0038)', tag_name: "Mandatory Component Type", tag_key: 'MandatoryComponentType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0076,0038)', tag_sym: :mandatory_component_type, tag_ndm: '00760038', tag_ary: [0x0076,0x0038], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0076,0040)', tag_name: "Component Sequence", tag_key: 'ComponentSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0076,0040)', tag_sym: :component_sequence, tag_ndm: '00760040', tag_ary: [0x0076,0x0040], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0076,0055)', tag_name: "Component ID", tag_key: 'ComponentID', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0076,0055)', tag_sym: :component_id, tag_ndm: '00760055', tag_ary: [0x0076,0x0055], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0076,0060)', tag_name: "Component Assembly Sequence", tag_key: 'ComponentAssemblySequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0076,0060)', tag_sym: :component_assembly_sequence, tag_ndm: '00760060', tag_ary: [0x0076,0x0060], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0076,0070)', tag_name: "Component 1 Referenced ID", tag_key: 'Component1ReferencedID', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0076,0070)', tag_sym: :component1_referenced_id, tag_ndm: '00760070', tag_ary: [0x0076,0x0070], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0076,0080)', tag_name: "Component 1 Referenced Mating Feature Set ID", tag_key: 'Component1ReferencedMatingFeatureSetID', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0076,0080)', tag_sym: :component1_referenced_mating_feature_set_id, tag_ndm: '00760080', tag_ary: [0x0076,0x0080], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0076,0090)', tag_name: "Component 1 Referenced Mating Feature ID", tag_key: 'Component1ReferencedMatingFeatureID', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0076,0090)', tag_sym: :component1_referenced_mating_feature_id, tag_ndm: '00760090', tag_ary: [0x0076,0x0090], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0076,00A0)', tag_name: "Component 2 Referenced ID", tag_key: 'Component2ReferencedID', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0076,00A0)', tag_sym: :component2_referenced_id, tag_ndm: '007600A0', tag_ary: [0x0076,0x00A0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0076,00B0)', tag_name: "Component 2 Referenced Mating Feature Set ID", tag_key: 'Component2ReferencedMatingFeatureSetID', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0076,00B0)', tag_sym: :component2_referenced_mating_feature_set_id, tag_ndm: '007600B0', tag_ary: [0x0076,0x00B0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0076,00C0)', tag_name: "Component 2 Referenced Mating Feature ID", tag_key: 'Component2ReferencedMatingFeatureID', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0076,00C0)', tag_sym: :component2_referenced_mating_feature_id, tag_ndm: '007600C0', tag_ary: [0x0076,0x00C0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0078,0001)', tag_name: "Implant Template Group Name", tag_key: 'ImplantTemplateGroupName', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0078,0001)', tag_sym: :implant_template_group_name, tag_ndm: '00780001', tag_ary: [0x0078,0x0001], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0078,0010)', tag_name: "Implant Template Group Description", tag_key: 'ImplantTemplateGroupDescription', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0078,0010)', tag_sym: :implant_template_group_description, tag_ndm: '00780010', tag_ary: [0x0078,0x0010], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0078,0020)', tag_name: "Implant Template Group Issuer", tag_key: 'ImplantTemplateGroupIssuer', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0078,0020)', tag_sym: :implant_template_group_issuer, tag_ndm: '00780020', tag_ary: [0x0078,0x0020], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0078,0024)', tag_name: "Implant Template Group Version", tag_key: 'ImplantTemplateGroupVersion', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0078,0024)', tag_sym: :implant_template_group_version, tag_ndm: '00780024', tag_ary: [0x0078,0x0024], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0078,0026)', tag_name: "Replaced Implant Template Group Sequence", tag_key: 'ReplacedImplantTemplateGroupSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0078,0026)', tag_sym: :replaced_implant_template_group_sequence, tag_ndm: '00780026', tag_ary: [0x0078,0x0026], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0078,0028)', tag_name: "Implant Template Group Target Anatomy Sequence", tag_key: 'ImplantTemplateGroupTargetAnatomySequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0078,0028)', tag_sym: :implant_template_group_target_anatomy_sequence, tag_ndm: '00780028', tag_ary: [0x0078,0x0028], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0078,002A)', tag_name: "Implant Template Group Members Sequence", tag_key: 'ImplantTemplateGroupMembersSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0078,002A)', tag_sym: :implant_template_group_members_sequence, tag_ndm: '0078002A', tag_ary: [0x0078,0x002A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0078,002E)', tag_name: "Implant Template Group Member ID", tag_key: 'ImplantTemplateGroupMemberID', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0078,002E)', tag_sym: :implant_template_group_member_id, tag_ndm: '0078002E', tag_ary: [0x0078,0x002E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0078,0050)', tag_name: "3D Implant Template Group Member Matching Point", tag_key: 'ThreeDImplantTemplateGroupMemberMatchingPoint', tag_vr: [:FD], tag_vm: ["3"], tag_str: '(0078,0050)', tag_sym: :three_d_implant_template_group_member_matching_point, tag_ndm: '00780050', tag_ary: [0x0078,0x0050], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0078,0060)', tag_name: "3D Implant Template Group Member Matching Axes", tag_key: 'ThreeDImplantTemplateGroupMemberMatchingAxes', tag_vr: [:FD], tag_vm: ["9"], tag_str: '(0078,0060)', tag_sym: :three_d_implant_template_group_member_matching_axes, tag_ndm: '00780060', tag_ary: [0x0078,0x0060], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0078,0070)', tag_name: "Implant Template Group Member Matching 2D Coordinates Sequence", tag_key: 'ImplantTemplateGroupMemberMatching2DCoordinatesSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0078,0070)', tag_sym: :implant_template_group_member_matching2d_coordinates_sequence, tag_ndm: '00780070', tag_ary: [0x0078,0x0070], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0078,0090)', tag_name: "2D Implant Template Group Member Matching Point", tag_key: 'TwoDImplantTemplateGroupMemberMatchingPoint', tag_vr: [:FD], tag_vm: ["2"], tag_str: '(0078,0090)', tag_sym: :two_d_implant_template_group_member_matching_point, tag_ndm: '00780090', tag_ary: [0x0078,0x0090], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0078,00A0)', tag_name: "2D Implant Template Group Member Matching Axes", tag_key: 'TwoDImplantTemplateGroupMemberMatchingAxes', tag_vr: [:FD], tag_vm: ["4"], tag_str: '(0078,00A0)', tag_sym: :two_d_implant_template_group_member_matching_axes, tag_ndm: '007800A0', tag_ary: [0x0078,0x00A0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0078,00B0)', tag_name: "Implant Template Group Variation Dimension Sequence", tag_key: 'ImplantTemplateGroupVariationDimensionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0078,00B0)', tag_sym: :implant_template_group_variation_dimension_sequence, tag_ndm: '007800B0', tag_ary: [0x0078,0x00B0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0078,00B2)', tag_name: "Implant Template Group Variation Dimension Name", tag_key: 'ImplantTemplateGroupVariationDimensionName', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0078,00B2)', tag_sym: :implant_template_group_variation_dimension_name, tag_ndm: '007800B2', tag_ary: [0x0078,0x00B2], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0078,00B4)', tag_name: "Implant Template Group Variation Dimension Rank Sequence", tag_key: 'ImplantTemplateGroupVariationDimensionRankSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0078,00B4)', tag_sym: :implant_template_group_variation_dimension_rank_sequence, tag_ndm: '007800B4', tag_ary: [0x0078,0x00B4], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0078,00B6)', tag_name: "Referenced Implant Template Group Member ID", tag_key: 'ReferencedImplantTemplateGroupMemberID', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0078,00B6)', tag_sym: :referenced_implant_template_group_member_id, tag_ndm: '007800B6', tag_ary: [0x0078,0x00B6], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0078,00B8)', tag_name: "Implant Template Group Variation Dimension Rank", tag_key: 'ImplantTemplateGroupVariationDimensionRank', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0078,00B8)', tag_sym: :implant_template_group_variation_dimension_rank, tag_ndm: '007800B8', tag_ary: [0x0078,0x00B8], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0080,0001)', tag_name: "Surface Scan Acquisition Type Code Sequence", tag_key: 'SurfaceScanAcquisitionTypeCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0080,0001)', tag_sym: :surface_scan_acquisition_type_code_sequence, tag_ndm: '00800001', tag_ary: [0x0080,0x0001], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0080,0002)', tag_name: "Surface Scan Mode Code Sequence", tag_key: 'SurfaceScanModeCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0080,0002)', tag_sym: :surface_scan_mode_code_sequence, tag_ndm: '00800002', tag_ary: [0x0080,0x0002], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0080,0003)', tag_name: "Registration Method Code Sequence", tag_key: 'RegistrationMethodCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0080,0003)', tag_sym: :registration_method_code_sequence, tag_ndm: '00800003', tag_ary: [0x0080,0x0003], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0080,0004)', tag_name: "Shot Duration Time", tag_key: 'ShotDurationTime', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0080,0004)', tag_sym: :shot_duration_time, tag_ndm: '00800004', tag_ary: [0x0080,0x0004], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0080,0005)', tag_name: "Shot Offset Time", tag_key: 'ShotOffsetTime', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(0080,0005)', tag_sym: :shot_offset_time, tag_ndm: '00800005', tag_ary: [0x0080,0x0005], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0080,0006)', tag_name: "Surface Point Presentation Value Data", tag_key: 'SurfacePointPresentationValueData', tag_vr: [:US], tag_vm: ["1-n"], tag_str: '(0080,0006)', tag_sym: :surface_point_presentation_value_data, tag_ndm: '00800006', tag_ary: [0x0080,0x0006], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0080,0007)', tag_name: "Surface Point Color CIELab Value Data", tag_key: 'SurfacePointColorCIELabValueData', tag_vr: [:US], tag_vm: ["3-3n"], tag_str: '(0080,0007)', tag_sym: :surface_point_color_cie_lab_value_data, tag_ndm: '00800007', tag_ary: [0x0080,0x0007], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0080,0008)', tag_name: "UV Mapping Sequence", tag_key: 'UVMappingSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0080,0008)', tag_sym: :uv_mapping_sequence, tag_ndm: '00800008', tag_ary: [0x0080,0x0008], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0080,0009)', tag_name: "Texture Label", tag_key: 'TextureLabel', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0080,0009)', tag_sym: :texture_label, tag_ndm: '00800009', tag_ary: [0x0080,0x0009], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0080,0010)', tag_name: "U Value Data", tag_key: 'UValueData', tag_vr: [:OF], tag_vm: ["1"], tag_str: '(0080,0010)', tag_sym: :u_value_data, tag_ndm: '00800010', tag_ary: [0x0080,0x0010], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0080,0011)', tag_name: "V Value Data", tag_key: 'VValueData', tag_vr: [:OF], tag_vm: ["1"], tag_str: '(0080,0011)', tag_sym: :v_value_data, tag_ndm: '00800011', tag_ary: [0x0080,0x0011], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0080,0012)', tag_name: "Referenced Texture Sequence", tag_key: 'ReferencedTextureSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0080,0012)', tag_sym: :referenced_texture_sequence, tag_ndm: '00800012', tag_ary: [0x0080,0x0012], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0080,0013)', tag_name: "Referenced Surface Data Sequence", tag_key: 'ReferencedSurfaceDataSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0080,0013)', tag_sym: :referenced_surface_data_sequence, tag_ndm: '00800013', tag_ary: [0x0080,0x0013], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0082,0001)', tag_name: "Assessment Summary", tag_key: 'AssessmentSummary', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0082,0001)', tag_sym: :assessment_summary, tag_ndm: '00820001', tag_ary: [0x0082,0x0001], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0082,0003)', tag_name: "Assessment Summary Description", tag_key: 'AssessmentSummaryDescription', tag_vr: [:UT], tag_vm: ["1"], tag_str: '(0082,0003)', tag_sym: :assessment_summary_description, tag_ndm: '00820003', tag_ary: [0x0082,0x0003], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0082,0004)', tag_name: "Assessed SOP Instance Sequence", tag_key: 'AssessedSOPInstanceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0082,0004)', tag_sym: :assessed_sop_instance_sequence, tag_ndm: '00820004', tag_ary: [0x0082,0x0004], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0082,0005)', tag_name: "Referenced Comparison SOP Instance Sequence", tag_key: 'ReferencedComparisonSOPInstanceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0082,0005)', tag_sym: :referenced_comparison_sop_instance_sequence, tag_ndm: '00820005', tag_ary: [0x0082,0x0005], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0082,0006)', tag_name: "Number of Assessment Observations", tag_key: 'NumberOfAssessmentObservations', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(0082,0006)', tag_sym: :number_of_assessment_observations, tag_ndm: '00820006', tag_ary: [0x0082,0x0006], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0082,0007)', tag_name: "Assessment Observations Sequence", tag_key: 'AssessmentObservationsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0082,0007)', tag_sym: :assessment_observations_sequence, tag_ndm: '00820007', tag_ary: [0x0082,0x0007], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0082,0008)', tag_name: "Observation Significance", tag_key: 'ObservationSignificance', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0082,0008)', tag_sym: :observation_significance, tag_ndm: '00820008', tag_ary: [0x0082,0x0008], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0082,000A)', tag_name: "Observation Description", tag_key: 'ObservationDescription', tag_vr: [:UT], tag_vm: ["1"], tag_str: '(0082,000A)', tag_sym: :observation_description, tag_ndm: '0082000A', tag_ary: [0x0082,0x000A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0082,000C)', tag_name: "Structured Constraint Observation Sequence", tag_key: 'StructuredConstraintObservationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0082,000C)', tag_sym: :structured_constraint_observation_sequence, tag_ndm: '0082000C', tag_ary: [0x0082,0x000C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0082,0010)', tag_name: "Assessed Attribute Value Sequence", tag_key: 'AssessedAttributeValueSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0082,0010)', tag_sym: :assessed_attribute_value_sequence, tag_ndm: '00820010', tag_ary: [0x0082,0x0010], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0082,0016)', tag_name: "Assessment Set ID", tag_key: 'AssessmentSetID', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0082,0016)', tag_sym: :assessment_set_id, tag_ndm: '00820016', tag_ary: [0x0082,0x0016], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0082,0017)', tag_name: "Assessment Requester Sequence", tag_key: 'AssessmentRequesterSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0082,0017)', tag_sym: :assessment_requester_sequence, tag_ndm: '00820017', tag_ary: [0x0082,0x0017], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0082,0018)', tag_name: "Selector Attribute Name", tag_key: 'SelectorAttributeName', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0082,0018)', tag_sym: :selector_attribute_name, tag_ndm: '00820018', tag_ary: [0x0082,0x0018], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0082,0019)', tag_name: "Selector Attribute Keyword", tag_key: 'SelectorAttributeKeyword', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0082,0019)', tag_sym: :selector_attribute_keyword, tag_ndm: '00820019', tag_ary: [0x0082,0x0019], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0082,0021)', tag_name: "Assessment Type Code Sequence", tag_key: 'AssessmentTypeCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0082,0021)', tag_sym: :assessment_type_code_sequence, tag_ndm: '00820021', tag_ary: [0x0082,0x0021], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0082,0022)', tag_name: "Observation Basis Code Sequence", tag_key: 'ObservationBasisCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0082,0022)', tag_sym: :observation_basis_code_sequence, tag_ndm: '00820022', tag_ary: [0x0082,0x0022], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0082,0023)', tag_name: "Assessment Label", tag_key: 'AssessmentLabel', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0082,0023)', tag_sym: :assessment_label, tag_ndm: '00820023', tag_ary: [0x0082,0x0023], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0082,0032)', tag_name: "Constraint Type", tag_key: 'ConstraintType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0082,0032)', tag_sym: :constraint_type, tag_ndm: '00820032', tag_ary: [0x0082,0x0032], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0082,0033)', tag_name: "Specification Selection Guidance", tag_key: 'SpecificationSelectionGuidance', tag_vr: [:UT], tag_vm: ["1"], tag_str: '(0082,0033)', tag_sym: :specification_selection_guidance, tag_ndm: '00820033', tag_ary: [0x0082,0x0033], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0082,0034)', tag_name: "Constraint Value Sequence", tag_key: 'ConstraintValueSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0082,0034)', tag_sym: :constraint_value_sequence, tag_ndm: '00820034', tag_ary: [0x0082,0x0034], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0082,0035)', tag_name: "Recommended Default Value Sequence", tag_key: 'RecommendedDefaultValueSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0082,0035)', tag_sym: :recommended_default_value_sequence, tag_ndm: '00820035', tag_ary: [0x0082,0x0035], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0082,0036)', tag_name: "Constraint Violation Significance", tag_key: 'ConstraintViolationSignificance', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0082,0036)', tag_sym: :constraint_violation_significance, tag_ndm: '00820036', tag_ary: [0x0082,0x0036], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0082,0037)', tag_name: "Constraint Violation Condition", tag_key: 'ConstraintViolationCondition', tag_vr: [:UT], tag_vm: ["1"], tag_str: '(0082,0037)', tag_sym: :constraint_violation_condition, tag_ndm: '00820037', tag_ary: [0x0082,0x0037], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0082,0038)', tag_name: "Modifiable Constraint Flag", tag_key: 'ModifiableConstraintFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0082,0038)', tag_sym: :modifiable_constraint_flag, tag_ndm: '00820038', tag_ary: [0x0082,0x0038], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0088,0130)', tag_name: "Storage Media File-set ID", tag_key: 'StorageMediaFileSetID', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(0088,0130)', tag_sym: :storage_media_file_set_id, tag_ndm: '00880130', tag_ary: [0x0088,0x0130], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0088,0140)', tag_name: "Storage Media File-set UID", tag_key: 'StorageMediaFileSetUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0088,0140)', tag_sym: :storage_media_file_set_uid, tag_ndm: '00880140', tag_ary: [0x0088,0x0140], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0088,0200)', tag_name: "Icon Image Sequence", tag_key: 'IconImageSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0088,0200)', tag_sym: :icon_image_sequence, tag_ndm: '00880200', tag_ary: [0x0088,0x0200], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0088,0904)', tag_name: "Topic Title", tag_key: 'TopicTitle', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0088,0904)', tag_sym: :topic_title, tag_ndm: '00880904', tag_ary: [0x0088,0x0904], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0088,0906)', tag_name: "Topic Subject", tag_key: 'TopicSubject', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(0088,0906)', tag_sym: :topic_subject, tag_ndm: '00880906', tag_ary: [0x0088,0x0906], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0088,0910)', tag_name: "Topic Author", tag_key: 'TopicAuthor', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0088,0910)', tag_sym: :topic_author, tag_ndm: '00880910', tag_ary: [0x0088,0x0910], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0088,0912)', tag_name: "Topic Keywords", tag_key: 'TopicKeywords', tag_vr: [:LO], tag_vm: ["1-32"], tag_str: '(0088,0912)', tag_sym: :topic_keywords, tag_ndm: '00880912', tag_ary: [0x0088,0x0912], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(0100,0410)', tag_name: "SOP Instance Status", tag_key: 'SOPInstanceStatus', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0100,0410)', tag_sym: :sop_instance_status, tag_ndm: '01000410', tag_ary: [0x0100,0x0410], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0100,0420)', tag_name: "SOP Authorization DateTime", tag_key: 'SOPAuthorizationDateTime', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(0100,0420)', tag_sym: :sop_authorization_date_time, tag_ndm: '01000420', tag_ary: [0x0100,0x0420], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0100,0424)', tag_name: "SOP Authorization Comment", tag_key: 'SOPAuthorizationComment', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(0100,0424)', tag_sym: :sop_authorization_comment, tag_ndm: '01000424', tag_ary: [0x0100,0x0424], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0100,0426)', tag_name: "Authorization Equipment Certification Number", tag_key: 'AuthorizationEquipmentCertificationNumber', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0100,0426)', tag_sym: :authorization_equipment_certification_number, tag_ndm: '01000426', tag_ary: [0x0100,0x0426], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0400,0005)', tag_name: "MAC ID Number", tag_key: 'MACIDNumber', tag_vr: [:US], tag_vm: ["1"], tag_str: '(0400,0005)', tag_sym: :macid_number, tag_ndm: '04000005', tag_ary: [0x0400,0x0005], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0400,0010)', tag_name: "MAC Calculation Transfer Syntax UID", tag_key: 'MACCalculationTransferSyntaxUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0400,0010)', tag_sym: :mac_calculation_transfer_syntax_uid, tag_ndm: '04000010', tag_ary: [0x0400,0x0010], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0400,0015)', tag_name: "MAC Algorithm", tag_key: 'MACAlgorithm', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0400,0015)', tag_sym: :mac_algorithm, tag_ndm: '04000015', tag_ary: [0x0400,0x0015], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0400,0020)', tag_name: "Data Elements Signed", tag_key: 'DataElementsSigned', tag_vr: [:AT], tag_vm: ["1-n"], tag_str: '(0400,0020)', tag_sym: :data_elements_signed, tag_ndm: '04000020', tag_ary: [0x0400,0x0020], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0400,0100)', tag_name: "Digital Signature UID", tag_key: 'DigitalSignatureUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0400,0100)', tag_sym: :digital_signature_uid, tag_ndm: '04000100', tag_ary: [0x0400,0x0100], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0400,0105)', tag_name: "Digital Signature DateTime", tag_key: 'DigitalSignatureDateTime', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(0400,0105)', tag_sym: :digital_signature_date_time, tag_ndm: '04000105', tag_ary: [0x0400,0x0105], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0400,0110)', tag_name: "Certificate Type", tag_key: 'CertificateType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0400,0110)', tag_sym: :certificate_type, tag_ndm: '04000110', tag_ary: [0x0400,0x0110], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0400,0115)', tag_name: "Certificate of Signer", tag_key: 'CertificateOfSigner', tag_vr: [:OB], tag_vm: ["1"], tag_str: '(0400,0115)', tag_sym: :certificate_of_signer, tag_ndm: '04000115', tag_ary: [0x0400,0x0115], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0400,0120)', tag_name: "Signature", tag_key: 'Signature', tag_vr: [:OB], tag_vm: ["1"], tag_str: '(0400,0120)', tag_sym: :signature, tag_ndm: '04000120', tag_ary: [0x0400,0x0120], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0400,0305)', tag_name: "Certified Timestamp Type", tag_key: 'CertifiedTimestampType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0400,0305)', tag_sym: :certified_timestamp_type, tag_ndm: '04000305', tag_ary: [0x0400,0x0305], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0400,0310)', tag_name: "Certified Timestamp", tag_key: 'CertifiedTimestamp', tag_vr: [:OB], tag_vm: ["1"], tag_str: '(0400,0310)', tag_sym: :certified_timestamp, tag_ndm: '04000310', tag_ary: [0x0400,0x0310], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0400,0315)', tag_name: "Placeholder (0400,0315)", tag_key: 'Placeholder_0400_0315', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(0400,0315)', tag_sym: :placeholder_0400_0315, tag_ndm: '04000315', tag_ary: [0x0400,0x0315], tag_multiple: false, tag_note: 'RET (2015c)'},
      { tag_ps: '(0400,0401)', tag_name: "Digital Signature Purpose Code Sequence", tag_key: 'DigitalSignaturePurposeCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0400,0401)', tag_sym: :digital_signature_purpose_code_sequence, tag_ndm: '04000401', tag_ary: [0x0400,0x0401], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0400,0402)', tag_name: "Referenced Digital Signature Sequence", tag_key: 'ReferencedDigitalSignatureSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0400,0402)', tag_sym: :referenced_digital_signature_sequence, tag_ndm: '04000402', tag_ary: [0x0400,0x0402], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0400,0403)', tag_name: "Referenced SOP Instance MAC Sequence", tag_key: 'ReferencedSOPInstanceMACSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0400,0403)', tag_sym: :referenced_sop_instance_mac_sequence, tag_ndm: '04000403', tag_ary: [0x0400,0x0403], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0400,0404)', tag_name: "MAC", tag_key: 'MAC', tag_vr: [:OB], tag_vm: ["1"], tag_str: '(0400,0404)', tag_sym: :mac, tag_ndm: '04000404', tag_ary: [0x0400,0x0404], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0400,0500)', tag_name: "Encrypted Attributes Sequence", tag_key: 'EncryptedAttributesSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0400,0500)', tag_sym: :encrypted_attributes_sequence, tag_ndm: '04000500', tag_ary: [0x0400,0x0500], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0400,0510)', tag_name: "Encrypted Content Transfer Syntax UID", tag_key: 'EncryptedContentTransferSyntaxUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(0400,0510)', tag_sym: :encrypted_content_transfer_syntax_uid, tag_ndm: '04000510', tag_ary: [0x0400,0x0510], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0400,0520)', tag_name: "Encrypted Content", tag_key: 'EncryptedContent', tag_vr: [:OB], tag_vm: ["1"], tag_str: '(0400,0520)', tag_sym: :encrypted_content, tag_ndm: '04000520', tag_ary: [0x0400,0x0520], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0400,0550)', tag_name: "Modified Attributes Sequence", tag_key: 'ModifiedAttributesSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0400,0550)', tag_sym: :modified_attributes_sequence, tag_ndm: '04000550', tag_ary: [0x0400,0x0550], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0400,0551)', tag_name: "Nonconforming Modified Attributes Sequence", tag_key: 'NonconformingModifiedAttributesSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0400,0551)', tag_sym: :nonconforming_modified_attributes_sequence, tag_ndm: '04000551', tag_ary: [0x0400,0x0551], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0400,0552)', tag_name: "Nonconforming Data Element Value", tag_key: 'NonconformingDataElementValue', tag_vr: [:OB], tag_vm: ["1"], tag_str: '(0400,0552)', tag_sym: :nonconforming_data_element_value, tag_ndm: '04000552', tag_ary: [0x0400,0x0552], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0400,0561)', tag_name: "Original Attributes Sequence", tag_key: 'OriginalAttributesSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(0400,0561)', tag_sym: :original_attributes_sequence, tag_ndm: '04000561', tag_ary: [0x0400,0x0561], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0400,0562)', tag_name: "Attribute Modification DateTime", tag_key: 'AttributeModificationDateTime', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(0400,0562)', tag_sym: :attribute_modification_date_time, tag_ndm: '04000562', tag_ary: [0x0400,0x0562], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0400,0563)', tag_name: "Modifying System", tag_key: 'ModifyingSystem', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0400,0563)', tag_sym: :modifying_system, tag_ndm: '04000563', tag_ary: [0x0400,0x0563], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0400,0564)', tag_name: "Source of Previous Values", tag_key: 'SourceOfPreviousValues', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(0400,0564)', tag_sym: :source_of_previous_values, tag_ndm: '04000564', tag_ary: [0x0400,0x0564], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0400,0565)', tag_name: "Reason for the Attribute Modification", tag_key: 'ReasonForTheAttributeModification', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0400,0565)', tag_sym: :reason_for_the_attribute_modification, tag_ndm: '04000565', tag_ary: [0x0400,0x0565], tag_multiple: false, tag_note: ''},
      { tag_ps: '(0400,0600)', tag_name: "Instance Origin Status", tag_key: 'InstanceOriginStatus', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(0400,0600)', tag_sym: :instance_origin_status, tag_ndm: '04000600', tag_ary: [0x0400,0x0600], tag_multiple: false, tag_note: ''},
      { tag_ps: '(1000,XXX0)', tag_name: "Escape Triplet", tag_key: 'EscapeTriplet', tag_vr: [:US], tag_vm: ["3"], tag_str: '(1000,2220)', tag_sym: :escape_triplet, tag_ndm: '10002220', tag_ary: [0x1000,0x2220], tag_multiple: true, tag_note: 'RET (2007)'},
      { tag_ps: '(1000,XXX1)', tag_name: "Run Length Triplet", tag_key: 'RunLengthTriplet', tag_vr: [:US], tag_vm: ["3"], tag_str: '(1000,2221)', tag_sym: :run_length_triplet, tag_ndm: '10002221', tag_ary: [0x1000,0x2221], tag_multiple: true, tag_note: 'RET (2007)'},
      { tag_ps: '(1000,XXX2)', tag_name: "Huffman Table Size", tag_key: 'HuffmanTableSize', tag_vr: [:US], tag_vm: ["1"], tag_str: '(1000,2222)', tag_sym: :huffman_table_size, tag_ndm: '10002222', tag_ary: [0x1000,0x2222], tag_multiple: true, tag_note: 'RET (2007)'},
      { tag_ps: '(1000,XXX3)', tag_name: "Huffman Table Triplet", tag_key: 'HuffmanTableTriplet', tag_vr: [:US], tag_vm: ["3"], tag_str: '(1000,2223)', tag_sym: :huffman_table_triplet, tag_ndm: '10002223', tag_ary: [0x1000,0x2223], tag_multiple: true, tag_note: 'RET (2007)'},
      { tag_ps: '(1000,XXX4)', tag_name: "Shift Table Size", tag_key: 'ShiftTableSize', tag_vr: [:US], tag_vm: ["1"], tag_str: '(1000,2224)', tag_sym: :shift_table_size, tag_ndm: '10002224', tag_ary: [0x1000,0x2224], tag_multiple: true, tag_note: 'RET (2007)'},
      { tag_ps: '(1000,XXX5)', tag_name: "Shift Table Triplet", tag_key: 'ShiftTableTriplet', tag_vr: [:US], tag_vm: ["3"], tag_str: '(1000,2225)', tag_sym: :shift_table_triplet, tag_ndm: '10002225', tag_ary: [0x1000,0x2225], tag_multiple: true, tag_note: 'RET (2007)'},
      { tag_ps: '(1010,XXXX)', tag_name: "Zonal Map", tag_key: 'ZonalMap', tag_vr: [:US], tag_vm: ["1-n"], tag_str: '(1010,2222)', tag_sym: :zonal_map, tag_ndm: '10102222', tag_ary: [0x1010,0x2222], tag_multiple: true, tag_note: 'RET (2007)'},
      { tag_ps: '(2000,0010)', tag_name: "Number of Copies", tag_key: 'NumberOfCopies', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(2000,0010)', tag_sym: :number_of_copies, tag_ndm: '20000010', tag_ary: [0x2000,0x0010], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2000,001E)', tag_name: "Printer Configuration Sequence", tag_key: 'PrinterConfigurationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(2000,001E)', tag_sym: :printer_configuration_sequence, tag_ndm: '2000001E', tag_ary: [0x2000,0x001E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2000,0020)', tag_name: "Print Priority", tag_key: 'PrintPriority', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(2000,0020)', tag_sym: :print_priority, tag_ndm: '20000020', tag_ary: [0x2000,0x0020], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2000,0030)', tag_name: "Medium Type", tag_key: 'MediumType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(2000,0030)', tag_sym: :medium_type, tag_ndm: '20000030', tag_ary: [0x2000,0x0030], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2000,0040)', tag_name: "Film Destination", tag_key: 'FilmDestination', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(2000,0040)', tag_sym: :film_destination, tag_ndm: '20000040', tag_ary: [0x2000,0x0040], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2000,0050)', tag_name: "Film Session Label", tag_key: 'FilmSessionLabel', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(2000,0050)', tag_sym: :film_session_label, tag_ndm: '20000050', tag_ary: [0x2000,0x0050], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2000,0060)', tag_name: "Memory Allocation", tag_key: 'MemoryAllocation', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(2000,0060)', tag_sym: :memory_allocation, tag_ndm: '20000060', tag_ary: [0x2000,0x0060], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2000,0061)', tag_name: "Maximum Memory Allocation", tag_key: 'MaximumMemoryAllocation', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(2000,0061)', tag_sym: :maximum_memory_allocation, tag_ndm: '20000061', tag_ary: [0x2000,0x0061], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2000,0062)', tag_name: "Color Image Printing Flag", tag_key: 'ColorImagePrintingFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(2000,0062)', tag_sym: :color_image_printing_flag, tag_ndm: '20000062', tag_ary: [0x2000,0x0062], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(2000,0063)', tag_name: "Collation Flag", tag_key: 'CollationFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(2000,0063)', tag_sym: :collation_flag, tag_ndm: '20000063', tag_ary: [0x2000,0x0063], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(2000,0065)', tag_name: "Annotation Flag", tag_key: 'AnnotationFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(2000,0065)', tag_sym: :annotation_flag, tag_ndm: '20000065', tag_ary: [0x2000,0x0065], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(2000,0067)', tag_name: "Image Overlay Flag", tag_key: 'ImageOverlayFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(2000,0067)', tag_sym: :image_overlay_flag, tag_ndm: '20000067', tag_ary: [0x2000,0x0067], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(2000,0069)', tag_name: "Presentation LUT Flag", tag_key: 'PresentationLUTFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(2000,0069)', tag_sym: :presentation_lut_flag, tag_ndm: '20000069', tag_ary: [0x2000,0x0069], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(2000,006A)', tag_name: "Image Box Presentation LUT Flag", tag_key: 'ImageBoxPresentationLUTFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(2000,006A)', tag_sym: :image_box_presentation_lut_flag, tag_ndm: '2000006A', tag_ary: [0x2000,0x006A], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(2000,00A0)', tag_name: "Memory Bit Depth", tag_key: 'MemoryBitDepth', tag_vr: [:US], tag_vm: ["1"], tag_str: '(2000,00A0)', tag_sym: :memory_bit_depth, tag_ndm: '200000A0', tag_ary: [0x2000,0x00A0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2000,00A1)', tag_name: "Printing Bit Depth", tag_key: 'PrintingBitDepth', tag_vr: [:US], tag_vm: ["1"], tag_str: '(2000,00A1)', tag_sym: :printing_bit_depth, tag_ndm: '200000A1', tag_ary: [0x2000,0x00A1], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2000,00A2)', tag_name: "Media Installed Sequence", tag_key: 'MediaInstalledSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(2000,00A2)', tag_sym: :media_installed_sequence, tag_ndm: '200000A2', tag_ary: [0x2000,0x00A2], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2000,00A4)', tag_name: "Other Media Available Sequence", tag_key: 'OtherMediaAvailableSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(2000,00A4)', tag_sym: :other_media_available_sequence, tag_ndm: '200000A4', tag_ary: [0x2000,0x00A4], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2000,00A8)', tag_name: "Supported Image Display Formats Sequence", tag_key: 'SupportedImageDisplayFormatsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(2000,00A8)', tag_sym: :supported_image_display_formats_sequence, tag_ndm: '200000A8', tag_ary: [0x2000,0x00A8], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2000,0500)', tag_name: "Referenced Film Box Sequence", tag_key: 'ReferencedFilmBoxSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(2000,0500)', tag_sym: :referenced_film_box_sequence, tag_ndm: '20000500', tag_ary: [0x2000,0x0500], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2000,0510)', tag_name: "Referenced Stored Print Sequence", tag_key: 'ReferencedStoredPrintSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(2000,0510)', tag_sym: :referenced_stored_print_sequence, tag_ndm: '20000510', tag_ary: [0x2000,0x0510], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(2010,0010)', tag_name: "Image Display Format", tag_key: 'ImageDisplayFormat', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(2010,0010)', tag_sym: :image_display_format, tag_ndm: '20100010', tag_ary: [0x2010,0x0010], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2010,0030)', tag_name: "Annotation Display Format ID", tag_key: 'AnnotationDisplayFormatID', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(2010,0030)', tag_sym: :annotation_display_format_id, tag_ndm: '20100030', tag_ary: [0x2010,0x0030], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2010,0040)', tag_name: "Film Orientation", tag_key: 'FilmOrientation', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(2010,0040)', tag_sym: :film_orientation, tag_ndm: '20100040', tag_ary: [0x2010,0x0040], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2010,0050)', tag_name: "Film Size ID", tag_key: 'FilmSizeID', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(2010,0050)', tag_sym: :film_size_id, tag_ndm: '20100050', tag_ary: [0x2010,0x0050], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2010,0052)', tag_name: "Printer Resolution ID", tag_key: 'PrinterResolutionID', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(2010,0052)', tag_sym: :printer_resolution_id, tag_ndm: '20100052', tag_ary: [0x2010,0x0052], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2010,0054)', tag_name: "Default Printer Resolution ID", tag_key: 'DefaultPrinterResolutionID', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(2010,0054)', tag_sym: :default_printer_resolution_id, tag_ndm: '20100054', tag_ary: [0x2010,0x0054], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2010,0060)', tag_name: "Magnification Type", tag_key: 'MagnificationType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(2010,0060)', tag_sym: :magnification_type, tag_ndm: '20100060', tag_ary: [0x2010,0x0060], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2010,0080)', tag_name: "Smoothing Type", tag_key: 'SmoothingType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(2010,0080)', tag_sym: :smoothing_type, tag_ndm: '20100080', tag_ary: [0x2010,0x0080], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2010,00A6)', tag_name: "Default Magnification Type", tag_key: 'DefaultMagnificationType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(2010,00A6)', tag_sym: :default_magnification_type, tag_ndm: '201000A6', tag_ary: [0x2010,0x00A6], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2010,00A7)', tag_name: "Other Magnification Types Available", tag_key: 'OtherMagnificationTypesAvailable', tag_vr: [:CS], tag_vm: ["1-n"], tag_str: '(2010,00A7)', tag_sym: :other_magnification_types_available, tag_ndm: '201000A7', tag_ary: [0x2010,0x00A7], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2010,00A8)', tag_name: "Default Smoothing Type", tag_key: 'DefaultSmoothingType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(2010,00A8)', tag_sym: :default_smoothing_type, tag_ndm: '201000A8', tag_ary: [0x2010,0x00A8], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2010,00A9)', tag_name: "Other Smoothing Types Available", tag_key: 'OtherSmoothingTypesAvailable', tag_vr: [:CS], tag_vm: ["1-n"], tag_str: '(2010,00A9)', tag_sym: :other_smoothing_types_available, tag_ndm: '201000A9', tag_ary: [0x2010,0x00A9], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2010,0100)', tag_name: "Border Density", tag_key: 'BorderDensity', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(2010,0100)', tag_sym: :border_density, tag_ndm: '20100100', tag_ary: [0x2010,0x0100], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2010,0110)', tag_name: "Empty Image Density", tag_key: 'EmptyImageDensity', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(2010,0110)', tag_sym: :empty_image_density, tag_ndm: '20100110', tag_ary: [0x2010,0x0110], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2010,0120)', tag_name: "Min Density", tag_key: 'MinDensity', tag_vr: [:US], tag_vm: ["1"], tag_str: '(2010,0120)', tag_sym: :min_density, tag_ndm: '20100120', tag_ary: [0x2010,0x0120], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2010,0130)', tag_name: "Max Density", tag_key: 'MaxDensity', tag_vr: [:US], tag_vm: ["1"], tag_str: '(2010,0130)', tag_sym: :max_density, tag_ndm: '20100130', tag_ary: [0x2010,0x0130], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2010,0140)', tag_name: "Trim", tag_key: 'Trim', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(2010,0140)', tag_sym: :trim, tag_ndm: '20100140', tag_ary: [0x2010,0x0140], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2010,0150)', tag_name: "Configuration Information", tag_key: 'ConfigurationInformation', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(2010,0150)', tag_sym: :configuration_information, tag_ndm: '20100150', tag_ary: [0x2010,0x0150], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2010,0152)', tag_name: "Configuration Information Description", tag_key: 'ConfigurationInformationDescription', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(2010,0152)', tag_sym: :configuration_information_description, tag_ndm: '20100152', tag_ary: [0x2010,0x0152], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2010,0154)', tag_name: "Maximum Collated Films", tag_key: 'MaximumCollatedFilms', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(2010,0154)', tag_sym: :maximum_collated_films, tag_ndm: '20100154', tag_ary: [0x2010,0x0154], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2010,015E)', tag_name: "Illumination", tag_key: 'Illumination', tag_vr: [:US], tag_vm: ["1"], tag_str: '(2010,015E)', tag_sym: :illumination, tag_ndm: '2010015E', tag_ary: [0x2010,0x015E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2010,0160)', tag_name: "Reflected Ambient Light", tag_key: 'ReflectedAmbientLight', tag_vr: [:US], tag_vm: ["1"], tag_str: '(2010,0160)', tag_sym: :reflected_ambient_light, tag_ndm: '20100160', tag_ary: [0x2010,0x0160], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2010,0376)', tag_name: "Printer Pixel Spacing", tag_key: 'PrinterPixelSpacing', tag_vr: [:DS], tag_vm: ["2"], tag_str: '(2010,0376)', tag_sym: :printer_pixel_spacing, tag_ndm: '20100376', tag_ary: [0x2010,0x0376], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2010,0500)', tag_name: "Referenced Film Session Sequence", tag_key: 'ReferencedFilmSessionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(2010,0500)', tag_sym: :referenced_film_session_sequence, tag_ndm: '20100500', tag_ary: [0x2010,0x0500], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2010,0510)', tag_name: "Referenced Image Box Sequence", tag_key: 'ReferencedImageBoxSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(2010,0510)', tag_sym: :referenced_image_box_sequence, tag_ndm: '20100510', tag_ary: [0x2010,0x0510], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2010,0520)', tag_name: "Referenced Basic Annotation Box Sequence", tag_key: 'ReferencedBasicAnnotationBoxSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(2010,0520)', tag_sym: :referenced_basic_annotation_box_sequence, tag_ndm: '20100520', tag_ary: [0x2010,0x0520], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2020,0010)', tag_name: "Image Box Position", tag_key: 'ImageBoxPosition', tag_vr: [:US], tag_vm: ["1"], tag_str: '(2020,0010)', tag_sym: :image_box_position, tag_ndm: '20200010', tag_ary: [0x2020,0x0010], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2020,0020)', tag_name: "Polarity", tag_key: 'Polarity', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(2020,0020)', tag_sym: :polarity, tag_ndm: '20200020', tag_ary: [0x2020,0x0020], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2020,0030)', tag_name: "Requested Image Size", tag_key: 'RequestedImageSize', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(2020,0030)', tag_sym: :requested_image_size, tag_ndm: '20200030', tag_ary: [0x2020,0x0030], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2020,0040)', tag_name: "Requested Decimate/Crop Behavior", tag_key: 'RequestedDecimateCropBehavior', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(2020,0040)', tag_sym: :requested_decimate_crop_behavior, tag_ndm: '20200040', tag_ary: [0x2020,0x0040], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2020,0050)', tag_name: "Requested Resolution ID", tag_key: 'RequestedResolutionID', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(2020,0050)', tag_sym: :requested_resolution_id, tag_ndm: '20200050', tag_ary: [0x2020,0x0050], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2020,00A0)', tag_name: "Requested Image Size Flag", tag_key: 'RequestedImageSizeFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(2020,00A0)', tag_sym: :requested_image_size_flag, tag_ndm: '202000A0', tag_ary: [0x2020,0x00A0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2020,00A2)', tag_name: "Decimate/Crop Result", tag_key: 'DecimateCropResult', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(2020,00A2)', tag_sym: :decimate_crop_result, tag_ndm: '202000A2', tag_ary: [0x2020,0x00A2], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2020,0110)', tag_name: "Basic Grayscale Image Sequence", tag_key: 'BasicGrayscaleImageSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(2020,0110)', tag_sym: :basic_grayscale_image_sequence, tag_ndm: '20200110', tag_ary: [0x2020,0x0110], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2020,0111)', tag_name: "Basic Color Image Sequence", tag_key: 'BasicColorImageSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(2020,0111)', tag_sym: :basic_color_image_sequence, tag_ndm: '20200111', tag_ary: [0x2020,0x0111], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2020,0130)', tag_name: "Referenced Image Overlay Box Sequence", tag_key: 'ReferencedImageOverlayBoxSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(2020,0130)', tag_sym: :referenced_image_overlay_box_sequence, tag_ndm: '20200130', tag_ary: [0x2020,0x0130], tag_multiple: false, tag_note: 'RET (1998)'},
      { tag_ps: '(2020,0140)', tag_name: "Referenced VOI LUT Box Sequence", tag_key: 'ReferencedVOILUTBoxSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(2020,0140)', tag_sym: :referenced_voi_lut_box_sequence, tag_ndm: '20200140', tag_ary: [0x2020,0x0140], tag_multiple: false, tag_note: 'RET (1998)'},
      { tag_ps: '(2030,0010)', tag_name: "Annotation Position", tag_key: 'AnnotationPosition', tag_vr: [:US], tag_vm: ["1"], tag_str: '(2030,0010)', tag_sym: :annotation_position, tag_ndm: '20300010', tag_ary: [0x2030,0x0010], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2030,0020)', tag_name: "Text String", tag_key: 'TextString', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(2030,0020)', tag_sym: :text_string, tag_ndm: '20300020', tag_ary: [0x2030,0x0020], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2040,0010)', tag_name: "Referenced Overlay Plane Sequence", tag_key: 'ReferencedOverlayPlaneSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(2040,0010)', tag_sym: :referenced_overlay_plane_sequence, tag_ndm: '20400010', tag_ary: [0x2040,0x0010], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(2040,0011)', tag_name: "Referenced Overlay Plane Groups", tag_key: 'ReferencedOverlayPlaneGroups', tag_vr: [:US], tag_vm: ["1-99"], tag_str: '(2040,0011)', tag_sym: :referenced_overlay_plane_groups, tag_ndm: '20400011', tag_ary: [0x2040,0x0011], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(2040,0020)', tag_name: "Overlay Pixel Data Sequence", tag_key: 'OverlayPixelDataSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(2040,0020)', tag_sym: :overlay_pixel_data_sequence, tag_ndm: '20400020', tag_ary: [0x2040,0x0020], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(2040,0060)', tag_name: "Overlay Magnification Type", tag_key: 'OverlayMagnificationType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(2040,0060)', tag_sym: :overlay_magnification_type, tag_ndm: '20400060', tag_ary: [0x2040,0x0060], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(2040,0070)', tag_name: "Overlay Smoothing Type", tag_key: 'OverlaySmoothingType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(2040,0070)', tag_sym: :overlay_smoothing_type, tag_ndm: '20400070', tag_ary: [0x2040,0x0070], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(2040,0072)', tag_name: "Overlay or Image Magnification", tag_key: 'OverlayOrImageMagnification', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(2040,0072)', tag_sym: :overlay_or_image_magnification, tag_ndm: '20400072', tag_ary: [0x2040,0x0072], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(2040,0074)', tag_name: "Magnify to Number of Columns", tag_key: 'MagnifyToNumberOfColumns', tag_vr: [:US], tag_vm: ["1"], tag_str: '(2040,0074)', tag_sym: :magnify_to_number_of_columns, tag_ndm: '20400074', tag_ary: [0x2040,0x0074], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(2040,0080)', tag_name: "Overlay Foreground Density", tag_key: 'OverlayForegroundDensity', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(2040,0080)', tag_sym: :overlay_foreground_density, tag_ndm: '20400080', tag_ary: [0x2040,0x0080], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(2040,0082)', tag_name: "Overlay Background Density", tag_key: 'OverlayBackgroundDensity', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(2040,0082)', tag_sym: :overlay_background_density, tag_ndm: '20400082', tag_ary: [0x2040,0x0082], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(2040,0090)', tag_name: "Overlay Mode", tag_key: 'OverlayMode', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(2040,0090)', tag_sym: :overlay_mode, tag_ndm: '20400090', tag_ary: [0x2040,0x0090], tag_multiple: false, tag_note: 'RET (1998)'},
      { tag_ps: '(2040,0100)', tag_name: "Threshold Density", tag_key: 'ThresholdDensity', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(2040,0100)', tag_sym: :threshold_density, tag_ndm: '20400100', tag_ary: [0x2040,0x0100], tag_multiple: false, tag_note: 'RET (1998)'},
      { tag_ps: '(2040,0500)', tag_name: "Referenced Image Box Sequence (Retired)", tag_key: 'ReferencedImageBoxSequenceRetired', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(2040,0500)', tag_sym: :referenced_image_box_sequence_retired, tag_ndm: '20400500', tag_ary: [0x2040,0x0500], tag_multiple: false, tag_note: 'RET (1993)'},
      { tag_ps: '(2050,0010)', tag_name: "Presentation LUT Sequence", tag_key: 'PresentationLUTSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(2050,0010)', tag_sym: :presentation_lut_sequence, tag_ndm: '20500010', tag_ary: [0x2050,0x0010], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2050,0020)', tag_name: "Presentation LUT Shape", tag_key: 'PresentationLUTShape', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(2050,0020)', tag_sym: :presentation_lut_shape, tag_ndm: '20500020', tag_ary: [0x2050,0x0020], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2050,0500)', tag_name: "Referenced Presentation LUT Sequence", tag_key: 'ReferencedPresentationLUTSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(2050,0500)', tag_sym: :referenced_presentation_lut_sequence, tag_ndm: '20500500', tag_ary: [0x2050,0x0500], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2100,0010)', tag_name: "Print Job ID", tag_key: 'PrintJobID', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(2100,0010)', tag_sym: :print_job_id, tag_ndm: '21000010', tag_ary: [0x2100,0x0010], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(2100,0020)', tag_name: "Execution Status", tag_key: 'ExecutionStatus', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(2100,0020)', tag_sym: :execution_status, tag_ndm: '21000020', tag_ary: [0x2100,0x0020], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2100,0030)', tag_name: "Execution Status Info", tag_key: 'ExecutionStatusInfo', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(2100,0030)', tag_sym: :execution_status_info, tag_ndm: '21000030', tag_ary: [0x2100,0x0030], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2100,0040)', tag_name: "Creation Date", tag_key: 'CreationDate', tag_vr: [:DA], tag_vm: ["1"], tag_str: '(2100,0040)', tag_sym: :creation_date, tag_ndm: '21000040', tag_ary: [0x2100,0x0040], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2100,0050)', tag_name: "Creation Time", tag_key: 'CreationTime', tag_vr: [:TM], tag_vm: ["1"], tag_str: '(2100,0050)', tag_sym: :creation_time, tag_ndm: '21000050', tag_ary: [0x2100,0x0050], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2100,0070)', tag_name: "Originator", tag_key: 'Originator', tag_vr: [:AE], tag_vm: ["1"], tag_str: '(2100,0070)', tag_sym: :originator, tag_ndm: '21000070', tag_ary: [0x2100,0x0070], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2100,0140)', tag_name: "Destination AE", tag_key: 'DestinationAE', tag_vr: [:AE], tag_vm: ["1"], tag_str: '(2100,0140)', tag_sym: :destination_ae, tag_ndm: '21000140', tag_ary: [0x2100,0x0140], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2100,0160)', tag_name: "Owner ID", tag_key: 'OwnerID', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(2100,0160)', tag_sym: :owner_id, tag_ndm: '21000160', tag_ary: [0x2100,0x0160], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2100,0170)', tag_name: "Number of Films", tag_key: 'NumberOfFilms', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(2100,0170)', tag_sym: :number_of_films, tag_ndm: '21000170', tag_ary: [0x2100,0x0170], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2100,0500)', tag_name: "Referenced Print Job Sequence (Pull Stored Print)", tag_key: 'ReferencedPrintJobSequencePullStoredPrint', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(2100,0500)', tag_sym: :referenced_print_job_sequence_pull_stored_print, tag_ndm: '21000500', tag_ary: [0x2100,0x0500], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(2110,0010)', tag_name: "Printer Status", tag_key: 'PrinterStatus', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(2110,0010)', tag_sym: :printer_status, tag_ndm: '21100010', tag_ary: [0x2110,0x0010], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2110,0020)', tag_name: "Printer Status Info", tag_key: 'PrinterStatusInfo', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(2110,0020)', tag_sym: :printer_status_info, tag_ndm: '21100020', tag_ary: [0x2110,0x0020], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2110,0030)', tag_name: "Printer Name", tag_key: 'PrinterName', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(2110,0030)', tag_sym: :printer_name, tag_ndm: '21100030', tag_ary: [0x2110,0x0030], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2110,0099)', tag_name: "Print Queue ID", tag_key: 'PrintQueueID', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(2110,0099)', tag_sym: :print_queue_id, tag_ndm: '21100099', tag_ary: [0x2110,0x0099], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(2120,0010)', tag_name: "Queue Status", tag_key: 'QueueStatus', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(2120,0010)', tag_sym: :queue_status, tag_ndm: '21200010', tag_ary: [0x2120,0x0010], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(2120,0050)', tag_name: "Print Job Description Sequence", tag_key: 'PrintJobDescriptionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(2120,0050)', tag_sym: :print_job_description_sequence, tag_ndm: '21200050', tag_ary: [0x2120,0x0050], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(2120,0070)', tag_name: "Referenced Print Job Sequence", tag_key: 'ReferencedPrintJobSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(2120,0070)', tag_sym: :referenced_print_job_sequence, tag_ndm: '21200070', tag_ary: [0x2120,0x0070], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(2130,0010)', tag_name: "Print Management Capabilities Sequence", tag_key: 'PrintManagementCapabilitiesSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(2130,0010)', tag_sym: :print_management_capabilities_sequence, tag_ndm: '21300010', tag_ary: [0x2130,0x0010], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(2130,0015)', tag_name: "Printer Characteristics Sequence", tag_key: 'PrinterCharacteristicsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(2130,0015)', tag_sym: :printer_characteristics_sequence, tag_ndm: '21300015', tag_ary: [0x2130,0x0015], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(2130,0030)', tag_name: "Film Box Content Sequence", tag_key: 'FilmBoxContentSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(2130,0030)', tag_sym: :film_box_content_sequence, tag_ndm: '21300030', tag_ary: [0x2130,0x0030], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(2130,0040)', tag_name: "Image Box Content Sequence", tag_key: 'ImageBoxContentSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(2130,0040)', tag_sym: :image_box_content_sequence, tag_ndm: '21300040', tag_ary: [0x2130,0x0040], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(2130,0050)', tag_name: "Annotation Content Sequence", tag_key: 'AnnotationContentSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(2130,0050)', tag_sym: :annotation_content_sequence, tag_ndm: '21300050', tag_ary: [0x2130,0x0050], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(2130,0060)', tag_name: "Image Overlay Box Content Sequence", tag_key: 'ImageOverlayBoxContentSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(2130,0060)', tag_sym: :image_overlay_box_content_sequence, tag_ndm: '21300060', tag_ary: [0x2130,0x0060], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(2130,0080)', tag_name: "Presentation LUT Content Sequence", tag_key: 'PresentationLUTContentSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(2130,0080)', tag_sym: :presentation_lut_content_sequence, tag_ndm: '21300080', tag_ary: [0x2130,0x0080], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(2130,00A0)', tag_name: "Proposed Study Sequence", tag_key: 'ProposedStudySequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(2130,00A0)', tag_sym: :proposed_study_sequence, tag_ndm: '213000A0', tag_ary: [0x2130,0x00A0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2130,00C0)', tag_name: "Original Image Sequence", tag_key: 'OriginalImageSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(2130,00C0)', tag_sym: :original_image_sequence, tag_ndm: '213000C0', tag_ary: [0x2130,0x00C0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2200,0001)', tag_name: "Label Using Information Extracted From Instances", tag_key: 'LabelUsingInformationExtractedFromInstances', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(2200,0001)', tag_sym: :label_using_information_extracted_from_instances, tag_ndm: '22000001', tag_ary: [0x2200,0x0001], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2200,0002)', tag_name: "Label Text", tag_key: 'LabelText', tag_vr: [:UT], tag_vm: ["1"], tag_str: '(2200,0002)', tag_sym: :label_text, tag_ndm: '22000002', tag_ary: [0x2200,0x0002], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2200,0003)', tag_name: "Label Style Selection", tag_key: 'LabelStyleSelection', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(2200,0003)', tag_sym: :label_style_selection, tag_ndm: '22000003', tag_ary: [0x2200,0x0003], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2200,0004)', tag_name: "Media Disposition", tag_key: 'MediaDisposition', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(2200,0004)', tag_sym: :media_disposition, tag_ndm: '22000004', tag_ary: [0x2200,0x0004], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2200,0005)', tag_name: "Barcode Value", tag_key: 'BarcodeValue', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(2200,0005)', tag_sym: :barcode_value, tag_ndm: '22000005', tag_ary: [0x2200,0x0005], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2200,0006)', tag_name: "Barcode Symbology", tag_key: 'BarcodeSymbology', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(2200,0006)', tag_sym: :barcode_symbology, tag_ndm: '22000006', tag_ary: [0x2200,0x0006], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2200,0007)', tag_name: "Allow Media Splitting", tag_key: 'AllowMediaSplitting', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(2200,0007)', tag_sym: :allow_media_splitting, tag_ndm: '22000007', tag_ary: [0x2200,0x0007], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2200,0008)', tag_name: "Include Non-DICOM Objects", tag_key: 'IncludeNonDICOMObjects', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(2200,0008)', tag_sym: :include_non_dicom_objects, tag_ndm: '22000008', tag_ary: [0x2200,0x0008], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2200,0009)', tag_name: "Include Display Application", tag_key: 'IncludeDisplayApplication', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(2200,0009)', tag_sym: :include_display_application, tag_ndm: '22000009', tag_ary: [0x2200,0x0009], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2200,000A)', tag_name: "Preserve Composite Instances After Media Creation", tag_key: 'PreserveCompositeInstancesAfterMediaCreation', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(2200,000A)', tag_sym: :preserve_composite_instances_after_media_creation, tag_ndm: '2200000A', tag_ary: [0x2200,0x000A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2200,000B)', tag_name: "Total Number of Pieces of Media Created", tag_key: 'TotalNumberOfPiecesOfMediaCreated', tag_vr: [:US], tag_vm: ["1"], tag_str: '(2200,000B)', tag_sym: :total_number_of_pieces_of_media_created, tag_ndm: '2200000B', tag_ary: [0x2200,0x000B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2200,000C)', tag_name: "Requested Media Application Profile", tag_key: 'RequestedMediaApplicationProfile', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(2200,000C)', tag_sym: :requested_media_application_profile, tag_ndm: '2200000C', tag_ary: [0x2200,0x000C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2200,000D)', tag_name: "Referenced Storage Media Sequence", tag_key: 'ReferencedStorageMediaSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(2200,000D)', tag_sym: :referenced_storage_media_sequence, tag_ndm: '2200000D', tag_ary: [0x2200,0x000D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2200,000E)', tag_name: "Failure Attributes", tag_key: 'FailureAttributes', tag_vr: [:AT], tag_vm: ["1-n"], tag_str: '(2200,000E)', tag_sym: :failure_attributes, tag_ndm: '2200000E', tag_ary: [0x2200,0x000E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2200,000F)', tag_name: "Allow Lossy Compression", tag_key: 'AllowLossyCompression', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(2200,000F)', tag_sym: :allow_lossy_compression, tag_ndm: '2200000F', tag_ary: [0x2200,0x000F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(2200,0020)', tag_name: "Request Priority", tag_key: 'RequestPriority', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(2200,0020)', tag_sym: :request_priority, tag_ndm: '22000020', tag_ary: [0x2200,0x0020], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,0002)', tag_name: "RT Image Label", tag_key: 'RTImageLabel', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(3002,0002)', tag_sym: :rt_image_label, tag_ndm: '30020002', tag_ary: [0x3002,0x0002], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,0003)', tag_name: "RT Image Name", tag_key: 'RTImageName', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(3002,0003)', tag_sym: :rt_image_name, tag_ndm: '30020003', tag_ary: [0x3002,0x0003], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,0004)', tag_name: "RT Image Description", tag_key: 'RTImageDescription', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(3002,0004)', tag_sym: :rt_image_description, tag_ndm: '30020004', tag_ary: [0x3002,0x0004], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,000A)', tag_name: "Reported Values Origin", tag_key: 'ReportedValuesOrigin', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(3002,000A)', tag_sym: :reported_values_origin, tag_ndm: '3002000A', tag_ary: [0x3002,0x000A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,000C)', tag_name: "RT Image Plane", tag_key: 'RTImagePlane', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(3002,000C)', tag_sym: :rt_image_plane, tag_ndm: '3002000C', tag_ary: [0x3002,0x000C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,000D)', tag_name: "X-Ray Image Receptor Translation", tag_key: 'XRayImageReceptorTranslation', tag_vr: [:DS], tag_vm: ["3"], tag_str: '(3002,000D)', tag_sym: :x_ray_image_receptor_translation, tag_ndm: '3002000D', tag_ary: [0x3002,0x000D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,000E)', tag_name: "X-Ray Image Receptor Angle", tag_key: 'XRayImageReceptorAngle', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(3002,000E)', tag_sym: :x_ray_image_receptor_angle, tag_ndm: '3002000E', tag_ary: [0x3002,0x000E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,0010)', tag_name: "RT Image Orientation", tag_key: 'RTImageOrientation', tag_vr: [:DS], tag_vm: ["6"], tag_str: '(3002,0010)', tag_sym: :rt_image_orientation, tag_ndm: '30020010', tag_ary: [0x3002,0x0010], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,0011)', tag_name: "Image Plane Pixel Spacing", tag_key: 'ImagePlanePixelSpacing', tag_vr: [:DS], tag_vm: ["2"], tag_str: '(3002,0011)', tag_sym: :image_plane_pixel_spacing, tag_ndm: '30020011', tag_ary: [0x3002,0x0011], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,0012)', tag_name: "RT Image Position", tag_key: 'RTImagePosition', tag_vr: [:DS], tag_vm: ["2"], tag_str: '(3002,0012)', tag_sym: :rt_image_position, tag_ndm: '30020012', tag_ary: [0x3002,0x0012], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,0020)', tag_name: "Radiation Machine Name", tag_key: 'RadiationMachineName', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(3002,0020)', tag_sym: :radiation_machine_name, tag_ndm: '30020020', tag_ary: [0x3002,0x0020], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,0022)', tag_name: "Radiation Machine SAD", tag_key: 'RadiationMachineSAD', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(3002,0022)', tag_sym: :radiation_machine_sad, tag_ndm: '30020022', tag_ary: [0x3002,0x0022], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,0024)', tag_name: "Radiation Machine SSD", tag_key: 'RadiationMachineSSD', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(3002,0024)', tag_sym: :radiation_machine_ssd, tag_ndm: '30020024', tag_ary: [0x3002,0x0024], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,0026)', tag_name: "RT Image SID", tag_key: 'RTImageSID', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(3002,0026)', tag_sym: :rt_image_sid, tag_ndm: '30020026', tag_ary: [0x3002,0x0026], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,0028)', tag_name: "Source to Reference Object Distance", tag_key: 'SourceToReferenceObjectDistance', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(3002,0028)', tag_sym: :source_to_reference_object_distance, tag_ndm: '30020028', tag_ary: [0x3002,0x0028], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,0029)', tag_name: "Fraction Number", tag_key: 'FractionNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(3002,0029)', tag_sym: :fraction_number, tag_ndm: '30020029', tag_ary: [0x3002,0x0029], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,0030)', tag_name: "Exposure Sequence", tag_key: 'ExposureSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3002,0030)', tag_sym: :exposure_sequence, tag_ndm: '30020030', tag_ary: [0x3002,0x0030], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,0032)', tag_name: "Meterset Exposure", tag_key: 'MetersetExposure', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(3002,0032)', tag_sym: :meterset_exposure, tag_ndm: '30020032', tag_ary: [0x3002,0x0032], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,0034)', tag_name: "Diaphragm Position", tag_key: 'DiaphragmPosition', tag_vr: [:DS], tag_vm: ["4"], tag_str: '(3002,0034)', tag_sym: :diaphragm_position, tag_ndm: '30020034', tag_ary: [0x3002,0x0034], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,0040)', tag_name: "Fluence Map Sequence", tag_key: 'FluenceMapSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3002,0040)', tag_sym: :fluence_map_sequence, tag_ndm: '30020040', tag_ary: [0x3002,0x0040], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,0041)', tag_name: "Fluence Data Source", tag_key: 'FluenceDataSource', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(3002,0041)', tag_sym: :fluence_data_source, tag_ndm: '30020041', tag_ary: [0x3002,0x0041], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,0042)', tag_name: "Fluence Data Scale", tag_key: 'FluenceDataScale', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(3002,0042)', tag_sym: :fluence_data_scale, tag_ndm: '30020042', tag_ary: [0x3002,0x0042], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,0050)', tag_name: "Primary Fluence Mode Sequence", tag_key: 'PrimaryFluenceModeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3002,0050)', tag_sym: :primary_fluence_mode_sequence, tag_ndm: '30020050', tag_ary: [0x3002,0x0050], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,0051)', tag_name: "Fluence Mode", tag_key: 'FluenceMode', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(3002,0051)', tag_sym: :fluence_mode, tag_ndm: '30020051', tag_ary: [0x3002,0x0051], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,0052)', tag_name: "Fluence Mode ID", tag_key: 'FluenceModeID', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(3002,0052)', tag_sym: :fluence_mode_id, tag_ndm: '30020052', tag_ary: [0x3002,0x0052], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,0100)', tag_name: "Selected Frame Number", tag_key: 'SelectedFrameNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(3002,0100)', tag_sym: :selected_frame_number, tag_ndm: '30020100', tag_ary: [0x3002,0x0100], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,0101)', tag_name: "Selected Frame Functional Groups Sequence", tag_key: 'SelectedFrameFunctionalGroupsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3002,0101)', tag_sym: :selected_frame_functional_groups_sequence, tag_ndm: '30020101', tag_ary: [0x3002,0x0101], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,0102)', tag_name: "RT Image Frame General Content Sequence", tag_key: 'RTImageFrameGeneralContentSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3002,0102)', tag_sym: :rt_image_frame_general_content_sequence, tag_ndm: '30020102', tag_ary: [0x3002,0x0102], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,0103)', tag_name: "RT Image Frame Context Sequence", tag_key: 'RTImageFrameContextSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3002,0103)', tag_sym: :rt_image_frame_context_sequence, tag_ndm: '30020103', tag_ary: [0x3002,0x0103], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,0104)', tag_name: "RT Image Scope Sequence", tag_key: 'RTImageScopeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3002,0104)', tag_sym: :rt_image_scope_sequence, tag_ndm: '30020104', tag_ary: [0x3002,0x0104], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,0105)', tag_name: "Beam Modifier Coordinates Presence Flag", tag_key: 'BeamModifierCoordinatesPresenceFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(3002,0105)', tag_sym: :beam_modifier_coordinates_presence_flag, tag_ndm: '30020105', tag_ary: [0x3002,0x0105], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,0106)', tag_name: "Start Cumulative Meterset", tag_key: 'StartCumulativeMeterset', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(3002,0106)', tag_sym: :start_cumulative_meterset, tag_ndm: '30020106', tag_ary: [0x3002,0x0106], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,0107)', tag_name: "Stop Cumulative Meterset", tag_key: 'StopCumulativeMeterset', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(3002,0107)', tag_sym: :stop_cumulative_meterset, tag_ndm: '30020107', tag_ary: [0x3002,0x0107], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,0108)', tag_name: "RT Acquisition Patient Position Sequence", tag_key: 'RTAcquisitionPatientPositionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3002,0108)', tag_sym: :rt_acquisition_patient_position_sequence, tag_ndm: '30020108', tag_ary: [0x3002,0x0108], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,0109)', tag_name: "RT Image Frame Imaging Device Position Sequence", tag_key: 'RTImageFrameImagingDevicePositionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3002,0109)', tag_sym: :rt_image_frame_imaging_device_position_sequence, tag_ndm: '30020109', tag_ary: [0x3002,0x0109], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,010A)', tag_name: "RT Image Frame kV Radiation Acquisition Sequence", tag_key: 'RTImageFramekVRadiationAcquisitionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3002,010A)', tag_sym: :rt_image_framek_v_radiation_acquisition_sequence, tag_ndm: '3002010A', tag_ary: [0x3002,0x010A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,010B)', tag_name: "RT Image Frame MV Radiation Acquisition Sequence", tag_key: 'RTImageFrameMVRadiationAcquisitionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3002,010B)', tag_sym: :rt_image_frame_mv_radiation_acquisition_sequence, tag_ndm: '3002010B', tag_ary: [0x3002,0x010B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,010C)', tag_name: "RT Image Frame Radiation Acquisition Sequence", tag_key: 'RTImageFrameRadiationAcquisitionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3002,010C)', tag_sym: :rt_image_frame_radiation_acquisition_sequence, tag_ndm: '3002010C', tag_ary: [0x3002,0x010C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,010D)', tag_name: "Imaging Source Position Sequence", tag_key: 'ImagingSourcePositionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3002,010D)', tag_sym: :imaging_source_position_sequence, tag_ndm: '3002010D', tag_ary: [0x3002,0x010D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,010E)', tag_name: "Image Receptor Position Sequence", tag_key: 'ImageReceptorPositionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3002,010E)', tag_sym: :image_receptor_position_sequence, tag_ndm: '3002010E', tag_ary: [0x3002,0x010E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,010F)', tag_name: "Device Position to Equipment Mapping Matrix", tag_key: 'DevicePositionToEquipmentMappingMatrix', tag_vr: [:FD], tag_vm: ["16"], tag_str: '(3002,010F)', tag_sym: :device_position_to_equipment_mapping_matrix, tag_ndm: '3002010F', tag_ary: [0x3002,0x010F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,0110)', tag_name: "Device Position Parameter Sequence", tag_key: 'DevicePositionParameterSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3002,0110)', tag_sym: :device_position_parameter_sequence, tag_ndm: '30020110', tag_ary: [0x3002,0x0110], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,0111)', tag_name: "Imaging Source Location Specification Type", tag_key: 'ImagingSourceLocationSpecificationType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(3002,0111)', tag_sym: :imaging_source_location_specification_type, tag_ndm: '30020111', tag_ary: [0x3002,0x0111], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,0112)', tag_name: "Imaging Device Location Matrix Sequence", tag_key: 'ImagingDeviceLocationMatrixSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3002,0112)', tag_sym: :imaging_device_location_matrix_sequence, tag_ndm: '30020112', tag_ary: [0x3002,0x0112], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,0113)', tag_name: "Imaging Device Location Parameter Sequence", tag_key: 'ImagingDeviceLocationParameterSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3002,0113)', tag_sym: :imaging_device_location_parameter_sequence, tag_ndm: '30020113', tag_ary: [0x3002,0x0113], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,0114)', tag_name: "Imaging Aperture Sequence", tag_key: 'ImagingApertureSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3002,0114)', tag_sym: :imaging_aperture_sequence, tag_ndm: '30020114', tag_ary: [0x3002,0x0114], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,0115)', tag_name: "Imaging Aperture Specification Type", tag_key: 'ImagingApertureSpecificationType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(3002,0115)', tag_sym: :imaging_aperture_specification_type, tag_ndm: '30020115', tag_ary: [0x3002,0x0115], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,0116)', tag_name: "Number of Acquisition Devices", tag_key: 'NumberOfAcquisitionDevices', tag_vr: [:US], tag_vm: ["1"], tag_str: '(3002,0116)', tag_sym: :number_of_acquisition_devices, tag_ndm: '30020116', tag_ary: [0x3002,0x0116], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,0117)', tag_name: "Acquisition Device Sequence", tag_key: 'AcquisitionDeviceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3002,0117)', tag_sym: :acquisition_device_sequence, tag_ndm: '30020117', tag_ary: [0x3002,0x0117], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,0118)', tag_name: "Acquisition Task Sequence", tag_key: 'AcquisitionTaskSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3002,0118)', tag_sym: :acquisition_task_sequence, tag_ndm: '30020118', tag_ary: [0x3002,0x0118], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,0119)', tag_name: "Acquisition Task Workitem Code Sequence", tag_key: 'AcquisitionTaskWorkitemCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3002,0119)', tag_sym: :acquisition_task_workitem_code_sequence, tag_ndm: '30020119', tag_ary: [0x3002,0x0119], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,011A)', tag_name: "Acquisition Subtask Sequence", tag_key: 'AcquisitionSubtaskSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3002,011A)', tag_sym: :acquisition_subtask_sequence, tag_ndm: '3002011A', tag_ary: [0x3002,0x011A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,011B)', tag_name: "Subtask Workitem Code Sequence", tag_key: 'SubtaskWorkitemCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3002,011B)', tag_sym: :subtask_workitem_code_sequence, tag_ndm: '3002011B', tag_ary: [0x3002,0x011B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,011C)', tag_name: "Acquisition Task Index", tag_key: 'AcquisitionTaskIndex', tag_vr: [:US], tag_vm: ["1"], tag_str: '(3002,011C)', tag_sym: :acquisition_task_index, tag_ndm: '3002011C', tag_ary: [0x3002,0x011C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,011D)', tag_name: "Acquisition Subtask Index", tag_key: 'AcquisitionSubtaskIndex', tag_vr: [:US], tag_vm: ["1"], tag_str: '(3002,011D)', tag_sym: :acquisition_subtask_index, tag_ndm: '3002011D', tag_ary: [0x3002,0x011D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,011E)', tag_name: "Referenced Baseline Parameters RT Radiation Instance Sequence", tag_key: 'ReferencedBaselineParametersRTRadiationInstanceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3002,011E)', tag_sym: :referenced_baseline_parameters_rt_radiation_instance_sequence, tag_ndm: '3002011E', tag_ary: [0x3002,0x011E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,011F)', tag_name: "Position Acquisition Template Identification Sequence", tag_key: 'PositionAcquisitionTemplateIdentificationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3002,011F)', tag_sym: :position_acquisition_template_identification_sequence, tag_ndm: '3002011F', tag_ary: [0x3002,0x011F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,0120)', tag_name: "Position Acquisition Template ID", tag_key: 'PositionAcquisitionTemplateID', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(3002,0120)', tag_sym: :position_acquisition_template_id, tag_ndm: '30020120', tag_ary: [0x3002,0x0120], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,0121)', tag_name: "Position Acquisition Template Name", tag_key: 'PositionAcquisitionTemplateName', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(3002,0121)', tag_sym: :position_acquisition_template_name, tag_ndm: '30020121', tag_ary: [0x3002,0x0121], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,0122)', tag_name: "Position Acquisition Template Code Sequence", tag_key: 'PositionAcquisitionTemplateCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3002,0122)', tag_sym: :position_acquisition_template_code_sequence, tag_ndm: '30020122', tag_ary: [0x3002,0x0122], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,0123)', tag_name: "Position Acquisition Template Description", tag_key: 'PositionAcquisitionTemplateDescription', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(3002,0123)', tag_sym: :position_acquisition_template_description, tag_ndm: '30020123', tag_ary: [0x3002,0x0123], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,0124)', tag_name: "Acquisition Task Applicability Sequence", tag_key: 'AcquisitionTaskApplicabilitySequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3002,0124)', tag_sym: :acquisition_task_applicability_sequence, tag_ndm: '30020124', tag_ary: [0x3002,0x0124], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,0125)', tag_name: "Projection Imaging Acquisition Parameter Sequence", tag_key: 'ProjectionImagingAcquisitionParameterSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3002,0125)', tag_sym: :projection_imaging_acquisition_parameter_sequence, tag_ndm: '30020125', tag_ary: [0x3002,0x0125], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,0126)', tag_name: "CT Imaging Acquisition Parameter Sequence", tag_key: 'CTImagingAcquisitionParameterSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3002,0126)', tag_sym: :ct_imaging_acquisition_parameter_sequence, tag_ndm: '30020126', tag_ary: [0x3002,0x0126], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,0127)', tag_name: "KV Imaging Generation Parameters Sequence", tag_key: 'KVImagingGenerationParametersSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3002,0127)', tag_sym: :kv_imaging_generation_parameters_sequence, tag_ndm: '30020127', tag_ary: [0x3002,0x0127], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,0128)', tag_name: "MV Imaging Generation Parameters Sequence", tag_key: 'MVImagingGenerationParametersSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3002,0128)', tag_sym: :mv_imaging_generation_parameters_sequence, tag_ndm: '30020128', tag_ary: [0x3002,0x0128], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,0129)', tag_name: "Acquisition Signal Type", tag_key: 'AcquisitionSignalType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(3002,0129)', tag_sym: :acquisition_signal_type, tag_ndm: '30020129', tag_ary: [0x3002,0x0129], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,012A)', tag_name: "Acquisition Method", tag_key: 'AcquisitionMethod', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(3002,012A)', tag_sym: :acquisition_method, tag_ndm: '3002012A', tag_ary: [0x3002,0x012A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,012B)', tag_name: "Scan Start Position Sequence", tag_key: 'ScanStartPositionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3002,012B)', tag_sym: :scan_start_position_sequence, tag_ndm: '3002012B', tag_ary: [0x3002,0x012B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,012C)', tag_name: "Scan Stop Position Sequence", tag_key: 'ScanStopPositionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3002,012C)', tag_sym: :scan_stop_position_sequence, tag_ndm: '3002012C', tag_ary: [0x3002,0x012C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,012D)', tag_name: "Imaging Source to Beam Modifier Definition Plane Distance", tag_key: 'ImagingSourceToBeamModifierDefinitionPlaneDistance', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(3002,012D)', tag_sym: :imaging_source_to_beam_modifier_definition_plane_distance, tag_ndm: '3002012D', tag_ary: [0x3002,0x012D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,012E)', tag_name: "Scan Arc Type", tag_key: 'ScanArcType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(3002,012E)', tag_sym: :scan_arc_type, tag_ndm: '3002012E', tag_ary: [0x3002,0x012E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,012F)', tag_name: "Detector Positioning Type", tag_key: 'DetectorPositioningType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(3002,012F)', tag_sym: :detector_positioning_type, tag_ndm: '3002012F', tag_ary: [0x3002,0x012F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,0130)', tag_name: "Additional RT Accessory Device Sequence", tag_key: 'AdditionalRTAccessoryDeviceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3002,0130)', tag_sym: :additional_rt_accessory_device_sequence, tag_ndm: '30020130', tag_ary: [0x3002,0x0130], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,0131)', tag_name: "Device-Specific Acquisition Parameter Sequence", tag_key: 'DeviceSpecificAcquisitionParameterSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3002,0131)', tag_sym: :device_specific_acquisition_parameter_sequence, tag_ndm: '30020131', tag_ary: [0x3002,0x0131], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,0132)', tag_name: "Referenced Position Reference Instance Sequence", tag_key: 'ReferencedPositionReferenceInstanceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3002,0132)', tag_sym: :referenced_position_reference_instance_sequence, tag_ndm: '30020132', tag_ary: [0x3002,0x0132], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,0133)', tag_name: "Energy Derivation Code Sequence", tag_key: 'EnergyDerivationCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3002,0133)', tag_sym: :energy_derivation_code_sequence, tag_ndm: '30020133', tag_ary: [0x3002,0x0133], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,0134)', tag_name: "Maximum Cumulative Meterset Exposure", tag_key: 'MaximumCumulativeMetersetExposure', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(3002,0134)', tag_sym: :maximum_cumulative_meterset_exposure, tag_ndm: '30020134', tag_ary: [0x3002,0x0134], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,0135)', tag_name: "Acquisition Initiation Sequence", tag_key: 'AcquisitionInitiationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3002,0135)', tag_sym: :acquisition_initiation_sequence, tag_ndm: '30020135', tag_ary: [0x3002,0x0135], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3002,0136)', tag_name: "RT Cone-Beam Imaging Geometry Sequence", tag_key: 'RTConeBeamImagingGeometrySequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3002,0136)', tag_sym: :rt_cone_beam_imaging_geometry_sequence, tag_ndm: '30020136', tag_ary: [0x3002,0x0136], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3004,0001)', tag_name: "DVH Type", tag_key: 'DVHType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(3004,0001)', tag_sym: :dvh_type, tag_ndm: '30040001', tag_ary: [0x3004,0x0001], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3004,0002)', tag_name: "Dose Units", tag_key: 'DoseUnits', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(3004,0002)', tag_sym: :dose_units, tag_ndm: '30040002', tag_ary: [0x3004,0x0002], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3004,0004)', tag_name: "Dose Type", tag_key: 'DoseType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(3004,0004)', tag_sym: :dose_type, tag_ndm: '30040004', tag_ary: [0x3004,0x0004], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3004,0005)', tag_name: "Spatial Transform of Dose", tag_key: 'SpatialTransformOfDose', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(3004,0005)', tag_sym: :spatial_transform_of_dose, tag_ndm: '30040005', tag_ary: [0x3004,0x0005], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3004,0006)', tag_name: "Dose Comment", tag_key: 'DoseComment', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(3004,0006)', tag_sym: :dose_comment, tag_ndm: '30040006', tag_ary: [0x3004,0x0006], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3004,0008)', tag_name: "Normalization Point", tag_key: 'NormalizationPoint', tag_vr: [:DS], tag_vm: ["3"], tag_str: '(3004,0008)', tag_sym: :normalization_point, tag_ndm: '30040008', tag_ary: [0x3004,0x0008], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3004,000A)', tag_name: "Dose Summation Type", tag_key: 'DoseSummationType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(3004,000A)', tag_sym: :dose_summation_type, tag_ndm: '3004000A', tag_ary: [0x3004,0x000A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3004,000C)', tag_name: "Grid Frame Offset Vector", tag_key: 'GridFrameOffsetVector', tag_vr: [:DS], tag_vm: ["2-n"], tag_str: '(3004,000C)', tag_sym: :grid_frame_offset_vector, tag_ndm: '3004000C', tag_ary: [0x3004,0x000C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3004,000E)', tag_name: "Dose Grid Scaling", tag_key: 'DoseGridScaling', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(3004,000E)', tag_sym: :dose_grid_scaling, tag_ndm: '3004000E', tag_ary: [0x3004,0x000E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3004,0010)', tag_name: "RT Dose ROI Sequence", tag_key: 'RTDoseROISequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3004,0010)', tag_sym: :rt_dose_roi_sequence, tag_ndm: '30040010', tag_ary: [0x3004,0x0010], tag_multiple: false, tag_note: 'RET (2022d)'},
      { tag_ps: '(3004,0012)', tag_name: "Dose Value", tag_key: 'DoseValue', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(3004,0012)', tag_sym: :dose_value, tag_ndm: '30040012', tag_ary: [0x3004,0x0012], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3004,0014)', tag_name: "Tissue Heterogeneity Correction", tag_key: 'TissueHeterogeneityCorrection', tag_vr: [:CS], tag_vm: ["1-3"], tag_str: '(3004,0014)', tag_sym: :tissue_heterogeneity_correction, tag_ndm: '30040014', tag_ary: [0x3004,0x0014], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3004,0016)', tag_name: "Recommended Isodose Level Sequence", tag_key: 'RecommendedIsodoseLevelSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3004,0016)', tag_sym: :recommended_isodose_level_sequence, tag_ndm: '30040016', tag_ary: [0x3004,0x0016], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3004,0040)', tag_name: "DVH Normalization Point", tag_key: 'DVHNormalizationPoint', tag_vr: [:DS], tag_vm: ["3"], tag_str: '(3004,0040)', tag_sym: :dvh_normalization_point, tag_ndm: '30040040', tag_ary: [0x3004,0x0040], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3004,0042)', tag_name: "DVH Normalization Dose Value", tag_key: 'DVHNormalizationDoseValue', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(3004,0042)', tag_sym: :dvh_normalization_dose_value, tag_ndm: '30040042', tag_ary: [0x3004,0x0042], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3004,0050)', tag_name: "DVH Sequence", tag_key: 'DVHSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3004,0050)', tag_sym: :dvh_sequence, tag_ndm: '30040050', tag_ary: [0x3004,0x0050], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3004,0052)', tag_name: "DVH Dose Scaling", tag_key: 'DVHDoseScaling', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(3004,0052)', tag_sym: :dvh_dose_scaling, tag_ndm: '30040052', tag_ary: [0x3004,0x0052], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3004,0054)', tag_name: "DVH Volume Units", tag_key: 'DVHVolumeUnits', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(3004,0054)', tag_sym: :dvh_volume_units, tag_ndm: '30040054', tag_ary: [0x3004,0x0054], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3004,0056)', tag_name: "DVH Number of Bins", tag_key: 'DVHNumberOfBins', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(3004,0056)', tag_sym: :dvh_number_of_bins, tag_ndm: '30040056', tag_ary: [0x3004,0x0056], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3004,0058)', tag_name: "DVH Data", tag_key: 'DVHData', tag_vr: [:DS], tag_vm: ["2-2n"], tag_str: '(3004,0058)', tag_sym: :dvh_data, tag_ndm: '30040058', tag_ary: [0x3004,0x0058], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3004,0060)', tag_name: "DVH Referenced ROI Sequence", tag_key: 'DVHReferencedROISequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3004,0060)', tag_sym: :dvh_referenced_roi_sequence, tag_ndm: '30040060', tag_ary: [0x3004,0x0060], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3004,0062)', tag_name: "DVH ROI Contribution Type", tag_key: 'DVHROIContributionType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(3004,0062)', tag_sym: :dvh_roi_contribution_type, tag_ndm: '30040062', tag_ary: [0x3004,0x0062], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3004,0070)', tag_name: "DVH Minimum Dose", tag_key: 'DVHMinimumDose', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(3004,0070)', tag_sym: :dvh_minimum_dose, tag_ndm: '30040070', tag_ary: [0x3004,0x0070], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3004,0072)', tag_name: "DVH Maximum Dose", tag_key: 'DVHMaximumDose', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(3004,0072)', tag_sym: :dvh_maximum_dose, tag_ndm: '30040072', tag_ary: [0x3004,0x0072], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3004,0074)', tag_name: "DVH Mean Dose", tag_key: 'DVHMeanDose', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(3004,0074)', tag_sym: :dvh_mean_dose, tag_ndm: '30040074', tag_ary: [0x3004,0x0074], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3006,0002)', tag_name: "Structure Set Label", tag_key: 'StructureSetLabel', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(3006,0002)', tag_sym: :structure_set_label, tag_ndm: '30060002', tag_ary: [0x3006,0x0002], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3006,0004)', tag_name: "Structure Set Name", tag_key: 'StructureSetName', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(3006,0004)', tag_sym: :structure_set_name, tag_ndm: '30060004', tag_ary: [0x3006,0x0004], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3006,0006)', tag_name: "Structure Set Description", tag_key: 'StructureSetDescription', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(3006,0006)', tag_sym: :structure_set_description, tag_ndm: '30060006', tag_ary: [0x3006,0x0006], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3006,0008)', tag_name: "Structure Set Date", tag_key: 'StructureSetDate', tag_vr: [:DA], tag_vm: ["1"], tag_str: '(3006,0008)', tag_sym: :structure_set_date, tag_ndm: '30060008', tag_ary: [0x3006,0x0008], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3006,0009)', tag_name: "Structure Set Time", tag_key: 'StructureSetTime', tag_vr: [:TM], tag_vm: ["1"], tag_str: '(3006,0009)', tag_sym: :structure_set_time, tag_ndm: '30060009', tag_ary: [0x3006,0x0009], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3006,0010)', tag_name: "Referenced Frame of Reference Sequence", tag_key: 'ReferencedFrameOfReferenceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3006,0010)', tag_sym: :referenced_frame_of_reference_sequence, tag_ndm: '30060010', tag_ary: [0x3006,0x0010], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3006,0012)', tag_name: "RT Referenced Study Sequence", tag_key: 'RTReferencedStudySequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3006,0012)', tag_sym: :rt_referenced_study_sequence, tag_ndm: '30060012', tag_ary: [0x3006,0x0012], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3006,0014)', tag_name: "RT Referenced Series Sequence", tag_key: 'RTReferencedSeriesSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3006,0014)', tag_sym: :rt_referenced_series_sequence, tag_ndm: '30060014', tag_ary: [0x3006,0x0014], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3006,0016)', tag_name: "Contour Image Sequence", tag_key: 'ContourImageSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3006,0016)', tag_sym: :contour_image_sequence, tag_ndm: '30060016', tag_ary: [0x3006,0x0016], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3006,0018)', tag_name: "Predecessor Structure Set Sequence", tag_key: 'PredecessorStructureSetSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3006,0018)', tag_sym: :predecessor_structure_set_sequence, tag_ndm: '30060018', tag_ary: [0x3006,0x0018], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3006,0020)', tag_name: "Structure Set ROI Sequence", tag_key: 'StructureSetROISequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3006,0020)', tag_sym: :structure_set_roi_sequence, tag_ndm: '30060020', tag_ary: [0x3006,0x0020], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3006,0022)', tag_name: "ROI Number", tag_key: 'ROINumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(3006,0022)', tag_sym: :roi_number, tag_ndm: '30060022', tag_ary: [0x3006,0x0022], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3006,0024)', tag_name: "Referenced Frame of Reference UID", tag_key: 'ReferencedFrameOfReferenceUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(3006,0024)', tag_sym: :referenced_frame_of_reference_uid, tag_ndm: '30060024', tag_ary: [0x3006,0x0024], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3006,0026)', tag_name: "ROI Name", tag_key: 'ROIName', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(3006,0026)', tag_sym: :roi_name, tag_ndm: '30060026', tag_ary: [0x3006,0x0026], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3006,0028)', tag_name: "ROI Description", tag_key: 'ROIDescription', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(3006,0028)', tag_sym: :roi_description, tag_ndm: '30060028', tag_ary: [0x3006,0x0028], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3006,002A)', tag_name: "ROI Display Color", tag_key: 'ROIDisplayColor', tag_vr: [:IS], tag_vm: ["3"], tag_str: '(3006,002A)', tag_sym: :roi_display_color, tag_ndm: '3006002A', tag_ary: [0x3006,0x002A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3006,002C)', tag_name: "ROI Volume", tag_key: 'ROIVolume', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(3006,002C)', tag_sym: :roi_volume, tag_ndm: '3006002C', tag_ary: [0x3006,0x002C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3006,002D)', tag_name: "ROI DateTime", tag_key: 'ROIDateTime', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(3006,002D)', tag_sym: :roi_date_time, tag_ndm: '3006002D', tag_ary: [0x3006,0x002D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3006,002E)', tag_name: "ROI Observation DateTime", tag_key: 'ROIObservationDateTime', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(3006,002E)', tag_sym: :roi_observation_date_time, tag_ndm: '3006002E', tag_ary: [0x3006,0x002E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3006,0030)', tag_name: "RT Related ROI Sequence", tag_key: 'RTRelatedROISequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3006,0030)', tag_sym: :rt_related_roi_sequence, tag_ndm: '30060030', tag_ary: [0x3006,0x0030], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3006,0033)', tag_name: "RT ROI Relationship", tag_key: 'RTROIRelationship', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(3006,0033)', tag_sym: :rt_roi_relationship, tag_ndm: '30060033', tag_ary: [0x3006,0x0033], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3006,0036)', tag_name: "ROI Generation Algorithm", tag_key: 'ROIGenerationAlgorithm', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(3006,0036)', tag_sym: :roi_generation_algorithm, tag_ndm: '30060036', tag_ary: [0x3006,0x0036], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3006,0037)', tag_name: "ROI Derivation Algorithm Identification Sequence", tag_key: 'ROIDerivationAlgorithmIdentificationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3006,0037)', tag_sym: :roi_derivation_algorithm_identification_sequence, tag_ndm: '30060037', tag_ary: [0x3006,0x0037], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3006,0038)', tag_name: "ROI Generation Description", tag_key: 'ROIGenerationDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(3006,0038)', tag_sym: :roi_generation_description, tag_ndm: '30060038', tag_ary: [0x3006,0x0038], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3006,0039)', tag_name: "ROI Contour Sequence", tag_key: 'ROIContourSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3006,0039)', tag_sym: :roi_contour_sequence, tag_ndm: '30060039', tag_ary: [0x3006,0x0039], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3006,0040)', tag_name: "Contour Sequence", tag_key: 'ContourSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3006,0040)', tag_sym: :contour_sequence, tag_ndm: '30060040', tag_ary: [0x3006,0x0040], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3006,0042)', tag_name: "Contour Geometric Type", tag_key: 'ContourGeometricType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(3006,0042)', tag_sym: :contour_geometric_type, tag_ndm: '30060042', tag_ary: [0x3006,0x0042], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3006,0044)', tag_name: "Contour Slab Thickness", tag_key: 'ContourSlabThickness', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(3006,0044)', tag_sym: :contour_slab_thickness, tag_ndm: '30060044', tag_ary: [0x3006,0x0044], tag_multiple: false, tag_note: 'RET (2020e)'},
      { tag_ps: '(3006,0045)', tag_name: "Contour Offset Vector", tag_key: 'ContourOffsetVector', tag_vr: [:DS], tag_vm: ["3"], tag_str: '(3006,0045)', tag_sym: :contour_offset_vector, tag_ndm: '30060045', tag_ary: [0x3006,0x0045], tag_multiple: false, tag_note: 'RET (2020e)'},
      { tag_ps: '(3006,0046)', tag_name: "Number of Contour Points", tag_key: 'NumberOfContourPoints', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(3006,0046)', tag_sym: :number_of_contour_points, tag_ndm: '30060046', tag_ary: [0x3006,0x0046], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3006,0048)', tag_name: "Contour Number", tag_key: 'ContourNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(3006,0048)', tag_sym: :contour_number, tag_ndm: '30060048', tag_ary: [0x3006,0x0048], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3006,0049)', tag_name: "Attached Contours", tag_key: 'AttachedContours', tag_vr: [:IS], tag_vm: ["1-n"], tag_str: '(3006,0049)', tag_sym: :attached_contours, tag_ndm: '30060049', tag_ary: [0x3006,0x0049], tag_multiple: false, tag_note: 'RET (2020e)'},
      { tag_ps: '(3006,004A)', tag_name: "Source Pixel Planes Characteristics Sequence", tag_key: 'SourcePixelPlanesCharacteristicsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3006,004A)', tag_sym: :source_pixel_planes_characteristics_sequence, tag_ndm: '3006004A', tag_ary: [0x3006,0x004A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3006,004B)', tag_name: "Source Series Sequence", tag_key: 'SourceSeriesSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3006,004B)', tag_sym: :source_series_sequence, tag_ndm: '3006004B', tag_ary: [0x3006,0x004B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3006,004C)', tag_name: "Source Series Information Sequence", tag_key: 'SourceSeriesInformationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3006,004C)', tag_sym: :source_series_information_sequence, tag_ndm: '3006004C', tag_ary: [0x3006,0x004C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3006,004D)', tag_name: "ROI Creator Sequence", tag_key: 'ROICreatorSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3006,004D)', tag_sym: :roi_creator_sequence, tag_ndm: '3006004D', tag_ary: [0x3006,0x004D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3006,004E)', tag_name: "ROI Interpreter Sequence", tag_key: 'ROIInterpreterSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3006,004E)', tag_sym: :roi_interpreter_sequence, tag_ndm: '3006004E', tag_ary: [0x3006,0x004E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3006,004F)', tag_name: "ROI Observation Context Code Sequence", tag_key: 'ROIObservationContextCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3006,004F)', tag_sym: :roi_observation_context_code_sequence, tag_ndm: '3006004F', tag_ary: [0x3006,0x004F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3006,0050)', tag_name: "Contour Data", tag_key: 'ContourData', tag_vr: [:DS], tag_vm: ["3-3n"], tag_str: '(3006,0050)', tag_sym: :contour_data, tag_ndm: '30060050', tag_ary: [0x3006,0x0050], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3006,0080)', tag_name: "RT ROI Observations Sequence", tag_key: 'RTROIObservationsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3006,0080)', tag_sym: :rt_roi_observations_sequence, tag_ndm: '30060080', tag_ary: [0x3006,0x0080], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3006,0082)', tag_name: "Observation Number", tag_key: 'ObservationNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(3006,0082)', tag_sym: :observation_number, tag_ndm: '30060082', tag_ary: [0x3006,0x0082], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3006,0084)', tag_name: "Referenced ROI Number", tag_key: 'ReferencedROINumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(3006,0084)', tag_sym: :referenced_roi_number, tag_ndm: '30060084', tag_ary: [0x3006,0x0084], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3006,0085)', tag_name: "ROI Observation Label", tag_key: 'ROIObservationLabel', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(3006,0085)', tag_sym: :roi_observation_label, tag_ndm: '30060085', tag_ary: [0x3006,0x0085], tag_multiple: false, tag_note: 'RET (2022b)'},
      { tag_ps: '(3006,0086)', tag_name: "RT ROI Identification Code Sequence", tag_key: 'RTROIIdentificationCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3006,0086)', tag_sym: :rt_roi_identification_code_sequence, tag_ndm: '30060086', tag_ary: [0x3006,0x0086], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3006,0088)', tag_name: "ROI Observation Description", tag_key: 'ROIObservationDescription', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(3006,0088)', tag_sym: :roi_observation_description, tag_ndm: '30060088', tag_ary: [0x3006,0x0088], tag_multiple: false, tag_note: 'RET (2022b)'},
      { tag_ps: '(3006,00A0)', tag_name: "Related RT ROI Observations Sequence", tag_key: 'RelatedRTROIObservationsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3006,00A0)', tag_sym: :related_rt_roi_observations_sequence, tag_ndm: '300600A0', tag_ary: [0x3006,0x00A0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3006,00A4)', tag_name: "RT ROI Interpreted Type", tag_key: 'RTROIInterpretedType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(3006,00A4)', tag_sym: :rt_roi_interpreted_type, tag_ndm: '300600A4', tag_ary: [0x3006,0x00A4], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3006,00A6)', tag_name: "ROI Interpreter", tag_key: 'ROIInterpreter', tag_vr: [:PN], tag_vm: ["1"], tag_str: '(3006,00A6)', tag_sym: :roi_interpreter, tag_ndm: '300600A6', tag_ary: [0x3006,0x00A6], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3006,00B0)', tag_name: "ROI Physical Properties Sequence", tag_key: 'ROIPhysicalPropertiesSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3006,00B0)', tag_sym: :roi_physical_properties_sequence, tag_ndm: '300600B0', tag_ary: [0x3006,0x00B0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3006,00B2)', tag_name: "ROI Physical Property", tag_key: 'ROIPhysicalProperty', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(3006,00B2)', tag_sym: :roi_physical_property, tag_ndm: '300600B2', tag_ary: [0x3006,0x00B2], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3006,00B4)', tag_name: "ROI Physical Property Value", tag_key: 'ROIPhysicalPropertyValue', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(3006,00B4)', tag_sym: :roi_physical_property_value, tag_ndm: '300600B4', tag_ary: [0x3006,0x00B4], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3006,00B6)', tag_name: "ROI Elemental Composition Sequence", tag_key: 'ROIElementalCompositionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3006,00B6)', tag_sym: :roi_elemental_composition_sequence, tag_ndm: '300600B6', tag_ary: [0x3006,0x00B6], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3006,00B7)', tag_name: "ROI Elemental Composition Atomic Number", tag_key: 'ROIElementalCompositionAtomicNumber', tag_vr: [:US], tag_vm: ["1"], tag_str: '(3006,00B7)', tag_sym: :roi_elemental_composition_atomic_number, tag_ndm: '300600B7', tag_ary: [0x3006,0x00B7], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3006,00B8)', tag_name: "ROI Elemental Composition Atomic Mass Fraction", tag_key: 'ROIElementalCompositionAtomicMassFraction', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(3006,00B8)', tag_sym: :roi_elemental_composition_atomic_mass_fraction, tag_ndm: '300600B8', tag_ary: [0x3006,0x00B8], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3006,00B9)', tag_name: "Additional RT ROI Identification Code Sequence", tag_key: 'AdditionalRTROIIdentificationCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3006,00B9)', tag_sym: :additional_rt_roi_identification_code_sequence, tag_ndm: '300600B9', tag_ary: [0x3006,0x00B9], tag_multiple: false, tag_note: 'RET (2016c)'},
      { tag_ps: '(3006,00C0)', tag_name: "Frame of Reference Relationship Sequence", tag_key: 'FrameOfReferenceRelationshipSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3006,00C0)', tag_sym: :frame_of_reference_relationship_sequence, tag_ndm: '300600C0', tag_ary: [0x3006,0x00C0], tag_multiple: false, tag_note: 'RET (2011)'},
      { tag_ps: '(3006,00C2)', tag_name: "Related Frame of Reference UID", tag_key: 'RelatedFrameOfReferenceUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(3006,00C2)', tag_sym: :related_frame_of_reference_uid, tag_ndm: '300600C2', tag_ary: [0x3006,0x00C2], tag_multiple: false, tag_note: 'RET (2011)'},
      { tag_ps: '(3006,00C4)', tag_name: "Frame of Reference Transformation Type", tag_key: 'FrameOfReferenceTransformationType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(3006,00C4)', tag_sym: :frame_of_reference_transformation_type, tag_ndm: '300600C4', tag_ary: [0x3006,0x00C4], tag_multiple: false, tag_note: 'RET (2011)'},
      { tag_ps: '(3006,00C6)', tag_name: "Frame of Reference Transformation Matrix", tag_key: 'FrameOfReferenceTransformationMatrix', tag_vr: [:DS], tag_vm: ["16"], tag_str: '(3006,00C6)', tag_sym: :frame_of_reference_transformation_matrix, tag_ndm: '300600C6', tag_ary: [0x3006,0x00C6], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3006,00C8)', tag_name: "Frame of Reference Transformation Comment", tag_key: 'FrameOfReferenceTransformationComment', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(3006,00C8)', tag_sym: :frame_of_reference_transformation_comment, tag_ndm: '300600C8', tag_ary: [0x3006,0x00C8], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3006,00C9)', tag_name: "Patient Location Coordinates Sequence", tag_key: 'PatientLocationCoordinatesSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3006,00C9)', tag_sym: :patient_location_coordinates_sequence, tag_ndm: '300600C9', tag_ary: [0x3006,0x00C9], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3006,00CA)', tag_name: "Patient Location Coordinates Code Sequence", tag_key: 'PatientLocationCoordinatesCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3006,00CA)', tag_sym: :patient_location_coordinates_code_sequence, tag_ndm: '300600CA', tag_ary: [0x3006,0x00CA], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3006,00CB)', tag_name: "Patient Support Position Sequence", tag_key: 'PatientSupportPositionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3006,00CB)', tag_sym: :patient_support_position_sequence, tag_ndm: '300600CB', tag_ary: [0x3006,0x00CB], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0010)', tag_name: "Measured Dose Reference Sequence", tag_key: 'MeasuredDoseReferenceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3008,0010)', tag_sym: :measured_dose_reference_sequence, tag_ndm: '30080010', tag_ary: [0x3008,0x0010], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0012)', tag_name: "Measured Dose Description", tag_key: 'MeasuredDoseDescription', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(3008,0012)', tag_sym: :measured_dose_description, tag_ndm: '30080012', tag_ary: [0x3008,0x0012], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0014)', tag_name: "Measured Dose Type", tag_key: 'MeasuredDoseType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(3008,0014)', tag_sym: :measured_dose_type, tag_ndm: '30080014', tag_ary: [0x3008,0x0014], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0016)', tag_name: "Measured Dose Value", tag_key: 'MeasuredDoseValue', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(3008,0016)', tag_sym: :measured_dose_value, tag_ndm: '30080016', tag_ary: [0x3008,0x0016], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0020)', tag_name: "Treatment Session Beam Sequence", tag_key: 'TreatmentSessionBeamSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3008,0020)', tag_sym: :treatment_session_beam_sequence, tag_ndm: '30080020', tag_ary: [0x3008,0x0020], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0021)', tag_name: "Treatment Session Ion Beam Sequence", tag_key: 'TreatmentSessionIonBeamSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3008,0021)', tag_sym: :treatment_session_ion_beam_sequence, tag_ndm: '30080021', tag_ary: [0x3008,0x0021], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0022)', tag_name: "Current Fraction Number", tag_key: 'CurrentFractionNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(3008,0022)', tag_sym: :current_fraction_number, tag_ndm: '30080022', tag_ary: [0x3008,0x0022], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0024)', tag_name: "Treatment Control Point Date", tag_key: 'TreatmentControlPointDate', tag_vr: [:DA], tag_vm: ["1"], tag_str: '(3008,0024)', tag_sym: :treatment_control_point_date, tag_ndm: '30080024', tag_ary: [0x3008,0x0024], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0025)', tag_name: "Treatment Control Point Time", tag_key: 'TreatmentControlPointTime', tag_vr: [:TM], tag_vm: ["1"], tag_str: '(3008,0025)', tag_sym: :treatment_control_point_time, tag_ndm: '30080025', tag_ary: [0x3008,0x0025], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,002A)', tag_name: "Treatment Termination Status", tag_key: 'TreatmentTerminationStatus', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(3008,002A)', tag_sym: :treatment_termination_status, tag_ndm: '3008002A', tag_ary: [0x3008,0x002A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,002B)', tag_name: "Treatment Termination Code", tag_key: 'TreatmentTerminationCode', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(3008,002B)', tag_sym: :treatment_termination_code, tag_ndm: '3008002B', tag_ary: [0x3008,0x002B], tag_multiple: false, tag_note: 'RET (2023a)'},
      { tag_ps: '(3008,002C)', tag_name: "Treatment Verification Status", tag_key: 'TreatmentVerificationStatus', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(3008,002C)', tag_sym: :treatment_verification_status, tag_ndm: '3008002C', tag_ary: [0x3008,0x002C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0030)', tag_name: "Referenced Treatment Record Sequence", tag_key: 'ReferencedTreatmentRecordSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3008,0030)', tag_sym: :referenced_treatment_record_sequence, tag_ndm: '30080030', tag_ary: [0x3008,0x0030], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0032)', tag_name: "Specified Primary Meterset", tag_key: 'SpecifiedPrimaryMeterset', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(3008,0032)', tag_sym: :specified_primary_meterset, tag_ndm: '30080032', tag_ary: [0x3008,0x0032], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0033)', tag_name: "Specified Secondary Meterset", tag_key: 'SpecifiedSecondaryMeterset', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(3008,0033)', tag_sym: :specified_secondary_meterset, tag_ndm: '30080033', tag_ary: [0x3008,0x0033], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0036)', tag_name: "Delivered Primary Meterset", tag_key: 'DeliveredPrimaryMeterset', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(3008,0036)', tag_sym: :delivered_primary_meterset, tag_ndm: '30080036', tag_ary: [0x3008,0x0036], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0037)', tag_name: "Delivered Secondary Meterset", tag_key: 'DeliveredSecondaryMeterset', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(3008,0037)', tag_sym: :delivered_secondary_meterset, tag_ndm: '30080037', tag_ary: [0x3008,0x0037], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,003A)', tag_name: "Specified Treatment Time", tag_key: 'SpecifiedTreatmentTime', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(3008,003A)', tag_sym: :specified_treatment_time, tag_ndm: '3008003A', tag_ary: [0x3008,0x003A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,003B)', tag_name: "Delivered Treatment Time", tag_key: 'DeliveredTreatmentTime', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(3008,003B)', tag_sym: :delivered_treatment_time, tag_ndm: '3008003B', tag_ary: [0x3008,0x003B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0040)', tag_name: "Control Point Delivery Sequence", tag_key: 'ControlPointDeliverySequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3008,0040)', tag_sym: :control_point_delivery_sequence, tag_ndm: '30080040', tag_ary: [0x3008,0x0040], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0041)', tag_name: "Ion Control Point Delivery Sequence", tag_key: 'IonControlPointDeliverySequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3008,0041)', tag_sym: :ion_control_point_delivery_sequence, tag_ndm: '30080041', tag_ary: [0x3008,0x0041], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0042)', tag_name: "Specified Meterset", tag_key: 'SpecifiedMeterset', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(3008,0042)', tag_sym: :specified_meterset, tag_ndm: '30080042', tag_ary: [0x3008,0x0042], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0044)', tag_name: "Delivered Meterset", tag_key: 'DeliveredMeterset', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(3008,0044)', tag_sym: :delivered_meterset, tag_ndm: '30080044', tag_ary: [0x3008,0x0044], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0045)', tag_name: "Meterset Rate Set", tag_key: 'MetersetRateSet', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(3008,0045)', tag_sym: :meterset_rate_set, tag_ndm: '30080045', tag_ary: [0x3008,0x0045], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0046)', tag_name: "Meterset Rate Delivered", tag_key: 'MetersetRateDelivered', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(3008,0046)', tag_sym: :meterset_rate_delivered, tag_ndm: '30080046', tag_ary: [0x3008,0x0046], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0047)', tag_name: "Scan Spot Metersets Delivered", tag_key: 'ScanSpotMetersetsDelivered', tag_vr: [:FL], tag_vm: ["1-n"], tag_str: '(3008,0047)', tag_sym: :scan_spot_metersets_delivered, tag_ndm: '30080047', tag_ary: [0x3008,0x0047], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0048)', tag_name: "Dose Rate Delivered", tag_key: 'DoseRateDelivered', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(3008,0048)', tag_sym: :dose_rate_delivered, tag_ndm: '30080048', tag_ary: [0x3008,0x0048], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0050)', tag_name: "Treatment Summary Calculated Dose Reference Sequence", tag_key: 'TreatmentSummaryCalculatedDoseReferenceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3008,0050)', tag_sym: :treatment_summary_calculated_dose_reference_sequence, tag_ndm: '30080050', tag_ary: [0x3008,0x0050], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0052)', tag_name: "Cumulative Dose to Dose Reference", tag_key: 'CumulativeDoseToDoseReference', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(3008,0052)', tag_sym: :cumulative_dose_to_dose_reference, tag_ndm: '30080052', tag_ary: [0x3008,0x0052], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0054)', tag_name: "First Treatment Date", tag_key: 'FirstTreatmentDate', tag_vr: [:DA], tag_vm: ["1"], tag_str: '(3008,0054)', tag_sym: :first_treatment_date, tag_ndm: '30080054', tag_ary: [0x3008,0x0054], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0056)', tag_name: "Most Recent Treatment Date", tag_key: 'MostRecentTreatmentDate', tag_vr: [:DA], tag_vm: ["1"], tag_str: '(3008,0056)', tag_sym: :most_recent_treatment_date, tag_ndm: '30080056', tag_ary: [0x3008,0x0056], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,005A)', tag_name: "Number of Fractions Delivered", tag_key: 'NumberOfFractionsDelivered', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(3008,005A)', tag_sym: :number_of_fractions_delivered, tag_ndm: '3008005A', tag_ary: [0x3008,0x005A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0060)', tag_name: "Override Sequence", tag_key: 'OverrideSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3008,0060)', tag_sym: :override_sequence, tag_ndm: '30080060', tag_ary: [0x3008,0x0060], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0061)', tag_name: "Parameter Sequence Pointer", tag_key: 'ParameterSequencePointer', tag_vr: [:AT], tag_vm: ["1"], tag_str: '(3008,0061)', tag_sym: :parameter_sequence_pointer, tag_ndm: '30080061', tag_ary: [0x3008,0x0061], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0062)', tag_name: "Override Parameter Pointer", tag_key: 'OverrideParameterPointer', tag_vr: [:AT], tag_vm: ["1"], tag_str: '(3008,0062)', tag_sym: :override_parameter_pointer, tag_ndm: '30080062', tag_ary: [0x3008,0x0062], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0063)', tag_name: "Parameter Item Index", tag_key: 'ParameterItemIndex', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(3008,0063)', tag_sym: :parameter_item_index, tag_ndm: '30080063', tag_ary: [0x3008,0x0063], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0064)', tag_name: "Measured Dose Reference Number", tag_key: 'MeasuredDoseReferenceNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(3008,0064)', tag_sym: :measured_dose_reference_number, tag_ndm: '30080064', tag_ary: [0x3008,0x0064], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0065)', tag_name: "Parameter Pointer", tag_key: 'ParameterPointer', tag_vr: [:AT], tag_vm: ["1"], tag_str: '(3008,0065)', tag_sym: :parameter_pointer, tag_ndm: '30080065', tag_ary: [0x3008,0x0065], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0066)', tag_name: "Override Reason", tag_key: 'OverrideReason', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(3008,0066)', tag_sym: :override_reason, tag_ndm: '30080066', tag_ary: [0x3008,0x0066], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0067)', tag_name: "Parameter Value Number", tag_key: 'ParameterValueNumber', tag_vr: [:US], tag_vm: ["1"], tag_str: '(3008,0067)', tag_sym: :parameter_value_number, tag_ndm: '30080067', tag_ary: [0x3008,0x0067], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0068)', tag_name: "Corrected Parameter Sequence", tag_key: 'CorrectedParameterSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3008,0068)', tag_sym: :corrected_parameter_sequence, tag_ndm: '30080068', tag_ary: [0x3008,0x0068], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,006A)', tag_name: "Correction Value", tag_key: 'CorrectionValue', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(3008,006A)', tag_sym: :correction_value, tag_ndm: '3008006A', tag_ary: [0x3008,0x006A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0070)', tag_name: "Calculated Dose Reference Sequence", tag_key: 'CalculatedDoseReferenceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3008,0070)', tag_sym: :calculated_dose_reference_sequence, tag_ndm: '30080070', tag_ary: [0x3008,0x0070], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0072)', tag_name: "Calculated Dose Reference Number", tag_key: 'CalculatedDoseReferenceNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(3008,0072)', tag_sym: :calculated_dose_reference_number, tag_ndm: '30080072', tag_ary: [0x3008,0x0072], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0074)', tag_name: "Calculated Dose Reference Description", tag_key: 'CalculatedDoseReferenceDescription', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(3008,0074)', tag_sym: :calculated_dose_reference_description, tag_ndm: '30080074', tag_ary: [0x3008,0x0074], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0076)', tag_name: "Calculated Dose Reference Dose Value", tag_key: 'CalculatedDoseReferenceDoseValue', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(3008,0076)', tag_sym: :calculated_dose_reference_dose_value, tag_ndm: '30080076', tag_ary: [0x3008,0x0076], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0078)', tag_name: "Start Meterset", tag_key: 'StartMeterset', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(3008,0078)', tag_sym: :start_meterset, tag_ndm: '30080078', tag_ary: [0x3008,0x0078], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,007A)', tag_name: "End Meterset", tag_key: 'EndMeterset', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(3008,007A)', tag_sym: :end_meterset, tag_ndm: '3008007A', tag_ary: [0x3008,0x007A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0080)', tag_name: "Referenced Measured Dose Reference Sequence", tag_key: 'ReferencedMeasuredDoseReferenceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3008,0080)', tag_sym: :referenced_measured_dose_reference_sequence, tag_ndm: '30080080', tag_ary: [0x3008,0x0080], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0082)', tag_name: "Referenced Measured Dose Reference Number", tag_key: 'ReferencedMeasuredDoseReferenceNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(3008,0082)', tag_sym: :referenced_measured_dose_reference_number, tag_ndm: '30080082', tag_ary: [0x3008,0x0082], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0090)', tag_name: "Referenced Calculated Dose Reference Sequence", tag_key: 'ReferencedCalculatedDoseReferenceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3008,0090)', tag_sym: :referenced_calculated_dose_reference_sequence, tag_ndm: '30080090', tag_ary: [0x3008,0x0090], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0092)', tag_name: "Referenced Calculated Dose Reference Number", tag_key: 'ReferencedCalculatedDoseReferenceNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(3008,0092)', tag_sym: :referenced_calculated_dose_reference_number, tag_ndm: '30080092', tag_ary: [0x3008,0x0092], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,00A0)', tag_name: "Beam Limiting Device Leaf Pairs Sequence", tag_key: 'BeamLimitingDeviceLeafPairsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3008,00A0)', tag_sym: :beam_limiting_device_leaf_pairs_sequence, tag_ndm: '300800A0', tag_ary: [0x3008,0x00A0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,00A1)', tag_name: "Enhanced RT Beam Limiting Device Sequence", tag_key: 'EnhancedRTBeamLimitingDeviceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3008,00A1)', tag_sym: :enhanced_rt_beam_limiting_device_sequence, tag_ndm: '300800A1', tag_ary: [0x3008,0x00A1], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,00A2)', tag_name: "Enhanced RT Beam Limiting Opening Sequence", tag_key: 'EnhancedRTBeamLimitingOpeningSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3008,00A2)', tag_sym: :enhanced_rt_beam_limiting_opening_sequence, tag_ndm: '300800A2', tag_ary: [0x3008,0x00A2], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,00A3)', tag_name: "Enhanced RT Beam Limiting Device Definition Flag", tag_key: 'EnhancedRTBeamLimitingDeviceDefinitionFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(3008,00A3)', tag_sym: :enhanced_rt_beam_limiting_device_definition_flag, tag_ndm: '300800A3', tag_ary: [0x3008,0x00A3], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,00A4)', tag_name: "Parallel RT Beam Delimiter Opening Extents", tag_key: 'ParallelRTBeamDelimiterOpeningExtents', tag_vr: [:FD], tag_vm: ["2-2n"], tag_str: '(3008,00A4)', tag_sym: :parallel_rt_beam_delimiter_opening_extents, tag_ndm: '300800A4', tag_ary: [0x3008,0x00A4], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,00B0)', tag_name: "Recorded Wedge Sequence", tag_key: 'RecordedWedgeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3008,00B0)', tag_sym: :recorded_wedge_sequence, tag_ndm: '300800B0', tag_ary: [0x3008,0x00B0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,00C0)', tag_name: "Recorded Compensator Sequence", tag_key: 'RecordedCompensatorSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3008,00C0)', tag_sym: :recorded_compensator_sequence, tag_ndm: '300800C0', tag_ary: [0x3008,0x00C0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,00D0)', tag_name: "Recorded Block Sequence", tag_key: 'RecordedBlockSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3008,00D0)', tag_sym: :recorded_block_sequence, tag_ndm: '300800D0', tag_ary: [0x3008,0x00D0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,00D1)', tag_name: "Recorded Block Slab Sequence", tag_key: 'RecordedBlockSlabSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3008,00D1)', tag_sym: :recorded_block_slab_sequence, tag_ndm: '300800D1', tag_ary: [0x3008,0x00D1], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,00E0)', tag_name: "Treatment Summary Measured Dose Reference Sequence", tag_key: 'TreatmentSummaryMeasuredDoseReferenceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3008,00E0)', tag_sym: :treatment_summary_measured_dose_reference_sequence, tag_ndm: '300800E0', tag_ary: [0x3008,0x00E0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,00F0)', tag_name: "Recorded Snout Sequence", tag_key: 'RecordedSnoutSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3008,00F0)', tag_sym: :recorded_snout_sequence, tag_ndm: '300800F0', tag_ary: [0x3008,0x00F0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,00F2)', tag_name: "Recorded Range Shifter Sequence", tag_key: 'RecordedRangeShifterSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3008,00F2)', tag_sym: :recorded_range_shifter_sequence, tag_ndm: '300800F2', tag_ary: [0x3008,0x00F2], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,00F4)', tag_name: "Recorded Lateral Spreading Device Sequence", tag_key: 'RecordedLateralSpreadingDeviceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3008,00F4)', tag_sym: :recorded_lateral_spreading_device_sequence, tag_ndm: '300800F4', tag_ary: [0x3008,0x00F4], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,00F6)', tag_name: "Recorded Range Modulator Sequence", tag_key: 'RecordedRangeModulatorSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3008,00F6)', tag_sym: :recorded_range_modulator_sequence, tag_ndm: '300800F6', tag_ary: [0x3008,0x00F6], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0100)', tag_name: "Recorded Source Sequence", tag_key: 'RecordedSourceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3008,0100)', tag_sym: :recorded_source_sequence, tag_ndm: '30080100', tag_ary: [0x3008,0x0100], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0105)', tag_name: "Source Serial Number", tag_key: 'SourceSerialNumber', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(3008,0105)', tag_sym: :source_serial_number, tag_ndm: '30080105', tag_ary: [0x3008,0x0105], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0110)', tag_name: "Treatment Session Application Setup Sequence", tag_key: 'TreatmentSessionApplicationSetupSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3008,0110)', tag_sym: :treatment_session_application_setup_sequence, tag_ndm: '30080110', tag_ary: [0x3008,0x0110], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0116)', tag_name: "Application Setup Check", tag_key: 'ApplicationSetupCheck', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(3008,0116)', tag_sym: :application_setup_check, tag_ndm: '30080116', tag_ary: [0x3008,0x0116], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0120)', tag_name: "Recorded Brachy Accessory Device Sequence", tag_key: 'RecordedBrachyAccessoryDeviceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3008,0120)', tag_sym: :recorded_brachy_accessory_device_sequence, tag_ndm: '30080120', tag_ary: [0x3008,0x0120], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0122)', tag_name: "Referenced Brachy Accessory Device Number", tag_key: 'ReferencedBrachyAccessoryDeviceNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(3008,0122)', tag_sym: :referenced_brachy_accessory_device_number, tag_ndm: '30080122', tag_ary: [0x3008,0x0122], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0130)', tag_name: "Recorded Channel Sequence", tag_key: 'RecordedChannelSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3008,0130)', tag_sym: :recorded_channel_sequence, tag_ndm: '30080130', tag_ary: [0x3008,0x0130], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0132)', tag_name: "Specified Channel Total Time", tag_key: 'SpecifiedChannelTotalTime', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(3008,0132)', tag_sym: :specified_channel_total_time, tag_ndm: '30080132', tag_ary: [0x3008,0x0132], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0134)', tag_name: "Delivered Channel Total Time", tag_key: 'DeliveredChannelTotalTime', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(3008,0134)', tag_sym: :delivered_channel_total_time, tag_ndm: '30080134', tag_ary: [0x3008,0x0134], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0136)', tag_name: "Specified Number of Pulses", tag_key: 'SpecifiedNumberOfPulses', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(3008,0136)', tag_sym: :specified_number_of_pulses, tag_ndm: '30080136', tag_ary: [0x3008,0x0136], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0138)', tag_name: "Delivered Number of Pulses", tag_key: 'DeliveredNumberOfPulses', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(3008,0138)', tag_sym: :delivered_number_of_pulses, tag_ndm: '30080138', tag_ary: [0x3008,0x0138], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,013A)', tag_name: "Specified Pulse Repetition Interval", tag_key: 'SpecifiedPulseRepetitionInterval', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(3008,013A)', tag_sym: :specified_pulse_repetition_interval, tag_ndm: '3008013A', tag_ary: [0x3008,0x013A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,013C)', tag_name: "Delivered Pulse Repetition Interval", tag_key: 'DeliveredPulseRepetitionInterval', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(3008,013C)', tag_sym: :delivered_pulse_repetition_interval, tag_ndm: '3008013C', tag_ary: [0x3008,0x013C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0140)', tag_name: "Recorded Source Applicator Sequence", tag_key: 'RecordedSourceApplicatorSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3008,0140)', tag_sym: :recorded_source_applicator_sequence, tag_ndm: '30080140', tag_ary: [0x3008,0x0140], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0142)', tag_name: "Referenced Source Applicator Number", tag_key: 'ReferencedSourceApplicatorNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(3008,0142)', tag_sym: :referenced_source_applicator_number, tag_ndm: '30080142', tag_ary: [0x3008,0x0142], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0150)', tag_name: "Recorded Channel Shield Sequence", tag_key: 'RecordedChannelShieldSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3008,0150)', tag_sym: :recorded_channel_shield_sequence, tag_ndm: '30080150', tag_ary: [0x3008,0x0150], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0152)', tag_name: "Referenced Channel Shield Number", tag_key: 'ReferencedChannelShieldNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(3008,0152)', tag_sym: :referenced_channel_shield_number, tag_ndm: '30080152', tag_ary: [0x3008,0x0152], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0160)', tag_name: "Brachy Control Point Delivered Sequence", tag_key: 'BrachyControlPointDeliveredSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3008,0160)', tag_sym: :brachy_control_point_delivered_sequence, tag_ndm: '30080160', tag_ary: [0x3008,0x0160], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0162)', tag_name: "Safe Position Exit Date", tag_key: 'SafePositionExitDate', tag_vr: [:DA], tag_vm: ["1"], tag_str: '(3008,0162)', tag_sym: :safe_position_exit_date, tag_ndm: '30080162', tag_ary: [0x3008,0x0162], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0164)', tag_name: "Safe Position Exit Time", tag_key: 'SafePositionExitTime', tag_vr: [:TM], tag_vm: ["1"], tag_str: '(3008,0164)', tag_sym: :safe_position_exit_time, tag_ndm: '30080164', tag_ary: [0x3008,0x0164], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0166)', tag_name: "Safe Position Return Date", tag_key: 'SafePositionReturnDate', tag_vr: [:DA], tag_vm: ["1"], tag_str: '(3008,0166)', tag_sym: :safe_position_return_date, tag_ndm: '30080166', tag_ary: [0x3008,0x0166], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0168)', tag_name: "Safe Position Return Time", tag_key: 'SafePositionReturnTime', tag_vr: [:TM], tag_vm: ["1"], tag_str: '(3008,0168)', tag_sym: :safe_position_return_time, tag_ndm: '30080168', tag_ary: [0x3008,0x0168], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0171)', tag_name: "Pulse Specific Brachy Control Point Delivered Sequence", tag_key: 'PulseSpecificBrachyControlPointDeliveredSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3008,0171)', tag_sym: :pulse_specific_brachy_control_point_delivered_sequence, tag_ndm: '30080171', tag_ary: [0x3008,0x0171], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0172)', tag_name: "Pulse Number", tag_key: 'PulseNumber', tag_vr: [:US], tag_vm: ["1"], tag_str: '(3008,0172)', tag_sym: :pulse_number, tag_ndm: '30080172', tag_ary: [0x3008,0x0172], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0173)', tag_name: "Brachy Pulse Control Point Delivered Sequence", tag_key: 'BrachyPulseControlPointDeliveredSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3008,0173)', tag_sym: :brachy_pulse_control_point_delivered_sequence, tag_ndm: '30080173', tag_ary: [0x3008,0x0173], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0200)', tag_name: "Current Treatment Status", tag_key: 'CurrentTreatmentStatus', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(3008,0200)', tag_sym: :current_treatment_status, tag_ndm: '30080200', tag_ary: [0x3008,0x0200], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0202)', tag_name: "Treatment Status Comment", tag_key: 'TreatmentStatusComment', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(3008,0202)', tag_sym: :treatment_status_comment, tag_ndm: '30080202', tag_ary: [0x3008,0x0202], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0220)', tag_name: "Fraction Group Summary Sequence", tag_key: 'FractionGroupSummarySequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3008,0220)', tag_sym: :fraction_group_summary_sequence, tag_ndm: '30080220', tag_ary: [0x3008,0x0220], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0223)', tag_name: "Referenced Fraction Number", tag_key: 'ReferencedFractionNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(3008,0223)', tag_sym: :referenced_fraction_number, tag_ndm: '30080223', tag_ary: [0x3008,0x0223], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0224)', tag_name: "Fraction Group Type", tag_key: 'FractionGroupType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(3008,0224)', tag_sym: :fraction_group_type, tag_ndm: '30080224', tag_ary: [0x3008,0x0224], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0230)', tag_name: "Beam Stopper Position", tag_key: 'BeamStopperPosition', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(3008,0230)', tag_sym: :beam_stopper_position, tag_ndm: '30080230', tag_ary: [0x3008,0x0230], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0240)', tag_name: "Fraction Status Summary Sequence", tag_key: 'FractionStatusSummarySequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3008,0240)', tag_sym: :fraction_status_summary_sequence, tag_ndm: '30080240', tag_ary: [0x3008,0x0240], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0250)', tag_name: "Treatment Date", tag_key: 'TreatmentDate', tag_vr: [:DA], tag_vm: ["1"], tag_str: '(3008,0250)', tag_sym: :treatment_date, tag_ndm: '30080250', tag_ary: [0x3008,0x0250], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3008,0251)', tag_name: "Treatment Time", tag_key: 'TreatmentTime', tag_vr: [:TM], tag_vm: ["1"], tag_str: '(3008,0251)', tag_sym: :treatment_time, tag_ndm: '30080251', tag_ary: [0x3008,0x0251], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0002)', tag_name: "RT Plan Label", tag_key: 'RTPlanLabel', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(300A,0002)', tag_sym: :rt_plan_label, tag_ndm: '300A0002', tag_ary: [0x300A,0x0002], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0003)', tag_name: "RT Plan Name", tag_key: 'RTPlanName', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(300A,0003)', tag_sym: :rt_plan_name, tag_ndm: '300A0003', tag_ary: [0x300A,0x0003], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0004)', tag_name: "RT Plan Description", tag_key: 'RTPlanDescription', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(300A,0004)', tag_sym: :rt_plan_description, tag_ndm: '300A0004', tag_ary: [0x300A,0x0004], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0006)', tag_name: "RT Plan Date", tag_key: 'RTPlanDate', tag_vr: [:DA], tag_vm: ["1"], tag_str: '(300A,0006)', tag_sym: :rt_plan_date, tag_ndm: '300A0006', tag_ary: [0x300A,0x0006], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0007)', tag_name: "RT Plan Time", tag_key: 'RTPlanTime', tag_vr: [:TM], tag_vm: ["1"], tag_str: '(300A,0007)', tag_sym: :rt_plan_time, tag_ndm: '300A0007', tag_ary: [0x300A,0x0007], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0009)', tag_name: "Treatment Protocols", tag_key: 'TreatmentProtocols', tag_vr: [:LO], tag_vm: ["1-n"], tag_str: '(300A,0009)', tag_sym: :treatment_protocols, tag_ndm: '300A0009', tag_ary: [0x300A,0x0009], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,000A)', tag_name: "Plan Intent", tag_key: 'PlanIntent', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,000A)', tag_sym: :plan_intent, tag_ndm: '300A000A', tag_ary: [0x300A,0x000A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,000B)', tag_name: "Treatment Sites", tag_key: 'TreatmentSites', tag_vr: [:LO], tag_vm: ["1-n"], tag_str: '(300A,000B)', tag_sym: :treatment_sites, tag_ndm: '300A000B', tag_ary: [0x300A,0x000B], tag_multiple: false, tag_note: 'RET (2021e)'},
      { tag_ps: '(300A,000C)', tag_name: "RT Plan Geometry", tag_key: 'RTPlanGeometry', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,000C)', tag_sym: :rt_plan_geometry, tag_ndm: '300A000C', tag_ary: [0x300A,0x000C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,000E)', tag_name: "Prescription Description", tag_key: 'PrescriptionDescription', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(300A,000E)', tag_sym: :prescription_description, tag_ndm: '300A000E', tag_ary: [0x300A,0x000E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0010)', tag_name: "Dose Reference Sequence", tag_key: 'DoseReferenceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0010)', tag_sym: :dose_reference_sequence, tag_ndm: '300A0010', tag_ary: [0x300A,0x0010], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0012)', tag_name: "Dose Reference Number", tag_key: 'DoseReferenceNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300A,0012)', tag_sym: :dose_reference_number, tag_ndm: '300A0012', tag_ary: [0x300A,0x0012], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0013)', tag_name: "Dose Reference UID", tag_key: 'DoseReferenceUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(300A,0013)', tag_sym: :dose_reference_uid, tag_ndm: '300A0013', tag_ary: [0x300A,0x0013], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0014)', tag_name: "Dose Reference Structure Type", tag_key: 'DoseReferenceStructureType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,0014)', tag_sym: :dose_reference_structure_type, tag_ndm: '300A0014', tag_ary: [0x300A,0x0014], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0015)', tag_name: "Nominal Beam Energy Unit", tag_key: 'NominalBeamEnergyUnit', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,0015)', tag_sym: :nominal_beam_energy_unit, tag_ndm: '300A0015', tag_ary: [0x300A,0x0015], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0016)', tag_name: "Dose Reference Description", tag_key: 'DoseReferenceDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(300A,0016)', tag_sym: :dose_reference_description, tag_ndm: '300A0016', tag_ary: [0x300A,0x0016], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0018)', tag_name: "Dose Reference Point Coordinates", tag_key: 'DoseReferencePointCoordinates', tag_vr: [:DS], tag_vm: ["3"], tag_str: '(300A,0018)', tag_sym: :dose_reference_point_coordinates, tag_ndm: '300A0018', tag_ary: [0x300A,0x0018], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,001A)', tag_name: "Nominal Prior Dose", tag_key: 'NominalPriorDose', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,001A)', tag_sym: :nominal_prior_dose, tag_ndm: '300A001A', tag_ary: [0x300A,0x001A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0020)', tag_name: "Dose Reference Type", tag_key: 'DoseReferenceType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,0020)', tag_sym: :dose_reference_type, tag_ndm: '300A0020', tag_ary: [0x300A,0x0020], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0021)', tag_name: "Constraint Weight", tag_key: 'ConstraintWeight', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,0021)', tag_sym: :constraint_weight, tag_ndm: '300A0021', tag_ary: [0x300A,0x0021], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0022)', tag_name: "Delivery Warning Dose", tag_key: 'DeliveryWarningDose', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,0022)', tag_sym: :delivery_warning_dose, tag_ndm: '300A0022', tag_ary: [0x300A,0x0022], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0023)', tag_name: "Delivery Maximum Dose", tag_key: 'DeliveryMaximumDose', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,0023)', tag_sym: :delivery_maximum_dose, tag_ndm: '300A0023', tag_ary: [0x300A,0x0023], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0025)', tag_name: "Target Minimum Dose", tag_key: 'TargetMinimumDose', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,0025)', tag_sym: :target_minimum_dose, tag_ndm: '300A0025', tag_ary: [0x300A,0x0025], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0026)', tag_name: "Target Prescription Dose", tag_key: 'TargetPrescriptionDose', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,0026)', tag_sym: :target_prescription_dose, tag_ndm: '300A0026', tag_ary: [0x300A,0x0026], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0027)', tag_name: "Target Maximum Dose", tag_key: 'TargetMaximumDose', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,0027)', tag_sym: :target_maximum_dose, tag_ndm: '300A0027', tag_ary: [0x300A,0x0027], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0028)', tag_name: "Target Underdose Volume Fraction", tag_key: 'TargetUnderdoseVolumeFraction', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,0028)', tag_sym: :target_underdose_volume_fraction, tag_ndm: '300A0028', tag_ary: [0x300A,0x0028], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,002A)', tag_name: "Organ at Risk Full-volume Dose", tag_key: 'OrganAtRiskFullVolumeDose', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,002A)', tag_sym: :organ_at_risk_full_volume_dose, tag_ndm: '300A002A', tag_ary: [0x300A,0x002A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,002B)', tag_name: "Organ at Risk Limit Dose", tag_key: 'OrganAtRiskLimitDose', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,002B)', tag_sym: :organ_at_risk_limit_dose, tag_ndm: '300A002B', tag_ary: [0x300A,0x002B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,002C)', tag_name: "Organ at Risk Maximum Dose", tag_key: 'OrganAtRiskMaximumDose', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,002C)', tag_sym: :organ_at_risk_maximum_dose, tag_ndm: '300A002C', tag_ary: [0x300A,0x002C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,002D)', tag_name: "Organ at Risk Overdose Volume Fraction", tag_key: 'OrganAtRiskOverdoseVolumeFraction', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,002D)', tag_sym: :organ_at_risk_overdose_volume_fraction, tag_ndm: '300A002D', tag_ary: [0x300A,0x002D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0040)', tag_name: "Tolerance Table Sequence", tag_key: 'ToleranceTableSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0040)', tag_sym: :tolerance_table_sequence, tag_ndm: '300A0040', tag_ary: [0x300A,0x0040], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0042)', tag_name: "Tolerance Table Number", tag_key: 'ToleranceTableNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300A,0042)', tag_sym: :tolerance_table_number, tag_ndm: '300A0042', tag_ary: [0x300A,0x0042], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0043)', tag_name: "Tolerance Table Label", tag_key: 'ToleranceTableLabel', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(300A,0043)', tag_sym: :tolerance_table_label, tag_ndm: '300A0043', tag_ary: [0x300A,0x0043], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0044)', tag_name: "Gantry Angle Tolerance", tag_key: 'GantryAngleTolerance', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,0044)', tag_sym: :gantry_angle_tolerance, tag_ndm: '300A0044', tag_ary: [0x300A,0x0044], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0046)', tag_name: "Beam Limiting Device Angle Tolerance", tag_key: 'BeamLimitingDeviceAngleTolerance', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,0046)', tag_sym: :beam_limiting_device_angle_tolerance, tag_ndm: '300A0046', tag_ary: [0x300A,0x0046], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0048)', tag_name: "Beam Limiting Device Tolerance Sequence", tag_key: 'BeamLimitingDeviceToleranceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0048)', tag_sym: :beam_limiting_device_tolerance_sequence, tag_ndm: '300A0048', tag_ary: [0x300A,0x0048], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,004A)', tag_name: "Beam Limiting Device Position Tolerance", tag_key: 'BeamLimitingDevicePositionTolerance', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,004A)', tag_sym: :beam_limiting_device_position_tolerance, tag_ndm: '300A004A', tag_ary: [0x300A,0x004A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,004B)', tag_name: "Snout Position Tolerance", tag_key: 'SnoutPositionTolerance', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(300A,004B)', tag_sym: :snout_position_tolerance, tag_ndm: '300A004B', tag_ary: [0x300A,0x004B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,004C)', tag_name: "Patient Support Angle Tolerance", tag_key: 'PatientSupportAngleTolerance', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,004C)', tag_sym: :patient_support_angle_tolerance, tag_ndm: '300A004C', tag_ary: [0x300A,0x004C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,004E)', tag_name: "Table Top Eccentric Angle Tolerance", tag_key: 'TableTopEccentricAngleTolerance', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,004E)', tag_sym: :table_top_eccentric_angle_tolerance, tag_ndm: '300A004E', tag_ary: [0x300A,0x004E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,004F)', tag_name: "Table Top Pitch Angle Tolerance", tag_key: 'TableTopPitchAngleTolerance', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(300A,004F)', tag_sym: :table_top_pitch_angle_tolerance, tag_ndm: '300A004F', tag_ary: [0x300A,0x004F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0050)', tag_name: "Table Top Roll Angle Tolerance", tag_key: 'TableTopRollAngleTolerance', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(300A,0050)', tag_sym: :table_top_roll_angle_tolerance, tag_ndm: '300A0050', tag_ary: [0x300A,0x0050], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0051)', tag_name: "Table Top Vertical Position Tolerance", tag_key: 'TableTopVerticalPositionTolerance', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,0051)', tag_sym: :table_top_vertical_position_tolerance, tag_ndm: '300A0051', tag_ary: [0x300A,0x0051], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0052)', tag_name: "Table Top Longitudinal Position Tolerance", tag_key: 'TableTopLongitudinalPositionTolerance', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,0052)', tag_sym: :table_top_longitudinal_position_tolerance, tag_ndm: '300A0052', tag_ary: [0x300A,0x0052], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0053)', tag_name: "Table Top Lateral Position Tolerance", tag_key: 'TableTopLateralPositionTolerance', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,0053)', tag_sym: :table_top_lateral_position_tolerance, tag_ndm: '300A0053', tag_ary: [0x300A,0x0053], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0054)', tag_name: "Table Top Position Alignment UID", tag_key: 'TableTopPositionAlignmentUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(300A,0054)', tag_sym: :table_top_position_alignment_uid, tag_ndm: '300A0054', tag_ary: [0x300A,0x0054], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0055)', tag_name: "RT Plan Relationship", tag_key: 'RTPlanRelationship', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,0055)', tag_sym: :rt_plan_relationship, tag_ndm: '300A0055', tag_ary: [0x300A,0x0055], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0070)', tag_name: "Fraction Group Sequence", tag_key: 'FractionGroupSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0070)', tag_sym: :fraction_group_sequence, tag_ndm: '300A0070', tag_ary: [0x300A,0x0070], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0071)', tag_name: "Fraction Group Number", tag_key: 'FractionGroupNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300A,0071)', tag_sym: :fraction_group_number, tag_ndm: '300A0071', tag_ary: [0x300A,0x0071], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0072)', tag_name: "Fraction Group Description", tag_key: 'FractionGroupDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(300A,0072)', tag_sym: :fraction_group_description, tag_ndm: '300A0072', tag_ary: [0x300A,0x0072], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0078)', tag_name: "Number of Fractions Planned", tag_key: 'NumberOfFractionsPlanned', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300A,0078)', tag_sym: :number_of_fractions_planned, tag_ndm: '300A0078', tag_ary: [0x300A,0x0078], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0079)', tag_name: "Number of Fraction Pattern Digits Per Day", tag_key: 'NumberOfFractionPatternDigitsPerDay', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300A,0079)', tag_sym: :number_of_fraction_pattern_digits_per_day, tag_ndm: '300A0079', tag_ary: [0x300A,0x0079], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,007A)', tag_name: "Repeat Fraction Cycle Length", tag_key: 'RepeatFractionCycleLength', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300A,007A)', tag_sym: :repeat_fraction_cycle_length, tag_ndm: '300A007A', tag_ary: [0x300A,0x007A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,007B)', tag_name: "Fraction Pattern", tag_key: 'FractionPattern', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(300A,007B)', tag_sym: :fraction_pattern, tag_ndm: '300A007B', tag_ary: [0x300A,0x007B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0080)', tag_name: "Number of Beams", tag_key: 'NumberOfBeams', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300A,0080)', tag_sym: :number_of_beams, tag_ndm: '300A0080', tag_ary: [0x300A,0x0080], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0082)', tag_name: "Beam Dose Specification Point", tag_key: 'BeamDoseSpecificationPoint', tag_vr: [:DS], tag_vm: ["3"], tag_str: '(300A,0082)', tag_sym: :beam_dose_specification_point, tag_ndm: '300A0082', tag_ary: [0x300A,0x0082], tag_multiple: false, tag_note: 'RET (2019c)'},
      { tag_ps: '(300A,0083)', tag_name: "Referenced Dose Reference UID", tag_key: 'ReferencedDoseReferenceUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(300A,0083)', tag_sym: :referenced_dose_reference_uid, tag_ndm: '300A0083', tag_ary: [0x300A,0x0083], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0084)', tag_name: "Beam Dose", tag_key: 'BeamDose', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,0084)', tag_sym: :beam_dose, tag_ndm: '300A0084', tag_ary: [0x300A,0x0084], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0086)', tag_name: "Beam Meterset", tag_key: 'BeamMeterset', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,0086)', tag_sym: :beam_meterset, tag_ndm: '300A0086', tag_ary: [0x300A,0x0086], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0088)', tag_name: "Beam Dose Point Depth", tag_key: 'BeamDosePointDepth', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(300A,0088)', tag_sym: :beam_dose_point_depth, tag_ndm: '300A0088', tag_ary: [0x300A,0x0088], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0089)', tag_name: "Beam Dose Point Equivalent Depth", tag_key: 'BeamDosePointEquivalentDepth', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(300A,0089)', tag_sym: :beam_dose_point_equivalent_depth, tag_ndm: '300A0089', tag_ary: [0x300A,0x0089], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,008A)', tag_name: "Beam Dose Point SSD", tag_key: 'BeamDosePointSSD', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(300A,008A)', tag_sym: :beam_dose_point_ssd, tag_ndm: '300A008A', tag_ary: [0x300A,0x008A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,008B)', tag_name: "Beam Dose Meaning", tag_key: 'BeamDoseMeaning', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,008B)', tag_sym: :beam_dose_meaning, tag_ndm: '300A008B', tag_ary: [0x300A,0x008B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,008C)', tag_name: "Beam Dose Verification Control Point Sequence", tag_key: 'BeamDoseVerificationControlPointSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,008C)', tag_sym: :beam_dose_verification_control_point_sequence, tag_ndm: '300A008C', tag_ary: [0x300A,0x008C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,008D)', tag_name: "Average Beam Dose Point Depth", tag_key: 'AverageBeamDosePointDepth', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(300A,008D)', tag_sym: :average_beam_dose_point_depth, tag_ndm: '300A008D', tag_ary: [0x300A,0x008D], tag_multiple: false, tag_note: 'RET (2017c)'},
      { tag_ps: '(300A,008E)', tag_name: "Average Beam Dose Point Equivalent Depth", tag_key: 'AverageBeamDosePointEquivalentDepth', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(300A,008E)', tag_sym: :average_beam_dose_point_equivalent_depth, tag_ndm: '300A008E', tag_ary: [0x300A,0x008E], tag_multiple: false, tag_note: 'RET (2017c)'},
      { tag_ps: '(300A,008F)', tag_name: "Average Beam Dose Point SSD", tag_key: 'AverageBeamDosePointSSD', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(300A,008F)', tag_sym: :average_beam_dose_point_ssd, tag_ndm: '300A008F', tag_ary: [0x300A,0x008F], tag_multiple: false, tag_note: 'RET (2017c)'},
      { tag_ps: '(300A,0090)', tag_name: "Beam Dose Type", tag_key: 'BeamDoseType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,0090)', tag_sym: :beam_dose_type, tag_ndm: '300A0090', tag_ary: [0x300A,0x0090], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0091)', tag_name: "Alternate Beam Dose", tag_key: 'AlternateBeamDose', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,0091)', tag_sym: :alternate_beam_dose, tag_ndm: '300A0091', tag_ary: [0x300A,0x0091], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0092)', tag_name: "Alternate Beam Dose Type", tag_key: 'AlternateBeamDoseType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,0092)', tag_sym: :alternate_beam_dose_type, tag_ndm: '300A0092', tag_ary: [0x300A,0x0092], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0093)', tag_name: "Depth Value Averaging Flag", tag_key: 'DepthValueAveragingFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,0093)', tag_sym: :depth_value_averaging_flag, tag_ndm: '300A0093', tag_ary: [0x300A,0x0093], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0094)', tag_name: "Beam Dose Point Source to External Contour Distance", tag_key: 'BeamDosePointSourceToExternalContourDistance', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,0094)', tag_sym: :beam_dose_point_source_to_external_contour_distance, tag_ndm: '300A0094', tag_ary: [0x300A,0x0094], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00A0)', tag_name: "Number of Brachy Application Setups", tag_key: 'NumberOfBrachyApplicationSetups', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300A,00A0)', tag_sym: :number_of_brachy_application_setups, tag_ndm: '300A00A0', tag_ary: [0x300A,0x00A0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00A2)', tag_name: "Brachy Application Setup Dose Specification Point", tag_key: 'BrachyApplicationSetupDoseSpecificationPoint', tag_vr: [:DS], tag_vm: ["3"], tag_str: '(300A,00A2)', tag_sym: :brachy_application_setup_dose_specification_point, tag_ndm: '300A00A2', tag_ary: [0x300A,0x00A2], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00A4)', tag_name: "Brachy Application Setup Dose", tag_key: 'BrachyApplicationSetupDose', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,00A4)', tag_sym: :brachy_application_setup_dose, tag_ndm: '300A00A4', tag_ary: [0x300A,0x00A4], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00B0)', tag_name: "Beam Sequence", tag_key: 'BeamSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,00B0)', tag_sym: :beam_sequence, tag_ndm: '300A00B0', tag_ary: [0x300A,0x00B0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00B2)', tag_name: "Treatment Machine Name", tag_key: 'TreatmentMachineName', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(300A,00B2)', tag_sym: :treatment_machine_name, tag_ndm: '300A00B2', tag_ary: [0x300A,0x00B2], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00B3)', tag_name: "Primary Dosimeter Unit", tag_key: 'PrimaryDosimeterUnit', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,00B3)', tag_sym: :primary_dosimeter_unit, tag_ndm: '300A00B3', tag_ary: [0x300A,0x00B3], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00B4)', tag_name: "Source-Axis Distance", tag_key: 'SourceAxisDistance', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,00B4)', tag_sym: :source_axis_distance, tag_ndm: '300A00B4', tag_ary: [0x300A,0x00B4], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00B6)', tag_name: "Beam Limiting Device Sequence", tag_key: 'BeamLimitingDeviceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,00B6)', tag_sym: :beam_limiting_device_sequence, tag_ndm: '300A00B6', tag_ary: [0x300A,0x00B6], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00B8)', tag_name: "RT Beam Limiting Device Type", tag_key: 'RTBeamLimitingDeviceType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,00B8)', tag_sym: :rt_beam_limiting_device_type, tag_ndm: '300A00B8', tag_ary: [0x300A,0x00B8], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00BA)', tag_name: "Source to Beam Limiting Device Distance", tag_key: 'SourceToBeamLimitingDeviceDistance', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,00BA)', tag_sym: :source_to_beam_limiting_device_distance, tag_ndm: '300A00BA', tag_ary: [0x300A,0x00BA], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00BB)', tag_name: "Isocenter to Beam Limiting Device Distance", tag_key: 'IsocenterToBeamLimitingDeviceDistance', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(300A,00BB)', tag_sym: :isocenter_to_beam_limiting_device_distance, tag_ndm: '300A00BB', tag_ary: [0x300A,0x00BB], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00BC)', tag_name: "Number of Leaf/Jaw Pairs", tag_key: 'NumberOfLeafJawPairs', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300A,00BC)', tag_sym: :number_of_leaf_jaw_pairs, tag_ndm: '300A00BC', tag_ary: [0x300A,0x00BC], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00BE)', tag_name: "Leaf Position Boundaries", tag_key: 'LeafPositionBoundaries', tag_vr: [:DS], tag_vm: ["3-n"], tag_str: '(300A,00BE)', tag_sym: :leaf_position_boundaries, tag_ndm: '300A00BE', tag_ary: [0x300A,0x00BE], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00C0)', tag_name: "Beam Number", tag_key: 'BeamNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300A,00C0)', tag_sym: :beam_number, tag_ndm: '300A00C0', tag_ary: [0x300A,0x00C0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00C2)', tag_name: "Beam Name", tag_key: 'BeamName', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(300A,00C2)', tag_sym: :beam_name, tag_ndm: '300A00C2', tag_ary: [0x300A,0x00C2], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00C3)', tag_name: "Beam Description", tag_key: 'BeamDescription', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(300A,00C3)', tag_sym: :beam_description, tag_ndm: '300A00C3', tag_ary: [0x300A,0x00C3], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00C4)', tag_name: "Beam Type", tag_key: 'BeamType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,00C4)', tag_sym: :beam_type, tag_ndm: '300A00C4', tag_ary: [0x300A,0x00C4], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00C5)', tag_name: "Beam Delivery Duration Limit", tag_key: 'BeamDeliveryDurationLimit', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(300A,00C5)', tag_sym: :beam_delivery_duration_limit, tag_ndm: '300A00C5', tag_ary: [0x300A,0x00C5], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00C6)', tag_name: "Radiation Type", tag_key: 'RadiationType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,00C6)', tag_sym: :radiation_type, tag_ndm: '300A00C6', tag_ary: [0x300A,0x00C6], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00C7)', tag_name: "High-Dose Technique Type", tag_key: 'HighDoseTechniqueType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,00C7)', tag_sym: :high_dose_technique_type, tag_ndm: '300A00C7', tag_ary: [0x300A,0x00C7], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00C8)', tag_name: "Reference Image Number", tag_key: 'ReferenceImageNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300A,00C8)', tag_sym: :reference_image_number, tag_ndm: '300A00C8', tag_ary: [0x300A,0x00C8], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00CA)', tag_name: "Planned Verification Image Sequence", tag_key: 'PlannedVerificationImageSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,00CA)', tag_sym: :planned_verification_image_sequence, tag_ndm: '300A00CA', tag_ary: [0x300A,0x00CA], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00CC)', tag_name: "Imaging Device-Specific Acquisition Parameters", tag_key: 'ImagingDeviceSpecificAcquisitionParameters', tag_vr: [:LO], tag_vm: ["1-n"], tag_str: '(300A,00CC)', tag_sym: :imaging_device_specific_acquisition_parameters, tag_ndm: '300A00CC', tag_ary: [0x300A,0x00CC], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00CE)', tag_name: "Treatment Delivery Type", tag_key: 'TreatmentDeliveryType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,00CE)', tag_sym: :treatment_delivery_type, tag_ndm: '300A00CE', tag_ary: [0x300A,0x00CE], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00D0)', tag_name: "Number of Wedges", tag_key: 'NumberOfWedges', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300A,00D0)', tag_sym: :number_of_wedges, tag_ndm: '300A00D0', tag_ary: [0x300A,0x00D0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00D1)', tag_name: "Wedge Sequence", tag_key: 'WedgeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,00D1)', tag_sym: :wedge_sequence, tag_ndm: '300A00D1', tag_ary: [0x300A,0x00D1], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00D2)', tag_name: "Wedge Number", tag_key: 'WedgeNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300A,00D2)', tag_sym: :wedge_number, tag_ndm: '300A00D2', tag_ary: [0x300A,0x00D2], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00D3)', tag_name: "Wedge Type", tag_key: 'WedgeType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,00D3)', tag_sym: :wedge_type, tag_ndm: '300A00D3', tag_ary: [0x300A,0x00D3], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00D4)', tag_name: "Wedge ID", tag_key: 'WedgeID', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(300A,00D4)', tag_sym: :wedge_id, tag_ndm: '300A00D4', tag_ary: [0x300A,0x00D4], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00D5)', tag_name: "Wedge Angle", tag_key: 'WedgeAngle', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300A,00D5)', tag_sym: :wedge_angle, tag_ndm: '300A00D5', tag_ary: [0x300A,0x00D5], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00D6)', tag_name: "Wedge Factor", tag_key: 'WedgeFactor', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,00D6)', tag_sym: :wedge_factor, tag_ndm: '300A00D6', tag_ary: [0x300A,0x00D6], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00D7)', tag_name: "Total Wedge Tray Water-Equivalent Thickness", tag_key: 'TotalWedgeTrayWaterEquivalentThickness', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(300A,00D7)', tag_sym: :total_wedge_tray_water_equivalent_thickness, tag_ndm: '300A00D7', tag_ary: [0x300A,0x00D7], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00D8)', tag_name: "Wedge Orientation", tag_key: 'WedgeOrientation', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,00D8)', tag_sym: :wedge_orientation, tag_ndm: '300A00D8', tag_ary: [0x300A,0x00D8], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00D9)', tag_name: "Isocenter to Wedge Tray Distance", tag_key: 'IsocenterToWedgeTrayDistance', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(300A,00D9)', tag_sym: :isocenter_to_wedge_tray_distance, tag_ndm: '300A00D9', tag_ary: [0x300A,0x00D9], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00DA)', tag_name: "Source to Wedge Tray Distance", tag_key: 'SourceToWedgeTrayDistance', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,00DA)', tag_sym: :source_to_wedge_tray_distance, tag_ndm: '300A00DA', tag_ary: [0x300A,0x00DA], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00DB)', tag_name: "Wedge Thin Edge Position", tag_key: 'WedgeThinEdgePosition', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(300A,00DB)', tag_sym: :wedge_thin_edge_position, tag_ndm: '300A00DB', tag_ary: [0x300A,0x00DB], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00DC)', tag_name: "Bolus ID", tag_key: 'BolusID', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(300A,00DC)', tag_sym: :bolus_id, tag_ndm: '300A00DC', tag_ary: [0x300A,0x00DC], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00DD)', tag_name: "Bolus Description", tag_key: 'BolusDescription', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(300A,00DD)', tag_sym: :bolus_description, tag_ndm: '300A00DD', tag_ary: [0x300A,0x00DD], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00DE)', tag_name: "Effective Wedge Angle", tag_key: 'EffectiveWedgeAngle', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,00DE)', tag_sym: :effective_wedge_angle, tag_ndm: '300A00DE', tag_ary: [0x300A,0x00DE], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00E0)', tag_name: "Number of Compensators", tag_key: 'NumberOfCompensators', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300A,00E0)', tag_sym: :number_of_compensators, tag_ndm: '300A00E0', tag_ary: [0x300A,0x00E0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00E1)', tag_name: "Material ID", tag_key: 'MaterialID', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(300A,00E1)', tag_sym: :material_id, tag_ndm: '300A00E1', tag_ary: [0x300A,0x00E1], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00E2)', tag_name: "Total Compensator Tray Factor", tag_key: 'TotalCompensatorTrayFactor', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,00E2)', tag_sym: :total_compensator_tray_factor, tag_ndm: '300A00E2', tag_ary: [0x300A,0x00E2], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00E3)', tag_name: "Compensator Sequence", tag_key: 'CompensatorSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,00E3)', tag_sym: :compensator_sequence, tag_ndm: '300A00E3', tag_ary: [0x300A,0x00E3], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00E4)', tag_name: "Compensator Number", tag_key: 'CompensatorNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300A,00E4)', tag_sym: :compensator_number, tag_ndm: '300A00E4', tag_ary: [0x300A,0x00E4], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00E5)', tag_name: "Compensator ID", tag_key: 'CompensatorID', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(300A,00E5)', tag_sym: :compensator_id, tag_ndm: '300A00E5', tag_ary: [0x300A,0x00E5], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00E6)', tag_name: "Source to Compensator Tray Distance", tag_key: 'SourceToCompensatorTrayDistance', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,00E6)', tag_sym: :source_to_compensator_tray_distance, tag_ndm: '300A00E6', tag_ary: [0x300A,0x00E6], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00E7)', tag_name: "Compensator Rows", tag_key: 'CompensatorRows', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300A,00E7)', tag_sym: :compensator_rows, tag_ndm: '300A00E7', tag_ary: [0x300A,0x00E7], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00E8)', tag_name: "Compensator Columns", tag_key: 'CompensatorColumns', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300A,00E8)', tag_sym: :compensator_columns, tag_ndm: '300A00E8', tag_ary: [0x300A,0x00E8], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00E9)', tag_name: "Compensator Pixel Spacing", tag_key: 'CompensatorPixelSpacing', tag_vr: [:DS], tag_vm: ["2"], tag_str: '(300A,00E9)', tag_sym: :compensator_pixel_spacing, tag_ndm: '300A00E9', tag_ary: [0x300A,0x00E9], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00EA)', tag_name: "Compensator Position", tag_key: 'CompensatorPosition', tag_vr: [:DS], tag_vm: ["2"], tag_str: '(300A,00EA)', tag_sym: :compensator_position, tag_ndm: '300A00EA', tag_ary: [0x300A,0x00EA], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00EB)', tag_name: "Compensator Transmission Data", tag_key: 'CompensatorTransmissionData', tag_vr: [:DS], tag_vm: ["1-n"], tag_str: '(300A,00EB)', tag_sym: :compensator_transmission_data, tag_ndm: '300A00EB', tag_ary: [0x300A,0x00EB], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00EC)', tag_name: "Compensator Thickness Data", tag_key: 'CompensatorThicknessData', tag_vr: [:DS], tag_vm: ["1-n"], tag_str: '(300A,00EC)', tag_sym: :compensator_thickness_data, tag_ndm: '300A00EC', tag_ary: [0x300A,0x00EC], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00ED)', tag_name: "Number of Boli", tag_key: 'NumberOfBoli', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300A,00ED)', tag_sym: :number_of_boli, tag_ndm: '300A00ED', tag_ary: [0x300A,0x00ED], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00EE)', tag_name: "Compensator Type", tag_key: 'CompensatorType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,00EE)', tag_sym: :compensator_type, tag_ndm: '300A00EE', tag_ary: [0x300A,0x00EE], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00EF)', tag_name: "Compensator Tray ID", tag_key: 'CompensatorTrayID', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(300A,00EF)', tag_sym: :compensator_tray_id, tag_ndm: '300A00EF', tag_ary: [0x300A,0x00EF], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00F0)', tag_name: "Number of Blocks", tag_key: 'NumberOfBlocks', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300A,00F0)', tag_sym: :number_of_blocks, tag_ndm: '300A00F0', tag_ary: [0x300A,0x00F0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00F2)', tag_name: "Total Block Tray Factor", tag_key: 'TotalBlockTrayFactor', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,00F2)', tag_sym: :total_block_tray_factor, tag_ndm: '300A00F2', tag_ary: [0x300A,0x00F2], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00F3)', tag_name: "Total Block Tray Water-Equivalent Thickness", tag_key: 'TotalBlockTrayWaterEquivalentThickness', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(300A,00F3)', tag_sym: :total_block_tray_water_equivalent_thickness, tag_ndm: '300A00F3', tag_ary: [0x300A,0x00F3], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00F4)', tag_name: "Block Sequence", tag_key: 'BlockSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,00F4)', tag_sym: :block_sequence, tag_ndm: '300A00F4', tag_ary: [0x300A,0x00F4], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00F5)', tag_name: "Block Tray ID", tag_key: 'BlockTrayID', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(300A,00F5)', tag_sym: :block_tray_id, tag_ndm: '300A00F5', tag_ary: [0x300A,0x00F5], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00F6)', tag_name: "Source to Block Tray Distance", tag_key: 'SourceToBlockTrayDistance', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,00F6)', tag_sym: :source_to_block_tray_distance, tag_ndm: '300A00F6', tag_ary: [0x300A,0x00F6], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00F7)', tag_name: "Isocenter to Block Tray Distance", tag_key: 'IsocenterToBlockTrayDistance', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(300A,00F7)', tag_sym: :isocenter_to_block_tray_distance, tag_ndm: '300A00F7', tag_ary: [0x300A,0x00F7], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00F8)', tag_name: "Block Type", tag_key: 'BlockType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,00F8)', tag_sym: :block_type, tag_ndm: '300A00F8', tag_ary: [0x300A,0x00F8], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00F9)', tag_name: "Accessory Code", tag_key: 'AccessoryCode', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(300A,00F9)', tag_sym: :accessory_code, tag_ndm: '300A00F9', tag_ary: [0x300A,0x00F9], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00FA)', tag_name: "Block Divergence", tag_key: 'BlockDivergence', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,00FA)', tag_sym: :block_divergence, tag_ndm: '300A00FA', tag_ary: [0x300A,0x00FA], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00FB)', tag_name: "Block Mounting Position", tag_key: 'BlockMountingPosition', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,00FB)', tag_sym: :block_mounting_position, tag_ndm: '300A00FB', tag_ary: [0x300A,0x00FB], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00FC)', tag_name: "Block Number", tag_key: 'BlockNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300A,00FC)', tag_sym: :block_number, tag_ndm: '300A00FC', tag_ary: [0x300A,0x00FC], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,00FE)', tag_name: "Block Name", tag_key: 'BlockName', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(300A,00FE)', tag_sym: :block_name, tag_ndm: '300A00FE', tag_ary: [0x300A,0x00FE], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0100)', tag_name: "Block Thickness", tag_key: 'BlockThickness', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,0100)', tag_sym: :block_thickness, tag_ndm: '300A0100', tag_ary: [0x300A,0x0100], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0102)', tag_name: "Block Transmission", tag_key: 'BlockTransmission', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,0102)', tag_sym: :block_transmission, tag_ndm: '300A0102', tag_ary: [0x300A,0x0102], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0104)', tag_name: "Block Number of Points", tag_key: 'BlockNumberOfPoints', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300A,0104)', tag_sym: :block_number_of_points, tag_ndm: '300A0104', tag_ary: [0x300A,0x0104], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0106)', tag_name: "Block Data", tag_key: 'BlockData', tag_vr: [:DS], tag_vm: ["2-2n"], tag_str: '(300A,0106)', tag_sym: :block_data, tag_ndm: '300A0106', tag_ary: [0x300A,0x0106], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0107)', tag_name: "Applicator Sequence", tag_key: 'ApplicatorSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0107)', tag_sym: :applicator_sequence, tag_ndm: '300A0107', tag_ary: [0x300A,0x0107], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0108)', tag_name: "Applicator ID", tag_key: 'ApplicatorID', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(300A,0108)', tag_sym: :applicator_id, tag_ndm: '300A0108', tag_ary: [0x300A,0x0108], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0109)', tag_name: "Applicator Type", tag_key: 'ApplicatorType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,0109)', tag_sym: :applicator_type, tag_ndm: '300A0109', tag_ary: [0x300A,0x0109], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,010A)', tag_name: "Applicator Description", tag_key: 'ApplicatorDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(300A,010A)', tag_sym: :applicator_description, tag_ndm: '300A010A', tag_ary: [0x300A,0x010A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,010C)', tag_name: "Cumulative Dose Reference Coefficient", tag_key: 'CumulativeDoseReferenceCoefficient', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,010C)', tag_sym: :cumulative_dose_reference_coefficient, tag_ndm: '300A010C', tag_ary: [0x300A,0x010C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,010E)', tag_name: "Final Cumulative Meterset Weight", tag_key: 'FinalCumulativeMetersetWeight', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,010E)', tag_sym: :final_cumulative_meterset_weight, tag_ndm: '300A010E', tag_ary: [0x300A,0x010E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0110)', tag_name: "Number of Control Points", tag_key: 'NumberOfControlPoints', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300A,0110)', tag_sym: :number_of_control_points, tag_ndm: '300A0110', tag_ary: [0x300A,0x0110], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0111)', tag_name: "Control Point Sequence", tag_key: 'ControlPointSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0111)', tag_sym: :control_point_sequence, tag_ndm: '300A0111', tag_ary: [0x300A,0x0111], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0112)', tag_name: "Control Point Index", tag_key: 'ControlPointIndex', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300A,0112)', tag_sym: :control_point_index, tag_ndm: '300A0112', tag_ary: [0x300A,0x0112], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0114)', tag_name: "Nominal Beam Energy", tag_key: 'NominalBeamEnergy', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,0114)', tag_sym: :nominal_beam_energy, tag_ndm: '300A0114', tag_ary: [0x300A,0x0114], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0115)', tag_name: "Dose Rate Set", tag_key: 'DoseRateSet', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,0115)', tag_sym: :dose_rate_set, tag_ndm: '300A0115', tag_ary: [0x300A,0x0115], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0116)', tag_name: "Wedge Position Sequence", tag_key: 'WedgePositionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0116)', tag_sym: :wedge_position_sequence, tag_ndm: '300A0116', tag_ary: [0x300A,0x0116], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0118)', tag_name: "Wedge Position", tag_key: 'WedgePosition', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,0118)', tag_sym: :wedge_position, tag_ndm: '300A0118', tag_ary: [0x300A,0x0118], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,011A)', tag_name: "Beam Limiting Device Position Sequence", tag_key: 'BeamLimitingDevicePositionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,011A)', tag_sym: :beam_limiting_device_position_sequence, tag_ndm: '300A011A', tag_ary: [0x300A,0x011A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,011C)', tag_name: "Leaf/Jaw Positions", tag_key: 'LeafJawPositions', tag_vr: [:DS], tag_vm: ["2-2n"], tag_str: '(300A,011C)', tag_sym: :leaf_jaw_positions, tag_ndm: '300A011C', tag_ary: [0x300A,0x011C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,011E)', tag_name: "Gantry Angle", tag_key: 'GantryAngle', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,011E)', tag_sym: :gantry_angle, tag_ndm: '300A011E', tag_ary: [0x300A,0x011E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,011F)', tag_name: "Gantry Rotation Direction", tag_key: 'GantryRotationDirection', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,011F)', tag_sym: :gantry_rotation_direction, tag_ndm: '300A011F', tag_ary: [0x300A,0x011F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0120)', tag_name: "Beam Limiting Device Angle", tag_key: 'BeamLimitingDeviceAngle', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,0120)', tag_sym: :beam_limiting_device_angle, tag_ndm: '300A0120', tag_ary: [0x300A,0x0120], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0121)', tag_name: "Beam Limiting Device Rotation Direction", tag_key: 'BeamLimitingDeviceRotationDirection', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,0121)', tag_sym: :beam_limiting_device_rotation_direction, tag_ndm: '300A0121', tag_ary: [0x300A,0x0121], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0122)', tag_name: "Patient Support Angle", tag_key: 'PatientSupportAngle', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,0122)', tag_sym: :patient_support_angle, tag_ndm: '300A0122', tag_ary: [0x300A,0x0122], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0123)', tag_name: "Patient Support Rotation Direction", tag_key: 'PatientSupportRotationDirection', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,0123)', tag_sym: :patient_support_rotation_direction, tag_ndm: '300A0123', tag_ary: [0x300A,0x0123], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0124)', tag_name: "Table Top Eccentric Axis Distance", tag_key: 'TableTopEccentricAxisDistance', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,0124)', tag_sym: :table_top_eccentric_axis_distance, tag_ndm: '300A0124', tag_ary: [0x300A,0x0124], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0125)', tag_name: "Table Top Eccentric Angle", tag_key: 'TableTopEccentricAngle', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,0125)', tag_sym: :table_top_eccentric_angle, tag_ndm: '300A0125', tag_ary: [0x300A,0x0125], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0126)', tag_name: "Table Top Eccentric Rotation Direction", tag_key: 'TableTopEccentricRotationDirection', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,0126)', tag_sym: :table_top_eccentric_rotation_direction, tag_ndm: '300A0126', tag_ary: [0x300A,0x0126], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0128)', tag_name: "Table Top Vertical Position", tag_key: 'TableTopVerticalPosition', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,0128)', tag_sym: :table_top_vertical_position, tag_ndm: '300A0128', tag_ary: [0x300A,0x0128], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0129)', tag_name: "Table Top Longitudinal Position", tag_key: 'TableTopLongitudinalPosition', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,0129)', tag_sym: :table_top_longitudinal_position, tag_ndm: '300A0129', tag_ary: [0x300A,0x0129], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,012A)', tag_name: "Table Top Lateral Position", tag_key: 'TableTopLateralPosition', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,012A)', tag_sym: :table_top_lateral_position, tag_ndm: '300A012A', tag_ary: [0x300A,0x012A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,012C)', tag_name: "Isocenter Position", tag_key: 'IsocenterPosition', tag_vr: [:DS], tag_vm: ["3"], tag_str: '(300A,012C)', tag_sym: :isocenter_position, tag_ndm: '300A012C', tag_ary: [0x300A,0x012C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,012E)', tag_name: "Surface Entry Point", tag_key: 'SurfaceEntryPoint', tag_vr: [:DS], tag_vm: ["3"], tag_str: '(300A,012E)', tag_sym: :surface_entry_point, tag_ndm: '300A012E', tag_ary: [0x300A,0x012E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0130)', tag_name: "Source to Surface Distance", tag_key: 'SourceToSurfaceDistance', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,0130)', tag_sym: :source_to_surface_distance, tag_ndm: '300A0130', tag_ary: [0x300A,0x0130], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0131)', tag_name: "Average Beam Dose Point Source to External Contour Distance", tag_key: 'AverageBeamDosePointSourceToExternalContourDistance', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(300A,0131)', tag_sym: :average_beam_dose_point_source_to_external_contour_distance, tag_ndm: '300A0131', tag_ary: [0x300A,0x0131], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0132)', tag_name: "Source to External Contour Distance", tag_key: 'SourceToExternalContourDistance', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(300A,0132)', tag_sym: :source_to_external_contour_distance, tag_ndm: '300A0132', tag_ary: [0x300A,0x0132], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0133)', tag_name: "External Contour Entry Point", tag_key: 'ExternalContourEntryPoint', tag_vr: [:FL], tag_vm: ["3"], tag_str: '(300A,0133)', tag_sym: :external_contour_entry_point, tag_ndm: '300A0133', tag_ary: [0x300A,0x0133], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0134)', tag_name: "Cumulative Meterset Weight", tag_key: 'CumulativeMetersetWeight', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,0134)', tag_sym: :cumulative_meterset_weight, tag_ndm: '300A0134', tag_ary: [0x300A,0x0134], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0135)', tag_name: "Placeholder (300A,0135)", tag_key: 'Placeholder_300A_0135', tag_vr: [:UN], tag_vm: ["1"], tag_str: '(300A,0135)', tag_sym: :placeholder_300a_0135, tag_ndm: '300A0135', tag_ary: [0x300A,0x0135], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(300A,0140)', tag_name: "Table Top Pitch Angle", tag_key: 'TableTopPitchAngle', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(300A,0140)', tag_sym: :table_top_pitch_angle, tag_ndm: '300A0140', tag_ary: [0x300A,0x0140], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0142)', tag_name: "Table Top Pitch Rotation Direction", tag_key: 'TableTopPitchRotationDirection', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,0142)', tag_sym: :table_top_pitch_rotation_direction, tag_ndm: '300A0142', tag_ary: [0x300A,0x0142], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0144)', tag_name: "Table Top Roll Angle", tag_key: 'TableTopRollAngle', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(300A,0144)', tag_sym: :table_top_roll_angle, tag_ndm: '300A0144', tag_ary: [0x300A,0x0144], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0146)', tag_name: "Table Top Roll Rotation Direction", tag_key: 'TableTopRollRotationDirection', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,0146)', tag_sym: :table_top_roll_rotation_direction, tag_ndm: '300A0146', tag_ary: [0x300A,0x0146], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0148)', tag_name: "Head Fixation Angle", tag_key: 'HeadFixationAngle', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(300A,0148)', tag_sym: :head_fixation_angle, tag_ndm: '300A0148', tag_ary: [0x300A,0x0148], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,014A)', tag_name: "Gantry Pitch Angle", tag_key: 'GantryPitchAngle', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(300A,014A)', tag_sym: :gantry_pitch_angle, tag_ndm: '300A014A', tag_ary: [0x300A,0x014A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,014C)', tag_name: "Gantry Pitch Rotation Direction", tag_key: 'GantryPitchRotationDirection', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,014C)', tag_sym: :gantry_pitch_rotation_direction, tag_ndm: '300A014C', tag_ary: [0x300A,0x014C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,014E)', tag_name: "Gantry Pitch Angle Tolerance", tag_key: 'GantryPitchAngleTolerance', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(300A,014E)', tag_sym: :gantry_pitch_angle_tolerance, tag_ndm: '300A014E', tag_ary: [0x300A,0x014E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0150)', tag_name: "Fixation Eye", tag_key: 'FixationEye', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,0150)', tag_sym: :fixation_eye, tag_ndm: '300A0150', tag_ary: [0x300A,0x0150], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0151)', tag_name: "Chair Head Frame Position", tag_key: 'ChairHeadFramePosition', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,0151)', tag_sym: :chair_head_frame_position, tag_ndm: '300A0151', tag_ary: [0x300A,0x0151], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0152)', tag_name: "Head Fixation Angle Tolerance", tag_key: 'HeadFixationAngleTolerance', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,0152)', tag_sym: :head_fixation_angle_tolerance, tag_ndm: '300A0152', tag_ary: [0x300A,0x0152], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0153)', tag_name: "Chair Head Frame Position Tolerance", tag_key: 'ChairHeadFramePositionTolerance', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,0153)', tag_sym: :chair_head_frame_position_tolerance, tag_ndm: '300A0153', tag_ary: [0x300A,0x0153], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0154)', tag_name: "Fixation Light Azimuthal Angle Tolerance", tag_key: 'FixationLightAzimuthalAngleTolerance', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,0154)', tag_sym: :fixation_light_azimuthal_angle_tolerance, tag_ndm: '300A0154', tag_ary: [0x300A,0x0154], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0155)', tag_name: "Fixation Light Polar Angle Tolerance", tag_key: 'FixationLightPolarAngleTolerance', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,0155)', tag_sym: :fixation_light_polar_angle_tolerance, tag_ndm: '300A0155', tag_ary: [0x300A,0x0155], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0180)', tag_name: "Patient Setup Sequence", tag_key: 'PatientSetupSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0180)', tag_sym: :patient_setup_sequence, tag_ndm: '300A0180', tag_ary: [0x300A,0x0180], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0182)', tag_name: "Patient Setup Number", tag_key: 'PatientSetupNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300A,0182)', tag_sym: :patient_setup_number, tag_ndm: '300A0182', tag_ary: [0x300A,0x0182], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0183)', tag_name: "Patient Setup Label", tag_key: 'PatientSetupLabel', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(300A,0183)', tag_sym: :patient_setup_label, tag_ndm: '300A0183', tag_ary: [0x300A,0x0183], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0184)', tag_name: "Patient Additional Position", tag_key: 'PatientAdditionalPosition', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(300A,0184)', tag_sym: :patient_additional_position, tag_ndm: '300A0184', tag_ary: [0x300A,0x0184], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0190)', tag_name: "Fixation Device Sequence", tag_key: 'FixationDeviceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0190)', tag_sym: :fixation_device_sequence, tag_ndm: '300A0190', tag_ary: [0x300A,0x0190], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0192)', tag_name: "Fixation Device Type", tag_key: 'FixationDeviceType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,0192)', tag_sym: :fixation_device_type, tag_ndm: '300A0192', tag_ary: [0x300A,0x0192], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0194)', tag_name: "Fixation Device Label", tag_key: 'FixationDeviceLabel', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(300A,0194)', tag_sym: :fixation_device_label, tag_ndm: '300A0194', tag_ary: [0x300A,0x0194], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0196)', tag_name: "Fixation Device Description", tag_key: 'FixationDeviceDescription', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(300A,0196)', tag_sym: :fixation_device_description, tag_ndm: '300A0196', tag_ary: [0x300A,0x0196], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0198)', tag_name: "Fixation Device Position", tag_key: 'FixationDevicePosition', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(300A,0198)', tag_sym: :fixation_device_position, tag_ndm: '300A0198', tag_ary: [0x300A,0x0198], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0199)', tag_name: "Fixation Device Pitch Angle", tag_key: 'FixationDevicePitchAngle', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(300A,0199)', tag_sym: :fixation_device_pitch_angle, tag_ndm: '300A0199', tag_ary: [0x300A,0x0199], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,019A)', tag_name: "Fixation Device Roll Angle", tag_key: 'FixationDeviceRollAngle', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(300A,019A)', tag_sym: :fixation_device_roll_angle, tag_ndm: '300A019A', tag_ary: [0x300A,0x019A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,01A0)', tag_name: "Shielding Device Sequence", tag_key: 'ShieldingDeviceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,01A0)', tag_sym: :shielding_device_sequence, tag_ndm: '300A01A0', tag_ary: [0x300A,0x01A0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,01A2)', tag_name: "Shielding Device Type", tag_key: 'ShieldingDeviceType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,01A2)', tag_sym: :shielding_device_type, tag_ndm: '300A01A2', tag_ary: [0x300A,0x01A2], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,01A4)', tag_name: "Shielding Device Label", tag_key: 'ShieldingDeviceLabel', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(300A,01A4)', tag_sym: :shielding_device_label, tag_ndm: '300A01A4', tag_ary: [0x300A,0x01A4], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,01A6)', tag_name: "Shielding Device Description", tag_key: 'ShieldingDeviceDescription', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(300A,01A6)', tag_sym: :shielding_device_description, tag_ndm: '300A01A6', tag_ary: [0x300A,0x01A6], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,01A8)', tag_name: "Shielding Device Position", tag_key: 'ShieldingDevicePosition', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(300A,01A8)', tag_sym: :shielding_device_position, tag_ndm: '300A01A8', tag_ary: [0x300A,0x01A8], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,01B0)', tag_name: "Setup Technique", tag_key: 'SetupTechnique', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,01B0)', tag_sym: :setup_technique, tag_ndm: '300A01B0', tag_ary: [0x300A,0x01B0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,01B2)', tag_name: "Setup Technique Description", tag_key: 'SetupTechniqueDescription', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(300A,01B2)', tag_sym: :setup_technique_description, tag_ndm: '300A01B2', tag_ary: [0x300A,0x01B2], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,01B4)', tag_name: "Setup Device Sequence", tag_key: 'SetupDeviceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,01B4)', tag_sym: :setup_device_sequence, tag_ndm: '300A01B4', tag_ary: [0x300A,0x01B4], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,01B6)', tag_name: "Setup Device Type", tag_key: 'SetupDeviceType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,01B6)', tag_sym: :setup_device_type, tag_ndm: '300A01B6', tag_ary: [0x300A,0x01B6], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,01B8)', tag_name: "Setup Device Label", tag_key: 'SetupDeviceLabel', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(300A,01B8)', tag_sym: :setup_device_label, tag_ndm: '300A01B8', tag_ary: [0x300A,0x01B8], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,01BA)', tag_name: "Setup Device Description", tag_key: 'SetupDeviceDescription', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(300A,01BA)', tag_sym: :setup_device_description, tag_ndm: '300A01BA', tag_ary: [0x300A,0x01BA], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,01BC)', tag_name: "Setup Device Parameter", tag_key: 'SetupDeviceParameter', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,01BC)', tag_sym: :setup_device_parameter, tag_ndm: '300A01BC', tag_ary: [0x300A,0x01BC], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,01D0)', tag_name: "Setup Reference Description", tag_key: 'SetupReferenceDescription', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(300A,01D0)', tag_sym: :setup_reference_description, tag_ndm: '300A01D0', tag_ary: [0x300A,0x01D0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,01D2)', tag_name: "Table Top Vertical Setup Displacement", tag_key: 'TableTopVerticalSetupDisplacement', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,01D2)', tag_sym: :table_top_vertical_setup_displacement, tag_ndm: '300A01D2', tag_ary: [0x300A,0x01D2], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,01D4)', tag_name: "Table Top Longitudinal Setup Displacement", tag_key: 'TableTopLongitudinalSetupDisplacement', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,01D4)', tag_sym: :table_top_longitudinal_setup_displacement, tag_ndm: '300A01D4', tag_ary: [0x300A,0x01D4], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,01D6)', tag_name: "Table Top Lateral Setup Displacement", tag_key: 'TableTopLateralSetupDisplacement', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,01D6)', tag_sym: :table_top_lateral_setup_displacement, tag_ndm: '300A01D6', tag_ary: [0x300A,0x01D6], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0200)', tag_name: "Brachy Treatment Technique", tag_key: 'BrachyTreatmentTechnique', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,0200)', tag_sym: :brachy_treatment_technique, tag_ndm: '300A0200', tag_ary: [0x300A,0x0200], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0202)', tag_name: "Brachy Treatment Type", tag_key: 'BrachyTreatmentType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,0202)', tag_sym: :brachy_treatment_type, tag_ndm: '300A0202', tag_ary: [0x300A,0x0202], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0206)', tag_name: "Treatment Machine Sequence", tag_key: 'TreatmentMachineSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0206)', tag_sym: :treatment_machine_sequence, tag_ndm: '300A0206', tag_ary: [0x300A,0x0206], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0210)', tag_name: "Source Sequence", tag_key: 'SourceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0210)', tag_sym: :source_sequence, tag_ndm: '300A0210', tag_ary: [0x300A,0x0210], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0212)', tag_name: "Source Number", tag_key: 'SourceNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300A,0212)', tag_sym: :source_number, tag_ndm: '300A0212', tag_ary: [0x300A,0x0212], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0214)', tag_name: "Source Type", tag_key: 'SourceType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,0214)', tag_sym: :source_type, tag_ndm: '300A0214', tag_ary: [0x300A,0x0214], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0216)', tag_name: "Source Manufacturer", tag_key: 'SourceManufacturer', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(300A,0216)', tag_sym: :source_manufacturer, tag_ndm: '300A0216', tag_ary: [0x300A,0x0216], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0218)', tag_name: "Active Source Diameter", tag_key: 'ActiveSourceDiameter', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,0218)', tag_sym: :active_source_diameter, tag_ndm: '300A0218', tag_ary: [0x300A,0x0218], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,021A)', tag_name: "Active Source Length", tag_key: 'ActiveSourceLength', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,021A)', tag_sym: :active_source_length, tag_ndm: '300A021A', tag_ary: [0x300A,0x021A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,021B)', tag_name: "Source Model ID", tag_key: 'SourceModelID', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(300A,021B)', tag_sym: :source_model_id, tag_ndm: '300A021B', tag_ary: [0x300A,0x021B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,021C)', tag_name: "Source Description", tag_key: 'SourceDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(300A,021C)', tag_sym: :source_description, tag_ndm: '300A021C', tag_ary: [0x300A,0x021C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0222)', tag_name: "Source Encapsulation Nominal Thickness", tag_key: 'SourceEncapsulationNominalThickness', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,0222)', tag_sym: :source_encapsulation_nominal_thickness, tag_ndm: '300A0222', tag_ary: [0x300A,0x0222], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0224)', tag_name: "Source Encapsulation Nominal Transmission", tag_key: 'SourceEncapsulationNominalTransmission', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,0224)', tag_sym: :source_encapsulation_nominal_transmission, tag_ndm: '300A0224', tag_ary: [0x300A,0x0224], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0226)', tag_name: "Source Isotope Name", tag_key: 'SourceIsotopeName', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(300A,0226)', tag_sym: :source_isotope_name, tag_ndm: '300A0226', tag_ary: [0x300A,0x0226], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0228)', tag_name: "Source Isotope Half Life", tag_key: 'SourceIsotopeHalfLife', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,0228)', tag_sym: :source_isotope_half_life, tag_ndm: '300A0228', tag_ary: [0x300A,0x0228], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0229)', tag_name: "Source Strength Units", tag_key: 'SourceStrengthUnits', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,0229)', tag_sym: :source_strength_units, tag_ndm: '300A0229', tag_ary: [0x300A,0x0229], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,022A)', tag_name: "Reference Air Kerma Rate", tag_key: 'ReferenceAirKermaRate', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,022A)', tag_sym: :reference_air_kerma_rate, tag_ndm: '300A022A', tag_ary: [0x300A,0x022A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,022B)', tag_name: "Source Strength", tag_key: 'SourceStrength', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,022B)', tag_sym: :source_strength, tag_ndm: '300A022B', tag_ary: [0x300A,0x022B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,022C)', tag_name: "Source Strength Reference Date", tag_key: 'SourceStrengthReferenceDate', tag_vr: [:DA], tag_vm: ["1"], tag_str: '(300A,022C)', tag_sym: :source_strength_reference_date, tag_ndm: '300A022C', tag_ary: [0x300A,0x022C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,022E)', tag_name: "Source Strength Reference Time", tag_key: 'SourceStrengthReferenceTime', tag_vr: [:TM], tag_vm: ["1"], tag_str: '(300A,022E)', tag_sym: :source_strength_reference_time, tag_ndm: '300A022E', tag_ary: [0x300A,0x022E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0230)', tag_name: "Application Setup Sequence", tag_key: 'ApplicationSetupSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0230)', tag_sym: :application_setup_sequence, tag_ndm: '300A0230', tag_ary: [0x300A,0x0230], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0232)', tag_name: "Application Setup Type", tag_key: 'ApplicationSetupType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,0232)', tag_sym: :application_setup_type, tag_ndm: '300A0232', tag_ary: [0x300A,0x0232], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0234)', tag_name: "Application Setup Number", tag_key: 'ApplicationSetupNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300A,0234)', tag_sym: :application_setup_number, tag_ndm: '300A0234', tag_ary: [0x300A,0x0234], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0236)', tag_name: "Application Setup Name", tag_key: 'ApplicationSetupName', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(300A,0236)', tag_sym: :application_setup_name, tag_ndm: '300A0236', tag_ary: [0x300A,0x0236], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0238)', tag_name: "Application Setup Manufacturer", tag_key: 'ApplicationSetupManufacturer', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(300A,0238)', tag_sym: :application_setup_manufacturer, tag_ndm: '300A0238', tag_ary: [0x300A,0x0238], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0240)', tag_name: "Template Number", tag_key: 'TemplateNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300A,0240)', tag_sym: :template_number, tag_ndm: '300A0240', tag_ary: [0x300A,0x0240], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0242)', tag_name: "Template Type", tag_key: 'TemplateType', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(300A,0242)', tag_sym: :template_type, tag_ndm: '300A0242', tag_ary: [0x300A,0x0242], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0244)', tag_name: "Template Name", tag_key: 'TemplateName', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(300A,0244)', tag_sym: :template_name, tag_ndm: '300A0244', tag_ary: [0x300A,0x0244], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0250)', tag_name: "Total Reference Air Kerma", tag_key: 'TotalReferenceAirKerma', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,0250)', tag_sym: :total_reference_air_kerma, tag_ndm: '300A0250', tag_ary: [0x300A,0x0250], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0260)', tag_name: "Brachy Accessory Device Sequence", tag_key: 'BrachyAccessoryDeviceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0260)', tag_sym: :brachy_accessory_device_sequence, tag_ndm: '300A0260', tag_ary: [0x300A,0x0260], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0262)', tag_name: "Brachy Accessory Device Number", tag_key: 'BrachyAccessoryDeviceNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300A,0262)', tag_sym: :brachy_accessory_device_number, tag_ndm: '300A0262', tag_ary: [0x300A,0x0262], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0263)', tag_name: "Brachy Accessory Device ID", tag_key: 'BrachyAccessoryDeviceID', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(300A,0263)', tag_sym: :brachy_accessory_device_id, tag_ndm: '300A0263', tag_ary: [0x300A,0x0263], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0264)', tag_name: "Brachy Accessory Device Type", tag_key: 'BrachyAccessoryDeviceType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,0264)', tag_sym: :brachy_accessory_device_type, tag_ndm: '300A0264', tag_ary: [0x300A,0x0264], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0266)', tag_name: "Brachy Accessory Device Name", tag_key: 'BrachyAccessoryDeviceName', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(300A,0266)', tag_sym: :brachy_accessory_device_name, tag_ndm: '300A0266', tag_ary: [0x300A,0x0266], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,026A)', tag_name: "Brachy Accessory Device Nominal Thickness", tag_key: 'BrachyAccessoryDeviceNominalThickness', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,026A)', tag_sym: :brachy_accessory_device_nominal_thickness, tag_ndm: '300A026A', tag_ary: [0x300A,0x026A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,026C)', tag_name: "Brachy Accessory Device Nominal Transmission", tag_key: 'BrachyAccessoryDeviceNominalTransmission', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,026C)', tag_sym: :brachy_accessory_device_nominal_transmission, tag_ndm: '300A026C', tag_ary: [0x300A,0x026C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0271)', tag_name: "Channel Effective Length", tag_key: 'ChannelEffectiveLength', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,0271)', tag_sym: :channel_effective_length, tag_ndm: '300A0271', tag_ary: [0x300A,0x0271], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0272)', tag_name: "Channel Inner Length", tag_key: 'ChannelInnerLength', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,0272)', tag_sym: :channel_inner_length, tag_ndm: '300A0272', tag_ary: [0x300A,0x0272], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0273)', tag_name: "Afterloader Channel ID", tag_key: 'AfterloaderChannelID', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(300A,0273)', tag_sym: :afterloader_channel_id, tag_ndm: '300A0273', tag_ary: [0x300A,0x0273], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0274)', tag_name: "Source Applicator Tip Length", tag_key: 'SourceApplicatorTipLength', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,0274)', tag_sym: :source_applicator_tip_length, tag_ndm: '300A0274', tag_ary: [0x300A,0x0274], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0280)', tag_name: "Channel Sequence", tag_key: 'ChannelSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0280)', tag_sym: :channel_sequence, tag_ndm: '300A0280', tag_ary: [0x300A,0x0280], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0282)', tag_name: "Channel Number", tag_key: 'ChannelNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300A,0282)', tag_sym: :channel_number, tag_ndm: '300A0282', tag_ary: [0x300A,0x0282], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0284)', tag_name: "Channel Length", tag_key: 'ChannelLength', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,0284)', tag_sym: :channel_length, tag_ndm: '300A0284', tag_ary: [0x300A,0x0284], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0286)', tag_name: "Channel Total Time", tag_key: 'ChannelTotalTime', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,0286)', tag_sym: :channel_total_time, tag_ndm: '300A0286', tag_ary: [0x300A,0x0286], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0288)', tag_name: "Source Movement Type", tag_key: 'SourceMovementType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,0288)', tag_sym: :source_movement_type, tag_ndm: '300A0288', tag_ary: [0x300A,0x0288], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,028A)', tag_name: "Number of Pulses", tag_key: 'NumberOfPulses', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300A,028A)', tag_sym: :number_of_pulses, tag_ndm: '300A028A', tag_ary: [0x300A,0x028A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,028C)', tag_name: "Pulse Repetition Interval", tag_key: 'PulseRepetitionInterval', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,028C)', tag_sym: :pulse_repetition_interval, tag_ndm: '300A028C', tag_ary: [0x300A,0x028C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0290)', tag_name: "Source Applicator Number", tag_key: 'SourceApplicatorNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300A,0290)', tag_sym: :source_applicator_number, tag_ndm: '300A0290', tag_ary: [0x300A,0x0290], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0291)', tag_name: "Source Applicator ID", tag_key: 'SourceApplicatorID', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(300A,0291)', tag_sym: :source_applicator_id, tag_ndm: '300A0291', tag_ary: [0x300A,0x0291], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0292)', tag_name: "Source Applicator Type", tag_key: 'SourceApplicatorType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,0292)', tag_sym: :source_applicator_type, tag_ndm: '300A0292', tag_ary: [0x300A,0x0292], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0294)', tag_name: "Source Applicator Name", tag_key: 'SourceApplicatorName', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(300A,0294)', tag_sym: :source_applicator_name, tag_ndm: '300A0294', tag_ary: [0x300A,0x0294], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0296)', tag_name: "Source Applicator Length", tag_key: 'SourceApplicatorLength', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,0296)', tag_sym: :source_applicator_length, tag_ndm: '300A0296', tag_ary: [0x300A,0x0296], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0298)', tag_name: "Source Applicator Manufacturer", tag_key: 'SourceApplicatorManufacturer', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(300A,0298)', tag_sym: :source_applicator_manufacturer, tag_ndm: '300A0298', tag_ary: [0x300A,0x0298], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,029C)', tag_name: "Source Applicator Wall Nominal Thickness", tag_key: 'SourceApplicatorWallNominalThickness', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,029C)', tag_sym: :source_applicator_wall_nominal_thickness, tag_ndm: '300A029C', tag_ary: [0x300A,0x029C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,029E)', tag_name: "Source Applicator Wall Nominal Transmission", tag_key: 'SourceApplicatorWallNominalTransmission', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,029E)', tag_sym: :source_applicator_wall_nominal_transmission, tag_ndm: '300A029E', tag_ary: [0x300A,0x029E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,02A0)', tag_name: "Source Applicator Step Size", tag_key: 'SourceApplicatorStepSize', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,02A0)', tag_sym: :source_applicator_step_size, tag_ndm: '300A02A0', tag_ary: [0x300A,0x02A0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,02A1)', tag_name: "Applicator Shape Referenced ROI Number", tag_key: 'ApplicatorShapeReferencedROINumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300A,02A1)', tag_sym: :applicator_shape_referenced_roi_number, tag_ndm: '300A02A1', tag_ary: [0x300A,0x02A1], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,02A2)', tag_name: "Transfer Tube Number", tag_key: 'TransferTubeNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300A,02A2)', tag_sym: :transfer_tube_number, tag_ndm: '300A02A2', tag_ary: [0x300A,0x02A2], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,02A4)', tag_name: "Transfer Tube Length", tag_key: 'TransferTubeLength', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,02A4)', tag_sym: :transfer_tube_length, tag_ndm: '300A02A4', tag_ary: [0x300A,0x02A4], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,02B0)', tag_name: "Channel Shield Sequence", tag_key: 'ChannelShieldSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,02B0)', tag_sym: :channel_shield_sequence, tag_ndm: '300A02B0', tag_ary: [0x300A,0x02B0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,02B2)', tag_name: "Channel Shield Number", tag_key: 'ChannelShieldNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300A,02B2)', tag_sym: :channel_shield_number, tag_ndm: '300A02B2', tag_ary: [0x300A,0x02B2], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,02B3)', tag_name: "Channel Shield ID", tag_key: 'ChannelShieldID', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(300A,02B3)', tag_sym: :channel_shield_id, tag_ndm: '300A02B3', tag_ary: [0x300A,0x02B3], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,02B4)', tag_name: "Channel Shield Name", tag_key: 'ChannelShieldName', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(300A,02B4)', tag_sym: :channel_shield_name, tag_ndm: '300A02B4', tag_ary: [0x300A,0x02B4], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,02B8)', tag_name: "Channel Shield Nominal Thickness", tag_key: 'ChannelShieldNominalThickness', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,02B8)', tag_sym: :channel_shield_nominal_thickness, tag_ndm: '300A02B8', tag_ary: [0x300A,0x02B8], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,02BA)', tag_name: "Channel Shield Nominal Transmission", tag_key: 'ChannelShieldNominalTransmission', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,02BA)', tag_sym: :channel_shield_nominal_transmission, tag_ndm: '300A02BA', tag_ary: [0x300A,0x02BA], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,02C8)', tag_name: "Final Cumulative Time Weight", tag_key: 'FinalCumulativeTimeWeight', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,02C8)', tag_sym: :final_cumulative_time_weight, tag_ndm: '300A02C8', tag_ary: [0x300A,0x02C8], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,02D0)', tag_name: "Brachy Control Point Sequence", tag_key: 'BrachyControlPointSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,02D0)', tag_sym: :brachy_control_point_sequence, tag_ndm: '300A02D0', tag_ary: [0x300A,0x02D0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,02D2)', tag_name: "Control Point Relative Position", tag_key: 'ControlPointRelativePosition', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,02D2)', tag_sym: :control_point_relative_position, tag_ndm: '300A02D2', tag_ary: [0x300A,0x02D2], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,02D4)', tag_name: "Control Point 3D Position", tag_key: 'ControlPoint3DPosition', tag_vr: [:DS], tag_vm: ["3"], tag_str: '(300A,02D4)', tag_sym: :control_point_3d_position, tag_ndm: '300A02D4', tag_ary: [0x300A,0x02D4], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,02D6)', tag_name: "Cumulative Time Weight", tag_key: 'CumulativeTimeWeight', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,02D6)', tag_sym: :cumulative_time_weight, tag_ndm: '300A02D6', tag_ary: [0x300A,0x02D6], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,02E0)', tag_name: "Compensator Divergence", tag_key: 'CompensatorDivergence', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,02E0)', tag_sym: :compensator_divergence, tag_ndm: '300A02E0', tag_ary: [0x300A,0x02E0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,02E1)', tag_name: "Compensator Mounting Position", tag_key: 'CompensatorMountingPosition', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,02E1)', tag_sym: :compensator_mounting_position, tag_ndm: '300A02E1', tag_ary: [0x300A,0x02E1], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,02E2)', tag_name: "Source to Compensator Distance", tag_key: 'SourceToCompensatorDistance', tag_vr: [:DS], tag_vm: ["1-n"], tag_str: '(300A,02E2)', tag_sym: :source_to_compensator_distance, tag_ndm: '300A02E2', tag_ary: [0x300A,0x02E2], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,02E3)', tag_name: "Total Compensator Tray Water-Equivalent Thickness", tag_key: 'TotalCompensatorTrayWaterEquivalentThickness', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(300A,02E3)', tag_sym: :total_compensator_tray_water_equivalent_thickness, tag_ndm: '300A02E3', tag_ary: [0x300A,0x02E3], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,02E4)', tag_name: "Isocenter to Compensator Tray Distance", tag_key: 'IsocenterToCompensatorTrayDistance', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(300A,02E4)', tag_sym: :isocenter_to_compensator_tray_distance, tag_ndm: '300A02E4', tag_ary: [0x300A,0x02E4], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,02E5)', tag_name: "Compensator Column Offset", tag_key: 'CompensatorColumnOffset', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(300A,02E5)', tag_sym: :compensator_column_offset, tag_ndm: '300A02E5', tag_ary: [0x300A,0x02E5], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,02E6)', tag_name: "Isocenter to Compensator Distances", tag_key: 'IsocenterToCompensatorDistances', tag_vr: [:FL], tag_vm: ["1-n"], tag_str: '(300A,02E6)', tag_sym: :isocenter_to_compensator_distances, tag_ndm: '300A02E6', tag_ary: [0x300A,0x02E6], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,02E7)', tag_name: "Compensator Relative Stopping Power Ratio", tag_key: 'CompensatorRelativeStoppingPowerRatio', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(300A,02E7)', tag_sym: :compensator_relative_stopping_power_ratio, tag_ndm: '300A02E7', tag_ary: [0x300A,0x02E7], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,02E8)', tag_name: "Compensator Milling Tool Diameter", tag_key: 'CompensatorMillingToolDiameter', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(300A,02E8)', tag_sym: :compensator_milling_tool_diameter, tag_ndm: '300A02E8', tag_ary: [0x300A,0x02E8], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,02EA)', tag_name: "Ion Range Compensator Sequence", tag_key: 'IonRangeCompensatorSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,02EA)', tag_sym: :ion_range_compensator_sequence, tag_ndm: '300A02EA', tag_ary: [0x300A,0x02EA], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,02EB)', tag_name: "Compensator Description", tag_key: 'CompensatorDescription', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(300A,02EB)', tag_sym: :compensator_description, tag_ndm: '300A02EB', tag_ary: [0x300A,0x02EB], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,02EC)', tag_name: "Compensator Surface Representation Flag", tag_key: 'CompensatorSurfaceRepresentationFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,02EC)', tag_sym: :compensator_surface_representation_flag, tag_ndm: '300A02EC', tag_ary: [0x300A,0x02EC], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0302)', tag_name: "Radiation Mass Number", tag_key: 'RadiationMassNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300A,0302)', tag_sym: :radiation_mass_number, tag_ndm: '300A0302', tag_ary: [0x300A,0x0302], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0304)', tag_name: "Radiation Atomic Number", tag_key: 'RadiationAtomicNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300A,0304)', tag_sym: :radiation_atomic_number, tag_ndm: '300A0304', tag_ary: [0x300A,0x0304], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0306)', tag_name: "Radiation Charge State", tag_key: 'RadiationChargeState', tag_vr: [:SS], tag_vm: ["1"], tag_str: '(300A,0306)', tag_sym: :radiation_charge_state, tag_ndm: '300A0306', tag_ary: [0x300A,0x0306], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0308)', tag_name: "Scan Mode", tag_key: 'ScanMode', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,0308)', tag_sym: :scan_mode, tag_ndm: '300A0308', tag_ary: [0x300A,0x0308], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0309)', tag_name: "Modulated Scan Mode Type", tag_key: 'ModulatedScanModeType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,0309)', tag_sym: :modulated_scan_mode_type, tag_ndm: '300A0309', tag_ary: [0x300A,0x0309], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,030A)', tag_name: "Virtual Source-Axis Distances", tag_key: 'VirtualSourceAxisDistances', tag_vr: [:FL], tag_vm: ["2"], tag_str: '(300A,030A)', tag_sym: :virtual_source_axis_distances, tag_ndm: '300A030A', tag_ary: [0x300A,0x030A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,030C)', tag_name: "Snout Sequence", tag_key: 'SnoutSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,030C)', tag_sym: :snout_sequence, tag_ndm: '300A030C', tag_ary: [0x300A,0x030C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,030D)', tag_name: "Snout Position", tag_key: 'SnoutPosition', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(300A,030D)', tag_sym: :snout_position, tag_ndm: '300A030D', tag_ary: [0x300A,0x030D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,030F)', tag_name: "Snout ID", tag_key: 'SnoutID', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(300A,030F)', tag_sym: :snout_id, tag_ndm: '300A030F', tag_ary: [0x300A,0x030F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0312)', tag_name: "Number of Range Shifters", tag_key: 'NumberOfRangeShifters', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300A,0312)', tag_sym: :number_of_range_shifters, tag_ndm: '300A0312', tag_ary: [0x300A,0x0312], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0314)', tag_name: "Range Shifter Sequence", tag_key: 'RangeShifterSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0314)', tag_sym: :range_shifter_sequence, tag_ndm: '300A0314', tag_ary: [0x300A,0x0314], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0316)', tag_name: "Range Shifter Number", tag_key: 'RangeShifterNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300A,0316)', tag_sym: :range_shifter_number, tag_ndm: '300A0316', tag_ary: [0x300A,0x0316], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0318)', tag_name: "Range Shifter ID", tag_key: 'RangeShifterID', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(300A,0318)', tag_sym: :range_shifter_id, tag_ndm: '300A0318', tag_ary: [0x300A,0x0318], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0320)', tag_name: "Range Shifter Type", tag_key: 'RangeShifterType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,0320)', tag_sym: :range_shifter_type, tag_ndm: '300A0320', tag_ary: [0x300A,0x0320], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0322)', tag_name: "Range Shifter Description", tag_key: 'RangeShifterDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(300A,0322)', tag_sym: :range_shifter_description, tag_ndm: '300A0322', tag_ary: [0x300A,0x0322], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0330)', tag_name: "Number of Lateral Spreading Devices", tag_key: 'NumberOfLateralSpreadingDevices', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300A,0330)', tag_sym: :number_of_lateral_spreading_devices, tag_ndm: '300A0330', tag_ary: [0x300A,0x0330], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0332)', tag_name: "Lateral Spreading Device Sequence", tag_key: 'LateralSpreadingDeviceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0332)', tag_sym: :lateral_spreading_device_sequence, tag_ndm: '300A0332', tag_ary: [0x300A,0x0332], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0334)', tag_name: "Lateral Spreading Device Number", tag_key: 'LateralSpreadingDeviceNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300A,0334)', tag_sym: :lateral_spreading_device_number, tag_ndm: '300A0334', tag_ary: [0x300A,0x0334], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0336)', tag_name: "Lateral Spreading Device ID", tag_key: 'LateralSpreadingDeviceID', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(300A,0336)', tag_sym: :lateral_spreading_device_id, tag_ndm: '300A0336', tag_ary: [0x300A,0x0336], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0338)', tag_name: "Lateral Spreading Device Type", tag_key: 'LateralSpreadingDeviceType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,0338)', tag_sym: :lateral_spreading_device_type, tag_ndm: '300A0338', tag_ary: [0x300A,0x0338], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,033A)', tag_name: "Lateral Spreading Device Description", tag_key: 'LateralSpreadingDeviceDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(300A,033A)', tag_sym: :lateral_spreading_device_description, tag_ndm: '300A033A', tag_ary: [0x300A,0x033A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,033C)', tag_name: "Lateral Spreading Device Water Equivalent Thickness", tag_key: 'LateralSpreadingDeviceWaterEquivalentThickness', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(300A,033C)', tag_sym: :lateral_spreading_device_water_equivalent_thickness, tag_ndm: '300A033C', tag_ary: [0x300A,0x033C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0340)', tag_name: "Number of Range Modulators", tag_key: 'NumberOfRangeModulators', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300A,0340)', tag_sym: :number_of_range_modulators, tag_ndm: '300A0340', tag_ary: [0x300A,0x0340], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0342)', tag_name: "Range Modulator Sequence", tag_key: 'RangeModulatorSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0342)', tag_sym: :range_modulator_sequence, tag_ndm: '300A0342', tag_ary: [0x300A,0x0342], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0344)', tag_name: "Range Modulator Number", tag_key: 'RangeModulatorNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300A,0344)', tag_sym: :range_modulator_number, tag_ndm: '300A0344', tag_ary: [0x300A,0x0344], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0346)', tag_name: "Range Modulator ID", tag_key: 'RangeModulatorID', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(300A,0346)', tag_sym: :range_modulator_id, tag_ndm: '300A0346', tag_ary: [0x300A,0x0346], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0348)', tag_name: "Range Modulator Type", tag_key: 'RangeModulatorType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,0348)', tag_sym: :range_modulator_type, tag_ndm: '300A0348', tag_ary: [0x300A,0x0348], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,034A)', tag_name: "Range Modulator Description", tag_key: 'RangeModulatorDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(300A,034A)', tag_sym: :range_modulator_description, tag_ndm: '300A034A', tag_ary: [0x300A,0x034A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,034C)', tag_name: "Beam Current Modulation ID", tag_key: 'BeamCurrentModulationID', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(300A,034C)', tag_sym: :beam_current_modulation_id, tag_ndm: '300A034C', tag_ary: [0x300A,0x034C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0350)', tag_name: "Patient Support Type", tag_key: 'PatientSupportType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,0350)', tag_sym: :patient_support_type, tag_ndm: '300A0350', tag_ary: [0x300A,0x0350], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0352)', tag_name: "Patient Support ID", tag_key: 'PatientSupportID', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(300A,0352)', tag_sym: :patient_support_id, tag_ndm: '300A0352', tag_ary: [0x300A,0x0352], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0354)', tag_name: "Patient Support Accessory Code", tag_key: 'PatientSupportAccessoryCode', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(300A,0354)', tag_sym: :patient_support_accessory_code, tag_ndm: '300A0354', tag_ary: [0x300A,0x0354], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0355)', tag_name: "Tray Accessory Code", tag_key: 'TrayAccessoryCode', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(300A,0355)', tag_sym: :tray_accessory_code, tag_ndm: '300A0355', tag_ary: [0x300A,0x0355], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0356)', tag_name: "Fixation Light Azimuthal Angle", tag_key: 'FixationLightAzimuthalAngle', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(300A,0356)', tag_sym: :fixation_light_azimuthal_angle, tag_ndm: '300A0356', tag_ary: [0x300A,0x0356], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0358)', tag_name: "Fixation Light Polar Angle", tag_key: 'FixationLightPolarAngle', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(300A,0358)', tag_sym: :fixation_light_polar_angle, tag_ndm: '300A0358', tag_ary: [0x300A,0x0358], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,035A)', tag_name: "Meterset Rate", tag_key: 'MetersetRate', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(300A,035A)', tag_sym: :meterset_rate, tag_ndm: '300A035A', tag_ary: [0x300A,0x035A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0360)', tag_name: "Range Shifter Settings Sequence", tag_key: 'RangeShifterSettingsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0360)', tag_sym: :range_shifter_settings_sequence, tag_ndm: '300A0360', tag_ary: [0x300A,0x0360], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0362)', tag_name: "Range Shifter Setting", tag_key: 'RangeShifterSetting', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(300A,0362)', tag_sym: :range_shifter_setting, tag_ndm: '300A0362', tag_ary: [0x300A,0x0362], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0364)', tag_name: "Isocenter to Range Shifter Distance", tag_key: 'IsocenterToRangeShifterDistance', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(300A,0364)', tag_sym: :isocenter_to_range_shifter_distance, tag_ndm: '300A0364', tag_ary: [0x300A,0x0364], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0366)', tag_name: "Range Shifter Water Equivalent Thickness", tag_key: 'RangeShifterWaterEquivalentThickness', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(300A,0366)', tag_sym: :range_shifter_water_equivalent_thickness, tag_ndm: '300A0366', tag_ary: [0x300A,0x0366], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0370)', tag_name: "Lateral Spreading Device Settings Sequence", tag_key: 'LateralSpreadingDeviceSettingsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0370)', tag_sym: :lateral_spreading_device_settings_sequence, tag_ndm: '300A0370', tag_ary: [0x300A,0x0370], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0372)', tag_name: "Lateral Spreading Device Setting", tag_key: 'LateralSpreadingDeviceSetting', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(300A,0372)', tag_sym: :lateral_spreading_device_setting, tag_ndm: '300A0372', tag_ary: [0x300A,0x0372], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0374)', tag_name: "Isocenter to Lateral Spreading Device Distance", tag_key: 'IsocenterToLateralSpreadingDeviceDistance', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(300A,0374)', tag_sym: :isocenter_to_lateral_spreading_device_distance, tag_ndm: '300A0374', tag_ary: [0x300A,0x0374], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0380)', tag_name: "Range Modulator Settings Sequence", tag_key: 'RangeModulatorSettingsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0380)', tag_sym: :range_modulator_settings_sequence, tag_ndm: '300A0380', tag_ary: [0x300A,0x0380], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0382)', tag_name: "Range Modulator Gating Start Value", tag_key: 'RangeModulatorGatingStartValue', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(300A,0382)', tag_sym: :range_modulator_gating_start_value, tag_ndm: '300A0382', tag_ary: [0x300A,0x0382], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0384)', tag_name: "Range Modulator Gating Stop Value", tag_key: 'RangeModulatorGatingStopValue', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(300A,0384)', tag_sym: :range_modulator_gating_stop_value, tag_ndm: '300A0384', tag_ary: [0x300A,0x0384], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0386)', tag_name: "Range Modulator Gating Start Water Equivalent Thickness", tag_key: 'RangeModulatorGatingStartWaterEquivalentThickness', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(300A,0386)', tag_sym: :range_modulator_gating_start_water_equivalent_thickness, tag_ndm: '300A0386', tag_ary: [0x300A,0x0386], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0388)', tag_name: "Range Modulator Gating Stop Water Equivalent Thickness", tag_key: 'RangeModulatorGatingStopWaterEquivalentThickness', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(300A,0388)', tag_sym: :range_modulator_gating_stop_water_equivalent_thickness, tag_ndm: '300A0388', tag_ary: [0x300A,0x0388], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,038A)', tag_name: "Isocenter to Range Modulator Distance", tag_key: 'IsocenterToRangeModulatorDistance', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(300A,038A)', tag_sym: :isocenter_to_range_modulator_distance, tag_ndm: '300A038A', tag_ary: [0x300A,0x038A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,038F)', tag_name: "Scan Spot Time Offset", tag_key: 'ScanSpotTimeOffset', tag_vr: [:FL], tag_vm: ["1-n"], tag_str: '(300A,038F)', tag_sym: :scan_spot_time_offset, tag_ndm: '300A038F', tag_ary: [0x300A,0x038F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0390)', tag_name: "Scan Spot Tune ID", tag_key: 'ScanSpotTuneID', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(300A,0390)', tag_sym: :scan_spot_tune_id, tag_ndm: '300A0390', tag_ary: [0x300A,0x0390], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0391)', tag_name: "Scan Spot Prescribed Indices", tag_key: 'ScanSpotPrescribedIndices', tag_vr: [:IS], tag_vm: ["1-n"], tag_str: '(300A,0391)', tag_sym: :scan_spot_prescribed_indices, tag_ndm: '300A0391', tag_ary: [0x300A,0x0391], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0392)', tag_name: "Number of Scan Spot Positions", tag_key: 'NumberOfScanSpotPositions', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300A,0392)', tag_sym: :number_of_scan_spot_positions, tag_ndm: '300A0392', tag_ary: [0x300A,0x0392], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0393)', tag_name: "Scan Spot Reordered", tag_key: 'ScanSpotReordered', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,0393)', tag_sym: :scan_spot_reordered, tag_ndm: '300A0393', tag_ary: [0x300A,0x0393], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0394)', tag_name: "Scan Spot Position Map", tag_key: 'ScanSpotPositionMap', tag_vr: [:FL], tag_vm: ["1-n"], tag_str: '(300A,0394)', tag_sym: :scan_spot_position_map, tag_ndm: '300A0394', tag_ary: [0x300A,0x0394], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0395)', tag_name: "Scan Spot Reordering Allowed", tag_key: 'ScanSpotReorderingAllowed', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,0395)', tag_sym: :scan_spot_reordering_allowed, tag_ndm: '300A0395', tag_ary: [0x300A,0x0395], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0396)', tag_name: "Scan Spot Meterset Weights", tag_key: 'ScanSpotMetersetWeights', tag_vr: [:FL], tag_vm: ["1-n"], tag_str: '(300A,0396)', tag_sym: :scan_spot_meterset_weights, tag_ndm: '300A0396', tag_ary: [0x300A,0x0396], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0398)', tag_name: "Scanning Spot Size", tag_key: 'ScanningSpotSize', tag_vr: [:FL], tag_vm: ["2"], tag_str: '(300A,0398)', tag_sym: :scanning_spot_size, tag_ndm: '300A0398', tag_ary: [0x300A,0x0398], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0399)', tag_name: "Scan Spot Sizes Delivered", tag_key: 'ScanSpotSizesDelivered', tag_vr: [:FL], tag_vm: ["2-2n"], tag_str: '(300A,0399)', tag_sym: :scan_spot_sizes_delivered, tag_ndm: '300A0399', tag_ary: [0x300A,0x0399], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,039A)', tag_name: "Number of Paintings", tag_key: 'NumberOfPaintings', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300A,039A)', tag_sym: :number_of_paintings, tag_ndm: '300A039A', tag_ary: [0x300A,0x039A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,03A0)', tag_name: "Ion Tolerance Table Sequence", tag_key: 'IonToleranceTableSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,03A0)', tag_sym: :ion_tolerance_table_sequence, tag_ndm: '300A03A0', tag_ary: [0x300A,0x03A0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,03A2)', tag_name: "Ion Beam Sequence", tag_key: 'IonBeamSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,03A2)', tag_sym: :ion_beam_sequence, tag_ndm: '300A03A2', tag_ary: [0x300A,0x03A2], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,03A4)', tag_name: "Ion Beam Limiting Device Sequence", tag_key: 'IonBeamLimitingDeviceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,03A4)', tag_sym: :ion_beam_limiting_device_sequence, tag_ndm: '300A03A4', tag_ary: [0x300A,0x03A4], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,03A6)', tag_name: "Ion Block Sequence", tag_key: 'IonBlockSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,03A6)', tag_sym: :ion_block_sequence, tag_ndm: '300A03A6', tag_ary: [0x300A,0x03A6], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,03A8)', tag_name: "Ion Control Point Sequence", tag_key: 'IonControlPointSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,03A8)', tag_sym: :ion_control_point_sequence, tag_ndm: '300A03A8', tag_ary: [0x300A,0x03A8], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,03AA)', tag_name: "Ion Wedge Sequence", tag_key: 'IonWedgeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,03AA)', tag_sym: :ion_wedge_sequence, tag_ndm: '300A03AA', tag_ary: [0x300A,0x03AA], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,03AC)', tag_name: "Ion Wedge Position Sequence", tag_key: 'IonWedgePositionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,03AC)', tag_sym: :ion_wedge_position_sequence, tag_ndm: '300A03AC', tag_ary: [0x300A,0x03AC], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0401)', tag_name: "Referenced Setup Image Sequence", tag_key: 'ReferencedSetupImageSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0401)', tag_sym: :referenced_setup_image_sequence, tag_ndm: '300A0401', tag_ary: [0x300A,0x0401], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0402)', tag_name: "Setup Image Comment", tag_key: 'SetupImageComment', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(300A,0402)', tag_sym: :setup_image_comment, tag_ndm: '300A0402', tag_ary: [0x300A,0x0402], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0410)', tag_name: "Motion Synchronization Sequence", tag_key: 'MotionSynchronizationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0410)', tag_sym: :motion_synchronization_sequence, tag_ndm: '300A0410', tag_ary: [0x300A,0x0410], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0412)', tag_name: "Control Point Orientation", tag_key: 'ControlPointOrientation', tag_vr: [:FL], tag_vm: ["3"], tag_str: '(300A,0412)', tag_sym: :control_point_orientation, tag_ndm: '300A0412', tag_ary: [0x300A,0x0412], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0420)', tag_name: "General Accessory Sequence", tag_key: 'GeneralAccessorySequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0420)', tag_sym: :general_accessory_sequence, tag_ndm: '300A0420', tag_ary: [0x300A,0x0420], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0421)', tag_name: "General Accessory ID", tag_key: 'GeneralAccessoryID', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(300A,0421)', tag_sym: :general_accessory_id, tag_ndm: '300A0421', tag_ary: [0x300A,0x0421], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0422)', tag_name: "General Accessory Description", tag_key: 'GeneralAccessoryDescription', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(300A,0422)', tag_sym: :general_accessory_description, tag_ndm: '300A0422', tag_ary: [0x300A,0x0422], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0423)', tag_name: "General Accessory Type", tag_key: 'GeneralAccessoryType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,0423)', tag_sym: :general_accessory_type, tag_ndm: '300A0423', tag_ary: [0x300A,0x0423], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0424)', tag_name: "General Accessory Number", tag_key: 'GeneralAccessoryNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300A,0424)', tag_sym: :general_accessory_number, tag_ndm: '300A0424', tag_ary: [0x300A,0x0424], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0425)', tag_name: "Source to General Accessory Distance", tag_key: 'SourceToGeneralAccessoryDistance', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(300A,0425)', tag_sym: :source_to_general_accessory_distance, tag_ndm: '300A0425', tag_ary: [0x300A,0x0425], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0426)', tag_name: "Isocenter to General Accessory Distance", tag_key: 'IsocenterToGeneralAccessoryDistance', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,0426)', tag_sym: :isocenter_to_general_accessory_distance, tag_ndm: '300A0426', tag_ary: [0x300A,0x0426], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0431)', tag_name: "Applicator Geometry Sequence", tag_key: 'ApplicatorGeometrySequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0431)', tag_sym: :applicator_geometry_sequence, tag_ndm: '300A0431', tag_ary: [0x300A,0x0431], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0432)', tag_name: "Applicator Aperture Shape", tag_key: 'ApplicatorApertureShape', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,0432)', tag_sym: :applicator_aperture_shape, tag_ndm: '300A0432', tag_ary: [0x300A,0x0432], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0433)', tag_name: "Applicator Opening", tag_key: 'ApplicatorOpening', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(300A,0433)', tag_sym: :applicator_opening, tag_ndm: '300A0433', tag_ary: [0x300A,0x0433], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0434)', tag_name: "Applicator Opening X", tag_key: 'ApplicatorOpeningX', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(300A,0434)', tag_sym: :applicator_opening_x, tag_ndm: '300A0434', tag_ary: [0x300A,0x0434], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0435)', tag_name: "Applicator Opening Y", tag_key: 'ApplicatorOpeningY', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(300A,0435)', tag_sym: :applicator_opening_y, tag_ndm: '300A0435', tag_ary: [0x300A,0x0435], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0436)', tag_name: "Source to Applicator Mounting Position Distance", tag_key: 'SourceToApplicatorMountingPositionDistance', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(300A,0436)', tag_sym: :source_to_applicator_mounting_position_distance, tag_ndm: '300A0436', tag_ary: [0x300A,0x0436], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0440)', tag_name: "Number of Block Slab Items", tag_key: 'NumberOfBlockSlabItems', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300A,0440)', tag_sym: :number_of_block_slab_items, tag_ndm: '300A0440', tag_ary: [0x300A,0x0440], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0441)', tag_name: "Block Slab Sequence", tag_key: 'BlockSlabSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0441)', tag_sym: :block_slab_sequence, tag_ndm: '300A0441', tag_ary: [0x300A,0x0441], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0442)', tag_name: "Block Slab Thickness", tag_key: 'BlockSlabThickness', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,0442)', tag_sym: :block_slab_thickness, tag_ndm: '300A0442', tag_ary: [0x300A,0x0442], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0443)', tag_name: "Block Slab Number", tag_key: 'BlockSlabNumber', tag_vr: [:US], tag_vm: ["1"], tag_str: '(300A,0443)', tag_sym: :block_slab_number, tag_ndm: '300A0443', tag_ary: [0x300A,0x0443], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0450)', tag_name: "Device Motion Control Sequence", tag_key: 'DeviceMotionControlSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0450)', tag_sym: :device_motion_control_sequence, tag_ndm: '300A0450', tag_ary: [0x300A,0x0450], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0451)', tag_name: "Device Motion Execution Mode", tag_key: 'DeviceMotionExecutionMode', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,0451)', tag_sym: :device_motion_execution_mode, tag_ndm: '300A0451', tag_ary: [0x300A,0x0451], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0452)', tag_name: "Device Motion Observation Mode", tag_key: 'DeviceMotionObservationMode', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,0452)', tag_sym: :device_motion_observation_mode, tag_ndm: '300A0452', tag_ary: [0x300A,0x0452], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0453)', tag_name: "Device Motion Parameter Code Sequence", tag_key: 'DeviceMotionParameterCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0453)', tag_sym: :device_motion_parameter_code_sequence, tag_ndm: '300A0453', tag_ary: [0x300A,0x0453], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0501)', tag_name: "Distal Depth Fraction", tag_key: 'DistalDepthFraction', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(300A,0501)', tag_sym: :distal_depth_fraction, tag_ndm: '300A0501', tag_ary: [0x300A,0x0501], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0502)', tag_name: "Distal Depth", tag_key: 'DistalDepth', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(300A,0502)', tag_sym: :distal_depth, tag_ndm: '300A0502', tag_ary: [0x300A,0x0502], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0503)', tag_name: "Nominal Range Modulation Fractions", tag_key: 'NominalRangeModulationFractions', tag_vr: [:FL], tag_vm: ["2"], tag_str: '(300A,0503)', tag_sym: :nominal_range_modulation_fractions, tag_ndm: '300A0503', tag_ary: [0x300A,0x0503], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0504)', tag_name: "Nominal Range Modulated Region Depths", tag_key: 'NominalRangeModulatedRegionDepths', tag_vr: [:FL], tag_vm: ["2"], tag_str: '(300A,0504)', tag_sym: :nominal_range_modulated_region_depths, tag_ndm: '300A0504', tag_ary: [0x300A,0x0504], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0505)', tag_name: "Depth Dose Parameters Sequence", tag_key: 'DepthDoseParametersSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0505)', tag_sym: :depth_dose_parameters_sequence, tag_ndm: '300A0505', tag_ary: [0x300A,0x0505], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0506)', tag_name: "Delivered Depth Dose Parameters Sequence", tag_key: 'DeliveredDepthDoseParametersSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0506)', tag_sym: :delivered_depth_dose_parameters_sequence, tag_ndm: '300A0506', tag_ary: [0x300A,0x0506], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0507)', tag_name: "Delivered Distal Depth Fraction", tag_key: 'DeliveredDistalDepthFraction', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(300A,0507)', tag_sym: :delivered_distal_depth_fraction, tag_ndm: '300A0507', tag_ary: [0x300A,0x0507], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0508)', tag_name: "Delivered Distal Depth", tag_key: 'DeliveredDistalDepth', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(300A,0508)', tag_sym: :delivered_distal_depth, tag_ndm: '300A0508', tag_ary: [0x300A,0x0508], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0509)', tag_name: "Delivered Nominal Range Modulation Fractions", tag_key: 'DeliveredNominalRangeModulationFractions', tag_vr: [:FL], tag_vm: ["2"], tag_str: '(300A,0509)', tag_sym: :delivered_nominal_range_modulation_fractions, tag_ndm: '300A0509', tag_ary: [0x300A,0x0509], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0510)', tag_name: "Delivered Nominal Range Modulated Region Depths", tag_key: 'DeliveredNominalRangeModulatedRegionDepths', tag_vr: [:FL], tag_vm: ["2"], tag_str: '(300A,0510)', tag_sym: :delivered_nominal_range_modulated_region_depths, tag_ndm: '300A0510', tag_ary: [0x300A,0x0510], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0511)', tag_name: "Delivered Reference Dose Definition", tag_key: 'DeliveredReferenceDoseDefinition', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,0511)', tag_sym: :delivered_reference_dose_definition, tag_ndm: '300A0511', tag_ary: [0x300A,0x0511], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0512)', tag_name: "Reference Dose Definition", tag_key: 'ReferenceDoseDefinition', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,0512)', tag_sym: :reference_dose_definition, tag_ndm: '300A0512', tag_ary: [0x300A,0x0512], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0600)', tag_name: "RT Control Point Index", tag_key: 'RTControlPointIndex', tag_vr: [:US], tag_vm: ["1"], tag_str: '(300A,0600)', tag_sym: :rt_control_point_index, tag_ndm: '300A0600', tag_ary: [0x300A,0x0600], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0601)', tag_name: "Radiation Generation Mode Index", tag_key: 'RadiationGenerationModeIndex', tag_vr: [:US], tag_vm: ["1"], tag_str: '(300A,0601)', tag_sym: :radiation_generation_mode_index, tag_ndm: '300A0601', tag_ary: [0x300A,0x0601], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0602)', tag_name: "Referenced Defined Device Index", tag_key: 'ReferencedDefinedDeviceIndex', tag_vr: [:US], tag_vm: ["1"], tag_str: '(300A,0602)', tag_sym: :referenced_defined_device_index, tag_ndm: '300A0602', tag_ary: [0x300A,0x0602], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0603)', tag_name: "Radiation Dose Identification Index", tag_key: 'RadiationDoseIdentificationIndex', tag_vr: [:US], tag_vm: ["1"], tag_str: '(300A,0603)', tag_sym: :radiation_dose_identification_index, tag_ndm: '300A0603', tag_ary: [0x300A,0x0603], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0604)', tag_name: "Number of RT Control Points", tag_key: 'NumberOfRTControlPoints', tag_vr: [:US], tag_vm: ["1"], tag_str: '(300A,0604)', tag_sym: :number_of_rt_control_points, tag_ndm: '300A0604', tag_ary: [0x300A,0x0604], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0605)', tag_name: "Referenced Radiation Generation Mode Index", tag_key: 'ReferencedRadiationGenerationModeIndex', tag_vr: [:US], tag_vm: ["1"], tag_str: '(300A,0605)', tag_sym: :referenced_radiation_generation_mode_index, tag_ndm: '300A0605', tag_ary: [0x300A,0x0605], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0606)', tag_name: "Treatment Position Index", tag_key: 'TreatmentPositionIndex', tag_vr: [:US], tag_vm: ["1"], tag_str: '(300A,0606)', tag_sym: :treatment_position_index, tag_ndm: '300A0606', tag_ary: [0x300A,0x0606], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0607)', tag_name: "Referenced Device Index", tag_key: 'ReferencedDeviceIndex', tag_vr: [:US], tag_vm: ["1"], tag_str: '(300A,0607)', tag_sym: :referenced_device_index, tag_ndm: '300A0607', tag_ary: [0x300A,0x0607], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0608)', tag_name: "Treatment Position Group Label", tag_key: 'TreatmentPositionGroupLabel', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(300A,0608)', tag_sym: :treatment_position_group_label, tag_ndm: '300A0608', tag_ary: [0x300A,0x0608], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0609)', tag_name: "Treatment Position Group UID", tag_key: 'TreatmentPositionGroupUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(300A,0609)', tag_sym: :treatment_position_group_uid, tag_ndm: '300A0609', tag_ary: [0x300A,0x0609], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,060A)', tag_name: "Treatment Position Group Sequence", tag_key: 'TreatmentPositionGroupSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,060A)', tag_sym: :treatment_position_group_sequence, tag_ndm: '300A060A', tag_ary: [0x300A,0x060A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,060B)', tag_name: "Referenced Treatment Position Index", tag_key: 'ReferencedTreatmentPositionIndex', tag_vr: [:US], tag_vm: ["1"], tag_str: '(300A,060B)', tag_sym: :referenced_treatment_position_index, tag_ndm: '300A060B', tag_ary: [0x300A,0x060B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,060C)', tag_name: "Referenced Radiation Dose Identification Index", tag_key: 'ReferencedRadiationDoseIdentificationIndex', tag_vr: [:US], tag_vm: ["1"], tag_str: '(300A,060C)', tag_sym: :referenced_radiation_dose_identification_index, tag_ndm: '300A060C', tag_ary: [0x300A,0x060C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,060D)', tag_name: "RT Accessory Holder Water-Equivalent Thickness", tag_key: 'RTAccessoryHolderWaterEquivalentThickness', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(300A,060D)', tag_sym: :rt_accessory_holder_water_equivalent_thickness, tag_ndm: '300A060D', tag_ary: [0x300A,0x060D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,060E)', tag_name: "Referenced RT Accessory Holder Device Index", tag_key: 'ReferencedRTAccessoryHolderDeviceIndex', tag_vr: [:US], tag_vm: ["1"], tag_str: '(300A,060E)', tag_sym: :referenced_rt_accessory_holder_device_index, tag_ndm: '300A060E', tag_ary: [0x300A,0x060E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,060F)', tag_name: "RT Accessory Holder Slot Existence Flag", tag_key: 'RTAccessoryHolderSlotExistenceFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,060F)', tag_sym: :rt_accessory_holder_slot_existence_flag, tag_ndm: '300A060F', tag_ary: [0x300A,0x060F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0610)', tag_name: "RT Accessory Holder Slot Sequence", tag_key: 'RTAccessoryHolderSlotSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0610)', tag_sym: :rt_accessory_holder_slot_sequence, tag_ndm: '300A0610', tag_ary: [0x300A,0x0610], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0611)', tag_name: "RT Accessory Holder Slot ID", tag_key: 'RTAccessoryHolderSlotID', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(300A,0611)', tag_sym: :rt_accessory_holder_slot_id, tag_ndm: '300A0611', tag_ary: [0x300A,0x0611], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0612)', tag_name: "RT Accessory Holder Slot Distance", tag_key: 'RTAccessoryHolderSlotDistance', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(300A,0612)', tag_sym: :rt_accessory_holder_slot_distance, tag_ndm: '300A0612', tag_ary: [0x300A,0x0612], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0613)', tag_name: "RT Accessory Slot Distance", tag_key: 'RTAccessorySlotDistance', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(300A,0613)', tag_sym: :rt_accessory_slot_distance, tag_ndm: '300A0613', tag_ary: [0x300A,0x0613], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0614)', tag_name: "RT Accessory Holder Definition Sequence", tag_key: 'RTAccessoryHolderDefinitionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0614)', tag_sym: :rt_accessory_holder_definition_sequence, tag_ndm: '300A0614', tag_ary: [0x300A,0x0614], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0615)', tag_name: "RT Accessory Device Slot ID", tag_key: 'RTAccessoryDeviceSlotID', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(300A,0615)', tag_sym: :rt_accessory_device_slot_id, tag_ndm: '300A0615', tag_ary: [0x300A,0x0615], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0616)', tag_name: "RT Radiation Sequence", tag_key: 'RTRadiationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0616)', tag_sym: :rt_radiation_sequence, tag_ndm: '300A0616', tag_ary: [0x300A,0x0616], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0617)', tag_name: "Radiation Dose Sequence", tag_key: 'RadiationDoseSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0617)', tag_sym: :radiation_dose_sequence, tag_ndm: '300A0617', tag_ary: [0x300A,0x0617], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0618)', tag_name: "Radiation Dose Identification Sequence", tag_key: 'RadiationDoseIdentificationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0618)', tag_sym: :radiation_dose_identification_sequence, tag_ndm: '300A0618', tag_ary: [0x300A,0x0618], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0619)', tag_name: "Radiation Dose Identification Label", tag_key: 'RadiationDoseIdentificationLabel', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(300A,0619)', tag_sym: :radiation_dose_identification_label, tag_ndm: '300A0619', tag_ary: [0x300A,0x0619], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,061A)', tag_name: "Reference Dose Type", tag_key: 'ReferenceDoseType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,061A)', tag_sym: :reference_dose_type, tag_ndm: '300A061A', tag_ary: [0x300A,0x061A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,061B)', tag_name: "Primary Dose Value Indicator", tag_key: 'PrimaryDoseValueIndicator', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,061B)', tag_sym: :primary_dose_value_indicator, tag_ndm: '300A061B', tag_ary: [0x300A,0x061B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,061C)', tag_name: "Dose Values Sequence", tag_key: 'DoseValuesSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,061C)', tag_sym: :dose_values_sequence, tag_ndm: '300A061C', tag_ary: [0x300A,0x061C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,061D)', tag_name: "Dose Value Purpose", tag_key: 'DoseValuePurpose', tag_vr: [:CS], tag_vm: ["1-n"], tag_str: '(300A,061D)', tag_sym: :dose_value_purpose, tag_ndm: '300A061D', tag_ary: [0x300A,0x061D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,061E)', tag_name: "Reference Dose Point Coordinates", tag_key: 'ReferenceDosePointCoordinates', tag_vr: [:FD], tag_vm: ["3"], tag_str: '(300A,061E)', tag_sym: :reference_dose_point_coordinates, tag_ndm: '300A061E', tag_ary: [0x300A,0x061E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,061F)', tag_name: "Radiation Dose Values Parameters Sequence", tag_key: 'RadiationDoseValuesParametersSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,061F)', tag_sym: :radiation_dose_values_parameters_sequence, tag_ndm: '300A061F', tag_ary: [0x300A,0x061F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0620)', tag_name: "Meterset to Dose Mapping Sequence", tag_key: 'MetersetToDoseMappingSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0620)', tag_sym: :meterset_to_dose_mapping_sequence, tag_ndm: '300A0620', tag_ary: [0x300A,0x0620], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0621)', tag_name: "Expected In-Vivo Measurement Values Sequence", tag_key: 'ExpectedInVivoMeasurementValuesSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0621)', tag_sym: :expected_in_vivo_measurement_values_sequence, tag_ndm: '300A0621', tag_ary: [0x300A,0x0621], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0622)', tag_name: "Expected In-Vivo Measurement Value Index", tag_key: 'ExpectedInVivoMeasurementValueIndex', tag_vr: [:US], tag_vm: ["1"], tag_str: '(300A,0622)', tag_sym: :expected_in_vivo_measurement_value_index, tag_ndm: '300A0622', tag_ary: [0x300A,0x0622], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0623)', tag_name: "Radiation Dose In-Vivo Measurement Label", tag_key: 'RadiationDoseInVivoMeasurementLabel', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(300A,0623)', tag_sym: :radiation_dose_in_vivo_measurement_label, tag_ndm: '300A0623', tag_ary: [0x300A,0x0623], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0624)', tag_name: "Radiation Dose Central Axis Displacement", tag_key: 'RadiationDoseCentralAxisDisplacement', tag_vr: [:FD], tag_vm: ["2"], tag_str: '(300A,0624)', tag_sym: :radiation_dose_central_axis_displacement, tag_ndm: '300A0624', tag_ary: [0x300A,0x0624], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0625)', tag_name: "Radiation Dose Value", tag_key: 'RadiationDoseValue', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(300A,0625)', tag_sym: :radiation_dose_value, tag_ndm: '300A0625', tag_ary: [0x300A,0x0625], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0626)', tag_name: "Radiation Dose Source to Skin Distance", tag_key: 'RadiationDoseSourceToSkinDistance', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(300A,0626)', tag_sym: :radiation_dose_source_to_skin_distance, tag_ndm: '300A0626', tag_ary: [0x300A,0x0626], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0627)', tag_name: "Radiation Dose Measurement Point Coordinates", tag_key: 'RadiationDoseMeasurementPointCoordinates', tag_vr: [:FD], tag_vm: ["3"], tag_str: '(300A,0627)', tag_sym: :radiation_dose_measurement_point_coordinates, tag_ndm: '300A0627', tag_ary: [0x300A,0x0627], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0628)', tag_name: "Radiation Dose Source to External Contour Distance", tag_key: 'RadiationDoseSourceToExternalContourDistance', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(300A,0628)', tag_sym: :radiation_dose_source_to_external_contour_distance, tag_ndm: '300A0628', tag_ary: [0x300A,0x0628], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0629)', tag_name: "RT Tolerance Set Sequence", tag_key: 'RTToleranceSetSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0629)', tag_sym: :rt_tolerance_set_sequence, tag_ndm: '300A0629', tag_ary: [0x300A,0x0629], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,062A)', tag_name: "RT Tolerance Set Label", tag_key: 'RTToleranceSetLabel', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(300A,062A)', tag_sym: :rt_tolerance_set_label, tag_ndm: '300A062A', tag_ary: [0x300A,0x062A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,062B)', tag_name: "Attribute Tolerance Values Sequence", tag_key: 'AttributeToleranceValuesSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,062B)', tag_sym: :attribute_tolerance_values_sequence, tag_ndm: '300A062B', tag_ary: [0x300A,0x062B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,062C)', tag_name: "Tolerance Value", tag_key: 'ToleranceValue', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(300A,062C)', tag_sym: :tolerance_value, tag_ndm: '300A062C', tag_ary: [0x300A,0x062C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,062D)', tag_name: "Patient Support Position Tolerance Sequence", tag_key: 'PatientSupportPositionToleranceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,062D)', tag_sym: :patient_support_position_tolerance_sequence, tag_ndm: '300A062D', tag_ary: [0x300A,0x062D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,062E)', tag_name: "Treatment Time Limit", tag_key: 'TreatmentTimeLimit', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(300A,062E)', tag_sym: :treatment_time_limit, tag_ndm: '300A062E', tag_ary: [0x300A,0x062E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,062F)', tag_name: "C-Arm Photon-Electron Control Point Sequence", tag_key: 'CArmPhotonElectronControlPointSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,062F)', tag_sym: :c_arm_photon_electron_control_point_sequence, tag_ndm: '300A062F', tag_ary: [0x300A,0x062F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0630)', tag_name: "Referenced RT Radiation Sequence", tag_key: 'ReferencedRTRadiationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0630)', tag_sym: :referenced_rt_radiation_sequence, tag_ndm: '300A0630', tag_ary: [0x300A,0x0630], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0631)', tag_name: "Referenced RT Instance Sequence", tag_key: 'ReferencedRTInstanceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0631)', tag_sym: :referenced_rt_instance_sequence, tag_ndm: '300A0631', tag_ary: [0x300A,0x0631], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0632)', tag_name: "Referenced RT Patient Setup Sequence", tag_key: 'ReferencedRTPatientSetupSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0632)', tag_sym: :referenced_rt_patient_setup_sequence, tag_ndm: '300A0632', tag_ary: [0x300A,0x0632], tag_multiple: false, tag_note: 'RET (2021c)'},
      { tag_ps: '(300A,0634)', tag_name: "Source to Patient Surface Distance", tag_key: 'SourceToPatientSurfaceDistance', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(300A,0634)', tag_sym: :source_to_patient_surface_distance, tag_ndm: '300A0634', tag_ary: [0x300A,0x0634], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0635)', tag_name: "Treatment Machine Special Mode Code Sequence", tag_key: 'TreatmentMachineSpecialModeCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0635)', tag_sym: :treatment_machine_special_mode_code_sequence, tag_ndm: '300A0635', tag_ary: [0x300A,0x0635], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0636)', tag_name: "Intended Number of Fractions", tag_key: 'IntendedNumberOfFractions', tag_vr: [:US], tag_vm: ["1"], tag_str: '(300A,0636)', tag_sym: :intended_number_of_fractions, tag_ndm: '300A0636', tag_ary: [0x300A,0x0636], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0637)', tag_name: "RT Radiation Set Intent", tag_key: 'RTRadiationSetIntent', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,0637)', tag_sym: :rt_radiation_set_intent, tag_ndm: '300A0637', tag_ary: [0x300A,0x0637], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0638)', tag_name: "RT Radiation Physical and Geometric Content Detail Flag", tag_key: 'RTRadiationPhysicalAndGeometricContentDetailFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,0638)', tag_sym: :rt_radiation_physical_and_geometric_content_detail_flag, tag_ndm: '300A0638', tag_ary: [0x300A,0x0638], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0639)', tag_name: "RT Record Flag", tag_key: 'RTRecordFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,0639)', tag_sym: :rt_record_flag, tag_ndm: '300A0639', tag_ary: [0x300A,0x0639], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,063A)', tag_name: "Treatment Device Identification Sequence", tag_key: 'TreatmentDeviceIdentificationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,063A)', tag_sym: :treatment_device_identification_sequence, tag_ndm: '300A063A', tag_ary: [0x300A,0x063A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,063B)', tag_name: "Referenced RT Physician Intent Sequence", tag_key: 'ReferencedRTPhysicianIntentSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,063B)', tag_sym: :referenced_rt_physician_intent_sequence, tag_ndm: '300A063B', tag_ary: [0x300A,0x063B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,063C)', tag_name: "Cumulative Meterset", tag_key: 'CumulativeMeterset', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(300A,063C)', tag_sym: :cumulative_meterset, tag_ndm: '300A063C', tag_ary: [0x300A,0x063C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,063D)', tag_name: "Delivery Rate", tag_key: 'DeliveryRate', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(300A,063D)', tag_sym: :delivery_rate, tag_ndm: '300A063D', tag_ary: [0x300A,0x063D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,063E)', tag_name: "Delivery Rate Unit Sequence", tag_key: 'DeliveryRateUnitSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,063E)', tag_sym: :delivery_rate_unit_sequence, tag_ndm: '300A063E', tag_ary: [0x300A,0x063E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,063F)', tag_name: "Treatment Position Sequence", tag_key: 'TreatmentPositionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,063F)', tag_sym: :treatment_position_sequence, tag_ndm: '300A063F', tag_ary: [0x300A,0x063F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0640)', tag_name: "Radiation Source-Axis Distance", tag_key: 'RadiationSourceAxisDistance', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(300A,0640)', tag_sym: :radiation_source_axis_distance, tag_ndm: '300A0640', tag_ary: [0x300A,0x0640], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0641)', tag_name: "Number of RT Beam Limiting Devices", tag_key: 'NumberOfRTBeamLimitingDevices', tag_vr: [:US], tag_vm: ["1"], tag_str: '(300A,0641)', tag_sym: :number_of_rt_beam_limiting_devices, tag_ndm: '300A0641', tag_ary: [0x300A,0x0641], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0642)', tag_name: "RT Beam Limiting Device Proximal Distance", tag_key: 'RTBeamLimitingDeviceProximalDistance', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(300A,0642)', tag_sym: :rt_beam_limiting_device_proximal_distance, tag_ndm: '300A0642', tag_ary: [0x300A,0x0642], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0643)', tag_name: "RT Beam Limiting Device Distal Distance", tag_key: 'RTBeamLimitingDeviceDistalDistance', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(300A,0643)', tag_sym: :rt_beam_limiting_device_distal_distance, tag_ndm: '300A0643', tag_ary: [0x300A,0x0643], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0644)', tag_name: "Parallel RT Beam Delimiter Device Orientation Label Code Sequence", tag_key: 'ParallelRTBeamDelimiterDeviceOrientationLabelCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0644)', tag_sym: :parallel_rt_beam_delimiter_device_orientation_label_code_sequence, tag_ndm: '300A0644', tag_ary: [0x300A,0x0644], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0645)', tag_name: "Beam Modifier Orientation Angle", tag_key: 'BeamModifierOrientationAngle', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(300A,0645)', tag_sym: :beam_modifier_orientation_angle, tag_ndm: '300A0645', tag_ary: [0x300A,0x0645], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0646)', tag_name: "Fixed RT Beam Delimiter Device Sequence", tag_key: 'FixedRTBeamDelimiterDeviceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0646)', tag_sym: :fixed_rt_beam_delimiter_device_sequence, tag_ndm: '300A0646', tag_ary: [0x300A,0x0646], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0647)', tag_name: "Parallel RT Beam Delimiter Device Sequence", tag_key: 'ParallelRTBeamDelimiterDeviceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0647)', tag_sym: :parallel_rt_beam_delimiter_device_sequence, tag_ndm: '300A0647', tag_ary: [0x300A,0x0647], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0648)', tag_name: "Number of Parallel RT Beam Delimiters", tag_key: 'NumberOfParallelRTBeamDelimiters', tag_vr: [:US], tag_vm: ["1"], tag_str: '(300A,0648)', tag_sym: :number_of_parallel_rt_beam_delimiters, tag_ndm: '300A0648', tag_ary: [0x300A,0x0648], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0649)', tag_name: "Parallel RT Beam Delimiter Boundaries", tag_key: 'ParallelRTBeamDelimiterBoundaries', tag_vr: [:FD], tag_vm: ["2-n"], tag_str: '(300A,0649)', tag_sym: :parallel_rt_beam_delimiter_boundaries, tag_ndm: '300A0649', tag_ary: [0x300A,0x0649], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,064A)', tag_name: "Parallel RT Beam Delimiter Positions", tag_key: 'ParallelRTBeamDelimiterPositions', tag_vr: [:FD], tag_vm: ["2-n"], tag_str: '(300A,064A)', tag_sym: :parallel_rt_beam_delimiter_positions, tag_ndm: '300A064A', tag_ary: [0x300A,0x064A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,064B)', tag_name: "RT Beam Limiting Device Offset", tag_key: 'RTBeamLimitingDeviceOffset', tag_vr: [:FD], tag_vm: ["2"], tag_str: '(300A,064B)', tag_sym: :rt_beam_limiting_device_offset, tag_ndm: '300A064B', tag_ary: [0x300A,0x064B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,064C)', tag_name: "RT Beam Delimiter Geometry Sequence", tag_key: 'RTBeamDelimiterGeometrySequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,064C)', tag_sym: :rt_beam_delimiter_geometry_sequence, tag_ndm: '300A064C', tag_ary: [0x300A,0x064C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,064D)', tag_name: "RT Beam Limiting Device Definition Sequence", tag_key: 'RTBeamLimitingDeviceDefinitionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,064D)', tag_sym: :rt_beam_limiting_device_definition_sequence, tag_ndm: '300A064D', tag_ary: [0x300A,0x064D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,064E)', tag_name: "Parallel RT Beam Delimiter Opening Mode", tag_key: 'ParallelRTBeamDelimiterOpeningMode', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,064E)', tag_sym: :parallel_rt_beam_delimiter_opening_mode, tag_ndm: '300A064E', tag_ary: [0x300A,0x064E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,064F)', tag_name: "Parallel RT Beam Delimiter Leaf Mounting Side", tag_key: 'ParallelRTBeamDelimiterLeafMountingSide', tag_vr: [:CS], tag_vm: ["1-n"], tag_str: '(300A,064F)', tag_sym: :parallel_rt_beam_delimiter_leaf_mounting_side, tag_ndm: '300A064F', tag_ary: [0x300A,0x064F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0650)', tag_name: "Patient Setup UID", tag_key: 'PatientSetupUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(300A,0650)', tag_sym: :patient_setup_uid, tag_ndm: '300A0650', tag_ary: [0x300A,0x0650], tag_multiple: false, tag_note: 'RET (2021c)'},
      { tag_ps: '(300A,0651)', tag_name: "Wedge Definition Sequence", tag_key: 'WedgeDefinitionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0651)', tag_sym: :wedge_definition_sequence, tag_ndm: '300A0651', tag_ary: [0x300A,0x0651], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0652)', tag_name: "Radiation Beam Wedge Angle", tag_key: 'RadiationBeamWedgeAngle', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(300A,0652)', tag_sym: :radiation_beam_wedge_angle, tag_ndm: '300A0652', tag_ary: [0x300A,0x0652], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0653)', tag_name: "Radiation Beam Wedge Thin Edge Distance", tag_key: 'RadiationBeamWedgeThinEdgeDistance', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(300A,0653)', tag_sym: :radiation_beam_wedge_thin_edge_distance, tag_ndm: '300A0653', tag_ary: [0x300A,0x0653], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0654)', tag_name: "Radiation Beam Effective Wedge Angle", tag_key: 'RadiationBeamEffectiveWedgeAngle', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(300A,0654)', tag_sym: :radiation_beam_effective_wedge_angle, tag_ndm: '300A0654', tag_ary: [0x300A,0x0654], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0655)', tag_name: "Number of Wedge Positions", tag_key: 'NumberOfWedgePositions', tag_vr: [:US], tag_vm: ["1"], tag_str: '(300A,0655)', tag_sym: :number_of_wedge_positions, tag_ndm: '300A0655', tag_ary: [0x300A,0x0655], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0656)', tag_name: "RT Beam Limiting Device Opening Sequence", tag_key: 'RTBeamLimitingDeviceOpeningSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0656)', tag_sym: :rt_beam_limiting_device_opening_sequence, tag_ndm: '300A0656', tag_ary: [0x300A,0x0656], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0657)', tag_name: "Number of RT Beam Limiting Device Openings", tag_key: 'NumberOfRTBeamLimitingDeviceOpenings', tag_vr: [:US], tag_vm: ["1"], tag_str: '(300A,0657)', tag_sym: :number_of_rt_beam_limiting_device_openings, tag_ndm: '300A0657', tag_ary: [0x300A,0x0657], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0658)', tag_name: "Radiation Dosimeter Unit Sequence", tag_key: 'RadiationDosimeterUnitSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0658)', tag_sym: :radiation_dosimeter_unit_sequence, tag_ndm: '300A0658', tag_ary: [0x300A,0x0658], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0659)', tag_name: "RT Device Distance Reference Location Code Sequence", tag_key: 'RTDeviceDistanceReferenceLocationCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0659)', tag_sym: :rt_device_distance_reference_location_code_sequence, tag_ndm: '300A0659', tag_ary: [0x300A,0x0659], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,065A)', tag_name: "Radiation Device Configuration and Commissioning Key Sequence", tag_key: 'RadiationDeviceConfigurationAndCommissioningKeySequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,065A)', tag_sym: :radiation_device_configuration_and_commissioning_key_sequence, tag_ndm: '300A065A', tag_ary: [0x300A,0x065A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,065B)', tag_name: "Patient Support Position Parameter Sequence", tag_key: 'PatientSupportPositionParameterSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,065B)', tag_sym: :patient_support_position_parameter_sequence, tag_ndm: '300A065B', tag_ary: [0x300A,0x065B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,065C)', tag_name: "Patient Support Position Specification Method", tag_key: 'PatientSupportPositionSpecificationMethod', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,065C)', tag_sym: :patient_support_position_specification_method, tag_ndm: '300A065C', tag_ary: [0x300A,0x065C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,065D)', tag_name: "Patient Support Position Device Parameter Sequence", tag_key: 'PatientSupportPositionDeviceParameterSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,065D)', tag_sym: :patient_support_position_device_parameter_sequence, tag_ndm: '300A065D', tag_ary: [0x300A,0x065D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,065E)', tag_name: "Device Order Index", tag_key: 'DeviceOrderIndex', tag_vr: [:US], tag_vm: ["1"], tag_str: '(300A,065E)', tag_sym: :device_order_index, tag_ndm: '300A065E', tag_ary: [0x300A,0x065E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,065F)', tag_name: "Patient Support Position Parameter Order Index", tag_key: 'PatientSupportPositionParameterOrderIndex', tag_vr: [:US], tag_vm: ["1"], tag_str: '(300A,065F)', tag_sym: :patient_support_position_parameter_order_index, tag_ndm: '300A065F', tag_ary: [0x300A,0x065F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0660)', tag_name: "Patient Support Position Device Tolerance Sequence", tag_key: 'PatientSupportPositionDeviceToleranceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0660)', tag_sym: :patient_support_position_device_tolerance_sequence, tag_ndm: '300A0660', tag_ary: [0x300A,0x0660], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0661)', tag_name: "Patient Support Position Tolerance Order Index", tag_key: 'PatientSupportPositionToleranceOrderIndex', tag_vr: [:US], tag_vm: ["1"], tag_str: '(300A,0661)', tag_sym: :patient_support_position_tolerance_order_index, tag_ndm: '300A0661', tag_ary: [0x300A,0x0661], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0662)', tag_name: "Compensator Definition Sequence", tag_key: 'CompensatorDefinitionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0662)', tag_sym: :compensator_definition_sequence, tag_ndm: '300A0662', tag_ary: [0x300A,0x0662], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0663)', tag_name: "Compensator Map Orientation", tag_key: 'CompensatorMapOrientation', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,0663)', tag_sym: :compensator_map_orientation, tag_ndm: '300A0663', tag_ary: [0x300A,0x0663], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0664)', tag_name: "Compensator Proximal Thickness Map", tag_key: 'CompensatorProximalThicknessMap', tag_vr: [:OF], tag_vm: ["1"], tag_str: '(300A,0664)', tag_sym: :compensator_proximal_thickness_map, tag_ndm: '300A0664', tag_ary: [0x300A,0x0664], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0665)', tag_name: "Compensator Distal Thickness Map", tag_key: 'CompensatorDistalThicknessMap', tag_vr: [:OF], tag_vm: ["1"], tag_str: '(300A,0665)', tag_sym: :compensator_distal_thickness_map, tag_ndm: '300A0665', tag_ary: [0x300A,0x0665], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0666)', tag_name: "Compensator Base Plane Offset", tag_key: 'CompensatorBasePlaneOffset', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(300A,0666)', tag_sym: :compensator_base_plane_offset, tag_ndm: '300A0666', tag_ary: [0x300A,0x0666], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0667)', tag_name: "Compensator Shape Fabrication Code Sequence", tag_key: 'CompensatorShapeFabricationCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0667)', tag_sym: :compensator_shape_fabrication_code_sequence, tag_ndm: '300A0667', tag_ary: [0x300A,0x0667], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0668)', tag_name: "Compensator Shape Sequence", tag_key: 'CompensatorShapeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0668)', tag_sym: :compensator_shape_sequence, tag_ndm: '300A0668', tag_ary: [0x300A,0x0668], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0669)', tag_name: "Radiation Beam Compensator Milling Tool Diameter", tag_key: 'RadiationBeamCompensatorMillingToolDiameter', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(300A,0669)', tag_sym: :radiation_beam_compensator_milling_tool_diameter, tag_ndm: '300A0669', tag_ary: [0x300A,0x0669], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,066A)', tag_name: "Block Definition Sequence", tag_key: 'BlockDefinitionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,066A)', tag_sym: :block_definition_sequence, tag_ndm: '300A066A', tag_ary: [0x300A,0x066A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,066B)', tag_name: "Block Edge Data", tag_key: 'BlockEdgeData', tag_vr: [:OF], tag_vm: ["1"], tag_str: '(300A,066B)', tag_sym: :block_edge_data, tag_ndm: '300A066B', tag_ary: [0x300A,0x066B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,066C)', tag_name: "Block Orientation", tag_key: 'BlockOrientation', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,066C)', tag_sym: :block_orientation, tag_ndm: '300A066C', tag_ary: [0x300A,0x066C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,066D)', tag_name: "Radiation Beam Block Thickness", tag_key: 'RadiationBeamBlockThickness', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(300A,066D)', tag_sym: :radiation_beam_block_thickness, tag_ndm: '300A066D', tag_ary: [0x300A,0x066D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,066E)', tag_name: "Radiation Beam Block Slab Thickness", tag_key: 'RadiationBeamBlockSlabThickness', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(300A,066E)', tag_sym: :radiation_beam_block_slab_thickness, tag_ndm: '300A066E', tag_ary: [0x300A,0x066E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,066F)', tag_name: "Block Edge Data Sequence", tag_key: 'BlockEdgeDataSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,066F)', tag_sym: :block_edge_data_sequence, tag_ndm: '300A066F', tag_ary: [0x300A,0x066F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0670)', tag_name: "Number of RT Accessory Holders", tag_key: 'NumberOfRTAccessoryHolders', tag_vr: [:US], tag_vm: ["1"], tag_str: '(300A,0670)', tag_sym: :number_of_rt_accessory_holders, tag_ndm: '300A0670', tag_ary: [0x300A,0x0670], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0671)', tag_name: "General Accessory Definition Sequence", tag_key: 'GeneralAccessoryDefinitionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0671)', tag_sym: :general_accessory_definition_sequence, tag_ndm: '300A0671', tag_ary: [0x300A,0x0671], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0672)', tag_name: "Number of General Accessories", tag_key: 'NumberOfGeneralAccessories', tag_vr: [:US], tag_vm: ["1"], tag_str: '(300A,0672)', tag_sym: :number_of_general_accessories, tag_ndm: '300A0672', tag_ary: [0x300A,0x0672], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0673)', tag_name: "Bolus Definition Sequence", tag_key: 'BolusDefinitionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0673)', tag_sym: :bolus_definition_sequence, tag_ndm: '300A0673', tag_ary: [0x300A,0x0673], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0674)', tag_name: "Number of Boluses", tag_key: 'NumberOfBoluses', tag_vr: [:US], tag_vm: ["1"], tag_str: '(300A,0674)', tag_sym: :number_of_boluses, tag_ndm: '300A0674', tag_ary: [0x300A,0x0674], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0675)', tag_name: "Equipment Frame of Reference UID", tag_key: 'EquipmentFrameOfReferenceUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(300A,0675)', tag_sym: :equipment_frame_of_reference_uid, tag_ndm: '300A0675', tag_ary: [0x300A,0x0675], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0676)', tag_name: "Equipment Frame of Reference Description", tag_key: 'EquipmentFrameOfReferenceDescription', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(300A,0676)', tag_sym: :equipment_frame_of_reference_description, tag_ndm: '300A0676', tag_ary: [0x300A,0x0676], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0677)', tag_name: "Equipment Reference Point Coordinates Sequence", tag_key: 'EquipmentReferencePointCoordinatesSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0677)', tag_sym: :equipment_reference_point_coordinates_sequence, tag_ndm: '300A0677', tag_ary: [0x300A,0x0677], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0678)', tag_name: "Equipment Reference Point Code Sequence", tag_key: 'EquipmentReferencePointCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0678)', tag_sym: :equipment_reference_point_code_sequence, tag_ndm: '300A0678', tag_ary: [0x300A,0x0678], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0679)', tag_name: "RT Beam Limiting Device Angle", tag_key: 'RTBeamLimitingDeviceAngle', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(300A,0679)', tag_sym: :rt_beam_limiting_device_angle, tag_ndm: '300A0679', tag_ary: [0x300A,0x0679], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,067A)', tag_name: "Source Roll Angle", tag_key: 'SourceRollAngle', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(300A,067A)', tag_sym: :source_roll_angle, tag_ndm: '300A067A', tag_ary: [0x300A,0x067A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,067B)', tag_name: "Radiation GenerationMode Sequence", tag_key: 'RadiationGenerationModeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,067B)', tag_sym: :radiation_generation_mode_sequence, tag_ndm: '300A067B', tag_ary: [0x300A,0x067B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,067C)', tag_name: "Radiation GenerationMode Label", tag_key: 'RadiationGenerationModeLabel', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(300A,067C)', tag_sym: :radiation_generation_mode_label, tag_ndm: '300A067C', tag_ary: [0x300A,0x067C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,067D)', tag_name: "Radiation GenerationMode Description", tag_key: 'RadiationGenerationModeDescription', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(300A,067D)', tag_sym: :radiation_generation_mode_description, tag_ndm: '300A067D', tag_ary: [0x300A,0x067D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,067E)', tag_name: "Radiation GenerationMode Machine Code Sequence", tag_key: 'RadiationGenerationModeMachineCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,067E)', tag_sym: :radiation_generation_mode_machine_code_sequence, tag_ndm: '300A067E', tag_ary: [0x300A,0x067E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,067F)', tag_name: "Radiation Type Code Sequence", tag_key: 'RadiationTypeCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,067F)', tag_sym: :radiation_type_code_sequence, tag_ndm: '300A067F', tag_ary: [0x300A,0x067F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0680)', tag_name: "Nominal Energy", tag_key: 'NominalEnergy', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,0680)', tag_sym: :nominal_energy, tag_ndm: '300A0680', tag_ary: [0x300A,0x0680], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0681)', tag_name: "Minimum Nominal Energy", tag_key: 'MinimumNominalEnergy', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,0681)', tag_sym: :minimum_nominal_energy, tag_ndm: '300A0681', tag_ary: [0x300A,0x0681], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0682)', tag_name: "Maximum Nominal Energy", tag_key: 'MaximumNominalEnergy', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300A,0682)', tag_sym: :maximum_nominal_energy, tag_ndm: '300A0682', tag_ary: [0x300A,0x0682], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0683)', tag_name: "Radiation Fluence Modifier Code Sequence", tag_key: 'RadiationFluenceModifierCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0683)', tag_sym: :radiation_fluence_modifier_code_sequence, tag_ndm: '300A0683', tag_ary: [0x300A,0x0683], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0684)', tag_name: "Energy Unit Code Sequence", tag_key: 'EnergyUnitCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0684)', tag_sym: :energy_unit_code_sequence, tag_ndm: '300A0684', tag_ary: [0x300A,0x0684], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0685)', tag_name: "Number of Radiation GenerationModes", tag_key: 'NumberOfRadiationGenerationModes', tag_vr: [:US], tag_vm: ["1"], tag_str: '(300A,0685)', tag_sym: :number_of_radiation_generation_modes, tag_ndm: '300A0685', tag_ary: [0x300A,0x0685], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0686)', tag_name: "Patient Support Devices Sequence", tag_key: 'PatientSupportDevicesSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0686)', tag_sym: :patient_support_devices_sequence, tag_ndm: '300A0686', tag_ary: [0x300A,0x0686], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0687)', tag_name: "Number of Patient Support Devices", tag_key: 'NumberOfPatientSupportDevices', tag_vr: [:US], tag_vm: ["1"], tag_str: '(300A,0687)', tag_sym: :number_of_patient_support_devices, tag_ndm: '300A0687', tag_ary: [0x300A,0x0687], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0688)', tag_name: "RT Beam Modifier Definition Distance", tag_key: 'RTBeamModifierDefinitionDistance', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(300A,0688)', tag_sym: :rt_beam_modifier_definition_distance, tag_ndm: '300A0688', tag_ary: [0x300A,0x0688], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0689)', tag_name: "Beam Area Limit Sequence", tag_key: 'BeamAreaLimitSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0689)', tag_sym: :beam_area_limit_sequence, tag_ndm: '300A0689', tag_ary: [0x300A,0x0689], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,068A)', tag_name: "Referenced RT Prescription Sequence", tag_key: 'ReferencedRTPrescriptionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,068A)', tag_sym: :referenced_rt_prescription_sequence, tag_ndm: '300A068A', tag_ary: [0x300A,0x068A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,068B)', tag_name: "Dose Value Interpretation", tag_key: 'DoseValueInterpretation', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,068B)', tag_sym: :dose_value_interpretation, tag_ndm: '300A068B', tag_ary: [0x300A,0x068B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0700)', tag_name: "Treatment Session UID", tag_key: 'TreatmentSessionUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(300A,0700)', tag_sym: :treatment_session_uid, tag_ndm: '300A0700', tag_ary: [0x300A,0x0700], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0701)', tag_name: "RT Radiation Usage", tag_key: 'RTRadiationUsage', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,0701)', tag_sym: :rt_radiation_usage, tag_ndm: '300A0701', tag_ary: [0x300A,0x0701], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0702)', tag_name: "Referenced RT Radiation Set Sequence", tag_key: 'ReferencedRTRadiationSetSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0702)', tag_sym: :referenced_rt_radiation_set_sequence, tag_ndm: '300A0702', tag_ary: [0x300A,0x0702], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0703)', tag_name: "Referenced RT Radiation Record Sequence", tag_key: 'ReferencedRTRadiationRecordSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0703)', tag_sym: :referenced_rt_radiation_record_sequence, tag_ndm: '300A0703', tag_ary: [0x300A,0x0703], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0704)', tag_name: "RT Radiation Set Delivery Number", tag_key: 'RTRadiationSetDeliveryNumber', tag_vr: [:US], tag_vm: ["1"], tag_str: '(300A,0704)', tag_sym: :rt_radiation_set_delivery_number, tag_ndm: '300A0704', tag_ary: [0x300A,0x0704], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0705)', tag_name: "Clinical Fraction Number", tag_key: 'ClinicalFractionNumber', tag_vr: [:US], tag_vm: ["1"], tag_str: '(300A,0705)', tag_sym: :clinical_fraction_number, tag_ndm: '300A0705', tag_ary: [0x300A,0x0705], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0706)', tag_name: "RT Treatment Fraction Completion Status", tag_key: 'RTTreatmentFractionCompletionStatus', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,0706)', tag_sym: :rt_treatment_fraction_completion_status, tag_ndm: '300A0706', tag_ary: [0x300A,0x0706], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0707)', tag_name: "RT Radiation Set Usage", tag_key: 'RTRadiationSetUsage', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,0707)', tag_sym: :rt_radiation_set_usage, tag_ndm: '300A0707', tag_ary: [0x300A,0x0707], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0708)', tag_name: "Treatment Delivery Continuation Flag", tag_key: 'TreatmentDeliveryContinuationFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,0708)', tag_sym: :treatment_delivery_continuation_flag, tag_ndm: '300A0708', tag_ary: [0x300A,0x0708], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0709)', tag_name: "Treatment Record Content Origin", tag_key: 'TreatmentRecordContentOrigin', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,0709)', tag_sym: :treatment_record_content_origin, tag_ndm: '300A0709', tag_ary: [0x300A,0x0709], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0714)', tag_name: "RT Treatment Termination Status", tag_key: 'RTTreatmentTerminationStatus', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,0714)', tag_sym: :rt_treatment_termination_status, tag_ndm: '300A0714', tag_ary: [0x300A,0x0714], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0715)', tag_name: "RT Treatment Termination Reason Code Sequence", tag_key: 'RTTreatmentTerminationReasonCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0715)', tag_sym: :rt_treatment_termination_reason_code_sequence, tag_ndm: '300A0715', tag_ary: [0x300A,0x0715], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0716)', tag_name: "Machine-Specific Treatment Termination Code Sequence", tag_key: 'MachineSpecificTreatmentTerminationCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0716)', tag_sym: :machine_specific_treatment_termination_code_sequence, tag_ndm: '300A0716', tag_ary: [0x300A,0x0716], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0722)', tag_name: "RT Radiation Salvage Record Control Point Sequence", tag_key: 'RTRadiationSalvageRecordControlPointSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0722)', tag_sym: :rt_radiation_salvage_record_control_point_sequence, tag_ndm: '300A0722', tag_ary: [0x300A,0x0722], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0723)', tag_name: "Starting Meterset Value Known Flag", tag_key: 'StartingMetersetValueKnownFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,0723)', tag_sym: :starting_meterset_value_known_flag, tag_ndm: '300A0723', tag_ary: [0x300A,0x0723], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0730)', tag_name: "Treatment Termination Description", tag_key: 'TreatmentTerminationDescription', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(300A,0730)', tag_sym: :treatment_termination_description, tag_ndm: '300A0730', tag_ary: [0x300A,0x0730], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0731)', tag_name: "Treatment Tolerance Violation Sequence", tag_key: 'TreatmentToleranceViolationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0731)', tag_sym: :treatment_tolerance_violation_sequence, tag_ndm: '300A0731', tag_ary: [0x300A,0x0731], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0732)', tag_name: "Treatment Tolerance Violation Category", tag_key: 'TreatmentToleranceViolationCategory', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,0732)', tag_sym: :treatment_tolerance_violation_category, tag_ndm: '300A0732', tag_ary: [0x300A,0x0732], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0733)', tag_name: "Treatment Tolerance Violation Attribute Sequence", tag_key: 'TreatmentToleranceViolationAttributeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0733)', tag_sym: :treatment_tolerance_violation_attribute_sequence, tag_ndm: '300A0733', tag_ary: [0x300A,0x0733], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0734)', tag_name: "Treatment Tolerance Violation Description", tag_key: 'TreatmentToleranceViolationDescription', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(300A,0734)', tag_sym: :treatment_tolerance_violation_description, tag_ndm: '300A0734', tag_ary: [0x300A,0x0734], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0735)', tag_name: "Treatment Tolerance Violation Identification", tag_key: 'TreatmentToleranceViolationIdentification', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(300A,0735)', tag_sym: :treatment_tolerance_violation_identification, tag_ndm: '300A0735', tag_ary: [0x300A,0x0735], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0736)', tag_name: "Treatment Tolerance Violation DateTime", tag_key: 'TreatmentToleranceViolationDateTime', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(300A,0736)', tag_sym: :treatment_tolerance_violation_date_time, tag_ndm: '300A0736', tag_ary: [0x300A,0x0736], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,073A)', tag_name: "Recorded RT Control Point DateTime", tag_key: 'RecordedRTControlPointDateTime', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(300A,073A)', tag_sym: :recorded_rt_control_point_date_time, tag_ndm: '300A073A', tag_ary: [0x300A,0x073A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,073B)', tag_name: "Referenced Radiation RT Control Point Index", tag_key: 'ReferencedRadiationRTControlPointIndex', tag_vr: [:US], tag_vm: ["1"], tag_str: '(300A,073B)', tag_sym: :referenced_radiation_rt_control_point_index, tag_ndm: '300A073B', tag_ary: [0x300A,0x073B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,073E)', tag_name: "Alternate Value Sequence", tag_key: 'AlternateValueSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,073E)', tag_sym: :alternate_value_sequence, tag_ndm: '300A073E', tag_ary: [0x300A,0x073E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,073F)', tag_name: "Confirmation Sequence", tag_key: 'ConfirmationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,073F)', tag_sym: :confirmation_sequence, tag_ndm: '300A073F', tag_ary: [0x300A,0x073F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0740)', tag_name: "Interlock Sequence", tag_key: 'InterlockSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0740)', tag_sym: :interlock_sequence, tag_ndm: '300A0740', tag_ary: [0x300A,0x0740], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0741)', tag_name: "Interlock DateTime", tag_key: 'InterlockDateTime', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(300A,0741)', tag_sym: :interlock_date_time, tag_ndm: '300A0741', tag_ary: [0x300A,0x0741], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0742)', tag_name: "Interlock Description", tag_key: 'InterlockDescription', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(300A,0742)', tag_sym: :interlock_description, tag_ndm: '300A0742', tag_ary: [0x300A,0x0742], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0743)', tag_name: "Interlock Originating Device Sequence", tag_key: 'InterlockOriginatingDeviceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0743)', tag_sym: :interlock_originating_device_sequence, tag_ndm: '300A0743', tag_ary: [0x300A,0x0743], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0744)', tag_name: "Interlock Code Sequence", tag_key: 'InterlockCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0744)', tag_sym: :interlock_code_sequence, tag_ndm: '300A0744', tag_ary: [0x300A,0x0744], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0745)', tag_name: "Interlock Resolution Code Sequence", tag_key: 'InterlockResolutionCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0745)', tag_sym: :interlock_resolution_code_sequence, tag_ndm: '300A0745', tag_ary: [0x300A,0x0745], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0746)', tag_name: "Interlock Resolution User Sequence", tag_key: 'InterlockResolutionUserSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0746)', tag_sym: :interlock_resolution_user_sequence, tag_ndm: '300A0746', tag_ary: [0x300A,0x0746], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0760)', tag_name: "Override DateTime", tag_key: 'OverrideDateTime', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(300A,0760)', tag_sym: :override_date_time, tag_ndm: '300A0760', tag_ary: [0x300A,0x0760], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0761)', tag_name: "Treatment Tolerance Violation Type Code Sequence", tag_key: 'TreatmentToleranceViolationTypeCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0761)', tag_sym: :treatment_tolerance_violation_type_code_sequence, tag_ndm: '300A0761', tag_ary: [0x300A,0x0761], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0762)', tag_name: "Treatment Tolerance Violation Cause Code Sequence", tag_key: 'TreatmentToleranceViolationCauseCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0762)', tag_sym: :treatment_tolerance_violation_cause_code_sequence, tag_ndm: '300A0762', tag_ary: [0x300A,0x0762], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0772)', tag_name: "Measured Meterset to Dose Mapping Sequence", tag_key: 'MeasuredMetersetToDoseMappingSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0772)', tag_sym: :measured_meterset_to_dose_mapping_sequence, tag_ndm: '300A0772', tag_ary: [0x300A,0x0772], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0773)', tag_name: "Referenced Expected In-Vivo Measurement Value Index", tag_key: 'ReferencedExpectedInVivoMeasurementValueIndex', tag_vr: [:US], tag_vm: ["1"], tag_str: '(300A,0773)', tag_sym: :referenced_expected_in_vivo_measurement_value_index, tag_ndm: '300A0773', tag_ary: [0x300A,0x0773], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0774)', tag_name: "Dose Measurement Device Code Sequence", tag_key: 'DoseMeasurementDeviceCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0774)', tag_sym: :dose_measurement_device_code_sequence, tag_ndm: '300A0774', tag_ary: [0x300A,0x0774], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0780)', tag_name: "Additional Parameter Recording Instance Sequence", tag_key: 'AdditionalParameterRecordingInstanceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0780)', tag_sym: :additional_parameter_recording_instance_sequence, tag_ndm: '300A0780', tag_ary: [0x300A,0x0780], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0782)', tag_name: "Placeholder (300A,0782)", tag_key: 'Placeholder_300A_0782', tag_vr: [:US], tag_vm: ["1"], tag_str: '(300A,0782)', tag_sym: :placeholder_300a_0782, tag_ndm: '300A0782', tag_ary: [0x300A,0x0782], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(300A,0783)', tag_name: "Interlock Origin Description", tag_key: 'InterlockOriginDescription', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(300A,0783)', tag_sym: :interlock_origin_description, tag_ndm: '300A0783', tag_ary: [0x300A,0x0783], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0784)', tag_name: "RT Patient Position Scope Sequence", tag_key: 'RTPatientPositionScopeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0784)', tag_sym: :rt_patient_position_scope_sequence, tag_ndm: '300A0784', tag_ary: [0x300A,0x0784], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0785)', tag_name: "Referenced Treatment Position Group UID", tag_key: 'ReferencedTreatmentPositionGroupUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(300A,0785)', tag_sym: :referenced_treatment_position_group_uid, tag_ndm: '300A0785', tag_ary: [0x300A,0x0785], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0786)', tag_name: "Radiation Order Index", tag_key: 'RadiationOrderIndex', tag_vr: [:US], tag_vm: ["1"], tag_str: '(300A,0786)', tag_sym: :radiation_order_index, tag_ndm: '300A0786', tag_ary: [0x300A,0x0786], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0787)', tag_name: "Omitted Radiation Sequence", tag_key: 'OmittedRadiationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0787)', tag_sym: :omitted_radiation_sequence, tag_ndm: '300A0787', tag_ary: [0x300A,0x0787], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0788)', tag_name: "Reason for Omission Code Sequence", tag_key: 'ReasonForOmissionCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0788)', tag_sym: :reason_for_omission_code_sequence, tag_ndm: '300A0788', tag_ary: [0x300A,0x0788], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0789)', tag_name: "RT Delivery Start Patient Position Sequence", tag_key: 'RTDeliveryStartPatientPositionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0789)', tag_sym: :rt_delivery_start_patient_position_sequence, tag_ndm: '300A0789', tag_ary: [0x300A,0x0789], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,078A)', tag_name: "RT Treatment Preparation Patient Position Sequence", tag_key: 'RTTreatmentPreparationPatientPositionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,078A)', tag_sym: :rt_treatment_preparation_patient_position_sequence, tag_ndm: '300A078A', tag_ary: [0x300A,0x078A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,078B)', tag_name: "Referenced RT Treatment Preparation Sequence", tag_key: 'ReferencedRTTreatmentPreparationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,078B)', tag_sym: :referenced_rt_treatment_preparation_sequence, tag_ndm: '300A078B', tag_ary: [0x300A,0x078B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,078C)', tag_name: "Referenced Patient Setup Photo Sequence", tag_key: 'ReferencedPatientSetupPhotoSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,078C)', tag_sym: :referenced_patient_setup_photo_sequence, tag_ndm: '300A078C', tag_ary: [0x300A,0x078C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,078D)', tag_name: "Patient Treatment Preparation Method Code Sequence", tag_key: 'PatientTreatmentPreparationMethodCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,078D)', tag_sym: :patient_treatment_preparation_method_code_sequence, tag_ndm: '300A078D', tag_ary: [0x300A,0x078D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,078E)', tag_name: "Patient Treatment Preparation Procedure Parameter Description", tag_key: 'PatientTreatmentPreparationProcedureParameterDescription', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(300A,078E)', tag_sym: :patient_treatment_preparation_procedure_parameter_description, tag_ndm: '300A078E', tag_ary: [0x300A,0x078E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,078F)', tag_name: "Patient Treatment Preparation Device Sequence", tag_key: 'PatientTreatmentPreparationDeviceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,078F)', tag_sym: :patient_treatment_preparation_device_sequence, tag_ndm: '300A078F', tag_ary: [0x300A,0x078F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0790)', tag_name: "Patient Treatment Preparation Procedure Sequence", tag_key: 'PatientTreatmentPreparationProcedureSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0790)', tag_sym: :patient_treatment_preparation_procedure_sequence, tag_ndm: '300A0790', tag_ary: [0x300A,0x0790], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0791)', tag_name: "Patient Treatment Preparation Procedure Code Sequence", tag_key: 'PatientTreatmentPreparationProcedureCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0791)', tag_sym: :patient_treatment_preparation_procedure_code_sequence, tag_ndm: '300A0791', tag_ary: [0x300A,0x0791], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0792)', tag_name: "Patient Treatment Preparation Method Description", tag_key: 'PatientTreatmentPreparationMethodDescription', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(300A,0792)', tag_sym: :patient_treatment_preparation_method_description, tag_ndm: '300A0792', tag_ary: [0x300A,0x0792], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0793)', tag_name: "Patient Treatment Preparation Procedure Parameter Sequence", tag_key: 'PatientTreatmentPreparationProcedureParameterSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0793)', tag_sym: :patient_treatment_preparation_procedure_parameter_sequence, tag_ndm: '300A0793', tag_ary: [0x300A,0x0793], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0794)', tag_name: "Patient Setup Photo Description", tag_key: 'PatientSetupPhotoDescription', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(300A,0794)', tag_sym: :patient_setup_photo_description, tag_ndm: '300A0794', tag_ary: [0x300A,0x0794], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0795)', tag_name: "Patient Treatment Preparation Procedure Index", tag_key: 'PatientTreatmentPreparationProcedureIndex', tag_vr: [:US], tag_vm: ["1"], tag_str: '(300A,0795)', tag_sym: :patient_treatment_preparation_procedure_index, tag_ndm: '300A0795', tag_ary: [0x300A,0x0795], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0796)', tag_name: "Referenced Patient Setup Procedure Index", tag_key: 'ReferencedPatientSetupProcedureIndex', tag_vr: [:US], tag_vm: ["1"], tag_str: '(300A,0796)', tag_sym: :referenced_patient_setup_procedure_index, tag_ndm: '300A0796', tag_ary: [0x300A,0x0796], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0797)', tag_name: "RT Radiation Task Sequence", tag_key: 'RTRadiationTaskSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0797)', tag_sym: :rt_radiation_task_sequence, tag_ndm: '300A0797', tag_ary: [0x300A,0x0797], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0798)', tag_name: "RT Patient Position Displacement Sequence", tag_key: 'RTPatientPositionDisplacementSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0798)', tag_sym: :rt_patient_position_displacement_sequence, tag_ndm: '300A0798', tag_ary: [0x300A,0x0798], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,0799)', tag_name: "RT Patient Position Sequence", tag_key: 'RTPatientPositionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,0799)', tag_sym: :rt_patient_position_sequence, tag_ndm: '300A0799', tag_ary: [0x300A,0x0799], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,079A)', tag_name: "Displacement Reference Label", tag_key: 'DisplacementReferenceLabel', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(300A,079A)', tag_sym: :displacement_reference_label, tag_ndm: '300A079A', tag_ary: [0x300A,0x079A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,079B)', tag_name: "Displacement Matrix", tag_key: 'DisplacementMatrix', tag_vr: [:FD], tag_vm: ["16"], tag_str: '(300A,079B)', tag_sym: :displacement_matrix, tag_ndm: '300A079B', tag_ary: [0x300A,0x079B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,079C)', tag_name: "Patient Support Displacement Sequence", tag_key: 'PatientSupportDisplacementSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,079C)', tag_sym: :patient_support_displacement_sequence, tag_ndm: '300A079C', tag_ary: [0x300A,0x079C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,079D)', tag_name: "Displacement Reference Location Code Sequence", tag_key: 'DisplacementReferenceLocationCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,079D)', tag_sym: :displacement_reference_location_code_sequence, tag_ndm: '300A079D', tag_ary: [0x300A,0x079D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,079E)', tag_name: "RT Radiation Set Delivery Usage", tag_key: 'RTRadiationSetDeliveryUsage', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300A,079E)', tag_sym: :rt_radiation_set_delivery_usage, tag_ndm: '300A079E', tag_ary: [0x300A,0x079E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,079F)', tag_name: "Patient Treatment Preparation Sequence", tag_key: 'PatientTreatmentPreparationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,079F)', tag_sym: :patient_treatment_preparation_sequence, tag_ndm: '300A079F', tag_ary: [0x300A,0x079F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,07A0)', tag_name: "Patient to Equipment Relationship Sequence", tag_key: 'PatientToEquipmentRelationshipSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,07A0)', tag_sym: :patient_to_equipment_relationship_sequence, tag_ndm: '300A07A0', tag_ary: [0x300A,0x07A0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300A,07A1)', tag_name: "Imaging Equipment to Treatment Delivery Device Relationship Sequence", tag_key: 'ImagingEquipmentToTreatmentDeliveryDeviceRelationshipSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300A,07A1)', tag_sym: :imaging_equipment_to_treatment_delivery_device_relationship_sequence, tag_ndm: '300A07A1', tag_ary: [0x300A,0x07A1], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300C,0002)', tag_name: "Referenced RT Plan Sequence", tag_key: 'ReferencedRTPlanSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300C,0002)', tag_sym: :referenced_rt_plan_sequence, tag_ndm: '300C0002', tag_ary: [0x300C,0x0002], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300C,0004)', tag_name: "Referenced Beam Sequence", tag_key: 'ReferencedBeamSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300C,0004)', tag_sym: :referenced_beam_sequence, tag_ndm: '300C0004', tag_ary: [0x300C,0x0004], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300C,0006)', tag_name: "Referenced Beam Number", tag_key: 'ReferencedBeamNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300C,0006)', tag_sym: :referenced_beam_number, tag_ndm: '300C0006', tag_ary: [0x300C,0x0006], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300C,0007)', tag_name: "Referenced Reference Image Number", tag_key: 'ReferencedReferenceImageNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300C,0007)', tag_sym: :referenced_reference_image_number, tag_ndm: '300C0007', tag_ary: [0x300C,0x0007], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300C,0008)', tag_name: "Start Cumulative Meterset Weight", tag_key: 'StartCumulativeMetersetWeight', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300C,0008)', tag_sym: :start_cumulative_meterset_weight, tag_ndm: '300C0008', tag_ary: [0x300C,0x0008], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300C,0009)', tag_name: "End Cumulative Meterset Weight", tag_key: 'EndCumulativeMetersetWeight', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(300C,0009)', tag_sym: :end_cumulative_meterset_weight, tag_ndm: '300C0009', tag_ary: [0x300C,0x0009], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300C,000A)', tag_name: "Referenced Brachy Application Setup Sequence", tag_key: 'ReferencedBrachyApplicationSetupSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300C,000A)', tag_sym: :referenced_brachy_application_setup_sequence, tag_ndm: '300C000A', tag_ary: [0x300C,0x000A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300C,000C)', tag_name: "Referenced Brachy Application Setup Number", tag_key: 'ReferencedBrachyApplicationSetupNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300C,000C)', tag_sym: :referenced_brachy_application_setup_number, tag_ndm: '300C000C', tag_ary: [0x300C,0x000C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300C,000E)', tag_name: "Referenced Source Number", tag_key: 'ReferencedSourceNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300C,000E)', tag_sym: :referenced_source_number, tag_ndm: '300C000E', tag_ary: [0x300C,0x000E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300C,0020)', tag_name: "Referenced Fraction Group Sequence", tag_key: 'ReferencedFractionGroupSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300C,0020)', tag_sym: :referenced_fraction_group_sequence, tag_ndm: '300C0020', tag_ary: [0x300C,0x0020], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300C,0022)', tag_name: "Referenced Fraction Group Number", tag_key: 'ReferencedFractionGroupNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300C,0022)', tag_sym: :referenced_fraction_group_number, tag_ndm: '300C0022', tag_ary: [0x300C,0x0022], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300C,0040)', tag_name: "Referenced Verification Image Sequence", tag_key: 'ReferencedVerificationImageSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300C,0040)', tag_sym: :referenced_verification_image_sequence, tag_ndm: '300C0040', tag_ary: [0x300C,0x0040], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300C,0042)', tag_name: "Referenced Reference Image Sequence", tag_key: 'ReferencedReferenceImageSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300C,0042)', tag_sym: :referenced_reference_image_sequence, tag_ndm: '300C0042', tag_ary: [0x300C,0x0042], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300C,0050)', tag_name: "Referenced Dose Reference Sequence", tag_key: 'ReferencedDoseReferenceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300C,0050)', tag_sym: :referenced_dose_reference_sequence, tag_ndm: '300C0050', tag_ary: [0x300C,0x0050], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300C,0051)', tag_name: "Referenced Dose Reference Number", tag_key: 'ReferencedDoseReferenceNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300C,0051)', tag_sym: :referenced_dose_reference_number, tag_ndm: '300C0051', tag_ary: [0x300C,0x0051], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300C,0055)', tag_name: "Brachy Referenced Dose Reference Sequence", tag_key: 'BrachyReferencedDoseReferenceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300C,0055)', tag_sym: :brachy_referenced_dose_reference_sequence, tag_ndm: '300C0055', tag_ary: [0x300C,0x0055], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300C,0060)', tag_name: "Referenced Structure Set Sequence", tag_key: 'ReferencedStructureSetSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300C,0060)', tag_sym: :referenced_structure_set_sequence, tag_ndm: '300C0060', tag_ary: [0x300C,0x0060], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300C,006A)', tag_name: "Referenced Patient Setup Number", tag_key: 'ReferencedPatientSetupNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300C,006A)', tag_sym: :referenced_patient_setup_number, tag_ndm: '300C006A', tag_ary: [0x300C,0x006A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300C,0080)', tag_name: "Referenced Dose Sequence", tag_key: 'ReferencedDoseSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300C,0080)', tag_sym: :referenced_dose_sequence, tag_ndm: '300C0080', tag_ary: [0x300C,0x0080], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300C,00A0)', tag_name: "Referenced Tolerance Table Number", tag_key: 'ReferencedToleranceTableNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300C,00A0)', tag_sym: :referenced_tolerance_table_number, tag_ndm: '300C00A0', tag_ary: [0x300C,0x00A0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300C,00B0)', tag_name: "Referenced Bolus Sequence", tag_key: 'ReferencedBolusSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300C,00B0)', tag_sym: :referenced_bolus_sequence, tag_ndm: '300C00B0', tag_ary: [0x300C,0x00B0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300C,00C0)', tag_name: "Referenced Wedge Number", tag_key: 'ReferencedWedgeNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300C,00C0)', tag_sym: :referenced_wedge_number, tag_ndm: '300C00C0', tag_ary: [0x300C,0x00C0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300C,00D0)', tag_name: "Referenced Compensator Number", tag_key: 'ReferencedCompensatorNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300C,00D0)', tag_sym: :referenced_compensator_number, tag_ndm: '300C00D0', tag_ary: [0x300C,0x00D0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300C,00E0)', tag_name: "Referenced Block Number", tag_key: 'ReferencedBlockNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300C,00E0)', tag_sym: :referenced_block_number, tag_ndm: '300C00E0', tag_ary: [0x300C,0x00E0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300C,00F0)', tag_name: "Referenced Control Point Index", tag_key: 'ReferencedControlPointIndex', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300C,00F0)', tag_sym: :referenced_control_point_index, tag_ndm: '300C00F0', tag_ary: [0x300C,0x00F0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300C,00F2)', tag_name: "Referenced Control Point Sequence", tag_key: 'ReferencedControlPointSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300C,00F2)', tag_sym: :referenced_control_point_sequence, tag_ndm: '300C00F2', tag_ary: [0x300C,0x00F2], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300C,00F4)', tag_name: "Referenced Start Control Point Index", tag_key: 'ReferencedStartControlPointIndex', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300C,00F4)', tag_sym: :referenced_start_control_point_index, tag_ndm: '300C00F4', tag_ary: [0x300C,0x00F4], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300C,00F6)', tag_name: "Referenced Stop Control Point Index", tag_key: 'ReferencedStopControlPointIndex', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300C,00F6)', tag_sym: :referenced_stop_control_point_index, tag_ndm: '300C00F6', tag_ary: [0x300C,0x00F6], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300C,0100)', tag_name: "Referenced Range Shifter Number", tag_key: 'ReferencedRangeShifterNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300C,0100)', tag_sym: :referenced_range_shifter_number, tag_ndm: '300C0100', tag_ary: [0x300C,0x0100], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300C,0102)', tag_name: "Referenced Lateral Spreading Device Number", tag_key: 'ReferencedLateralSpreadingDeviceNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300C,0102)', tag_sym: :referenced_lateral_spreading_device_number, tag_ndm: '300C0102', tag_ary: [0x300C,0x0102], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300C,0104)', tag_name: "Referenced Range Modulator Number", tag_key: 'ReferencedRangeModulatorNumber', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(300C,0104)', tag_sym: :referenced_range_modulator_number, tag_ndm: '300C0104', tag_ary: [0x300C,0x0104], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300C,0111)', tag_name: "Omitted Beam Task Sequence", tag_key: 'OmittedBeamTaskSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300C,0111)', tag_sym: :omitted_beam_task_sequence, tag_ndm: '300C0111', tag_ary: [0x300C,0x0111], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300C,0112)', tag_name: "Reason for Omission", tag_key: 'ReasonForOmission', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300C,0112)', tag_sym: :reason_for_omission, tag_ndm: '300C0112', tag_ary: [0x300C,0x0112], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300C,0113)', tag_name: "Reason for Omission Description", tag_key: 'ReasonForOmissionDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(300C,0113)', tag_sym: :reason_for_omission_description, tag_ndm: '300C0113', tag_ary: [0x300C,0x0113], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300C,0114)', tag_name: "Prescription Overview Sequence", tag_key: 'PrescriptionOverviewSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300C,0114)', tag_sym: :prescription_overview_sequence, tag_ndm: '300C0114', tag_ary: [0x300C,0x0114], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300C,0115)', tag_name: "Total Prescription Dose", tag_key: 'TotalPrescriptionDose', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(300C,0115)', tag_sym: :total_prescription_dose, tag_ndm: '300C0115', tag_ary: [0x300C,0x0115], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300C,0116)', tag_name: "Plan Overview Sequence", tag_key: 'PlanOverviewSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300C,0116)', tag_sym: :plan_overview_sequence, tag_ndm: '300C0116', tag_ary: [0x300C,0x0116], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300C,0117)', tag_name: "Plan Overview Index", tag_key: 'PlanOverviewIndex', tag_vr: [:US], tag_vm: ["1"], tag_str: '(300C,0117)', tag_sym: :plan_overview_index, tag_ndm: '300C0117', tag_ary: [0x300C,0x0117], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300C,0118)', tag_name: "Referenced Plan Overview Index", tag_key: 'ReferencedPlanOverviewIndex', tag_vr: [:US], tag_vm: ["1"], tag_str: '(300C,0118)', tag_sym: :referenced_plan_overview_index, tag_ndm: '300C0118', tag_ary: [0x300C,0x0118], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300C,0119)', tag_name: "Number of Fractions Included", tag_key: 'NumberOfFractionsIncluded', tag_vr: [:US], tag_vm: ["1"], tag_str: '(300C,0119)', tag_sym: :number_of_fractions_included, tag_ndm: '300C0119', tag_ary: [0x300C,0x0119], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300C,0120)', tag_name: "Dose Calibration Conditions Sequence", tag_key: 'DoseCalibrationConditionsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300C,0120)', tag_sym: :dose_calibration_conditions_sequence, tag_ndm: '300C0120', tag_ary: [0x300C,0x0120], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300C,0121)', tag_name: "Absorbed Dose to Meterset Ratio", tag_key: 'AbsorbedDoseToMetersetRatio', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(300C,0121)', tag_sym: :absorbed_dose_to_meterset_ratio, tag_ndm: '300C0121', tag_ary: [0x300C,0x0121], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300C,0122)', tag_name: "Delineated Radiation Field Size", tag_key: 'DelineatedRadiationFieldSize', tag_vr: [:FD], tag_vm: ["2"], tag_str: '(300C,0122)', tag_sym: :delineated_radiation_field_size, tag_ndm: '300C0122', tag_ary: [0x300C,0x0122], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300C,0123)', tag_name: "Dose Calibration Conditions Verified Flag", tag_key: 'DoseCalibrationConditionsVerifiedFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300C,0123)', tag_sym: :dose_calibration_conditions_verified_flag, tag_ndm: '300C0123', tag_ary: [0x300C,0x0123], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300C,0124)', tag_name: "Calibration Reference Point Depth", tag_key: 'CalibrationReferencePointDepth', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(300C,0124)', tag_sym: :calibration_reference_point_depth, tag_ndm: '300C0124', tag_ary: [0x300C,0x0124], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300C,0125)', tag_name: "Gating Beam Hold Transition Sequence", tag_key: 'GatingBeamHoldTransitionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300C,0125)', tag_sym: :gating_beam_hold_transition_sequence, tag_ndm: '300C0125', tag_ary: [0x300C,0x0125], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300C,0126)', tag_name: "Beam Hold Transition", tag_key: 'BeamHoldTransition', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300C,0126)', tag_sym: :beam_hold_transition, tag_ndm: '300C0126', tag_ary: [0x300C,0x0126], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300C,0127)', tag_name: "Beam Hold Transition DateTime", tag_key: 'BeamHoldTransitionDateTime', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(300C,0127)', tag_sym: :beam_hold_transition_date_time, tag_ndm: '300C0127', tag_ary: [0x300C,0x0127], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300C,0128)', tag_name: "Beam Hold Originating Device Sequence", tag_key: 'BeamHoldOriginatingDeviceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(300C,0128)', tag_sym: :beam_hold_originating_device_sequence, tag_ndm: '300C0128', tag_ary: [0x300C,0x0128], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300C,0129)', tag_name: "Beam Hold Transition Trigger Source", tag_key: 'BeamHoldTransitionTriggerSource', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300C,0129)', tag_sym: :beam_hold_transition_trigger_source, tag_ndm: '300C0129', tag_ary: [0x300C,0x0129], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300E,0002)', tag_name: "Approval Status", tag_key: 'ApprovalStatus', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(300E,0002)', tag_sym: :approval_status, tag_ndm: '300E0002', tag_ary: [0x300E,0x0002], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300E,0004)', tag_name: "Review Date", tag_key: 'ReviewDate', tag_vr: [:DA], tag_vm: ["1"], tag_str: '(300E,0004)', tag_sym: :review_date, tag_ndm: '300E0004', tag_ary: [0x300E,0x0004], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300E,0005)', tag_name: "Review Time", tag_key: 'ReviewTime', tag_vr: [:TM], tag_vm: ["1"], tag_str: '(300E,0005)', tag_sym: :review_time, tag_ndm: '300E0005', tag_ary: [0x300E,0x0005], tag_multiple: false, tag_note: ''},
      { tag_ps: '(300E,0008)', tag_name: "Reviewer Name", tag_key: 'ReviewerName', tag_vr: [:PN], tag_vm: ["1"], tag_str: '(300E,0008)', tag_sym: :reviewer_name, tag_ndm: '300E0008', tag_ary: [0x300E,0x0008], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0001)', tag_name: "Radiobiological Dose Effect Sequence", tag_key: 'RadiobiologicalDoseEffectSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,0001)', tag_sym: :radiobiological_dose_effect_sequence, tag_ndm: '30100001', tag_ary: [0x3010,0x0001], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0002)', tag_name: "Radiobiological Dose Effect Flag", tag_key: 'RadiobiologicalDoseEffectFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(3010,0002)', tag_sym: :radiobiological_dose_effect_flag, tag_ndm: '30100002', tag_ary: [0x3010,0x0002], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0003)', tag_name: "Effective Dose Calculation Method Category Code Sequence", tag_key: 'EffectiveDoseCalculationMethodCategoryCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,0003)', tag_sym: :effective_dose_calculation_method_category_code_sequence, tag_ndm: '30100003', tag_ary: [0x3010,0x0003], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0004)', tag_name: "Effective Dose Calculation Method Code Sequence", tag_key: 'EffectiveDoseCalculationMethodCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,0004)', tag_sym: :effective_dose_calculation_method_code_sequence, tag_ndm: '30100004', tag_ary: [0x3010,0x0004], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0005)', tag_name: "Effective Dose Calculation Method Description", tag_key: 'EffectiveDoseCalculationMethodDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(3010,0005)', tag_sym: :effective_dose_calculation_method_description, tag_ndm: '30100005', tag_ary: [0x3010,0x0005], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0006)', tag_name: "Conceptual Volume UID", tag_key: 'ConceptualVolumeUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(3010,0006)', tag_sym: :conceptual_volume_uid, tag_ndm: '30100006', tag_ary: [0x3010,0x0006], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0007)', tag_name: "Originating SOP Instance Reference Sequence", tag_key: 'OriginatingSOPInstanceReferenceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,0007)', tag_sym: :originating_sop_instance_reference_sequence, tag_ndm: '30100007', tag_ary: [0x3010,0x0007], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0008)', tag_name: "Conceptual Volume Constituent Sequence", tag_key: 'ConceptualVolumeConstituentSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,0008)', tag_sym: :conceptual_volume_constituent_sequence, tag_ndm: '30100008', tag_ary: [0x3010,0x0008], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0009)', tag_name: "Equivalent Conceptual Volume Instance Reference Sequence", tag_key: 'EquivalentConceptualVolumeInstanceReferenceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,0009)', tag_sym: :equivalent_conceptual_volume_instance_reference_sequence, tag_ndm: '30100009', tag_ary: [0x3010,0x0009], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,000A)', tag_name: "Equivalent Conceptual Volumes Sequence", tag_key: 'EquivalentConceptualVolumesSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,000A)', tag_sym: :equivalent_conceptual_volumes_sequence, tag_ndm: '3010000A', tag_ary: [0x3010,0x000A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,000B)', tag_name: "Referenced Conceptual Volume UID", tag_key: 'ReferencedConceptualVolumeUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(3010,000B)', tag_sym: :referenced_conceptual_volume_uid, tag_ndm: '3010000B', tag_ary: [0x3010,0x000B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,000C)', tag_name: "Conceptual Volume Combination Expression", tag_key: 'ConceptualVolumeCombinationExpression', tag_vr: [:UT], tag_vm: ["1"], tag_str: '(3010,000C)', tag_sym: :conceptual_volume_combination_expression, tag_ndm: '3010000C', tag_ary: [0x3010,0x000C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,000D)', tag_name: "Conceptual Volume Constituent Index", tag_key: 'ConceptualVolumeConstituentIndex', tag_vr: [:US], tag_vm: ["1"], tag_str: '(3010,000D)', tag_sym: :conceptual_volume_constituent_index, tag_ndm: '3010000D', tag_ary: [0x3010,0x000D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,000E)', tag_name: "Conceptual Volume Combination Flag", tag_key: 'ConceptualVolumeCombinationFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(3010,000E)', tag_sym: :conceptual_volume_combination_flag, tag_ndm: '3010000E', tag_ary: [0x3010,0x000E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,000F)', tag_name: "Conceptual Volume Combination Description", tag_key: 'ConceptualVolumeCombinationDescription', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(3010,000F)', tag_sym: :conceptual_volume_combination_description, tag_ndm: '3010000F', tag_ary: [0x3010,0x000F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0010)', tag_name: "Conceptual Volume Segmentation Defined Flag", tag_key: 'ConceptualVolumeSegmentationDefinedFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(3010,0010)', tag_sym: :conceptual_volume_segmentation_defined_flag, tag_ndm: '30100010', tag_ary: [0x3010,0x0010], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0011)', tag_name: "Conceptual Volume Segmentation Reference Sequence", tag_key: 'ConceptualVolumeSegmentationReferenceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,0011)', tag_sym: :conceptual_volume_segmentation_reference_sequence, tag_ndm: '30100011', tag_ary: [0x3010,0x0011], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0012)', tag_name: "Conceptual Volume Constituent Segmentation Reference Sequence", tag_key: 'ConceptualVolumeConstituentSegmentationReferenceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,0012)', tag_sym: :conceptual_volume_constituent_segmentation_reference_sequence, tag_ndm: '30100012', tag_ary: [0x3010,0x0012], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0013)', tag_name: "Constituent Conceptual Volume UID", tag_key: 'ConstituentConceptualVolumeUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(3010,0013)', tag_sym: :constituent_conceptual_volume_uid, tag_ndm: '30100013', tag_ary: [0x3010,0x0013], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0014)', tag_name: "Derivation Conceptual Volume Sequence", tag_key: 'DerivationConceptualVolumeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,0014)', tag_sym: :derivation_conceptual_volume_sequence, tag_ndm: '30100014', tag_ary: [0x3010,0x0014], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0015)', tag_name: "Source Conceptual Volume UID", tag_key: 'SourceConceptualVolumeUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(3010,0015)', tag_sym: :source_conceptual_volume_uid, tag_ndm: '30100015', tag_ary: [0x3010,0x0015], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0016)', tag_name: "Conceptual Volume Derivation Algorithm Sequence", tag_key: 'ConceptualVolumeDerivationAlgorithmSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,0016)', tag_sym: :conceptual_volume_derivation_algorithm_sequence, tag_ndm: '30100016', tag_ary: [0x3010,0x0016], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0017)', tag_name: "Conceptual Volume Description", tag_key: 'ConceptualVolumeDescription', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(3010,0017)', tag_sym: :conceptual_volume_description, tag_ndm: '30100017', tag_ary: [0x3010,0x0017], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0018)', tag_name: "Source Conceptual Volume Sequence", tag_key: 'SourceConceptualVolumeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,0018)', tag_sym: :source_conceptual_volume_sequence, tag_ndm: '30100018', tag_ary: [0x3010,0x0018], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0019)', tag_name: "Author Identification Sequence", tag_key: 'AuthorIdentificationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,0019)', tag_sym: :author_identification_sequence, tag_ndm: '30100019', tag_ary: [0x3010,0x0019], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,001A)', tag_name: "Manufacturer's Model Version", tag_key: 'ManufacturerModelVersion', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(3010,001A)', tag_sym: :manufacturer_model_version, tag_ndm: '3010001A', tag_ary: [0x3010,0x001A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,001B)', tag_name: "Device Alternate Identifier", tag_key: 'DeviceAlternateIdentifier', tag_vr: [:UC], tag_vm: ["1"], tag_str: '(3010,001B)', tag_sym: :device_alternate_identifier, tag_ndm: '3010001B', tag_ary: [0x3010,0x001B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,001C)', tag_name: "Device Alternate Identifier Type", tag_key: 'DeviceAlternateIdentifierType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(3010,001C)', tag_sym: :device_alternate_identifier_type, tag_ndm: '3010001C', tag_ary: [0x3010,0x001C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,001D)', tag_name: "Device Alternate Identifier Format", tag_key: 'DeviceAlternateIdentifierFormat', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(3010,001D)', tag_sym: :device_alternate_identifier_format, tag_ndm: '3010001D', tag_ary: [0x3010,0x001D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,001E)', tag_name: "Segmentation Creation Template Label", tag_key: 'SegmentationCreationTemplateLabel', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(3010,001E)', tag_sym: :segmentation_creation_template_label, tag_ndm: '3010001E', tag_ary: [0x3010,0x001E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,001F)', tag_name: "Segmentation Template UID", tag_key: 'SegmentationTemplateUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(3010,001F)', tag_sym: :segmentation_template_uid, tag_ndm: '3010001F', tag_ary: [0x3010,0x001F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0020)', tag_name: "Referenced Segment Reference Index", tag_key: 'ReferencedSegmentReferenceIndex', tag_vr: [:US], tag_vm: ["1"], tag_str: '(3010,0020)', tag_sym: :referenced_segment_reference_index, tag_ndm: '30100020', tag_ary: [0x3010,0x0020], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0021)', tag_name: "Segment Reference Sequence", tag_key: 'SegmentReferenceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,0021)', tag_sym: :segment_reference_sequence, tag_ndm: '30100021', tag_ary: [0x3010,0x0021], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0022)', tag_name: "Segment Reference Index", tag_key: 'SegmentReferenceIndex', tag_vr: [:US], tag_vm: ["1"], tag_str: '(3010,0022)', tag_sym: :segment_reference_index, tag_ndm: '30100022', tag_ary: [0x3010,0x0022], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0023)', tag_name: "Direct Segment Reference Sequence", tag_key: 'DirectSegmentReferenceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,0023)', tag_sym: :direct_segment_reference_sequence, tag_ndm: '30100023', tag_ary: [0x3010,0x0023], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0024)', tag_name: "Combination Segment Reference Sequence", tag_key: 'CombinationSegmentReferenceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,0024)', tag_sym: :combination_segment_reference_sequence, tag_ndm: '30100024', tag_ary: [0x3010,0x0024], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0025)', tag_name: "Conceptual Volume Sequence", tag_key: 'ConceptualVolumeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,0025)', tag_sym: :conceptual_volume_sequence, tag_ndm: '30100025', tag_ary: [0x3010,0x0025], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0026)', tag_name: "Segmented RT Accessory Device Sequence", tag_key: 'SegmentedRTAccessoryDeviceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,0026)', tag_sym: :segmented_rt_accessory_device_sequence, tag_ndm: '30100026', tag_ary: [0x3010,0x0026], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0027)', tag_name: "Segment Characteristics Sequence", tag_key: 'SegmentCharacteristicsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,0027)', tag_sym: :segment_characteristics_sequence, tag_ndm: '30100027', tag_ary: [0x3010,0x0027], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0028)', tag_name: "Related Segment Characteristics Sequence", tag_key: 'RelatedSegmentCharacteristicsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,0028)', tag_sym: :related_segment_characteristics_sequence, tag_ndm: '30100028', tag_ary: [0x3010,0x0028], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0029)', tag_name: "Segment Characteristics Precedence", tag_key: 'SegmentCharacteristicsPrecedence', tag_vr: [:US], tag_vm: ["1"], tag_str: '(3010,0029)', tag_sym: :segment_characteristics_precedence, tag_ndm: '30100029', tag_ary: [0x3010,0x0029], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,002A)', tag_name: "RT Segment Annotation Sequence", tag_key: 'RTSegmentAnnotationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,002A)', tag_sym: :rt_segment_annotation_sequence, tag_ndm: '3010002A', tag_ary: [0x3010,0x002A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,002B)', tag_name: "Segment Annotation Category Code Sequence", tag_key: 'SegmentAnnotationCategoryCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,002B)', tag_sym: :segment_annotation_category_code_sequence, tag_ndm: '3010002B', tag_ary: [0x3010,0x002B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,002C)', tag_name: "Segment Annotation Type Code Sequence", tag_key: 'SegmentAnnotationTypeCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,002C)', tag_sym: :segment_annotation_type_code_sequence, tag_ndm: '3010002C', tag_ary: [0x3010,0x002C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,002D)', tag_name: "Device Label", tag_key: 'DeviceLabel', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(3010,002D)', tag_sym: :device_label, tag_ndm: '3010002D', tag_ary: [0x3010,0x002D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,002E)', tag_name: "Device Type Code Sequence", tag_key: 'DeviceTypeCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,002E)', tag_sym: :device_type_code_sequence, tag_ndm: '3010002E', tag_ary: [0x3010,0x002E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,002F)', tag_name: "Segment Annotation Type Modifier Code Sequence", tag_key: 'SegmentAnnotationTypeModifierCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,002F)', tag_sym: :segment_annotation_type_modifier_code_sequence, tag_ndm: '3010002F', tag_ary: [0x3010,0x002F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0030)', tag_name: "Patient Equipment Relationship Code Sequence", tag_key: 'PatientEquipmentRelationshipCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,0030)', tag_sym: :patient_equipment_relationship_code_sequence, tag_ndm: '30100030', tag_ary: [0x3010,0x0030], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0031)', tag_name: "Referenced Fiducials UID", tag_key: 'ReferencedFiducialsUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(3010,0031)', tag_sym: :referenced_fiducials_uid, tag_ndm: '30100031', tag_ary: [0x3010,0x0031], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0032)', tag_name: "Patient Treatment Orientation Sequence", tag_key: 'PatientTreatmentOrientationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,0032)', tag_sym: :patient_treatment_orientation_sequence, tag_ndm: '30100032', tag_ary: [0x3010,0x0032], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0033)', tag_name: "User Content Label", tag_key: 'UserContentLabel', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(3010,0033)', tag_sym: :user_content_label, tag_ndm: '30100033', tag_ary: [0x3010,0x0033], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0034)', tag_name: "User Content Long Label", tag_key: 'UserContentLongLabel', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(3010,0034)', tag_sym: :user_content_long_label, tag_ndm: '30100034', tag_ary: [0x3010,0x0034], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0035)', tag_name: "Entity Label", tag_key: 'EntityLabel', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(3010,0035)', tag_sym: :entity_label, tag_ndm: '30100035', tag_ary: [0x3010,0x0035], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0036)', tag_name: "Entity Name", tag_key: 'EntityName', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(3010,0036)', tag_sym: :entity_name, tag_ndm: '30100036', tag_ary: [0x3010,0x0036], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0037)', tag_name: "Entity Description", tag_key: 'EntityDescription', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(3010,0037)', tag_sym: :entity_description, tag_ndm: '30100037', tag_ary: [0x3010,0x0037], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0038)', tag_name: "Entity Long Label", tag_key: 'EntityLongLabel', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(3010,0038)', tag_sym: :entity_long_label, tag_ndm: '30100038', tag_ary: [0x3010,0x0038], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0039)', tag_name: "Device Index", tag_key: 'DeviceIndex', tag_vr: [:US], tag_vm: ["1"], tag_str: '(3010,0039)', tag_sym: :device_index, tag_ndm: '30100039', tag_ary: [0x3010,0x0039], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,003A)', tag_name: "RT Treatment Phase Index", tag_key: 'RTTreatmentPhaseIndex', tag_vr: [:US], tag_vm: ["1"], tag_str: '(3010,003A)', tag_sym: :rt_treatment_phase_index, tag_ndm: '3010003A', tag_ary: [0x3010,0x003A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,003B)', tag_name: "RT Treatment Phase UID", tag_key: 'RTTreatmentPhaseUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(3010,003B)', tag_sym: :rt_treatment_phase_uid, tag_ndm: '3010003B', tag_ary: [0x3010,0x003B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,003C)', tag_name: "RT Prescription Index", tag_key: 'RTPrescriptionIndex', tag_vr: [:US], tag_vm: ["1"], tag_str: '(3010,003C)', tag_sym: :rt_prescription_index, tag_ndm: '3010003C', tag_ary: [0x3010,0x003C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,003D)', tag_name: "RT Segment Annotation Index", tag_key: 'RTSegmentAnnotationIndex', tag_vr: [:US], tag_vm: ["1"], tag_str: '(3010,003D)', tag_sym: :rt_segment_annotation_index, tag_ndm: '3010003D', tag_ary: [0x3010,0x003D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,003E)', tag_name: "Basis RT Treatment Phase Index", tag_key: 'BasisRTTreatmentPhaseIndex', tag_vr: [:US], tag_vm: ["1"], tag_str: '(3010,003E)', tag_sym: :basis_rt_treatment_phase_index, tag_ndm: '3010003E', tag_ary: [0x3010,0x003E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,003F)', tag_name: "Related RT Treatment Phase Index", tag_key: 'RelatedRTTreatmentPhaseIndex', tag_vr: [:US], tag_vm: ["1"], tag_str: '(3010,003F)', tag_sym: :related_rt_treatment_phase_index, tag_ndm: '3010003F', tag_ary: [0x3010,0x003F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0040)', tag_name: "Referenced RT Treatment Phase Index", tag_key: 'ReferencedRTTreatmentPhaseIndex', tag_vr: [:US], tag_vm: ["1"], tag_str: '(3010,0040)', tag_sym: :referenced_rt_treatment_phase_index, tag_ndm: '30100040', tag_ary: [0x3010,0x0040], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0041)', tag_name: "Referenced RT Prescription Index", tag_key: 'ReferencedRTPrescriptionIndex', tag_vr: [:US], tag_vm: ["1"], tag_str: '(3010,0041)', tag_sym: :referenced_rt_prescription_index, tag_ndm: '30100041', tag_ary: [0x3010,0x0041], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0042)', tag_name: "Referenced Parent RT Prescription Index", tag_key: 'ReferencedParentRTPrescriptionIndex', tag_vr: [:US], tag_vm: ["1"], tag_str: '(3010,0042)', tag_sym: :referenced_parent_rt_prescription_index, tag_ndm: '30100042', tag_ary: [0x3010,0x0042], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0043)', tag_name: "Manufacturer's Device Identifier", tag_key: 'ManufacturerDeviceIdentifier', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(3010,0043)', tag_sym: :manufacturer_device_identifier, tag_ndm: '30100043', tag_ary: [0x3010,0x0043], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0044)', tag_name: "Instance-Level Referenced Performed Procedure Step Sequence", tag_key: 'InstanceLevelReferencedPerformedProcedureStepSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,0044)', tag_sym: :instance_level_referenced_performed_procedure_step_sequence, tag_ndm: '30100044', tag_ary: [0x3010,0x0044], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0045)', tag_name: "RT Treatment Phase Intent Presence Flag", tag_key: 'RTTreatmentPhaseIntentPresenceFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(3010,0045)', tag_sym: :rt_treatment_phase_intent_presence_flag, tag_ndm: '30100045', tag_ary: [0x3010,0x0045], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0046)', tag_name: "Radiotherapy Treatment Type", tag_key: 'RadiotherapyTreatmentType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(3010,0046)', tag_sym: :radiotherapy_treatment_type, tag_ndm: '30100046', tag_ary: [0x3010,0x0046], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0047)', tag_name: "Teletherapy Radiation Type", tag_key: 'TeletherapyRadiationType', tag_vr: [:CS], tag_vm: ["1-n"], tag_str: '(3010,0047)', tag_sym: :teletherapy_radiation_type, tag_ndm: '30100047', tag_ary: [0x3010,0x0047], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0048)', tag_name: "Brachytherapy Source Type", tag_key: 'BrachytherapySourceType', tag_vr: [:CS], tag_vm: ["1-n"], tag_str: '(3010,0048)', tag_sym: :brachytherapy_source_type, tag_ndm: '30100048', tag_ary: [0x3010,0x0048], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0049)', tag_name: "Referenced RT Treatment Phase Sequence", tag_key: 'ReferencedRTTreatmentPhaseSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,0049)', tag_sym: :referenced_rt_treatment_phase_sequence, tag_ndm: '30100049', tag_ary: [0x3010,0x0049], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,004A)', tag_name: "Referenced Direct Segment Instance Sequence", tag_key: 'ReferencedDirectSegmentInstanceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,004A)', tag_sym: :referenced_direct_segment_instance_sequence, tag_ndm: '3010004A', tag_ary: [0x3010,0x004A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,004B)', tag_name: "Intended RT Treatment Phase Sequence", tag_key: 'IntendedRTTreatmentPhaseSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,004B)', tag_sym: :intended_rt_treatment_phase_sequence, tag_ndm: '3010004B', tag_ary: [0x3010,0x004B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,004C)', tag_name: "Intended Phase Start Date", tag_key: 'IntendedPhaseStartDate', tag_vr: [:DA], tag_vm: ["1"], tag_str: '(3010,004C)', tag_sym: :intended_phase_start_date, tag_ndm: '3010004C', tag_ary: [0x3010,0x004C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,004D)', tag_name: "Intended Phase End Date", tag_key: 'IntendedPhaseEndDate', tag_vr: [:DA], tag_vm: ["1"], tag_str: '(3010,004D)', tag_sym: :intended_phase_end_date, tag_ndm: '3010004D', tag_ary: [0x3010,0x004D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,004E)', tag_name: "RT Treatment Phase Interval Sequence", tag_key: 'RTTreatmentPhaseIntervalSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,004E)', tag_sym: :rt_treatment_phase_interval_sequence, tag_ndm: '3010004E', tag_ary: [0x3010,0x004E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,004F)', tag_name: "Temporal Relationship Interval Anchor", tag_key: 'TemporalRelationshipIntervalAnchor', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(3010,004F)', tag_sym: :temporal_relationship_interval_anchor, tag_ndm: '3010004F', tag_ary: [0x3010,0x004F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0050)', tag_name: "Minimum Number of Interval Days", tag_key: 'MinimumNumberOfIntervalDays', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(3010,0050)', tag_sym: :minimum_number_of_interval_days, tag_ndm: '30100050', tag_ary: [0x3010,0x0050], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0051)', tag_name: "Maximum Number of Interval Days", tag_key: 'MaximumNumberOfIntervalDays', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(3010,0051)', tag_sym: :maximum_number_of_interval_days, tag_ndm: '30100051', tag_ary: [0x3010,0x0051], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0052)', tag_name: "Pertinent SOP Classes in Study", tag_key: 'PertinentSOPClassesInStudy', tag_vr: [:UI], tag_vm: ["1-n"], tag_str: '(3010,0052)', tag_sym: :pertinent_sop_classes_in_study, tag_ndm: '30100052', tag_ary: [0x3010,0x0052], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0053)', tag_name: "Pertinent SOP Classes in Series", tag_key: 'PertinentSOPClassesInSeries', tag_vr: [:UI], tag_vm: ["1-n"], tag_str: '(3010,0053)', tag_sym: :pertinent_sop_classes_in_series, tag_ndm: '30100053', tag_ary: [0x3010,0x0053], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0054)', tag_name: "RT Prescription Label", tag_key: 'RTPrescriptionLabel', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(3010,0054)', tag_sym: :rt_prescription_label, tag_ndm: '30100054', tag_ary: [0x3010,0x0054], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0055)', tag_name: "RT Physician Intent Predecessor Sequence", tag_key: 'RTPhysicianIntentPredecessorSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,0055)', tag_sym: :rt_physician_intent_predecessor_sequence, tag_ndm: '30100055', tag_ary: [0x3010,0x0055], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0056)', tag_name: "RT Treatment Approach Label", tag_key: 'RTTreatmentApproachLabel', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(3010,0056)', tag_sym: :rt_treatment_approach_label, tag_ndm: '30100056', tag_ary: [0x3010,0x0056], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0057)', tag_name: "RT Physician Intent Sequence", tag_key: 'RTPhysicianIntentSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,0057)', tag_sym: :rt_physician_intent_sequence, tag_ndm: '30100057', tag_ary: [0x3010,0x0057], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0058)', tag_name: "RT Physician Intent Index", tag_key: 'RTPhysicianIntentIndex', tag_vr: [:US], tag_vm: ["1"], tag_str: '(3010,0058)', tag_sym: :rt_physician_intent_index, tag_ndm: '30100058', tag_ary: [0x3010,0x0058], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0059)', tag_name: "RT Treatment Intent Type", tag_key: 'RTTreatmentIntentType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(3010,0059)', tag_sym: :rt_treatment_intent_type, tag_ndm: '30100059', tag_ary: [0x3010,0x0059], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,005A)', tag_name: "RT Physician Intent Narrative", tag_key: 'RTPhysicianIntentNarrative', tag_vr: [:UT], tag_vm: ["1"], tag_str: '(3010,005A)', tag_sym: :rt_physician_intent_narrative, tag_ndm: '3010005A', tag_ary: [0x3010,0x005A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,005B)', tag_name: "RT Protocol Code Sequence", tag_key: 'RTProtocolCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,005B)', tag_sym: :rt_protocol_code_sequence, tag_ndm: '3010005B', tag_ary: [0x3010,0x005B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,005C)', tag_name: "Reason for Superseding", tag_key: 'ReasonForSuperseding', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(3010,005C)', tag_sym: :reason_for_superseding, tag_ndm: '3010005C', tag_ary: [0x3010,0x005C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,005D)', tag_name: "RT Diagnosis Code Sequence", tag_key: 'RTDiagnosisCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,005D)', tag_sym: :rt_diagnosis_code_sequence, tag_ndm: '3010005D', tag_ary: [0x3010,0x005D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,005E)', tag_name: "Referenced RT Physician Intent Index", tag_key: 'ReferencedRTPhysicianIntentIndex', tag_vr: [:US], tag_vm: ["1"], tag_str: '(3010,005E)', tag_sym: :referenced_rt_physician_intent_index, tag_ndm: '3010005E', tag_ary: [0x3010,0x005E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,005F)', tag_name: "RT Physician Intent Input Instance Sequence", tag_key: 'RTPhysicianIntentInputInstanceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,005F)', tag_sym: :rt_physician_intent_input_instance_sequence, tag_ndm: '3010005F', tag_ary: [0x3010,0x005F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0060)', tag_name: "RT Anatomic Prescription Sequence", tag_key: 'RTAnatomicPrescriptionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,0060)', tag_sym: :rt_anatomic_prescription_sequence, tag_ndm: '30100060', tag_ary: [0x3010,0x0060], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0061)', tag_name: "Prior Treatment Dose Description", tag_key: 'PriorTreatmentDoseDescription', tag_vr: [:UT], tag_vm: ["1"], tag_str: '(3010,0061)', tag_sym: :prior_treatment_dose_description, tag_ndm: '30100061', tag_ary: [0x3010,0x0061], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0062)', tag_name: "Prior Treatment Reference Sequence", tag_key: 'PriorTreatmentReferenceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,0062)', tag_sym: :prior_treatment_reference_sequence, tag_ndm: '30100062', tag_ary: [0x3010,0x0062], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0063)', tag_name: "Dosimetric Objective Evaluation Scope", tag_key: 'DosimetricObjectiveEvaluationScope', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(3010,0063)', tag_sym: :dosimetric_objective_evaluation_scope, tag_ndm: '30100063', tag_ary: [0x3010,0x0063], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0064)', tag_name: "Therapeutic Role Category Code Sequence", tag_key: 'TherapeuticRoleCategoryCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,0064)', tag_sym: :therapeutic_role_category_code_sequence, tag_ndm: '30100064', tag_ary: [0x3010,0x0064], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0065)', tag_name: "Therapeutic Role Type Code Sequence", tag_key: 'TherapeuticRoleTypeCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,0065)', tag_sym: :therapeutic_role_type_code_sequence, tag_ndm: '30100065', tag_ary: [0x3010,0x0065], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0066)', tag_name: "Conceptual Volume Optimization Precedence", tag_key: 'ConceptualVolumeOptimizationPrecedence', tag_vr: [:US], tag_vm: ["1"], tag_str: '(3010,0066)', tag_sym: :conceptual_volume_optimization_precedence, tag_ndm: '30100066', tag_ary: [0x3010,0x0066], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0067)', tag_name: "Conceptual Volume Category Code Sequence", tag_key: 'ConceptualVolumeCategoryCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,0067)', tag_sym: :conceptual_volume_category_code_sequence, tag_ndm: '30100067', tag_ary: [0x3010,0x0067], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0068)', tag_name: "Conceptual Volume Blocking Constraint", tag_key: 'ConceptualVolumeBlockingConstraint', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(3010,0068)', tag_sym: :conceptual_volume_blocking_constraint, tag_ndm: '30100068', tag_ary: [0x3010,0x0068], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0069)', tag_name: "Conceptual Volume Type Code Sequence", tag_key: 'ConceptualVolumeTypeCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,0069)', tag_sym: :conceptual_volume_type_code_sequence, tag_ndm: '30100069', tag_ary: [0x3010,0x0069], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,006A)', tag_name: "Conceptual Volume Type Modifier Code Sequence", tag_key: 'ConceptualVolumeTypeModifierCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,006A)', tag_sym: :conceptual_volume_type_modifier_code_sequence, tag_ndm: '3010006A', tag_ary: [0x3010,0x006A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,006B)', tag_name: "RT Prescription Sequence", tag_key: 'RTPrescriptionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,006B)', tag_sym: :rt_prescription_sequence, tag_ndm: '3010006B', tag_ary: [0x3010,0x006B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,006C)', tag_name: "Dosimetric Objective Sequence", tag_key: 'DosimetricObjectiveSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,006C)', tag_sym: :dosimetric_objective_sequence, tag_ndm: '3010006C', tag_ary: [0x3010,0x006C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,006D)', tag_name: "Dosimetric Objective Type Code Sequence", tag_key: 'DosimetricObjectiveTypeCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,006D)', tag_sym: :dosimetric_objective_type_code_sequence, tag_ndm: '3010006D', tag_ary: [0x3010,0x006D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,006E)', tag_name: "Dosimetric Objective UID", tag_key: 'DosimetricObjectiveUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(3010,006E)', tag_sym: :dosimetric_objective_uid, tag_ndm: '3010006E', tag_ary: [0x3010,0x006E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,006F)', tag_name: "Referenced Dosimetric Objective UID", tag_key: 'ReferencedDosimetricObjectiveUID', tag_vr: [:UI], tag_vm: ["1"], tag_str: '(3010,006F)', tag_sym: :referenced_dosimetric_objective_uid, tag_ndm: '3010006F', tag_ary: [0x3010,0x006F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0070)', tag_name: "Dosimetric Objective Parameter Sequence", tag_key: 'DosimetricObjectiveParameterSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,0070)', tag_sym: :dosimetric_objective_parameter_sequence, tag_ndm: '30100070', tag_ary: [0x3010,0x0070], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0071)', tag_name: "Referenced Dosimetric Objectives Sequence", tag_key: 'ReferencedDosimetricObjectivesSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,0071)', tag_sym: :referenced_dosimetric_objectives_sequence, tag_ndm: '30100071', tag_ary: [0x3010,0x0071], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0073)', tag_name: "Absolute Dosimetric Objective Flag", tag_key: 'AbsoluteDosimetricObjectiveFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(3010,0073)', tag_sym: :absolute_dosimetric_objective_flag, tag_ndm: '30100073', tag_ary: [0x3010,0x0073], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0074)', tag_name: "Dosimetric Objective Weight", tag_key: 'DosimetricObjectiveWeight', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(3010,0074)', tag_sym: :dosimetric_objective_weight, tag_ndm: '30100074', tag_ary: [0x3010,0x0074], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0075)', tag_name: "Dosimetric Objective Purpose", tag_key: 'DosimetricObjectivePurpose', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(3010,0075)', tag_sym: :dosimetric_objective_purpose, tag_ndm: '30100075', tag_ary: [0x3010,0x0075], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0076)', tag_name: "Planning Input Information Sequence", tag_key: 'PlanningInputInformationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,0076)', tag_sym: :planning_input_information_sequence, tag_ndm: '30100076', tag_ary: [0x3010,0x0076], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0077)', tag_name: "Treatment Site", tag_key: 'TreatmentSite', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(3010,0077)', tag_sym: :treatment_site, tag_ndm: '30100077', tag_ary: [0x3010,0x0077], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0078)', tag_name: "Treatment Site Code Sequence", tag_key: 'TreatmentSiteCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,0078)', tag_sym: :treatment_site_code_sequence, tag_ndm: '30100078', tag_ary: [0x3010,0x0078], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0079)', tag_name: "Fraction Pattern Sequence", tag_key: 'FractionPatternSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,0079)', tag_sym: :fraction_pattern_sequence, tag_ndm: '30100079', tag_ary: [0x3010,0x0079], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,007A)', tag_name: "Treatment Technique Notes", tag_key: 'TreatmentTechniqueNotes', tag_vr: [:UT], tag_vm: ["1"], tag_str: '(3010,007A)', tag_sym: :treatment_technique_notes, tag_ndm: '3010007A', tag_ary: [0x3010,0x007A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,007B)', tag_name: "Prescription Notes", tag_key: 'PrescriptionNotes', tag_vr: [:UT], tag_vm: ["1"], tag_str: '(3010,007B)', tag_sym: :prescription_notes, tag_ndm: '3010007B', tag_ary: [0x3010,0x007B], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,007C)', tag_name: "Number of Interval Fractions", tag_key: 'NumberOfIntervalFractions', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(3010,007C)', tag_sym: :number_of_interval_fractions, tag_ndm: '3010007C', tag_ary: [0x3010,0x007C], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,007D)', tag_name: "Number of Fractions", tag_key: 'NumberOfFractions', tag_vr: [:US], tag_vm: ["1"], tag_str: '(3010,007D)', tag_sym: :number_of_fractions, tag_ndm: '3010007D', tag_ary: [0x3010,0x007D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,007E)', tag_name: "Intended Delivery Duration", tag_key: 'IntendedDeliveryDuration', tag_vr: [:US], tag_vm: ["1"], tag_str: '(3010,007E)', tag_sym: :intended_delivery_duration, tag_ndm: '3010007E', tag_ary: [0x3010,0x007E], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,007F)', tag_name: "Fractionation Notes", tag_key: 'FractionationNotes', tag_vr: [:UT], tag_vm: ["1"], tag_str: '(3010,007F)', tag_sym: :fractionation_notes, tag_ndm: '3010007F', tag_ary: [0x3010,0x007F], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0080)', tag_name: "RT Treatment Technique Code Sequence", tag_key: 'RTTreatmentTechniqueCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,0080)', tag_sym: :rt_treatment_technique_code_sequence, tag_ndm: '30100080', tag_ary: [0x3010,0x0080], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0081)', tag_name: "Prescription Notes Sequence", tag_key: 'PrescriptionNotesSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,0081)', tag_sym: :prescription_notes_sequence, tag_ndm: '30100081', tag_ary: [0x3010,0x0081], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0082)', tag_name: "Fraction-Based Relationship Sequence", tag_key: 'FractionBasedRelationshipSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,0082)', tag_sym: :fraction_based_relationship_sequence, tag_ndm: '30100082', tag_ary: [0x3010,0x0082], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0083)', tag_name: "Fraction-Based Relationship Interval Anchor", tag_key: 'FractionBasedRelationshipIntervalAnchor', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(3010,0083)', tag_sym: :fraction_based_relationship_interval_anchor, tag_ndm: '30100083', tag_ary: [0x3010,0x0083], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0084)', tag_name: "Minimum Hours between Fractions", tag_key: 'MinimumHoursBetweenFractions', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(3010,0084)', tag_sym: :minimum_hours_between_fractions, tag_ndm: '30100084', tag_ary: [0x3010,0x0084], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0085)', tag_name: "Intended Fraction Start Time", tag_key: 'IntendedFractionStartTime', tag_vr: [:TM], tag_vm: ["1-n"], tag_str: '(3010,0085)', tag_sym: :intended_fraction_start_time, tag_ndm: '30100085', tag_ary: [0x3010,0x0085], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0086)', tag_name: "Intended Start Day of Week", tag_key: 'IntendedStartDayOfWeek', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(3010,0086)', tag_sym: :intended_start_day_of_week, tag_ndm: '30100086', tag_ary: [0x3010,0x0086], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0087)', tag_name: "Weekday Fraction Pattern Sequence", tag_key: 'WeekdayFractionPatternSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,0087)', tag_sym: :weekday_fraction_pattern_sequence, tag_ndm: '30100087', tag_ary: [0x3010,0x0087], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0088)', tag_name: "Delivery Time Structure Code Sequence", tag_key: 'DeliveryTimeStructureCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,0088)', tag_sym: :delivery_time_structure_code_sequence, tag_ndm: '30100088', tag_ary: [0x3010,0x0088], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0089)', tag_name: "Treatment Site Modifier Code Sequence", tag_key: 'TreatmentSiteModifierCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,0089)', tag_sym: :treatment_site_modifier_code_sequence, tag_ndm: '30100089', tag_ary: [0x3010,0x0089], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0090)', tag_name: "Robotic Base Location Indicator", tag_key: 'RoboticBaseLocationIndicator', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(3010,0090)', tag_sym: :robotic_base_location_indicator, tag_ndm: '30100090', tag_ary: [0x3010,0x0090], tag_multiple: false, tag_note: 'RET (2022e)'},
      { tag_ps: '(3010,0091)', tag_name: "Robotic Path Node Set Code Sequence", tag_key: 'RoboticPathNodeSetCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,0091)', tag_sym: :robotic_path_node_set_code_sequence, tag_ndm: '30100091', tag_ary: [0x3010,0x0091], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0092)', tag_name: "Robotic Node Identifier", tag_key: 'RoboticNodeIdentifier', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(3010,0092)', tag_sym: :robotic_node_identifier, tag_ndm: '30100092', tag_ary: [0x3010,0x0092], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0093)', tag_name: "RT Treatment Source Coordinates", tag_key: 'RTTreatmentSourceCoordinates', tag_vr: [:FD], tag_vm: ["3"], tag_str: '(3010,0093)', tag_sym: :rt_treatment_source_coordinates, tag_ndm: '30100093', tag_ary: [0x3010,0x0093], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0094)', tag_name: "Radiation Source Coordinate SystemYaw Angle", tag_key: 'RadiationSourceCoordinateSystemYawAngle', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(3010,0094)', tag_sym: :radiation_source_coordinate_system_yaw_angle, tag_ndm: '30100094', tag_ary: [0x3010,0x0094], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0095)', tag_name: "Radiation Source Coordinate SystemRoll Angle", tag_key: 'RadiationSourceCoordinateSystemRollAngle', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(3010,0095)', tag_sym: :radiation_source_coordinate_system_roll_angle, tag_ndm: '30100095', tag_ary: [0x3010,0x0095], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0096)', tag_name: "Radiation Source Coordinate System Pitch Angle", tag_key: 'RadiationSourceCoordinateSystemPitchAngle', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(3010,0096)', tag_sym: :radiation_source_coordinate_system_pitch_angle, tag_ndm: '30100096', tag_ary: [0x3010,0x0096], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0097)', tag_name: "Robotic Path Control Point Sequence", tag_key: 'RoboticPathControlPointSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,0097)', tag_sym: :robotic_path_control_point_sequence, tag_ndm: '30100097', tag_ary: [0x3010,0x0097], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0098)', tag_name: "Tomotherapeutic Control Point Sequence", tag_key: 'TomotherapeuticControlPointSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,0098)', tag_sym: :tomotherapeutic_control_point_sequence, tag_ndm: '30100098', tag_ary: [0x3010,0x0098], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,0099)', tag_name: "Tomotherapeutic Leaf Open Durations", tag_key: 'TomotherapeuticLeafOpenDurations', tag_vr: [:FD], tag_vm: ["1-n"], tag_str: '(3010,0099)', tag_sym: :tomotherapeutic_leaf_open_durations, tag_ndm: '30100099', tag_ary: [0x3010,0x0099], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,009A)', tag_name: "Tomotherapeutic Leaf Initial Closed Durations", tag_key: 'TomotherapeuticLeafInitialClosedDurations', tag_vr: [:FD], tag_vm: ["1-n"], tag_str: '(3010,009A)', tag_sym: :tomotherapeutic_leaf_initial_closed_durations, tag_ndm: '3010009A', tag_ary: [0x3010,0x009A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(3010,00A0)', tag_name: "Conceptual Volume Identification Sequence", tag_key: 'ConceptualVolumeIdentificationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(3010,00A0)', tag_sym: :conceptual_volume_identification_sequence, tag_ndm: '301000A0', tag_ary: [0x3010,0x00A0], tag_multiple: false, tag_note: ''},
      { tag_ps: '(4000,0010)', tag_name: "Arbitrary", tag_key: 'Arbitrary', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(4000,0010)', tag_sym: :arbitrary, tag_ndm: '40000010', tag_ary: [0x4000,0x0010], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(4000,4000)', tag_name: "Text Comments", tag_key: 'TextComments', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(4000,4000)', tag_sym: :text_comments, tag_ndm: '40004000', tag_ary: [0x4000,0x4000], tag_multiple: false, tag_note: 'RET'},
      { tag_ps: '(4008,0040)', tag_name: "Results ID", tag_key: 'ResultsID', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(4008,0040)', tag_sym: :results_id, tag_ndm: '40080040', tag_ary: [0x4008,0x0040], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(4008,0042)', tag_name: "Results ID Issuer", tag_key: 'ResultsIDIssuer', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(4008,0042)', tag_sym: :results_id_issuer, tag_ndm: '40080042', tag_ary: [0x4008,0x0042], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(4008,0050)', tag_name: "Referenced Interpretation Sequence", tag_key: 'ReferencedInterpretationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(4008,0050)', tag_sym: :referenced_interpretation_sequence, tag_ndm: '40080050', tag_ary: [0x4008,0x0050], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(4008,00FF)', tag_name: "Report Production Status (Trial)", tag_key: 'ReportProductionStatusTrial', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(4008,00FF)', tag_sym: :report_production_status_trial, tag_ndm: '400800FF', tag_ary: [0x4008,0x00FF], tag_multiple: false, tag_note: 'RET (2009)'},
      { tag_ps: '(4008,0100)', tag_name: "Interpretation Recorded Date", tag_key: 'InterpretationRecordedDate', tag_vr: [:DA], tag_vm: ["1"], tag_str: '(4008,0100)', tag_sym: :interpretation_recorded_date, tag_ndm: '40080100', tag_ary: [0x4008,0x0100], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(4008,0101)', tag_name: "Interpretation Recorded Time", tag_key: 'InterpretationRecordedTime', tag_vr: [:TM], tag_vm: ["1"], tag_str: '(4008,0101)', tag_sym: :interpretation_recorded_time, tag_ndm: '40080101', tag_ary: [0x4008,0x0101], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(4008,0102)', tag_name: "Interpretation Recorder", tag_key: 'InterpretationRecorder', tag_vr: [:PN], tag_vm: ["1"], tag_str: '(4008,0102)', tag_sym: :interpretation_recorder, tag_ndm: '40080102', tag_ary: [0x4008,0x0102], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(4008,0103)', tag_name: "Reference to Recorded Sound", tag_key: 'ReferenceToRecordedSound', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(4008,0103)', tag_sym: :reference_to_recorded_sound, tag_ndm: '40080103', tag_ary: [0x4008,0x0103], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(4008,0108)', tag_name: "Interpretation Transcription Date", tag_key: 'InterpretationTranscriptionDate', tag_vr: [:DA], tag_vm: ["1"], tag_str: '(4008,0108)', tag_sym: :interpretation_transcription_date, tag_ndm: '40080108', tag_ary: [0x4008,0x0108], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(4008,0109)', tag_name: "Interpretation Transcription Time", tag_key: 'InterpretationTranscriptionTime', tag_vr: [:TM], tag_vm: ["1"], tag_str: '(4008,0109)', tag_sym: :interpretation_transcription_time, tag_ndm: '40080109', tag_ary: [0x4008,0x0109], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(4008,010A)', tag_name: "Interpretation Transcriber", tag_key: 'InterpretationTranscriber', tag_vr: [:PN], tag_vm: ["1"], tag_str: '(4008,010A)', tag_sym: :interpretation_transcriber, tag_ndm: '4008010A', tag_ary: [0x4008,0x010A], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(4008,010B)', tag_name: "Interpretation Text", tag_key: 'InterpretationText', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(4008,010B)', tag_sym: :interpretation_text, tag_ndm: '4008010B', tag_ary: [0x4008,0x010B], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(4008,010C)', tag_name: "Interpretation Author", tag_key: 'InterpretationAuthor', tag_vr: [:PN], tag_vm: ["1"], tag_str: '(4008,010C)', tag_sym: :interpretation_author, tag_ndm: '4008010C', tag_ary: [0x4008,0x010C], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(4008,0111)', tag_name: "Interpretation Approver Sequence", tag_key: 'InterpretationApproverSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(4008,0111)', tag_sym: :interpretation_approver_sequence, tag_ndm: '40080111', tag_ary: [0x4008,0x0111], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(4008,0112)', tag_name: "Interpretation Approval Date", tag_key: 'InterpretationApprovalDate', tag_vr: [:DA], tag_vm: ["1"], tag_str: '(4008,0112)', tag_sym: :interpretation_approval_date, tag_ndm: '40080112', tag_ary: [0x4008,0x0112], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(4008,0113)', tag_name: "Interpretation Approval Time", tag_key: 'InterpretationApprovalTime', tag_vr: [:TM], tag_vm: ["1"], tag_str: '(4008,0113)', tag_sym: :interpretation_approval_time, tag_ndm: '40080113', tag_ary: [0x4008,0x0113], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(4008,0114)', tag_name: "Physician Approving Interpretation", tag_key: 'PhysicianApprovingInterpretation', tag_vr: [:PN], tag_vm: ["1"], tag_str: '(4008,0114)', tag_sym: :physician_approving_interpretation, tag_ndm: '40080114', tag_ary: [0x4008,0x0114], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(4008,0115)', tag_name: "Interpretation Diagnosis Description", tag_key: 'InterpretationDiagnosisDescription', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(4008,0115)', tag_sym: :interpretation_diagnosis_description, tag_ndm: '40080115', tag_ary: [0x4008,0x0115], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(4008,0117)', tag_name: "Interpretation Diagnosis Code Sequence", tag_key: 'InterpretationDiagnosisCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(4008,0117)', tag_sym: :interpretation_diagnosis_code_sequence, tag_ndm: '40080117', tag_ary: [0x4008,0x0117], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(4008,0118)', tag_name: "Results Distribution List Sequence", tag_key: 'ResultsDistributionListSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(4008,0118)', tag_sym: :results_distribution_list_sequence, tag_ndm: '40080118', tag_ary: [0x4008,0x0118], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(4008,0119)', tag_name: "Distribution Name", tag_key: 'DistributionName', tag_vr: [:PN], tag_vm: ["1"], tag_str: '(4008,0119)', tag_sym: :distribution_name, tag_ndm: '40080119', tag_ary: [0x4008,0x0119], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(4008,011A)', tag_name: "Distribution Address", tag_key: 'DistributionAddress', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(4008,011A)', tag_sym: :distribution_address, tag_ndm: '4008011A', tag_ary: [0x4008,0x011A], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(4008,0200)', tag_name: "Interpretation ID", tag_key: 'InterpretationID', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(4008,0200)', tag_sym: :interpretation_id, tag_ndm: '40080200', tag_ary: [0x4008,0x0200], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(4008,0202)', tag_name: "Interpretation ID Issuer", tag_key: 'InterpretationIDIssuer', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(4008,0202)', tag_sym: :interpretation_id_issuer, tag_ndm: '40080202', tag_ary: [0x4008,0x0202], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(4008,0210)', tag_name: "Interpretation Type ID", tag_key: 'InterpretationTypeID', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(4008,0210)', tag_sym: :interpretation_type_id, tag_ndm: '40080210', tag_ary: [0x4008,0x0210], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(4008,0212)', tag_name: "Interpretation Status ID", tag_key: 'InterpretationStatusID', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(4008,0212)', tag_sym: :interpretation_status_id, tag_ndm: '40080212', tag_ary: [0x4008,0x0212], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(4008,0300)', tag_name: "Impressions", tag_key: 'Impressions', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(4008,0300)', tag_sym: :impressions, tag_ndm: '40080300', tag_ary: [0x4008,0x0300], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(4008,4000)', tag_name: "Results Comments", tag_key: 'ResultsComments', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(4008,4000)', tag_sym: :results_comments, tag_ndm: '40084000', tag_ary: [0x4008,0x4000], tag_multiple: false, tag_note: 'RET (2004)'},
      { tag_ps: '(4010,0001)', tag_name: "Low Energy Detectors", tag_key: 'LowEnergyDetectors', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(4010,0001)', tag_sym: :low_energy_detectors, tag_ndm: '40100001', tag_ary: [0x4010,0x0001], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,0002)', tag_name: "High Energy Detectors", tag_key: 'HighEnergyDetectors', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(4010,0002)', tag_sym: :high_energy_detectors, tag_ndm: '40100002', tag_ary: [0x4010,0x0002], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,0004)', tag_name: "Detector Geometry Sequence", tag_key: 'DetectorGeometrySequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(4010,0004)', tag_sym: :detector_geometry_sequence, tag_ndm: '40100004', tag_ary: [0x4010,0x0004], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1001)', tag_name: "Threat ROI Voxel Sequence", tag_key: 'ThreatROIVoxelSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(4010,1001)', tag_sym: :threat_roi_voxel_sequence, tag_ndm: '40101001', tag_ary: [0x4010,0x1001], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1004)', tag_name: "Threat ROI Base", tag_key: 'ThreatROIBase', tag_vr: [:FL], tag_vm: ["3"], tag_str: '(4010,1004)', tag_sym: :threat_roi_base, tag_ndm: '40101004', tag_ary: [0x4010,0x1004], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1005)', tag_name: "Threat ROI Extents", tag_key: 'ThreatROIExtents', tag_vr: [:FL], tag_vm: ["3"], tag_str: '(4010,1005)', tag_sym: :threat_roi_extents, tag_ndm: '40101005', tag_ary: [0x4010,0x1005], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1006)', tag_name: "Threat ROI Bitmap", tag_key: 'ThreatROIBitmap', tag_vr: [:OB], tag_vm: ["1"], tag_str: '(4010,1006)', tag_sym: :threat_roi_bitmap, tag_ndm: '40101006', tag_ary: [0x4010,0x1006], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1007)', tag_name: "Route Segment ID", tag_key: 'RouteSegmentID', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(4010,1007)', tag_sym: :route_segment_id, tag_ndm: '40101007', tag_ary: [0x4010,0x1007], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1008)', tag_name: "Gantry Type", tag_key: 'GantryType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(4010,1008)', tag_sym: :gantry_type, tag_ndm: '40101008', tag_ary: [0x4010,0x1008], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1009)', tag_name: "OOI Owner Type", tag_key: 'OOIOwnerType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(4010,1009)', tag_sym: :ooi_owner_type, tag_ndm: '40101009', tag_ary: [0x4010,0x1009], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,100A)', tag_name: "Route Segment Sequence", tag_key: 'RouteSegmentSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(4010,100A)', tag_sym: :route_segment_sequence, tag_ndm: '4010100A', tag_ary: [0x4010,0x100A], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1010)', tag_name: "Potential Threat Object ID", tag_key: 'PotentialThreatObjectID', tag_vr: [:US], tag_vm: ["1"], tag_str: '(4010,1010)', tag_sym: :potential_threat_object_id, tag_ndm: '40101010', tag_ary: [0x4010,0x1010], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1011)', tag_name: "Threat Sequence", tag_key: 'ThreatSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(4010,1011)', tag_sym: :threat_sequence, tag_ndm: '40101011', tag_ary: [0x4010,0x1011], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1012)', tag_name: "Threat Category", tag_key: 'ThreatCategory', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(4010,1012)', tag_sym: :threat_category, tag_ndm: '40101012', tag_ary: [0x4010,0x1012], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1013)', tag_name: "Threat Category Description", tag_key: 'ThreatCategoryDescription', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(4010,1013)', tag_sym: :threat_category_description, tag_ndm: '40101013', tag_ary: [0x4010,0x1013], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1014)', tag_name: "ATD Ability Assessment", tag_key: 'ATDAbilityAssessment', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(4010,1014)', tag_sym: :atd_ability_assessment, tag_ndm: '40101014', tag_ary: [0x4010,0x1014], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1015)', tag_name: "ATD Assessment Flag", tag_key: 'ATDAssessmentFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(4010,1015)', tag_sym: :atd_assessment_flag, tag_ndm: '40101015', tag_ary: [0x4010,0x1015], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1016)', tag_name: "ATD Assessment Probability", tag_key: 'ATDAssessmentProbability', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(4010,1016)', tag_sym: :atd_assessment_probability, tag_ndm: '40101016', tag_ary: [0x4010,0x1016], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1017)', tag_name: "Mass", tag_key: 'Mass', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(4010,1017)', tag_sym: :mass, tag_ndm: '40101017', tag_ary: [0x4010,0x1017], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1018)', tag_name: "Density", tag_key: 'Density', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(4010,1018)', tag_sym: :density, tag_ndm: '40101018', tag_ary: [0x4010,0x1018], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1019)', tag_name: "Z Effective", tag_key: 'ZEffective', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(4010,1019)', tag_sym: :z_effective, tag_ndm: '40101019', tag_ary: [0x4010,0x1019], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,101A)', tag_name: "Boarding Pass ID", tag_key: 'BoardingPassID', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(4010,101A)', tag_sym: :boarding_pass_id, tag_ndm: '4010101A', tag_ary: [0x4010,0x101A], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,101B)', tag_name: "Center of Mass", tag_key: 'CenterOfMass', tag_vr: [:FL], tag_vm: ["3"], tag_str: '(4010,101B)', tag_sym: :center_of_mass, tag_ndm: '4010101B', tag_ary: [0x4010,0x101B], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,101C)', tag_name: "Center of PTO", tag_key: 'CenterOfPTO', tag_vr: [:FL], tag_vm: ["3"], tag_str: '(4010,101C)', tag_sym: :center_of_pto, tag_ndm: '4010101C', tag_ary: [0x4010,0x101C], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,101D)', tag_name: "Bounding Polygon", tag_key: 'BoundingPolygon', tag_vr: [:FL], tag_vm: ["6-n"], tag_str: '(4010,101D)', tag_sym: :bounding_polygon, tag_ndm: '4010101D', tag_ary: [0x4010,0x101D], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,101E)', tag_name: "Route Segment Start Location ID", tag_key: 'RouteSegmentStartLocationID', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(4010,101E)', tag_sym: :route_segment_start_location_id, tag_ndm: '4010101E', tag_ary: [0x4010,0x101E], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,101F)', tag_name: "Route Segment End Location ID", tag_key: 'RouteSegmentEndLocationID', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(4010,101F)', tag_sym: :route_segment_end_location_id, tag_ndm: '4010101F', tag_ary: [0x4010,0x101F], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1020)', tag_name: "Route Segment Location ID Type", tag_key: 'RouteSegmentLocationIDType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(4010,1020)', tag_sym: :route_segment_location_id_type, tag_ndm: '40101020', tag_ary: [0x4010,0x1020], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1021)', tag_name: "Abort Reason", tag_key: 'AbortReason', tag_vr: [:CS], tag_vm: ["1-n"], tag_str: '(4010,1021)', tag_sym: :abort_reason, tag_ndm: '40101021', tag_ary: [0x4010,0x1021], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1023)', tag_name: "Volume of PTO", tag_key: 'VolumeOfPTO', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(4010,1023)', tag_sym: :volume_of_pto, tag_ndm: '40101023', tag_ary: [0x4010,0x1023], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1024)', tag_name: "Abort Flag", tag_key: 'AbortFlag', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(4010,1024)', tag_sym: :abort_flag, tag_ndm: '40101024', tag_ary: [0x4010,0x1024], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1025)', tag_name: "Route Segment Start Time", tag_key: 'RouteSegmentStartTime', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(4010,1025)', tag_sym: :route_segment_start_time, tag_ndm: '40101025', tag_ary: [0x4010,0x1025], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1026)', tag_name: "Route Segment End Time", tag_key: 'RouteSegmentEndTime', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(4010,1026)', tag_sym: :route_segment_end_time, tag_ndm: '40101026', tag_ary: [0x4010,0x1026], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1027)', tag_name: "TDR Type", tag_key: 'TDRType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(4010,1027)', tag_sym: :tdr_type, tag_ndm: '40101027', tag_ary: [0x4010,0x1027], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1028)', tag_name: "International Route Segment", tag_key: 'InternationalRouteSegment', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(4010,1028)', tag_sym: :international_route_segment, tag_ndm: '40101028', tag_ary: [0x4010,0x1028], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1029)', tag_name: "Threat Detection Algorithm and Version", tag_key: 'ThreatDetectionAlgorithmAndVersion', tag_vr: [:LO], tag_vm: ["1-n"], tag_str: '(4010,1029)', tag_sym: :threat_detection_algorithm_and_version, tag_ndm: '40101029', tag_ary: [0x4010,0x1029], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,102A)', tag_name: "Assigned Location", tag_key: 'AssignedLocation', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(4010,102A)', tag_sym: :assigned_location, tag_ndm: '4010102A', tag_ary: [0x4010,0x102A], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,102B)', tag_name: "Alarm Decision Time", tag_key: 'AlarmDecisionTime', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(4010,102B)', tag_sym: :alarm_decision_time, tag_ndm: '4010102B', tag_ary: [0x4010,0x102B], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1031)', tag_name: "Alarm Decision", tag_key: 'AlarmDecision', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(4010,1031)', tag_sym: :alarm_decision, tag_ndm: '40101031', tag_ary: [0x4010,0x1031], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1033)', tag_name: "Number of Total Objects", tag_key: 'NumberOfTotalObjects', tag_vr: [:US], tag_vm: ["1"], tag_str: '(4010,1033)', tag_sym: :number_of_total_objects, tag_ndm: '40101033', tag_ary: [0x4010,0x1033], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1034)', tag_name: "Number of Alarm Objects", tag_key: 'NumberOfAlarmObjects', tag_vr: [:US], tag_vm: ["1"], tag_str: '(4010,1034)', tag_sym: :number_of_alarm_objects, tag_ndm: '40101034', tag_ary: [0x4010,0x1034], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1037)', tag_name: "PTO Representation Sequence", tag_key: 'PTORepresentationSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(4010,1037)', tag_sym: :pto_representation_sequence, tag_ndm: '40101037', tag_ary: [0x4010,0x1037], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1038)', tag_name: "ATD Assessment Sequence", tag_key: 'ATDAssessmentSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(4010,1038)', tag_sym: :atd_assessment_sequence, tag_ndm: '40101038', tag_ary: [0x4010,0x1038], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1039)', tag_name: "TIP Type", tag_key: 'TIPType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(4010,1039)', tag_sym: :tip_type, tag_ndm: '40101039', tag_ary: [0x4010,0x1039], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,103A)', tag_name: "DICOS Version", tag_key: 'DICOSVersion', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(4010,103A)', tag_sym: :dicos_version, tag_ndm: '4010103A', tag_ary: [0x4010,0x103A], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1041)', tag_name: "OOI Owner Creation Time", tag_key: 'OOIOwnerCreationTime', tag_vr: [:DT], tag_vm: ["1"], tag_str: '(4010,1041)', tag_sym: :ooi_owner_creation_time, tag_ndm: '40101041', tag_ary: [0x4010,0x1041], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1042)', tag_name: "OOI Type", tag_key: 'OOIType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(4010,1042)', tag_sym: :ooi_type, tag_ndm: '40101042', tag_ary: [0x4010,0x1042], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1043)', tag_name: "OOI Size", tag_key: 'OOISize', tag_vr: [:FL], tag_vm: ["3"], tag_str: '(4010,1043)', tag_sym: :ooi_size, tag_ndm: '40101043', tag_ary: [0x4010,0x1043], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1044)', tag_name: "Acquisition Status", tag_key: 'AcquisitionStatus', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(4010,1044)', tag_sym: :acquisition_status, tag_ndm: '40101044', tag_ary: [0x4010,0x1044], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1045)', tag_name: "Basis Materials Code Sequence", tag_key: 'BasisMaterialsCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(4010,1045)', tag_sym: :basis_materials_code_sequence, tag_ndm: '40101045', tag_ary: [0x4010,0x1045], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1046)', tag_name: "Phantom Type", tag_key: 'PhantomType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(4010,1046)', tag_sym: :phantom_type, tag_ndm: '40101046', tag_ary: [0x4010,0x1046], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1047)', tag_name: "OOI Owner Sequence", tag_key: 'OOIOwnerSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(4010,1047)', tag_sym: :ooi_owner_sequence, tag_ndm: '40101047', tag_ary: [0x4010,0x1047], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1048)', tag_name: "Scan Type", tag_key: 'ScanType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(4010,1048)', tag_sym: :scan_type, tag_ndm: '40101048', tag_ary: [0x4010,0x1048], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1051)', tag_name: "Itinerary ID", tag_key: 'ItineraryID', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(4010,1051)', tag_sym: :itinerary_id, tag_ndm: '40101051', tag_ary: [0x4010,0x1051], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1052)', tag_name: "Itinerary ID Type", tag_key: 'ItineraryIDType', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(4010,1052)', tag_sym: :itinerary_id_type, tag_ndm: '40101052', tag_ary: [0x4010,0x1052], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1053)', tag_name: "Itinerary ID Assigning Authority", tag_key: 'ItineraryIDAssigningAuthority', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(4010,1053)', tag_sym: :itinerary_id_assigning_authority, tag_ndm: '40101053', tag_ary: [0x4010,0x1053], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1054)', tag_name: "Route ID", tag_key: 'RouteID', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(4010,1054)', tag_sym: :route_id, tag_ndm: '40101054', tag_ary: [0x4010,0x1054], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1055)', tag_name: "Route ID Assigning Authority", tag_key: 'RouteIDAssigningAuthority', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(4010,1055)', tag_sym: :route_id_assigning_authority, tag_ndm: '40101055', tag_ary: [0x4010,0x1055], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1056)', tag_name: "Inbound Arrival Type", tag_key: 'InboundArrivalType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(4010,1056)', tag_sym: :inbound_arrival_type, tag_ndm: '40101056', tag_ary: [0x4010,0x1056], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1058)', tag_name: "Carrier ID", tag_key: 'CarrierID', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(4010,1058)', tag_sym: :carrier_id, tag_ndm: '40101058', tag_ary: [0x4010,0x1058], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1059)', tag_name: "Carrier ID Assigning Authority", tag_key: 'CarrierIDAssigningAuthority', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(4010,1059)', tag_sym: :carrier_id_assigning_authority, tag_ndm: '40101059', tag_ary: [0x4010,0x1059], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1060)', tag_name: "Source Orientation", tag_key: 'SourceOrientation', tag_vr: [:FL], tag_vm: ["3"], tag_str: '(4010,1060)', tag_sym: :source_orientation, tag_ndm: '40101060', tag_ary: [0x4010,0x1060], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1061)', tag_name: "Source Position", tag_key: 'SourcePosition', tag_vr: [:FL], tag_vm: ["3"], tag_str: '(4010,1061)', tag_sym: :source_position, tag_ndm: '40101061', tag_ary: [0x4010,0x1061], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1062)', tag_name: "Belt Height", tag_key: 'BeltHeight', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(4010,1062)', tag_sym: :belt_height, tag_ndm: '40101062', tag_ary: [0x4010,0x1062], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1064)', tag_name: "Algorithm Routing Code Sequence", tag_key: 'AlgorithmRoutingCodeSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(4010,1064)', tag_sym: :algorithm_routing_code_sequence, tag_ndm: '40101064', tag_ary: [0x4010,0x1064], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1067)', tag_name: "Transport Classification", tag_key: 'TransportClassification', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(4010,1067)', tag_sym: :transport_classification, tag_ndm: '40101067', tag_ary: [0x4010,0x1067], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1068)', tag_name: "OOI Type Descriptor", tag_key: 'OOITypeDescriptor', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(4010,1068)', tag_sym: :ooi_type_descriptor, tag_ndm: '40101068', tag_ary: [0x4010,0x1068], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1069)', tag_name: "Total Processing Time", tag_key: 'TotalProcessingTime', tag_vr: [:FL], tag_vm: ["1"], tag_str: '(4010,1069)', tag_sym: :total_processing_time, tag_ndm: '40101069', tag_ary: [0x4010,0x1069], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,106C)', tag_name: "Detector Calibration Data", tag_key: 'DetectorCalibrationData', tag_vr: [:OB], tag_vm: ["1"], tag_str: '(4010,106C)', tag_sym: :detector_calibration_data, tag_ndm: '4010106C', tag_ary: [0x4010,0x106C], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,106D)', tag_name: "Additional Screening Performed", tag_key: 'AdditionalScreeningPerformed', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(4010,106D)', tag_sym: :additional_screening_performed, tag_ndm: '4010106D', tag_ary: [0x4010,0x106D], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,106E)', tag_name: "Additional Inspection Selection Criteria", tag_key: 'AdditionalInspectionSelectionCriteria', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(4010,106E)', tag_sym: :additional_inspection_selection_criteria, tag_ndm: '4010106E', tag_ary: [0x4010,0x106E], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,106F)', tag_name: "Additional Inspection Method Sequence", tag_key: 'AdditionalInspectionMethodSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(4010,106F)', tag_sym: :additional_inspection_method_sequence, tag_ndm: '4010106F', tag_ary: [0x4010,0x106F], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1070)', tag_name: "AIT Device Type", tag_key: 'AITDeviceType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(4010,1070)', tag_sym: :ait_device_type, tag_ndm: '40101070', tag_ary: [0x4010,0x1070], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1071)', tag_name: "QR Measurements Sequence", tag_key: 'QRMeasurementsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(4010,1071)', tag_sym: :qr_measurements_sequence, tag_ndm: '40101071', tag_ary: [0x4010,0x1071], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1072)', tag_name: "Target Material Sequence", tag_key: 'TargetMaterialSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(4010,1072)', tag_sym: :target_material_sequence, tag_ndm: '40101072', tag_ary: [0x4010,0x1072], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1073)', tag_name: "SNR Threshold", tag_key: 'SNRThreshold', tag_vr: [:FD], tag_vm: ["1"], tag_str: '(4010,1073)', tag_sym: :snr_threshold, tag_ndm: '40101073', tag_ary: [0x4010,0x1073], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1075)', tag_name: "Image Scale Representation", tag_key: 'ImageScaleRepresentation', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(4010,1075)', tag_sym: :image_scale_representation, tag_ndm: '40101075', tag_ary: [0x4010,0x1075], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1076)', tag_name: "Referenced PTO Sequence", tag_key: 'ReferencedPTOSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(4010,1076)', tag_sym: :referenced_pto_sequence, tag_ndm: '40101076', tag_ary: [0x4010,0x1076], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1077)', tag_name: "Referenced TDR Instance Sequence", tag_key: 'ReferencedTDRInstanceSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(4010,1077)', tag_sym: :referenced_tdr_instance_sequence, tag_ndm: '40101077', tag_ary: [0x4010,0x1077], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1078)', tag_name: "PTO Location Description", tag_key: 'PTOLocationDescription', tag_vr: [:ST], tag_vm: ["1"], tag_str: '(4010,1078)', tag_sym: :pto_location_description, tag_ndm: '40101078', tag_ary: [0x4010,0x1078], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,1079)', tag_name: "Anomaly Locator Indicator Sequence", tag_key: 'AnomalyLocatorIndicatorSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(4010,1079)', tag_sym: :anomaly_locator_indicator_sequence, tag_ndm: '40101079', tag_ary: [0x4010,0x1079], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,107A)', tag_name: "Anomaly Locator Indicator", tag_key: 'AnomalyLocatorIndicator', tag_vr: [:FL], tag_vm: ["3"], tag_str: '(4010,107A)', tag_sym: :anomaly_locator_indicator, tag_ndm: '4010107A', tag_ary: [0x4010,0x107A], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,107B)', tag_name: "PTO Region Sequence", tag_key: 'PTORegionSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(4010,107B)', tag_sym: :pto_region_sequence, tag_ndm: '4010107B', tag_ary: [0x4010,0x107B], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,107C)', tag_name: "Inspection Selection Criteria", tag_key: 'InspectionSelectionCriteria', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(4010,107C)', tag_sym: :inspection_selection_criteria, tag_ndm: '4010107C', tag_ary: [0x4010,0x107C], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,107D)', tag_name: "Secondary Inspection Method Sequence", tag_key: 'SecondaryInspectionMethodSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(4010,107D)', tag_sym: :secondary_inspection_method_sequence, tag_ndm: '4010107D', tag_ary: [0x4010,0x107D], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4010,107E)', tag_name: "PRCS to RCS Orientation", tag_key: 'PRCSToRCSOrientation', tag_vr: [:DS], tag_vm: ["6"], tag_str: '(4010,107E)', tag_sym: :prcs_to_rcs_orientation, tag_ndm: '4010107E', tag_ary: [0x4010,0x107E], tag_multiple: false, tag_note: 'DICOS'},
      { tag_ps: '(4FFE,0001)', tag_name: "MAC Parameters Sequence", tag_key: 'MACParametersSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(4FFE,0001)', tag_sym: :mac_parameters_sequence, tag_ndm: '4FFE0001', tag_ary: [0x4FFE,0x0001], tag_multiple: false, tag_note: ''},
      { tag_ps: '(50XX,0005)', tag_name: "Curve Dimensions", tag_key: 'CurveDimensions', tag_vr: [:US], tag_vm: ["1"], tag_str: '(5022,0005)', tag_sym: :curve_dimensions, tag_ndm: '50220005', tag_ary: [0x5022,0x0005], tag_multiple: true, tag_note: 'RET (2004)'},
      { tag_ps: '(50XX,0010)', tag_name: "Number of Points", tag_key: 'NumberOfPoints', tag_vr: [:US], tag_vm: ["1"], tag_str: '(5022,0010)', tag_sym: :number_of_points, tag_ndm: '50220010', tag_ary: [0x5022,0x0010], tag_multiple: true, tag_note: 'RET (2004)'},
      { tag_ps: '(50XX,0020)', tag_name: "Type of Data", tag_key: 'TypeOfData', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(5022,0020)', tag_sym: :type_of_data, tag_ndm: '50220020', tag_ary: [0x5022,0x0020], tag_multiple: true, tag_note: 'RET (2004)'},
      { tag_ps: '(50XX,0022)', tag_name: "Curve Description", tag_key: 'CurveDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(5022,0022)', tag_sym: :curve_description, tag_ndm: '50220022', tag_ary: [0x5022,0x0022], tag_multiple: true, tag_note: 'RET (2004)'},
      { tag_ps: '(50XX,0030)', tag_name: "Axis Units", tag_key: 'AxisUnits', tag_vr: [:SH], tag_vm: ["1-n"], tag_str: '(5022,0030)', tag_sym: :axis_units, tag_ndm: '50220030', tag_ary: [0x5022,0x0030], tag_multiple: true, tag_note: 'RET (2004)'},
      { tag_ps: '(50XX,0040)', tag_name: "Axis Labels", tag_key: 'AxisLabels', tag_vr: [:SH], tag_vm: ["1-n"], tag_str: '(5022,0040)', tag_sym: :axis_labels, tag_ndm: '50220040', tag_ary: [0x5022,0x0040], tag_multiple: true, tag_note: 'RET (2004)'},
      { tag_ps: '(50XX,0103)', tag_name: "Data Value Representation", tag_key: 'DataValueRepresentation', tag_vr: [:US], tag_vm: ["1"], tag_str: '(5022,0103)', tag_sym: :data_value_representation, tag_ndm: '50220103', tag_ary: [0x5022,0x0103], tag_multiple: true, tag_note: 'RET (2004)'},
      { tag_ps: '(50XX,0104)', tag_name: "Minimum Coordinate Value", tag_key: 'MinimumCoordinateValue', tag_vr: [:US], tag_vm: ["1-n"], tag_str: '(5022,0104)', tag_sym: :minimum_coordinate_value, tag_ndm: '50220104', tag_ary: [0x5022,0x0104], tag_multiple: true, tag_note: 'RET (2004)'},
      { tag_ps: '(50XX,0105)', tag_name: "Maximum Coordinate Value", tag_key: 'MaximumCoordinateValue', tag_vr: [:US], tag_vm: ["1-n"], tag_str: '(5022,0105)', tag_sym: :maximum_coordinate_value, tag_ndm: '50220105', tag_ary: [0x5022,0x0105], tag_multiple: true, tag_note: 'RET (2004)'},
      { tag_ps: '(50XX,0106)', tag_name: "Curve Range", tag_key: 'CurveRange', tag_vr: [:SH], tag_vm: ["1-n"], tag_str: '(5022,0106)', tag_sym: :curve_range, tag_ndm: '50220106', tag_ary: [0x5022,0x0106], tag_multiple: true, tag_note: 'RET (2004)'},
      { tag_ps: '(50XX,0110)', tag_name: "Curve Data Descriptor", tag_key: 'CurveDataDescriptor', tag_vr: [:US], tag_vm: ["1-n"], tag_str: '(5022,0110)', tag_sym: :curve_data_descriptor, tag_ndm: '50220110', tag_ary: [0x5022,0x0110], tag_multiple: true, tag_note: 'RET (2004)'},
      { tag_ps: '(50XX,0112)', tag_name: "Coordinate Start Value", tag_key: 'CoordinateStartValue', tag_vr: [:US], tag_vm: ["1-n"], tag_str: '(5022,0112)', tag_sym: :coordinate_start_value, tag_ndm: '50220112', tag_ary: [0x5022,0x0112], tag_multiple: true, tag_note: 'RET (2004)'},
      { tag_ps: '(50XX,0114)', tag_name: "Coordinate Step Value", tag_key: 'CoordinateStepValue', tag_vr: [:US], tag_vm: ["1-n"], tag_str: '(5022,0114)', tag_sym: :coordinate_step_value, tag_ndm: '50220114', tag_ary: [0x5022,0x0114], tag_multiple: true, tag_note: 'RET (2004)'},
      { tag_ps: '(50XX,1001)', tag_name: "Curve Activation Layer", tag_key: 'CurveActivationLayer', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(5022,1001)', tag_sym: :curve_activation_layer, tag_ndm: '50221001', tag_ary: [0x5022,0x1001], tag_multiple: true, tag_note: 'RET (2004)'},
      { tag_ps: '(50XX,2000)', tag_name: "Audio Type", tag_key: 'AudioType', tag_vr: [:US], tag_vm: ["1"], tag_str: '(5022,2000)', tag_sym: :audio_type, tag_ndm: '50222000', tag_ary: [0x5022,0x2000], tag_multiple: true, tag_note: 'RET (2004)'},
      { tag_ps: '(50XX,2002)', tag_name: "Audio Sample Format", tag_key: 'AudioSampleFormat', tag_vr: [:US], tag_vm: ["1"], tag_str: '(5022,2002)', tag_sym: :audio_sample_format, tag_ndm: '50222002', tag_ary: [0x5022,0x2002], tag_multiple: true, tag_note: 'RET (2004)'},
      { tag_ps: '(50XX,2004)', tag_name: "Number of Channels", tag_key: 'NumberOfChannels', tag_vr: [:US], tag_vm: ["1"], tag_str: '(5022,2004)', tag_sym: :number_of_channels, tag_ndm: '50222004', tag_ary: [0x5022,0x2004], tag_multiple: true, tag_note: 'RET (2004)'},
      { tag_ps: '(50XX,2006)', tag_name: "Number of Samples", tag_key: 'NumberOfSamples', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(5022,2006)', tag_sym: :number_of_samples, tag_ndm: '50222006', tag_ary: [0x5022,0x2006], tag_multiple: true, tag_note: 'RET (2004)'},
      { tag_ps: '(50XX,2008)', tag_name: "Sample Rate", tag_key: 'SampleRate', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(5022,2008)', tag_sym: :sample_rate, tag_ndm: '50222008', tag_ary: [0x5022,0x2008], tag_multiple: true, tag_note: 'RET (2004)'},
      { tag_ps: '(50XX,200A)', tag_name: "Total Time", tag_key: 'TotalTime', tag_vr: [:UL], tag_vm: ["1"], tag_str: '(5022,200A)', tag_sym: :total_time, tag_ndm: '5022200A', tag_ary: [0x5022,0x200A], tag_multiple: true, tag_note: 'RET (2004)'},
      { tag_ps: '(50XX,200C)', tag_name: "Audio Sample Data", tag_key: 'AudioSampleData', tag_vr: [:OB, :OW], tag_vm: ["1"], tag_str: '(5022,200C)', tag_sym: :audio_sample_data, tag_ndm: '5022200C', tag_ary: [0x5022,0x200C], tag_multiple: true, tag_note: 'RET (2004)'},
      { tag_ps: '(50XX,200E)', tag_name: "Audio Comments", tag_key: 'AudioComments', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(5022,200E)', tag_sym: :audio_comments, tag_ndm: '5022200E', tag_ary: [0x5022,0x200E], tag_multiple: true, tag_note: 'RET (2004)'},
      { tag_ps: '(50XX,2500)', tag_name: "Curve Label", tag_key: 'CurveLabel', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(5022,2500)', tag_sym: :curve_label, tag_ndm: '50222500', tag_ary: [0x5022,0x2500], tag_multiple: true, tag_note: 'RET (2004)'},
      { tag_ps: '(50XX,2600)', tag_name: "Curve Referenced Overlay Sequence", tag_key: 'CurveReferencedOverlaySequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(5022,2600)', tag_sym: :curve_referenced_overlay_sequence, tag_ndm: '50222600', tag_ary: [0x5022,0x2600], tag_multiple: true, tag_note: 'RET (2004)'},
      { tag_ps: '(50XX,2610)', tag_name: "Curve Referenced Overlay Group", tag_key: 'CurveReferencedOverlayGroup', tag_vr: [:US], tag_vm: ["1"], tag_str: '(5022,2610)', tag_sym: :curve_referenced_overlay_group, tag_ndm: '50222610', tag_ary: [0x5022,0x2610], tag_multiple: true, tag_note: 'RET (2004)'},
      { tag_ps: '(50XX,3000)', tag_name: "Curve Data", tag_key: 'CurveData', tag_vr: [:OB, :OW], tag_vm: ["1"], tag_str: '(5022,3000)', tag_sym: :curve_data, tag_ndm: '50223000', tag_ary: [0x5022,0x3000], tag_multiple: true, tag_note: 'RET (2004)'},
      { tag_ps: '(5200,9229)', tag_name: "Shared Functional Groups Sequence", tag_key: 'SharedFunctionalGroupsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(5200,9229)', tag_sym: :shared_functional_groups_sequence, tag_ndm: '52009229', tag_ary: [0x5200,0x9229], tag_multiple: false, tag_note: ''},
      { tag_ps: '(5200,9230)', tag_name: "Per-Frame Functional Groups Sequence", tag_key: 'PerFrameFunctionalGroupsSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(5200,9230)', tag_sym: :per_frame_functional_groups_sequence, tag_ndm: '52009230', tag_ary: [0x5200,0x9230], tag_multiple: false, tag_note: ''},
      { tag_ps: '(5400,0100)', tag_name: "Waveform Sequence", tag_key: 'WaveformSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(5400,0100)', tag_sym: :waveform_sequence, tag_ndm: '54000100', tag_ary: [0x5400,0x0100], tag_multiple: false, tag_note: ''},
      { tag_ps: '(5400,0110)', tag_name: "Channel Minimum Value", tag_key: 'ChannelMinimumValue', tag_vr: [:OB, :OW], tag_vm: ["1"], tag_str: '(5400,0110)', tag_sym: :channel_minimum_value, tag_ndm: '54000110', tag_ary: [0x5400,0x0110], tag_multiple: false, tag_note: ''},
      { tag_ps: '(5400,0112)', tag_name: "Channel Maximum Value", tag_key: 'ChannelMaximumValue', tag_vr: [:OB, :OW], tag_vm: ["1"], tag_str: '(5400,0112)', tag_sym: :channel_maximum_value, tag_ndm: '54000112', tag_ary: [0x5400,0x0112], tag_multiple: false, tag_note: ''},
      { tag_ps: '(5400,1004)', tag_name: "Waveform Bits Allocated", tag_key: 'WaveformBitsAllocated', tag_vr: [:US], tag_vm: ["1"], tag_str: '(5400,1004)', tag_sym: :waveform_bits_allocated, tag_ndm: '54001004', tag_ary: [0x5400,0x1004], tag_multiple: false, tag_note: ''},
      { tag_ps: '(5400,1006)', tag_name: "Waveform Sample Interpretation", tag_key: 'WaveformSampleInterpretation', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(5400,1006)', tag_sym: :waveform_sample_interpretation, tag_ndm: '54001006', tag_ary: [0x5400,0x1006], tag_multiple: false, tag_note: ''},
      { tag_ps: '(5400,100A)', tag_name: "Waveform Padding Value", tag_key: 'WaveformPaddingValue', tag_vr: [:OB, :OW], tag_vm: ["1"], tag_str: '(5400,100A)', tag_sym: :waveform_padding_value, tag_ndm: '5400100A', tag_ary: [0x5400,0x100A], tag_multiple: false, tag_note: ''},
      { tag_ps: '(5400,1010)', tag_name: "Waveform Data", tag_key: 'WaveformData', tag_vr: [:OB, :OW], tag_vm: ["1"], tag_str: '(5400,1010)', tag_sym: :waveform_data, tag_ndm: '54001010', tag_ary: [0x5400,0x1010], tag_multiple: false, tag_note: ''},
      { tag_ps: '(5600,0010)', tag_name: "First Order Phase Correction Angle", tag_key: 'FirstOrderPhaseCorrectionAngle', tag_vr: [:OF], tag_vm: ["1"], tag_str: '(5600,0010)', tag_sym: :first_order_phase_correction_angle, tag_ndm: '56000010', tag_ary: [0x5600,0x0010], tag_multiple: false, tag_note: ''},
      { tag_ps: '(5600,0020)', tag_name: "Spectroscopy Data", tag_key: 'SpectroscopyData', tag_vr: [:OF], tag_vm: ["1"], tag_str: '(5600,0020)', tag_sym: :spectroscopy_data, tag_ndm: '56000020', tag_ary: [0x5600,0x0020], tag_multiple: false, tag_note: ''},
      { tag_ps: '(60XX,0010)', tag_name: "Overlay Rows", tag_key: 'OverlayRows', tag_vr: [:US], tag_vm: ["1"], tag_str: '(6022,0010)', tag_sym: :overlay_rows, tag_ndm: '60220010', tag_ary: [0x6022,0x0010], tag_multiple: true, tag_note: ''},
      { tag_ps: '(60XX,0011)', tag_name: "Overlay Columns", tag_key: 'OverlayColumns', tag_vr: [:US], tag_vm: ["1"], tag_str: '(6022,0011)', tag_sym: :overlay_columns, tag_ndm: '60220011', tag_ary: [0x6022,0x0011], tag_multiple: true, tag_note: ''},
      { tag_ps: '(60XX,0012)', tag_name: "Overlay Planes", tag_key: 'OverlayPlanes', tag_vr: [:US], tag_vm: ["1"], tag_str: '(6022,0012)', tag_sym: :overlay_planes, tag_ndm: '60220012', tag_ary: [0x6022,0x0012], tag_multiple: true, tag_note: 'RET (2007)'},
      { tag_ps: '(60XX,0015)', tag_name: "Number of Frames in Overlay", tag_key: 'NumberOfFramesInOverlay', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(6022,0015)', tag_sym: :number_of_frames_in_overlay, tag_ndm: '60220015', tag_ary: [0x6022,0x0015], tag_multiple: true, tag_note: ''},
      { tag_ps: '(60XX,0022)', tag_name: "Overlay Description", tag_key: 'OverlayDescription', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(6022,0022)', tag_sym: :overlay_description, tag_ndm: '60220022', tag_ary: [0x6022,0x0022], tag_multiple: true, tag_note: ''},
      { tag_ps: '(60XX,0040)', tag_name: "Overlay Type", tag_key: 'OverlayType', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(6022,0040)', tag_sym: :overlay_type, tag_ndm: '60220040', tag_ary: [0x6022,0x0040], tag_multiple: true, tag_note: ''},
      { tag_ps: '(60XX,0045)', tag_name: "Overlay Subtype", tag_key: 'OverlaySubtype', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(6022,0045)', tag_sym: :overlay_subtype, tag_ndm: '60220045', tag_ary: [0x6022,0x0045], tag_multiple: true, tag_note: ''},
      { tag_ps: '(60XX,0050)', tag_name: "Overlay Origin", tag_key: 'OverlayOrigin', tag_vr: [:SS], tag_vm: ["2"], tag_str: '(6022,0050)', tag_sym: :overlay_origin, tag_ndm: '60220050', tag_ary: [0x6022,0x0050], tag_multiple: true, tag_note: ''},
      { tag_ps: '(60XX,0051)', tag_name: "Image Frame Origin", tag_key: 'ImageFrameOrigin', tag_vr: [:US], tag_vm: ["1"], tag_str: '(6022,0051)', tag_sym: :image_frame_origin, tag_ndm: '60220051', tag_ary: [0x6022,0x0051], tag_multiple: true, tag_note: ''},
      { tag_ps: '(60XX,0052)', tag_name: "Overlay Plane Origin", tag_key: 'OverlayPlaneOrigin', tag_vr: [:US], tag_vm: ["1"], tag_str: '(6022,0052)', tag_sym: :overlay_plane_origin, tag_ndm: '60220052', tag_ary: [0x6022,0x0052], tag_multiple: true, tag_note: 'RET (2007)'},
      { tag_ps: '(60XX,0060)', tag_name: "Overlay Compression Code", tag_key: 'OverlayCompressionCode', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(6022,0060)', tag_sym: :overlay_compression_code, tag_ndm: '60220060', tag_ary: [0x6022,0x0060], tag_multiple: true, tag_note: 'RET'},
      { tag_ps: '(60XX,0061)', tag_name: "Overlay Compression Originator", tag_key: 'OverlayCompressionOriginator', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(6022,0061)', tag_sym: :overlay_compression_originator, tag_ndm: '60220061', tag_ary: [0x6022,0x0061], tag_multiple: true, tag_note: 'RET (2007)'},
      { tag_ps: '(60XX,0062)', tag_name: "Overlay Compression Label", tag_key: 'OverlayCompressionLabel', tag_vr: [:SH], tag_vm: ["1"], tag_str: '(6022,0062)', tag_sym: :overlay_compression_label, tag_ndm: '60220062', tag_ary: [0x6022,0x0062], tag_multiple: true, tag_note: 'RET (2007)'},
      { tag_ps: '(60XX,0063)', tag_name: "Overlay Compression Description", tag_key: 'OverlayCompressionDescription', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(6022,0063)', tag_sym: :overlay_compression_description, tag_ndm: '60220063', tag_ary: [0x6022,0x0063], tag_multiple: true, tag_note: 'RET (2007)'},
      { tag_ps: '(60XX,0066)', tag_name: "Overlay Compression Step Pointers", tag_key: 'OverlayCompressionStepPointers', tag_vr: [:AT], tag_vm: ["1-n"], tag_str: '(6022,0066)', tag_sym: :overlay_compression_step_pointers, tag_ndm: '60220066', tag_ary: [0x6022,0x0066], tag_multiple: true, tag_note: 'RET (2007)'},
      { tag_ps: '(60XX,0068)', tag_name: "Overlay Repeat Interval", tag_key: 'OverlayRepeatInterval', tag_vr: [:US], tag_vm: ["1"], tag_str: '(6022,0068)', tag_sym: :overlay_repeat_interval, tag_ndm: '60220068', tag_ary: [0x6022,0x0068], tag_multiple: true, tag_note: 'RET (2007)'},
      { tag_ps: '(60XX,0069)', tag_name: "Overlay Bits Grouped", tag_key: 'OverlayBitsGrouped', tag_vr: [:US], tag_vm: ["1"], tag_str: '(6022,0069)', tag_sym: :overlay_bits_grouped, tag_ndm: '60220069', tag_ary: [0x6022,0x0069], tag_multiple: true, tag_note: 'RET (2007)'},
      { tag_ps: '(60XX,0100)', tag_name: "Overlay Bits Allocated", tag_key: 'OverlayBitsAllocated', tag_vr: [:US], tag_vm: ["1"], tag_str: '(6022,0100)', tag_sym: :overlay_bits_allocated, tag_ndm: '60220100', tag_ary: [0x6022,0x0100], tag_multiple: true, tag_note: ''},
      { tag_ps: '(60XX,0102)', tag_name: "Overlay Bit Position", tag_key: 'OverlayBitPosition', tag_vr: [:US], tag_vm: ["1"], tag_str: '(6022,0102)', tag_sym: :overlay_bit_position, tag_ndm: '60220102', tag_ary: [0x6022,0x0102], tag_multiple: true, tag_note: ''},
      { tag_ps: '(60XX,0110)', tag_name: "Overlay Format", tag_key: 'OverlayFormat', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(6022,0110)', tag_sym: :overlay_format, tag_ndm: '60220110', tag_ary: [0x6022,0x0110], tag_multiple: true, tag_note: 'RET'},
      { tag_ps: '(60XX,0200)', tag_name: "Overlay Location", tag_key: 'OverlayLocation', tag_vr: [:US], tag_vm: ["1"], tag_str: '(6022,0200)', tag_sym: :overlay_location, tag_ndm: '60220200', tag_ary: [0x6022,0x0200], tag_multiple: true, tag_note: 'RET'},
      { tag_ps: '(60XX,0800)', tag_name: "Overlay Code Label", tag_key: 'OverlayCodeLabel', tag_vr: [:CS], tag_vm: ["1-n"], tag_str: '(6022,0800)', tag_sym: :overlay_code_label, tag_ndm: '60220800', tag_ary: [0x6022,0x0800], tag_multiple: true, tag_note: 'RET (2007)'},
      { tag_ps: '(60XX,0802)', tag_name: "Overlay Number of Tables", tag_key: 'OverlayNumberOfTables', tag_vr: [:US], tag_vm: ["1"], tag_str: '(6022,0802)', tag_sym: :overlay_number_of_tables, tag_ndm: '60220802', tag_ary: [0x6022,0x0802], tag_multiple: true, tag_note: 'RET (2007)'},
      { tag_ps: '(60XX,0803)', tag_name: "Overlay Code Table Location", tag_key: 'OverlayCodeTableLocation', tag_vr: [:AT], tag_vm: ["1-n"], tag_str: '(6022,0803)', tag_sym: :overlay_code_table_location, tag_ndm: '60220803', tag_ary: [0x6022,0x0803], tag_multiple: true, tag_note: 'RET (2007)'},
      { tag_ps: '(60XX,0804)', tag_name: "Overlay Bits For Code Word", tag_key: 'OverlayBitsForCodeWord', tag_vr: [:US], tag_vm: ["1"], tag_str: '(6022,0804)', tag_sym: :overlay_bits_for_code_word, tag_ndm: '60220804', tag_ary: [0x6022,0x0804], tag_multiple: true, tag_note: 'RET (2007)'},
      { tag_ps: '(60XX,1001)', tag_name: "Overlay Activation Layer", tag_key: 'OverlayActivationLayer', tag_vr: [:CS], tag_vm: ["1"], tag_str: '(6022,1001)', tag_sym: :overlay_activation_layer, tag_ndm: '60221001', tag_ary: [0x6022,0x1001], tag_multiple: true, tag_note: ''},
      { tag_ps: '(60XX,1100)', tag_name: "Overlay Descriptor - Gray", tag_key: 'OverlayDescriptorGray', tag_vr: [:US], tag_vm: ["1"], tag_str: '(6022,1100)', tag_sym: :overlay_descriptor_gray, tag_ndm: '60221100', tag_ary: [0x6022,0x1100], tag_multiple: true, tag_note: 'RET (1996)'},
      { tag_ps: '(60XX,1101)', tag_name: "Overlay Descriptor - Red", tag_key: 'OverlayDescriptorRed', tag_vr: [:US], tag_vm: ["1"], tag_str: '(6022,1101)', tag_sym: :overlay_descriptor_red, tag_ndm: '60221101', tag_ary: [0x6022,0x1101], tag_multiple: true, tag_note: 'RET (1996)'},
      { tag_ps: '(60XX,1102)', tag_name: "Overlay Descriptor - Green", tag_key: 'OverlayDescriptorGreen', tag_vr: [:US], tag_vm: ["1"], tag_str: '(6022,1102)', tag_sym: :overlay_descriptor_green, tag_ndm: '60221102', tag_ary: [0x6022,0x1102], tag_multiple: true, tag_note: 'RET (1996)'},
      { tag_ps: '(60XX,1103)', tag_name: "Overlay Descriptor - Blue", tag_key: 'OverlayDescriptorBlue', tag_vr: [:US], tag_vm: ["1"], tag_str: '(6022,1103)', tag_sym: :overlay_descriptor_blue, tag_ndm: '60221103', tag_ary: [0x6022,0x1103], tag_multiple: true, tag_note: 'RET (1996)'},
      { tag_ps: '(60XX,1200)', tag_name: "Overlays - Gray", tag_key: 'OverlaysGray', tag_vr: [:US], tag_vm: ["1-n"], tag_str: '(6022,1200)', tag_sym: :overlays_gray, tag_ndm: '60221200', tag_ary: [0x6022,0x1200], tag_multiple: true, tag_note: 'RET (1996)'},
      { tag_ps: '(60XX,1201)', tag_name: "Overlays - Red", tag_key: 'OverlaysRed', tag_vr: [:US], tag_vm: ["1-n"], tag_str: '(6022,1201)', tag_sym: :overlays_red, tag_ndm: '60221201', tag_ary: [0x6022,0x1201], tag_multiple: true, tag_note: 'RET (1996)'},
      { tag_ps: '(60XX,1202)', tag_name: "Overlays - Green", tag_key: 'OverlaysGreen', tag_vr: [:US], tag_vm: ["1-n"], tag_str: '(6022,1202)', tag_sym: :overlays_green, tag_ndm: '60221202', tag_ary: [0x6022,0x1202], tag_multiple: true, tag_note: 'RET (1996)'},
      { tag_ps: '(60XX,1203)', tag_name: "Overlays - Blue", tag_key: 'OverlaysBlue', tag_vr: [:US], tag_vm: ["1-n"], tag_str: '(6022,1203)', tag_sym: :overlays_blue, tag_ndm: '60221203', tag_ary: [0x6022,0x1203], tag_multiple: true, tag_note: 'RET (1996)'},
      { tag_ps: '(60XX,1301)', tag_name: "ROI Area", tag_key: 'ROIArea', tag_vr: [:IS], tag_vm: ["1"], tag_str: '(6022,1301)', tag_sym: :roi_area, tag_ndm: '60221301', tag_ary: [0x6022,0x1301], tag_multiple: true, tag_note: ''},
      { tag_ps: '(60XX,1302)', tag_name: "ROI Mean", tag_key: 'ROIMean', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(6022,1302)', tag_sym: :roi_mean, tag_ndm: '60221302', tag_ary: [0x6022,0x1302], tag_multiple: true, tag_note: ''},
      { tag_ps: '(60XX,1303)', tag_name: "ROI Standard Deviation", tag_key: 'ROIStandardDeviation', tag_vr: [:DS], tag_vm: ["1"], tag_str: '(6022,1303)', tag_sym: :roi_standard_deviation, tag_ndm: '60221303', tag_ary: [0x6022,0x1303], tag_multiple: true, tag_note: ''},
      { tag_ps: '(60XX,1500)', tag_name: "Overlay Label", tag_key: 'OverlayLabel', tag_vr: [:LO], tag_vm: ["1"], tag_str: '(6022,1500)', tag_sym: :overlay_label, tag_ndm: '60221500', tag_ary: [0x6022,0x1500], tag_multiple: true, tag_note: ''},
      { tag_ps: '(60XX,3000)', tag_name: "Overlay Data", tag_key: 'OverlayData', tag_vr: [:OB, :OW], tag_vm: ["1"], tag_str: '(6022,3000)', tag_sym: :overlay_data, tag_ndm: '60223000', tag_ary: [0x6022,0x3000], tag_multiple: true, tag_note: ''},
      { tag_ps: '(60XX,4000)', tag_name: "Overlay Comments", tag_key: 'OverlayComments', tag_vr: [:LT], tag_vm: ["1"], tag_str: '(6022,4000)', tag_sym: :overlay_comments, tag_ndm: '60224000', tag_ary: [0x6022,0x4000], tag_multiple: true, tag_note: 'RET'},
      { tag_ps: '(7FE0,0001)', tag_name: "Extended Offset Table", tag_key: 'ExtendedOffsetTable', tag_vr: [:OV], tag_vm: ["1"], tag_str: '(7FE0,0001)', tag_sym: :extended_offset_table, tag_ndm: '7FE00001', tag_ary: [0x7FE0,0x0001], tag_multiple: false, tag_note: ''},
      { tag_ps: '(7FE0,0002)', tag_name: "Extended Offset Table Lengths", tag_key: 'ExtendedOffsetTableLengths', tag_vr: [:OV], tag_vm: ["1"], tag_str: '(7FE0,0002)', tag_sym: :extended_offset_table_lengths, tag_ndm: '7FE00002', tag_ary: [0x7FE0,0x0002], tag_multiple: false, tag_note: ''},
      { tag_ps: '(7FE0,0003)', tag_name: "Encapsulated Pixel Data Value Total Length", tag_key: 'EncapsulatedPixelDataValueTotalLength', tag_vr: [:UV], tag_vm: ["1"], tag_str: '(7FE0,0003)', tag_sym: :encapsulated_pixel_data_value_total_length, tag_ndm: '7FE00003', tag_ary: [0x7FE0,0x0003], tag_multiple: false, tag_note: ''},
      { tag_ps: '(7FE0,0008)', tag_name: "Float Pixel Data", tag_key: 'FloatPixelData', tag_vr: [:OF], tag_vm: ["1"], tag_str: '(7FE0,0008)', tag_sym: :float_pixel_data, tag_ndm: '7FE00008', tag_ary: [0x7FE0,0x0008], tag_multiple: false, tag_note: ''},
      { tag_ps: '(7FE0,0009)', tag_name: "Double Float Pixel Data", tag_key: 'DoubleFloatPixelData', tag_vr: [:OD], tag_vm: ["1"], tag_str: '(7FE0,0009)', tag_sym: :double_float_pixel_data, tag_ndm: '7FE00009', tag_ary: [0x7FE0,0x0009], tag_multiple: false, tag_note: ''},
      { tag_ps: '(7FE0,0010)', tag_name: "Pixel Data", tag_key: 'PixelData', tag_vr: [:OB, :OW], tag_vm: ["1"], tag_str: '(7FE0,0010)', tag_sym: :pixel_data, tag_ndm: '7FE00010', tag_ary: [0x7FE0,0x0010], tag_multiple: false, tag_note: ''},
      { tag_ps: '(7FE0,0020)', tag_name: "Coefficients SDVN", tag_key: 'CoefficientsSDVN', tag_vr: [:OW], tag_vm: ["1"], tag_str: '(7FE0,0020)', tag_sym: :coefficients_sdvn, tag_ndm: '7FE00020', tag_ary: [0x7FE0,0x0020], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(7FE0,0030)', tag_name: "Coefficients SDHN", tag_key: 'CoefficientsSDHN', tag_vr: [:OW], tag_vm: ["1"], tag_str: '(7FE0,0030)', tag_sym: :coefficients_sdhn, tag_ndm: '7FE00030', tag_ary: [0x7FE0,0x0030], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(7FE0,0040)', tag_name: "Coefficients SDDN", tag_key: 'CoefficientsSDDN', tag_vr: [:OW], tag_vm: ["1"], tag_str: '(7FE0,0040)', tag_sym: :coefficients_sddn, tag_ndm: '7FE00040', tag_ary: [0x7FE0,0x0040], tag_multiple: false, tag_note: 'RET (2007)'},
      { tag_ps: '(7FXX,0010)', tag_name: "Variable Pixel Data", tag_key: 'VariablePixelData', tag_vr: [:OB, :OW], tag_vm: ["1"], tag_str: '(7F22,0010)', tag_sym: :variable_pixel_data, tag_ndm: '7F220010', tag_ary: [0x7F22,0x0010], tag_multiple: true, tag_note: 'RET (2007)'},
      { tag_ps: '(7FXX,0011)', tag_name: "Variable Next Data Group", tag_key: 'VariableNextDataGroup', tag_vr: [:US], tag_vm: ["1"], tag_str: '(7F22,0011)', tag_sym: :variable_next_data_group, tag_ndm: '7F220011', tag_ary: [0x7F22,0x0011], tag_multiple: true, tag_note: 'RET (2007)'},
      { tag_ps: '(7FXX,0020)', tag_name: "Variable Coefficients SDVN", tag_key: 'VariableCoefficientsSDVN', tag_vr: [:OW], tag_vm: ["1"], tag_str: '(7F22,0020)', tag_sym: :variable_coefficients_sdvn, tag_ndm: '7F220020', tag_ary: [0x7F22,0x0020], tag_multiple: true, tag_note: 'RET (2007)'},
      { tag_ps: '(7FXX,0030)', tag_name: "Variable Coefficients SDHN", tag_key: 'VariableCoefficientsSDHN', tag_vr: [:OW], tag_vm: ["1"], tag_str: '(7F22,0030)', tag_sym: :variable_coefficients_sdhn, tag_ndm: '7F220030', tag_ary: [0x7F22,0x0030], tag_multiple: true, tag_note: 'RET (2007)'},
      { tag_ps: '(7FXX,0040)', tag_name: "Variable Coefficients SDDN", tag_key: 'VariableCoefficientsSDDN', tag_vr: [:OW], tag_vm: ["1"], tag_str: '(7F22,0040)', tag_sym: :variable_coefficients_sddn, tag_ndm: '7F220040', tag_ary: [0x7F22,0x0040], tag_multiple: true, tag_note: 'RET (2007)'},
      { tag_ps: '(FFFA,FFFA)', tag_name: "Digital Signatures Sequence", tag_key: 'DigitalSignaturesSequence', tag_vr: [:SQ], tag_vm: ["1"], tag_str: '(FFFA,FFFA)', tag_sym: :digital_signatures_sequence, tag_ndm: 'FFFAFFFA', tag_ary: [0xFFFA,0xFFFA], tag_multiple: false, tag_note: ''},
      { tag_ps: '(FFFC,FFFC)', tag_name: "Data Set Trailing Padding", tag_key: 'DataSetTrailingPadding', tag_vr: [:OB], tag_vm: ["1"], tag_str: '(FFFC,FFFC)', tag_sym: :data_set_trailing_padding, tag_ndm: 'FFFCFFFC', tag_ary: [0xFFFC,0xFFFC], tag_multiple: false, tag_note: ''},
      { tag_ps: '(FFFE,E000)', tag_name: "Item", tag_key: 'Item', tag_vr: [:"See Note"], tag_vm: ["1"], tag_str: '(FFFE,E000)', tag_sym: :item, tag_ndm: 'FFFEE000', tag_ary: [0xFFFE,0xE000], tag_multiple: false, tag_note: ''},
      { tag_ps: '(FFFE,E00D)', tag_name: "Item Delimitation Item", tag_key: 'ItemDelimitationItem', tag_vr: [:"See Note"], tag_vm: ["1"], tag_str: '(FFFE,E00D)', tag_sym: :item_delimitation_item, tag_ndm: 'FFFEE00D', tag_ary: [0xFFFE,0xE00D], tag_multiple: false, tag_note: ''},
      { tag_ps: '(FFFE,E0DD)', tag_name: "Sequence Delimitation Item", tag_key: 'SequenceDelimitationItem', tag_vr: [:"See Note"], tag_vm: ["1"], tag_str: '(FFFE,E0DD)', tag_sym: :sequence_delimitation_item, tag_ndm: 'FFFEE0DD', tag_ary: [0xFFFE,0xE0DD], tag_multiple: false, tag_note: ''},
    ]
  end
end
